@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-27
  * Description : a folder view for date albums.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  * Copyright (C) 2014      by Michael G. Hansen <mike at mghansen dot de>
  *
@@ -36,18 +36,18 @@
 #include "album.h"
 #include "coredb.h"
 #include "applicationsettings.h"
-#include "albumtreeview.h"
+#include "datetreeview.h"
 #include "monthwidget.h"
 
 namespace Digikam
 {
 
-class DateFolderView::Private
+class Q_DECL_HIDDEN DateFolderView::Private
 {
 public:
 
-    Private() :
-        active(false),
+    explicit Private()
+      : active(false),
         selected(),
         dateTreeView(0),
         monthview(0)
@@ -58,7 +58,7 @@ public:
 
     QString            selected;
 
-    DateAlbumTreeView* dateTreeView;
+    DateTreeView*      dateTreeView;
     MonthWidget*       monthview;
 };
 
@@ -69,7 +69,7 @@ DateFolderView::DateFolderView(QWidget* const parent, DateAlbumModel* const date
 {
     setObjectName(QLatin1String("DateFolderView"));
 
-    d->dateTreeView = new DateAlbumTreeView(this);
+    d->dateTreeView = new DateTreeView(this);
     d->dateTreeView->setAlbumModel(dateAlbumModel);
     d->dateTreeView->setAlbumManagerCurrentAlbum(true);
     d->monthview    = new MonthWidget(this);
@@ -91,9 +91,9 @@ DateFolderView::~DateFolderView()
     saveState();
 }
 
-void DateFolderView::setImageModel(ImageFilterModel* const model)
+void DateFolderView::setItemModel(ItemFilterModel* const model)
 {
-    d->monthview->setImageModel(model);
+    d->monthview->setItemModel(model);
 }
 
 void DateFolderView::setActive(const bool val)
@@ -210,4 +210,4 @@ AlbumPointer<DAlbum> DateFolderView::currentAlbum() const
     return AlbumPointer<DAlbum> (d->dateTreeView->currentAlbum());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
