@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2002-01-10
  * Description : a combo box to list date.
  *               this widget come from libkdepim.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2002      by Cornelius Schumacher <schumacher at kde dot org>
  * Copyright (C) 2003-2004 by Reinhold Kainhofer <reinhold at kainhofer dot com>
  * Copyright (C) 2004      by Tobias Koenig <tokoe at kde dot org>
@@ -50,7 +50,7 @@
 namespace Digikam
 {
 
-class DateValidator : public QValidator
+class Q_DECL_HIDDEN DateValidator : public QValidator
 {
 public:
 
@@ -96,12 +96,12 @@ private:
 
 // -----------------------------------------------------------------------------------
 
-class DDateEdit::Private
+class Q_DECL_HIDDEN DDateEdit::Private
 {
 public:
 
-    Private() :
-        readOnly(false),
+    explicit Private()
+      : readOnly(false),
         textChanged(false),
         discardNextMousePress(false),
         popup(0)
@@ -205,7 +205,7 @@ void DDateEdit::showPopup()
     }
 
     QRect desk          = QApplication::desktop()->screenGeometry(this);
-    QPoint popupPoint   = mapToGlobal(QPoint(0,0));
+    QPoint popupPoint   = mapToGlobal(QPoint(0, 0));
     int dateFrameHeight = d->popup->sizeHint().height();
 
     if (popupPoint.y() + height() + dateFrameHeight > desk.bottom())
@@ -477,7 +477,7 @@ void DDateEdit::setupKeywords()
 
     for (int i = 1; i <= 7; ++i)
     {
-        dayName = QLocale().dayName(i, QLocale::LongFormat).toLower();
+        dayName = QLocale().standaloneDayName(i, QLocale::LongFormat).toLower();
         d->keywordMap.insert(dayName, i + 100);
     }
 }
@@ -507,4 +507,4 @@ void DDateEdit::updateView()
     blockSignals(blocked);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
