@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-04-21
  * Description : A date selection widget.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 1997      by Tim D. Gilman <tdgilman at best dot org>
  * Copyright (C) 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * Copyright (C) 2007      by John Layt <john at layt dot net>
@@ -69,11 +69,11 @@ void DDatePicker::initWidget(const QDate& dt)
     const int spacingHint       = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
     QBoxLayout* const topLayout = new QVBoxLayout(this);
     topLayout->setSpacing(0);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
 
     d->navigationLayout = new QHBoxLayout();
     d->navigationLayout->setSpacing(0);
-    d->navigationLayout->setMargin(0);
+    d->navigationLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(d->navigationLayout);
     d->navigationLayout->addStretch();
     d->yearBackward     = new QToolButton(this);
@@ -186,7 +186,7 @@ void DDatePicker::initWidget(const QDate& dt)
     topLayout->addWidget(d->table);
 
     QBoxLayout* const bottomLayout = new QHBoxLayout();
-    bottomLayout->setMargin(0);
+    bottomLayout->setContentsMargins(0, 0, 0, 0);
     bottomLayout->setSpacing(0);
     topLayout->addLayout(bottomLayout);
 
@@ -230,7 +230,15 @@ void DDatePicker::resizeEvent(QResizeEvent* e)
 
 void DDatePicker::dateChangedSlot(const QDate& dt)
 {
-    d->line->setText(locale().toString(dt, QLocale::ShortFormat));
+    QString dateFormat = locale().dateFormat(QLocale::ShortFormat);
+
+    if (!dateFormat.contains(QLatin1String("yyyy")))
+    {
+        dateFormat.replace(QLatin1String("yy"),
+                           QLatin1String("yyyy"));
+    }
+
+    d->line->setText(dt.toString(dateFormat));
     d->selectMonth->setText(locale().standaloneMonthName(dt.month(), QLocale::LongFormat));
     d->fillWeeksCombo();
 
@@ -323,10 +331,10 @@ void DDatePicker::selectMonthClicked()
 
     QMenu popup(d->selectMonth);
     // Populate the pick list with all the month names, this may change by year
-    // JPL do we need to do somethng here for months that fall outside valid range?
+    // JPL do we need to do something here for months that fall outside valid range?
     const int monthsInYear = QDate(thisDate.year() + 1, 1, 1).addDays(-1).month();
 
-    for (int m = 1; m <= monthsInYear; m++)
+    for (int m = 1 ; m <= monthsInYear ; ++m)
     {
         popup.addAction(locale().standaloneMonthName(m))->setData(m);
     }
@@ -427,7 +435,15 @@ DDateTable *DDatePicker::dateTable() const
 
 void DDatePicker::lineEnterPressed()
 {
-    QDate newDate = QDate::fromString(d->line->text(), locale().dateFormat());
+    QString dateFormat = locale().dateFormat(QLocale::ShortFormat);
+
+    if (!dateFormat.contains(QLatin1String("yyyy")))
+    {
+        dateFormat.replace(QLatin1String("yy"),
+                           QLatin1String("yyyy"));
+    }
+
+    QDate newDate = QDate::fromString(d->line->text(), dateFormat);
 
     if (newDate.isValid())
     {
@@ -560,4 +576,4 @@ bool DDatePicker::hasCloseButton() const
     return (d->closeButton);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
