@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-04-21
  * Description : A date selection widget.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 1997      by Tim D. Gilman <tdgilman at best dot org>
  * Copyright (C) 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * Copyright (C) 2007      by John Layt <john at layt dot net>
@@ -55,7 +55,7 @@ QValidator::State DatePickerValidator::validate(QString& text, int&) const
 
     QLocale locale = m_picker->locale();
 
-    for (int i = 0; i < 3; i++)
+    for (int i = 0 ; i < 3 ; ++i)
     {
         QDate tmp = locale.toDate(text, formats[i]);
 
@@ -174,7 +174,7 @@ void DDatePicker::Private::fillWeeksCombo()
         // e.g. 1st day of this year may fall in week 53 of previous year
         int weekYear       = thisYear;
         const int week     = day.weekNumber(&weekYear);
-        QString weekString = i18n("Week %1", QString::number(week));
+        QString weekString = i18n("Week %1", week);
 
         // show that this is a week from a different year
         if (weekYear != thisYear)
@@ -220,4 +220,4 @@ QDate DDatePicker::Private::validDateInYearMonth(int year, int month)
     return newDate;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
