@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-04-21
  * Description : A date selection widget.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 1997      by Tim D. Gilman <tdgilman at best dot org>
  * Copyright (C) 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * Copyright (C) 2007      by John Layt <john at layt dot net>
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef DDATEPICKER_P_H
-#define DDATEPICKER_P_H
+#ifndef DIGIKAM_DDATE_PICKER_PRIVATE_H
+#define DIGIKAM_DDATE_PICKER_PRIVATE_H
 
 // Qt includes
 
@@ -45,7 +45,7 @@
 namespace Digikam
 {
 
-class DatePickerValidator : public QValidator
+class Q_DECL_HIDDEN DatePickerValidator : public QValidator
 {
 public:
 
@@ -60,7 +60,7 @@ private:
 
 // ------------------------------------------------------------------------------
 
-class DatePickerYearSelector : public QLineEdit
+class Q_DECL_HIDDEN DatePickerYearSelector : public QLineEdit
 {
     Q_OBJECT
 
@@ -93,7 +93,7 @@ private:
 
 // ------------------------------------------------------------------------------
 
-class DDatePicker::Private
+class Q_DECL_HIDDEN DDatePicker::Private
 {
 public:
 
@@ -137,6 +137,6 @@ public:
     int                  fontsize;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DDATEPICKER_P_H
+#endif // DIGIKAM_DDATE_PICKER_PRIVATE_H
