@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-04-21
  * Description : a menu widget to pick a date.
  *
  * Copyright (C) 2004      by Bram Schoenmakers <bramschoenmakers at kde dot nl>
  * Copyright (C) 2006      by Mikolaj Machowski <mikmach at wp dot pl>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@
 namespace Digikam
 {
 
-class DDatePickerAction : public QWidgetAction
+class Q_DECL_HIDDEN DDatePickerAction : public QWidgetAction
 {
 public:
 
@@ -74,12 +74,12 @@ private:
 
 // ---------------------------------------------------------------------------------------
 
-class DDatePickerPopup::Private
+class Q_DECL_HIDDEN DDatePickerPopup::Private
 {
 public:
 
-    Private() :
-        datePicker(0)
+    explicit Private()
+      : datePicker(0)
     {
     }
 
@@ -246,4 +246,4 @@ void DDatePickerPopup::slotPrevMonth()
     emit dateChanged(QDate::currentDate().addMonths(-1));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
