@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-04-21
  * Description : a menu widget to pick a date.
  *
  * Copyright (C) 2004      by Bram Schoenmakers <bramschoenmakers at kde dot nl>
  * Copyright (C) 2006      by Mikolaj Machowski <mikmach at wp dot pl>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DDATEPICKERPOPUP_H
-#define DDATEPICKERPOPUP_H
+#ifndef DIGIKAM_DDATE_PICKER_POP_UP_H
+#define DIGIKAM_DDATE_PICKER_POP_UP_H
 
 // Qt includes
 
@@ -39,19 +39,19 @@ namespace Digikam
 {
 
 /**
-   @short This menu helps the user to select a date quickly.
-
-   This menu helps the user to select a date quickly. It offers various ways of selecting, e.g. with a DDatePicker or with words like "Tomorrow".
-
-   The available items are:
-
-   @li NoDate: A menu-item with "No Date". If chosen, the datepicker will emit a null QDate.
-   @li DatePicker: Show a DDatePicker-widget.
-   @li Words: Show items like "Today", "Tomorrow" or "Next Week".
-
-   When supplying multiple items, separate each item with a bitwise OR.
-*/
-class DDatePickerPopup: public QMenu
+ * @short This menu helps the user to select a date quickly.
+ *
+ * This menu helps the user to select a date quickly. It offers various ways of selecting, e.g. with a DDatePicker or with words like "Tomorrow".
+ *
+ * The available items are:
+ *
+ * @li NoDate: A menu-item with "No Date". If chosen, the datepicker will emit a null QDate.
+ * @li DatePicker: Show a DDatePicker-widget.
+ * @li Words: Show items like "Today", "Tomorrow" or "Next Week".
+ *
+ * When supplying multiple items, separate each item with a bitwise OR.
+ */
+class DDatePickerPopup : public QMenu
 {
     Q_OBJECT
 
@@ -69,40 +69,44 @@ public:
 public:
 
     /**
-       A constructor for the DDatePickerPopup.
-
-       @param items List of all desirable items, separated with a bitwise OR.
-       @param date Initial date of datepicker-widget.
-       @param parent The object's parent.
-    */
-    explicit DDatePickerPopup(Items items = DatePicker, const QDate& date = QDate::currentDate(),
+     * A constructor for the DDatePickerPopup.
+     *
+     * @param items List of all desirable items, separated with a bitwise OR.
+     * @param date Initial date of datepicker-widget.
+     * @param parent The object's parent.
+     */
+    explicit DDatePickerPopup(Items items,
+                              const QDate& date = QDate::currentDate(),
                               QWidget* const parent = 0);
-    virtual ~DDatePickerPopup();
+    ~DDatePickerPopup();
 
     /**
-       @return A pointer to the private variable mDatePicker, an instance of
-       DDatePicker.
-    */
+     * @return A pointer to the private variable mDatePicker, an instance of
+     * DDatePicker.
+     */
     DDatePicker* datePicker() const;
 
     void setDate(const QDate& date);
 
 #if 0
-    /** Set items which should be shown and rebuilds the menu afterwards. Only if the menu is not visible.
-    @param items List of all desirable items, separated with a bitwise OR.
-    */
+    /**
+     * Set items which should be shown and rebuilds the menu afterwards. Only if the menu is not visible.
+     * @param items List of all desirable items, separated with a bitwise OR.
+     */
     void setItems(int items = 1);
 #endif
 
-    /** @return Returns the bitwise result of the active items in the popup. */
+    /**
+     * @return Returns the bitwise result of the active items in the popup.
+     */
     int items() const;
 
 Q_SIGNALS:
 
     /**
-      This signal emits the new date (selected with datepicker or other
-      menu-items).
-    */
+     *  This signal emits the new date (selected with datepicker or other
+     *  menu-items).
+     */
     void dateChanged(const QDate&);
 
 protected Q_SLOTS:
@@ -127,12 +131,14 @@ private:
 
 private:
 
+    DDatePickerPopup(); // Disable
+
     class Private;
     Private* const d;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(DDatePickerPopup::Items)
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DDATEPICKERPOPUP_H
+#endif // DIGIKAM_DDATE_PICKER_POP_UP_H
