@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-21
  * Description : a widget to edit time stamp.
  *
  * Copyright (C) 2005      by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,12 +35,12 @@
 namespace Digikam
 {
 
-class DDateTimeEdit::Private
+class Q_DECL_HIDDEN DDateTimeEdit::Private
 {
 public:
 
-    Private() :
-        timePopUp(0),
+    explicit Private()
+      : timePopUp(0),
         datePopUp(0)
     {
     }
@@ -94,4 +94,4 @@ void DDateTimeEdit::slotDateTimeChanged()
     emit dateTimeChanged(dateTime());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
