@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-21
  * Description : a widget to edit time stamp.
  *
  * Copyright (C) 2005      by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DDATETIMEEDIT_H
-#define DDATETIMEEDIT_H
+#ifndef DIGIKAM_DDATE_TIME_EDIT_H
+#define DIGIKAM_DDATE_TIME_EDIT_H
 
 // Qt includes
 
@@ -53,7 +53,7 @@ public:
      * @param parent the parent widget
      * @param name the name of the widget
      */
-    DDateTimeEdit(QWidget* const parent, const QString& name);
+    explicit DDateTimeEdit(QWidget* const parent, const QString& name);
 
     /**
      * destructor
@@ -74,8 +74,8 @@ public:
 Q_SIGNALS:
 
     /**
-     *  This signal is emitted whenever the user modifies the date or time.
-     *  The passed date and time can be invalid.
+     * This signal is emitted whenever the user modifies the date or time.
+     * The passed date and time can be invalid.
      */
     void dateTimeChanged(const QDateTime& dateTime);
 
@@ -89,6 +89,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // KDATETIMEEDIT_H
+#endif // DIGIKAM_DDATE_TIME_EDIT_H
