@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-04-21
  * Description : Frame with popup menu behavior.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 1997      by Tim D. Gilman <tdgilman at best dot org>
  * Copyright (C) 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * Copyright (C) 2007      by John Layt <john at layt dot net>
@@ -36,7 +36,7 @@
 namespace Digikam
 {
 
-class DPopupFrame::Private
+class Q_DECL_HIDDEN DPopupFrame::Private
 {
 public:
 
@@ -61,7 +61,7 @@ public:
     OutsideClickCatcher* outsideClickCatcher;
 };
 
-class DPopupFrame::Private::OutsideClickCatcher : public QObject
+class Q_DECL_HIDDEN DPopupFrame::Private::OutsideClickCatcher : public QObject
 {
 public:
 
@@ -228,4 +228,4 @@ int DPopupFrame::exec(int x, int y)
     return exec(QPoint(x, y));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
