@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-04-21
  * Description : Frame with popup menu behavior.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 1997      by Tim D. Gilman <tdgilman at best dot org>
  * Copyright (C) 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * Copyright (C) 2007      by John Layt <john at layt dot net>
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef DPOPUPFRAME_H
-#define DPOPUPFRAME_H
+#ifndef DIGIKAM_DPOP_UP_FRAME_H
+#define DIGIKAM_DPOP_UP_FRAME_H
 
 // Qt includes
 
@@ -114,6 +114,6 @@ private:
     Q_DISABLE_COPY(DPopupFrame)
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DPOPUPFRAME_H
+#endif // DIGIKAM_DPOP_UP_FRAME_H
