@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-02
  * Description : a widget to perform month selection.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2011      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -41,13 +41,13 @@
 
 // Local includes
 
-#include "imagefiltermodel.h"
-#include "imagemodel.h"
+#include "itemfiltermodel.h"
+#include "itemmodel.h"
 
 namespace Digikam
 {
 
-class MonthWidget::Private
+class Q_DECL_HIDDEN MonthWidget::Private
 {
 public:
 
@@ -70,8 +70,8 @@ public:
 
 public:
 
-    Private() :
-        active(true),
+    explicit Private()
+      : active(true),
         model(0),
         timer(0),
         year(0),
@@ -85,7 +85,7 @@ public:
 
     bool              active;
 
-    ImageFilterModel* model;
+    ItemFilterModel* model;
     QTimer*           timer;
 
     int               year;
@@ -143,7 +143,7 @@ void MonthWidget::setYearMonth(int year, int month)
     d->year  = year;
     d->month = month;
 
-    for (int i=0; i<42; ++i)
+    for (int i = 0 ; i < 42 ; ++i)
     {
         d->days[i].active    = false;
         d->days[i].selected  = false;
@@ -154,7 +154,7 @@ void MonthWidget::setYearMonth(int year, int month)
     QDate date(year, month, 1);
     int s = date.dayOfWeek();
 
-    for (int i=s; i<(s+date.daysInMonth()); ++i)
+    for (int i = s ; i < (s+date.daysInMonth()) ; ++i)
     {
         d->days[i-1].day = i-s+1;
     }
@@ -187,7 +187,7 @@ void MonthWidget::paintEvent(QPaintEvent*)
     fnOrig.setBold(false);
 
     QPainter p(&pix);
-    p.fillRect(0, 0, cr.width(), cr.height(), palette().color(QPalette::Background));
+    p.fillRect(0, 0, cr.width(), cr.height(), palette().color(QPalette::Window));
 
     QRect r(0, 0, d->currw, d->currh);
     QRect rsmall;
@@ -196,12 +196,12 @@ void MonthWidget::paintEvent(QPaintEvent*)
     int index = 0;
     bool weekvisible;
 
-    for (int j=3; j<9; ++j)
+    for (int j = 3 ; j < 9 ; ++j)
     {
         sy          = d->currh * j;
         weekvisible = false;
 
-        for (int i=1; i<8; ++i)
+        for (int i = 1 ; i < 8 ; ++i)
         {
             sx     = d->currw * i;
             r.moveTopLeft(QPoint(sx,sy));
@@ -262,7 +262,7 @@ void MonthWidget::paintEvent(QPaintEvent*)
 
     sy = 2*d->currh;
 
-    for (int i = 1; i < 8; ++i)
+    for (int i = 1 ; i < 8 ; ++i)
     {
         sx     = d->currw * i;
         r.moveTopLeft(QPoint(sx+1,sy+1));
@@ -270,7 +270,7 @@ void MonthWidget::paintEvent(QPaintEvent*)
         rsmall.setWidth(r.width() - 2);
         rsmall.setHeight(r.height() - 2);
         p.drawText(rsmall, Qt::AlignVCenter|Qt::AlignHCenter,
-                   QLocale().dayName(i, QLocale::ShortFormat).remove(2, 1));
+                   QLocale().standaloneDayName(i, QLocale::ShortFormat).remove(2, 1));
         ++index;
     }
 
@@ -280,7 +280,7 @@ void MonthWidget::paintEvent(QPaintEvent*)
     p.setFont(fnBold);
 
     p.drawText(r, Qt::AlignCenter, QString::fromUtf8("%1 %2")
-               .arg(QLocale().monthName(d->month, QLocale::LongFormat))
+               .arg(QLocale().standaloneMonthName(d->month, QLocale::LongFormat))
                .arg(QDate(d->year, d->month, 1).year()));
 
     p.end();
@@ -296,7 +296,7 @@ void MonthWidget::mousePressEvent(QMouseEvent* e)
 
     if (e->modifiers() != Qt::ControlModifier)
     {
-        for (int i=0; i<42; ++i)
+        for (int i = 0 ; i < 42 ; ++i)
         {
             if (d->days[i].selected)
             {
@@ -317,11 +317,11 @@ void MonthWidget::mousePressEvent(QMouseEvent* e)
     QRect r3(d->currw, d->currh*2, d->currw*7, d->currh);
 
     // Click on a weekday
-    if ( r3.contains(e->pos()))
+    if (r3.contains(e->pos()))
     {
         int j = (e->pos().x() - d->currw)/d->currw;
 
-        for (int i=0; i<6; ++i)
+        for (int i = 0 ; i < 6 ; ++i)
         {
             d->days[i*7+j].selected = !d->days[i*7+j].selected;
         }
@@ -331,7 +331,7 @@ void MonthWidget::mousePressEvent(QMouseEvent* e)
     {
         int j = (e->pos().y() - 3*d->currh)/d->currh;
 
-        for (int i=0; i<7; ++i)
+        for (int i = 0 ; i < 7 ; ++i)
         {
             d->days[j*7+i].selected = !d->days[j*7+i].selected;
         }
@@ -348,12 +348,12 @@ void MonthWidget::mousePressEvent(QMouseEvent* e)
             int endSelection = j*7+i;
 
             if (endSelection > firstSelected)
-                for (int i2=firstSelected ; i2 <= endSelection; ++i2)
+                for (int i2=firstSelected ; i2 <= endSelection ; ++i2)
                 {
                     d->days[i2].selected = true;
                 }
             else if (endSelection < firstSelected)
-                for (int i2=lastSelected ; i2 >= endSelection; --i2)
+                for (int i2=lastSelected ; i2 >= endSelection ; --i2)
                 {
                     d->days[i2].selected = true;
                 }
@@ -366,7 +366,7 @@ void MonthWidget::mousePressEvent(QMouseEvent* e)
 
     QList<QDateTime> filterDays;
 
-    for (int i=0; i<42; ++i)
+    for (int i = 0 ; i < 42 ; ++i)
     {
         if (d->days[i].selected && d->days[i].day != -1)
         {
@@ -409,7 +409,7 @@ void MonthWidget::setActive(bool val)
     }
 }
 
-void MonthWidget::setImageModel(ImageFilterModel* model)
+void MonthWidget::setItemModel(ItemFilterModel* model)
 {
     if (d->model)
     {
@@ -426,16 +426,16 @@ void MonthWidget::connectModel()
 {
     if (d->model)
     {
-        connect(d->model, &ImageFilterModel::destroyed,
+        connect(d->model, &ItemFilterModel::destroyed,
                 this, &MonthWidget::slotModelDestroyed);
 
-        connect(d->model, &ImageFilterModel::rowsInserted,
+        connect(d->model, &ItemFilterModel::rowsInserted,
                 this, &MonthWidget::triggerUpdateDays);
 
-        connect(d->model, &ImageFilterModel::rowsRemoved,
+        connect(d->model, &ItemFilterModel::rowsRemoved,
                 this, &MonthWidget::triggerUpdateDays);
 
-        connect(d->model, &ImageFilterModel::modelReset,
+        connect(d->model, &ItemFilterModel::modelReset,
                 this, &MonthWidget::triggerUpdateDays);
 /*
         connect(d->model, SIGNAL(triggerUpdateDays()),
@@ -457,7 +457,7 @@ void MonthWidget::triggerUpdateDays()
 
 void MonthWidget::resetDayCounts()
 {
-    for (int i=0; i<42; ++i)
+    for (int i = 0 ; i < 42 ; ++i)
     {
         d->days[i].active    = false;
         d->days[i].numImages = 0;
@@ -480,7 +480,7 @@ void MonthWidget::updateDays()
 
     const int size = d->model->rowCount();
 
-    for (int i=0; i<size; ++i)
+    for (int i = 0 ; i < size ; ++i)
     {
         QModelIndex index = d->model->index(i, 0);
 
@@ -489,14 +489,14 @@ void MonthWidget::updateDays()
             continue;
         }
 
-        QDateTime dt = d->model->data(index, ImageModel::CreationDateRole).toDateTime();
+        QDateTime dt = d->model->data(index, ItemModel::CreationDateRole).toDateTime();
 
         if (dt.isNull())
         {
             continue;
         }
 
-        for (int i=0; i<42; ++i)
+        for (int i = 0 ; i < 42 ; ++i)
         {
             if (d->days[i].day == dt.date().day())
             {
@@ -517,4 +517,4 @@ void MonthWidget::slotModelDestroyed()
     update();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
