@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-02
  * Description : a widget to perform month selection.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef MONTHWIDGET_H
-#define MONTHWIDGET_H
+#ifndef DIGIKAM_MONTH_WIDGET_H
+#define DIGIKAM_MONTH_WIDGET_H
 
 // Qt includes
 
@@ -31,7 +31,7 @@
 
 // Local includes
 
-#include "imageinfo.h"
+#include "iteminfo.h"
 
 class QResizeEvent;
 class QPaintEvent;
@@ -39,7 +39,7 @@ class QMouseEvent;
 
 namespace Digikam
 {
-class ImageFilterModel;
+class ItemFilterModel;
 
 class MonthWidget : public QWidget
 {
@@ -50,7 +50,7 @@ public:
     explicit MonthWidget(QWidget* const parent);
     ~MonthWidget();
 
-    void setImageModel(ImageFilterModel* const model);
+    void setItemModel(ItemFilterModel* const model);
 
     void setYearMonth(int year, int month);
     QSize sizeHint() const;
@@ -84,6 +84,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* MONTHWIDGET_H */
+#endif // DIGIKAM_MONTH_WIDGET_H
