@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-12-08
  * Description : a widget to display date and time statistics of pictures
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2011-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -49,7 +49,7 @@
 namespace Digikam
 {
 
-class TimeLineWidget::Private
+class Q_DECL_HIDDEN TimeLineWidget::Private
 {
 
 public :
@@ -59,8 +59,8 @@ public :
 
 public:
 
-    Private() :
-        validMouseEvent(false),
+    explicit Private()
+      : validMouseEvent(false),
         selMouseEvent(false),
         maxCountByDay(1),
         maxCountByWeek(1),
@@ -315,7 +315,7 @@ int TimeLineWidget::cursorInfo(QString& infoDate) const
             infoDate      = i18nc("Week #weeknumber - month name - year string\nStart:\tEnd: ",
                                   "Week #%1 - %2 %3\n%4\t%5",
                                   weekNb,
-                                  QLocale().monthName(date.month(), QLocale::LongFormat),
+                                  QLocale().standaloneMonthName(date.month(), QLocale::LongFormat),
                                   QLocale().toString(date, QLatin1String("yyyy")),
                                   i18n("Start: ") + QLocale().toString(date, QLatin1String("dd")),
                                   i18n("End: ")   + QLocale().toString(endDate, QLatin1String("dd")));
@@ -326,7 +326,7 @@ int TimeLineWidget::cursorInfo(QString& infoDate) const
         {
             infoDate = i18nc("month-name year-string",
                              "%1 %2",
-                             QLocale().monthName(date.month(), QLocale::LongFormat),
+                             QLocale().standaloneMonthName(date.month(), QLocale::LongFormat),
                              QLocale().toString(date, QLatin1String("yyyy")));
             break;
         }
@@ -456,16 +456,35 @@ DateRangeList TimeLineWidget::selectedDateRange(int& totalCount) const
     QDateTime sdt, edt;
     QDate     date;
 
-    for (it3 = d->dayStatMap.begin() ; it3 != d->dayStatMap.end(); ++it3)
+    if (d->selMinDateTime.isValid() &&
+        d->selMaxDateTime.isValid() &&
+        d->selMinDateTime != d->selMaxDateTime)
     {
-        if (it3.value().second == Selected)
+        for (it3 = d->dayStatMap.begin() ; it3 != d->dayStatMap.end() ; ++it3)
         {
-            date = QDate(it3.key().first, 1, 1);
-            date = date.addDays(it3.key().second - 1);
-            sdt  = QDateTime(date);
-            edt  = sdt.addDays(1);
-            list.append(DateRange(sdt, edt));
-            totalCount += it3.value().first;
+            if (it3.value().second == Selected)
+            {
+                totalCount += it3.value().first;
+            }
+        }
+
+        sdt = d->selMinDateTime;
+        edt = nextDateTime(d->selMaxDateTime);
+        list.append(DateRange(sdt, edt));
+    }
+    else
+    {
+        for (it3 = d->dayStatMap.begin() ; it3 != d->dayStatMap.end() ; ++it3)
+        {
+            if (it3.value().second == Selected)
+            {
+                date = QDate(it3.key().first, 1, 1);
+                date = date.addDays(it3.key().second - 1);
+                sdt  = QDateTime(date);
+                edt  = sdt.addDays(1);
+                list.append(DateRange(sdt, edt));
+                totalCount += it3.value().first;
+            }
         }
     }
 
@@ -760,7 +779,7 @@ void TimeLineWidget::paintItem(QPainter& p, const QRect& barRect,
                 fnt.setPointSize(fnt.pointSize() - 4);
                 p.setFont(fnt);
                 p.setPen(subDateColor);
-                QString txt = QLocale().dayName(ref.date().day(), QLocale::ShortFormat);
+                QString txt = QLocale().standaloneDayName(ref.date().day(), QLocale::ShortFormat);
                 QRect br    = p.fontMetrics().boundingRect(0, 0, width(), height(), 0, txt);
                 p.drawText(barRect.left() + ((barRect.width() - br.width()) / 2),
                            barRect.bottom() + br.height(), txt);
@@ -828,7 +847,7 @@ void TimeLineWidget::paintItem(QPainter& p, const QRect& barRect,
                 fnt.setPointSize(fnt.pointSize() - 4);
                 p.setFont(fnt);
                 p.setPen(subDateColor);
-                QString txt = QLocale().monthName(ref.date().month(), QLocale::ShortFormat);
+                QString txt = QLocale().standaloneMonthName(ref.date().month(), QLocale::ShortFormat);
                 QRect br    = p.fontMetrics().boundingRect(0, 0, width(), height(), 0, txt);
                 p.drawText(barRect.left() + ((barRect.width() - br.width()) / 2),
                            barRect.bottom() + br.height(), txt);
@@ -1038,10 +1057,10 @@ void TimeLineWidget::paintEvent(QPaintEvent*)
         }
         else
         {
-            dateColor = palette().color(QPalette::Foreground);
+            dateColor = palette().color(QPalette::WindowText);
         }
 
-        p.setPen(palette().color(QPalette::Foreground));
+        p.setPen(palette().color(QPalette::WindowText));
         p.fillRect(barRect, QBrush(qApp->palette().color(QPalette::Link)));
         p.drawLine(barRect.topLeft(), barRect.topRight());
         p.drawLine(barRect.topRight(), barRect.bottomRight());
@@ -1058,7 +1077,7 @@ void TimeLineWidget::paintEvent(QPaintEvent*)
             }
             else
             {
-                subDateColor = palette().color(QPalette::Active, QPalette::Foreground);
+                subDateColor = palette().color(QPalette::Active, QPalette::WindowText);
             }
         }
         else
@@ -1123,10 +1142,10 @@ void TimeLineWidget::paintEvent(QPaintEvent*)
         }
         else
         {
-            dateColor = palette().color(QPalette::Foreground);
+            dateColor = palette().color(QPalette::WindowText);
         }
 
-        p.setPen(palette().color(QPalette::Foreground));
+        p.setPen(palette().color(QPalette::WindowText));
         p.fillRect(barRect, QBrush(qApp->palette().color(QPalette::Link)));
         p.drawLine(barRect.topLeft(), barRect.topRight());
         p.drawLine(barRect.topRight(), barRect.bottomRight());
@@ -1143,7 +1162,7 @@ void TimeLineWidget::paintEvent(QPaintEvent*)
             }
             else
             {
-                subDateColor = palette().color(QPalette::Active, QPalette::Foreground);
+                subDateColor = palette().color(QPalette::Active, QPalette::WindowText);
             }
         }
         else
@@ -2069,4 +2088,4 @@ void TimeLineWidget::handleSelectionRange(QDateTime& selEndDateTime)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
