@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-12-08
  * Description : a widget to display date and time statistics of pictures
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2011-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef TIMELINEWIDGET_H
-#define TIMELINEWIDGET_H
+#ifndef DIGIKAM_TIME_LINE_WIDGET_H
+#define DIGIKAM_TIME_LINE_WIDGET_H
 
 // Qt includes
 
@@ -34,7 +34,7 @@
 #include <QWheelEvent>
 #include <QMouseEvent>
 
-// Local inclues
+// Local includes
 
 #include "searchmodificationhelper.h"
 
@@ -83,7 +83,9 @@ public:
     QDateTime cursorDateTime() const;
     int       cursorInfo(QString& infoDate) const;
 
-    /** Return a list of Date-Range based on selection performed on days-map */
+    /**
+     * Return a list of Date-Range based on selection performed on days-map
+     */
     DateRangeList selectedDateRange(int& totalCount) const;
     void          setSelectedDateRange(const DateRangeList& list);
 
@@ -159,6 +161,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // TIMELINEWIDGET_H
+#endif // DIGIKAM_TIME_LINE_WIDGET_H
