@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-09-07
  * Description : Qt Model for ImportUI - drag and drop handling
  *
  * Copyright (C) 2012      by Islam Wazery <wazery at ubuntu dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,12 +43,12 @@
 #include "camiteminfo.h"
 #include "albummanager.h"
 #include "digikamapp.h"
-#include "digikamview.h"
+#include "itemiconview.h"
 
 namespace Digikam
 {
 
-ImportDragDropHandler::ImportDragDropHandler(ImportImageModel* const model)
+ImportDragDropHandler::ImportDragDropHandler(ImportItemModel* const model)
     : AbstractItemDragDropHandler(model)
 {
 }
@@ -238,9 +238,9 @@ QMimeData* ImportDragDropHandler::createMimeData(const QList<QModelIndex>& index
     return (new DCameraItemListDrag(lst));
 }
 
-ImportImageModel* ImportDragDropHandler::model() const
+ImportItemModel* ImportDragDropHandler::model() const
 {
-    return static_cast<ImportImageModel*>(m_model);
+    return static_cast<ImportItemModel*>(m_model);
 }
 
 } // namespace Digikam
