@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-09-07
  * Description : Qt Model for ImportUI - drag and drop handling
  *
  * Copyright (C) 2012 by Islam Wazery <wazery at ubuntu dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef IMPORTDRAGDROP_H
-#define IMPORTDRAGDROP_H
+#ifndef DIGIKAM_IMPORT_DRAG_DROP_H
+#define DIGIKAM_IMPORT_DRAG_DROP_H
 
 // Qt includes
 
@@ -45,9 +45,9 @@ class DIGIKAM_EXPORT ImportDragDropHandler : public AbstractItemDragDropHandler
 
 public:
 
-    explicit ImportDragDropHandler(ImportImageModel* const model);
+    explicit ImportDragDropHandler(ImportItemModel* const model);
 
-    ImportImageModel* model() const;
+    ImportItemModel* model() const;
 
     virtual bool           dropEvent(QAbstractItemView* view, const QDropEvent* e, const QModelIndex& droppedOn);
     virtual Qt::DropAction accepts(const QDropEvent* e, const QModelIndex& dropIndex);
@@ -74,4 +74,4 @@ private:
 
 } // namespace Digikam
 
-#endif // IMPORTDRAGDROP_H
+#endif // DIGIKAM_IMPORT_DRAG_DROP_H
