@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-21
  * Description : Qt Model for Tag - drag and drop handling
@@ -41,7 +41,7 @@
 #include "digikam_debug.h"
 #include "albummanager.h"
 #include "ddragobjects.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "albumtreeview.h"
 
 namespace Digikam
@@ -82,7 +82,8 @@ bool TagDragDropHandler::dropEvent(QAbstractItemView* view, const QDropEvent* e,
         }
 
         QMenu popMenu(view);
-        QAction* const gotoAction = popMenu.addAction(QIcon::fromTheme(QLatin1String("go-jump")), i18n("&Move Here"));
+        QAction* const gotoAction  = popMenu.addAction(QIcon::fromTheme(QLatin1String("go-jump")), i18n("&Move Here"));
+        QAction* const mergeAction = popMenu.addAction(QIcon::fromTheme(QLatin1String("merge")),   i18n("M&erge Here"));
         popMenu.addSeparator();
         popMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("C&ancel"));
         popMenu.setMouseTracking(true);
@@ -124,6 +125,25 @@ bool TagDragDropHandler::dropEvent(QAbstractItemView* view, const QDropEvent* e,
                     QMessageBox::critical(view, qApp->applicationName(), errMsg);
                 }
 
+                if (view && !view->isVisible())
+                {
+                    view->setVisible(true);
+                }
+            }
+            else if (choice == mergeAction)
+            {
+                if (!destAlbum)
+                {
+                    return false;
+                }
+
+                QString errMsg;
+
+                if (!AlbumManager::instance()->mergeTAlbum(talbum, destAlbum, true, errMsg))
+                {
+                    QMessageBox::critical(view, qApp->applicationName(), errMsg);
+                }
+
                 if (view && !view->isVisible())
                 {
                     view->setVisible(true);
@@ -136,21 +156,20 @@ bool TagDragDropHandler::dropEvent(QAbstractItemView* view, const QDropEvent* e,
     else if (DItemDrag::canDecode(e->mimeData()))
     {
         QList<QUrl>      urls;
-        QList<QUrl>      kioURLs;
         QList<int>       albumIDs;
         QList<qlonglong> imageIDs;
 
-        if (!DItemDrag::decode(e->mimeData(), urls, kioURLs, albumIDs, imageIDs))
+        if (!DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs))
         {
             return false;
         }
 
-        if (urls.isEmpty() || kioURLs.isEmpty() || albumIDs.isEmpty() || imageIDs.isEmpty())
+        if (urls.isEmpty() || albumIDs.isEmpty() || imageIDs.isEmpty())
         {
             return false;
         }
 
-        if (imageIDs.size() == 1 && ImageInfo(imageIDs.first()).tagIds().contains(destAlbum->id()))
+        if (imageIDs.size() == 1 && ItemInfo(imageIDs.first()).tagIds().contains(destAlbum->id()))
         {
             // Setting the dropped image as the album thumbnail
             // If the ctrl key is pressed, when dropping the image, the
