@@ -1,16 +1,16 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2000-12-05
  * Description : filters view for the right sidebar
  *
  * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  * Copyright (C) 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2011 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C)      2014 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C)      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -52,12 +52,12 @@
 namespace Digikam
 {
 
-class FilterSideBarWidget::Private
+class Q_DECL_HIDDEN FilterSideBarWidget::Private
 {
 public:
 
-    Private() :
-        space(0),
+    explicit Private()
+      : space(0),
         expanderVlay(0),
         tagFilterView(0),
         tagFilterSearchBar(0),
@@ -66,7 +66,7 @@ public:
         tagFilterModel(0),
         tagOrCondAction(0),
         tagAndCondAction(0),
-        tagMatchCond(ImageFilterSettings::OrCondition),
+        tagMatchCond(ItemFilterSettings::OrCondition),
         colorLabelFilter(0),
         geolocationFilter(0),
         pickLabelFilter(0),
@@ -92,7 +92,7 @@ public:
     TagModel*                              tagFilterModel;
     QAction*                               tagOrCondAction;
     QAction*                               tagAndCondAction;
-    ImageFilterSettings::MatchingCondition tagMatchCond;
+    ItemFilterSettings::MatchingCondition tagMatchCond;
 
     ColorLabelFilter*                      colorLabelFilter;
     GeolocationFilter*                     geolocationFilter;
@@ -113,7 +113,9 @@ const QString FilterSideBarWidget::Private::configMatchingConditionEntry(QLatin1
 // ---------------------------------------------------------------------------------------------------
 
 FilterSideBarWidget::FilterSideBarWidget(QWidget* const parent, TagModel* const tagFilterModel)
-    : DVBox(parent), StateSavingObject(this), d(new Private)
+    : DVBox(parent),
+      StateSavingObject(this),
+      d(new Private)
 {
     setObjectName(QLatin1String("TagFilter Sidebar"));
 
@@ -143,8 +145,8 @@ FilterSideBarWidget::FilterSideBarWidget(QWidget* const parent, TagModel* const
     QWidget* const box3   = new QWidget(d->expbox);
     d->tagFilterModel     = tagFilterModel;
     d->tagFilterView      = new TagFilterView(box3, tagFilterModel);
-    d->tagFilterView->setObjectName(QLatin1String("DigikamViewTagFilterView"));
-    d->tagFilterSearchBar = new SearchTextBar(box3, QLatin1String("DigikamViewTagFilterSearchBar"));
+    d->tagFilterView->setObjectName(QLatin1String("ItemIconViewTagFilterView"));
+    d->tagFilterSearchBar = new SearchTextBar(box3, QLatin1String("ItemIconViewTagFilterSearchBar"));
     d->tagFilterSearchBar->setModel(d->tagFilterView->filteredModel(),
                                     AbstractAlbumModel::AlbumIdRole, AbstractAlbumModel::AlbumTitleRole);
     d->tagFilterSearchBar->setFilterModel(d->tagFilterView->albumFilterModel());
@@ -210,8 +212,8 @@ FilterSideBarWidget::FilterSideBarWidget(QWidget* const parent, TagModel* const
     connect(d->mimeFilter, SIGNAL(activated(int)),
             this, SIGNAL(signalMimeTypeFilterChanged(int)));
 
-    connect(d->geolocationFilter, SIGNAL(signalFilterChanged(ImageFilterSettings::GeolocationCondition)),
-            this, SIGNAL(signalGeolocationFilterChanged(ImageFilterSettings::GeolocationCondition)));
+    connect(d->geolocationFilter, SIGNAL(signalFilterChanged(ItemFilterSettings::GeolocationCondition)),
+            this, SIGNAL(signalGeolocationFilterChanged(ItemFilterSettings::GeolocationCondition)));
 
     connect(d->textFilter, SIGNAL(signalSearchTextFilterSettings(SearchTextFilterSettings)),
             this, SIGNAL(signalSearchTextFilterChanged(SearchTextFilterSettings)));
@@ -234,8 +236,8 @@ FilterSideBarWidget::FilterSideBarWidget(QWidget* const parent, TagModel* const
     connect(d->tagOptionsMenu, SIGNAL(aboutToShow()),
             this, SLOT(slotTagOptionsMenu()));
 
-    connect(d->ratingFilter, SIGNAL(signalRatingFilterChanged(int,ImageFilterSettings::RatingCondition,bool)),
-            this, SIGNAL(signalRatingFilterChanged(int,ImageFilterSettings::RatingCondition,bool)));
+    connect(d->ratingFilter, SIGNAL(signalRatingFilterChanged(int,ItemFilterSettings::RatingCondition,bool)),
+            this, SIGNAL(signalRatingFilterChanged(int,ItemFilterSettings::RatingCondition,bool)));
 }
 
 FilterSideBarWidget::~FilterSideBarWidget()
@@ -250,10 +252,10 @@ void FilterSideBarWidget::slotTagOptionsMenu()
 
     switch (d->tagMatchCond)
     {
-        case ImageFilterSettings::OrCondition:
+        case ItemFilterSettings::OrCondition:
             d->tagOrCondAction->setChecked(true);
             break;
-        case ImageFilterSettings::AndCondition:
+        case ItemFilterSettings::AndCondition:
             d->tagAndCondAction->setChecked(true);
             break;
     }
@@ -281,15 +283,15 @@ void FilterSideBarWidget::slotResetFilters()
 {
     d->textFilter->reset();
     d->mimeFilter->setMimeFilter(MimeFilter::AllFiles);
-    d->geolocationFilter->setGeolocationFilter(ImageFilterSettings::GeolocationNoFilter);
+    d->geolocationFilter->setGeolocationFilter(ItemFilterSettings::GeolocationNoFilter);
     d->tagFilterView->slotResetCheckState();
     d->withoutTagCheckBox->setChecked(false);
     d->colorLabelFilter->reset();
     d->pickLabelFilter->reset();
     d->ratingFilter->setRating(0);
-    d->ratingFilter->setRatingFilterCondition(ImageFilterSettings::GreaterEqualCondition);
+    d->ratingFilter->setRatingFilterCondition(ItemFilterSettings::GreaterEqualCondition);
     d->ratingFilter->setExcludeUnratedItems(false);
-    d->tagMatchCond = ImageFilterSettings::OrCondition;
+    d->tagMatchCond = ItemFilterSettings::OrCondition;
 }
 
 void FilterSideBarWidget::slotTagOptionsTriggered(QAction* action)
@@ -298,11 +300,11 @@ void FilterSideBarWidget::slotTagOptionsTriggered(QAction* action)
     {
         if (action == d->tagOrCondAction)
         {
-            d->tagMatchCond = ImageFilterSettings::OrCondition;
+            d->tagMatchCond = ItemFilterSettings::OrCondition;
         }
         else if (action == d->tagAndCondAction)
         {
-            d->tagMatchCond = ImageFilterSettings::AndCondition;
+            d->tagMatchCond = ItemFilterSettings::AndCondition;
         }
     }
 
@@ -344,7 +346,7 @@ void FilterSideBarWidget::filterChanged()
     QList<int> clTagIds;
     QList<int> plTagIds;
 
-    if (!showUntagged || d->tagMatchCond == ImageFilterSettings::OrCondition)
+    if (!showUntagged || d->tagMatchCond == ItemFilterSettings::OrCondition)
     {
         foreach(TAlbum* tag, d->tagFilterView->getCheckedTags())
         {
@@ -398,12 +400,12 @@ void FilterSideBarWidget::doLoadState()
                                                                    (int)SearchTextFilterSettings::All)));
 
 
-    d->ratingFilter->setRatingFilterCondition((ImageFilterSettings::RatingCondition)
+    d->ratingFilter->setRatingFilterCondition((ItemFilterSettings::RatingCondition)
                                               (ApplicationSettings::instance()->getRatingFilterCond()));
 
-    d->tagMatchCond = (ImageFilterSettings::MatchingCondition)
+    d->tagMatchCond = (ItemFilterSettings::MatchingCondition)
                       (group.readEntry(entryName(d->configMatchingConditionEntry),
-                                                  (int)ImageFilterSettings::OrCondition));
+                                                  (int)ItemFilterSettings::OrCondition));
 
     d->tagFilterView->loadState();
 
