@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2000-12-05
  * Description : tag filter view for the right sidebar
  *
  * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  * Copyright (C) 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,16 +38,17 @@
 #include "digikam_debug.h"
 #include "albummodel.h"
 #include "contextmenuhelper.h"
+#include "tagmodificationhelper.h"
 
 namespace Digikam
 {
 
-class TagFilterView::Private
+class Q_DECL_HIDDEN TagFilterView::Private
 {
 public:
 
-    Private() :
-        onRestoreTagFiltersAction(0),
+    explicit Private()
+      : onRestoreTagFiltersAction(0),
         offRestoreTagFiltersAction(0),
         ignoreTagAction(0),
         includeTagAction(0),
@@ -83,6 +84,10 @@ TagFilterView::TagFilterView(QWidget* const parent, TagModel* const tagFilterMod
     d->ignoreTagAction            = d->tagFilterModeAction->addAction(i18n("Ignore This Tag"));
     d->includeTagAction           = d->tagFilterModeAction->addAction(QIcon::fromTheme(QLatin1String("list-add")),    i18n("Must Have This Tag"));
     d->excludeTagAction           = d->tagFilterModeAction->addAction(QIcon::fromTheme(QLatin1String("list-remove")), i18n("Must Not Have This Tag"));
+
+    connect(tagModificationHelper(), SIGNAL(aboutToDeleteTag(TAlbum*)),
+            this, SLOT(slotDeleteTagByContextMenu(TAlbum*)));
+
 }
 
 TagFilterView::~TagFilterView()
@@ -149,4 +154,9 @@ void TagFilterView::handleCustomContextMenuAction(QAction* action, AlbumPointer<
     }
 }
 
+void TagFilterView::slotDeleteTagByContextMenu(TAlbum* tag)
+{
+    albumModel()->setCheckState(tag, Qt::Unchecked);
+}
+
 } // namespace Digikam
