@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-10-14
  * Description : overlay for assigning names to faces
  *
  * Copyright (C) 2010      by Aditya Bhatt <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ASSIGNNAMEOVERLAY_H
-#define ASSIGNNAMEOVERLAY_H
+#ifndef DIGIKAM_ASSIGN_NAME_OVERLAY_H
+#define DIGIKAM_ASSIGN_NAME_OVERLAY_H
 
 // Qt includes
 
@@ -32,21 +32,21 @@
 
 // Local includes
 
-#include "imagedelegateoverlay.h"
-#include "itemviewimagedelegate.h"
+#include "itemdelegateoverlay.h"
+#include "itemviewdelegate.h"
 
 namespace Digikam
 {
 
 class AssignNameWidget;
 class FaceTagsIface;
-class ImageInfo;
+class ItemInfo;
 class TaggingAction;
 
 class AssignNameOverlay : public PersistentWidgetDelegateOverlay
 {
     Q_OBJECT
-    REQUIRE_DELEGATE(ItemViewImageDelegate)
+    REQUIRE_DELEGATE(ItemViewDelegate)
 
 public:
 
@@ -62,8 +62,8 @@ Q_SIGNALS:
 
 protected Q_SLOTS:
 
-    void slotAssigned(const TaggingAction& action, const ImageInfo&, const QVariant& faceIdentifier);
-    void slotRejected(const ImageInfo&, const QVariant& faceIdentifier);
+    void slotAssigned(const TaggingAction& action, const ItemInfo&, const QVariant& faceIdentifier);
+    void slotRejected(const ItemInfo&, const QVariant& faceIdentifier);
 
 protected:
 
@@ -82,6 +82,10 @@ protected:
     void updatePosition();
     void updateFace();
 
+private:
+
+    AssignNameOverlay(); // Disable default constructor.
+
 private:
 
     class Private;
@@ -90,4 +94,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* IMAGERATINGOVERLAY_H */
+#endif // DIGIKAM_ASSIGN_NAME_OVERLAY_H
