@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-02-28
  * Description : overlay for extra functionality of the group indicator
  *
  * Copyright (C) 2011      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GROUPINDICATOROVERLAY_H
-#define GROUPINDICATOROVERLAY_H
+#ifndef DIGIKAM_GROUP_INDICATOR_OVERLAY_H
+#define DIGIKAM_GROUP_INDICATOR_OVERLAY_H
 
 // Qt includes
 
@@ -32,8 +32,8 @@
 
 // Local includes
 
-#include "imagedelegateoverlay.h"
-#include "itemviewimagedelegate.h"
+#include "itemdelegateoverlay.h"
+#include "itemviewdelegate.h"
 
 namespace Digikam
 {
@@ -61,7 +61,7 @@ Q_SIGNALS:
 class GroupIndicatorOverlay : public AbstractWidgetDelegateOverlay
 {
     Q_OBJECT
-    REQUIRE_DELEGATE(ItemViewImageDelegate)
+    REQUIRE_DELEGATE(ItemViewDelegate)
 
 public:
 
@@ -97,4 +97,4 @@ protected:
 
 } // namespace Digikam
 
-#endif /* GROUPINDICATOROVERLAY_H */
+#endif // DIGIKAM_GROUP_INDICATOR_OVERLAY_H
