@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation
  *
  * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C)      2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2002-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2002-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
@@ -41,7 +41,6 @@
 // Local includes
 
 #include "digikam_config.h"
-#include "digikam_export.h"
 #include "dxmlguiwindow.h"
 #include "digikam_export.h"
 
@@ -54,11 +53,11 @@ namespace Digikam
 {
 
 class Album;
-class DigikamView;
+class ItemIconView;
 class FaceScanSettings;
 class FilterStatusBar;
-class ImageInfo;
-class ImageInfoList;
+class ItemInfo;
+class ItemInfoList;
 class CameraType;
 
 class DIGIKAM_EXPORT DigikamApp : public DXmlGuiWindow
@@ -67,31 +66,25 @@ class DIGIKAM_EXPORT DigikamApp : public DXmlGuiWindow
 
 public:
 
-    DigikamApp();
+    explicit DigikamApp();
     ~DigikamApp();
 
     virtual void show();
     void restoreSession();
 
-    QMenu* slideShowMenu() const;
-
-    void autoDetect();
-    void downloadFrom(const QString& cameraGuiPath);
-    void downloadFromUdi(const QString& udi);
     void enableZoomPlusAction(bool val);
     void enableZoomMinusAction(bool val);
     void enableAlbumBackwardHistory(bool enable);
     void enableAlbumForwardHistory(bool enable);
 
-    void startInternalDatabase();
-    void stopInternalDatabase();
-
-    void rebuild();
-
-    DigikamView* view() const;
+    ItemIconView* view()    const;
+    QMenu* slideShowMenu() const;
 
     static DigikamApp* instance();
-    static QString scannerTargetPlace();
+
+public:
+
+    DInfoInterface* infoIface(DPluginAction* const ac);
 
 Q_SIGNALS:
 
@@ -106,9 +99,6 @@ Q_SIGNALS:
 
     void signalWindowHasMoved();
 
-    void queuedOpenCameraUiFromPath(const QString& path);
-    void queuedOpenSolidDevice(const QString& udi);
-
 protected:
 
     bool queryClose();
@@ -117,41 +107,19 @@ protected:
 
 private:
 
-    bool    setup();
-    bool    setupICC();
-    void    setupView();
-    void    setupViewConnections();
-    void    setupStatusBar();
-    void    setupActions();
-    void    setupAccelerators();
-    void    setupExifOrientationActions();
-    void    setupImageTransformActions();
-    void    setupSelectToolsAction();
-    void    loadPlugins();
-    void    loadCameras();
-    void    populateThemes();
-    void    preloadWindows();
-    void    fillSolidMenus();
-    bool    checkSolidCamera(const Solid::Device& cameraDevice);
-    QString labelForSolidCamera(const Solid::Device& cameraDevice);
-    void    openSolidCamera(const QString& udi, const QString& label = QString());
-    void    openSolidUsmDevice(const QString& udi, const QString& label = QString());
-    void    updateCameraMenu();
-    void    updateQuickImportAction();
-    void    initGui();
-    void    showThumbBar(bool visible);
-    void    showSideBars(bool visible);
-    bool    thumbbarVisibility() const;
-    void    customizedFullScreenMode(bool set);
-    void    toggleShowBar();
+    void showThumbBar(bool visible);
+    void showSideBars(bool visible);
+    bool thumbbarVisibility() const;
+    void customizedFullScreenMode(bool set);
+    void customizedTrashView(bool set);
+    void toggleShowBar();
 
 private Q_SLOTS:
 
     void slotAlbumSelected(Album*);
-    void slotImageSelected(const ImageInfoList&, const ImageInfoList&);
+    void slotImageSelected(const ItemInfoList&, const ItemInfoList&);
     void slotSelectionChanged(int selectionCount);
     void slotExit();
-    void slotShowKipiHelp();
     void slotDBStat();
     void slotComponentsInfo();
 
@@ -161,28 +129,12 @@ private Q_SLOTS:
     void slotAboutToShowForwardMenu();
     void slotAboutToShowBackwardMenu();
 
-    void slotSetup();
-    void slotSetupCamera();
-    void slotSetupChanged();
     void slotColorManagementOptionsChanged();
     void slotToggleColorManagedView();
-    void slotSetCheckedExifOrientationAction(const ImageInfo& info);
+    void slotSetCheckedExifOrientationAction(const ItemInfo& info);
     void slotResetExifOrientationActions();
     void slotTransformAction();
 
-    void slotOpenSolidCamera(QAction*);
-    void slotOpenManualCamera(QAction*);
-    void slotOpenSolidUsmDevice(QAction*);
-    void slotOpenSolidDevice(const QString& udi);
-    void slotOpenCameraUiFromPath(const QString& path);
-    void slotSolidSetupDone(Solid::ErrorType errorType, QVariant errorData, const QString& udi);
-    void slotSolidDeviceChanged(const QString& udi);
-    void slotCameraAdded(CameraType*);
-    void slotCameraRemoved(QAction*);
-    void slotCameraAutoDetect();
-    void downloadImages(const QString& folder);
-    void cameraAutoDetect();
-
     void slotToggleLeftSideBar();
     void slotToggleRightSideBar();
     void slotPreviousLeftSideBarTab();
@@ -191,21 +143,6 @@ private Q_SLOTS:
     void slotNextRightSideBarTab();
 
     void slotToggleShowBar();
-    void slotEditKeys();
-
-    void slotMaintenance();
-    void slotMaintenanceDone();
-    void slotExpoBlending();
-    void slotPanorama();
-    void slotVideoSlideshow();
-    void slotSendByMail();
-    void slotPrintCreator();
-    void slotHtmlGallery();
-    void slotCalendar();
-    void slotPresentation();
-    void slotMediaServer();
-
-    void slotDatabaseMigration();
 
     void slotZoomSliderChanged(int);
     void slotThumbSizeChanged(int);
@@ -217,13 +154,110 @@ private Q_SLOTS:
     void slotSwitchedToTableView();
     void slotSwitchedToTrashView();
 
-    void slotImportAddImages();
-    void slotImportAddFolders();
+// -- Internal setup methods implemented in digikamapp_setup.cpp ----------------------------------------
+
+private:
+
+    void setupView();
+    void setupViewConnections();
+    void setupStatusBar();
+    void setupActions();
+    void setupAccelerators();
+    void setupExifOrientationActions();
+    void setupImageTransformActions();
+    void populateThemes();
+    void preloadWindows();
+    void initGui();
+
+// -- Extra tool methods implemented in digikamapp_tools.cpp ----------------------------------------
+
+private:
+
+    void setupSelectToolsAction();
+
+private Q_SLOTS:
+
+    void slotMaintenance();
+    void slotMaintenanceDone();
+    void slotDatabaseMigration();
+
+// -- Configure methods implemented in digikamapp_config.cpp ----------------------------------------
+
+private:
+
+    bool setup();
+    bool setupICC();
+
+private Q_SLOTS:
+
+    void slotSetup();
+    void slotSetupChanged();
+    void slotEditKeys();
     void slotThemeChanged();
 
-    void slotImportFromScanner();
-    void slotEditMetadata();
-    void slotEditGeolocation();
+// -- Import tools methods implemented in digikamapp_import.cpp -------------------------------------
+
+private:
+
+    void updateQuickImportAction();
+
+private Q_SLOTS:
+
+    void slotImportedImagefromScanner(const QUrl& url);
+    void slotImportAddImages();
+    void slotImportAddFolders();
+
+// -- Camera management methods implemented in digikamapp_camera.cpp --------------------------------
+
+public:
+
+    void autoDetect();
+    void downloadFrom(const QString& cameraGuiPath);
+    void downloadFromUdi(const QString& udi);
+
+Q_SIGNALS:
+
+    void queuedOpenCameraUiFromPath(const QString& path);
+
+private:
+
+    void loadCameras();
+    void updateCameraMenu();
+
+private Q_SLOTS:
+
+    void slotSetupCamera();
+    void slotOpenManualCamera(QAction*);
+    void slotCameraAdded(CameraType*);
+    void slotCameraRemoved(QAction*);
+    void slotCameraAutoDetect();
+    void slotOpenCameraUiFromPath(const QString& path);
+    void downloadImages(const QString& folder);
+    void cameraAutoDetect();
+
+// -- Solid based methods implemented in digikamapp_solid.cpp ---------------------------------------
+
+Q_SIGNALS:
+
+    void queuedOpenSolidDevice(const QString& udi);
+
+private:
+
+    void    fillSolidMenus();
+    bool    checkSolidCamera(const Solid::Device& cameraDevice);
+    QString labelForSolidCamera(const Solid::Device& cameraDevice);
+    void    openSolidCamera(const QString& udi, const QString& label = QString());
+    void    openSolidUsmDevice(const QString& udi, const QString& label = QString());
+
+private Q_SLOTS:
+
+    void slotOpenSolidCamera(QAction*);
+    void slotOpenSolidUsmDevice(QAction*);
+    void slotOpenSolidDevice(const QString& udi);
+    void slotSolidSetupDone(Solid::ErrorType errorType, QVariant errorData, const QString& udi);
+    void slotSolidDeviceChanged(const QString& udi);
+
+// -- Internal private container --------------------------------------------------------------------
 
 private:
 
@@ -233,6 +267,6 @@ private:
     static DigikamApp* m_instance;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif  // DIGIKAM_APP_H
+#endif // DIGIKAM_APP_H
