@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-31-01
  * Description : main digiKam interface implementation
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2014      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,40 +34,127 @@
 #include <QString>
 #include <QAction>
 #include <QMenu>
+#include <QApplication>
+#include <QStringList>
+#include <QDomDocument>
+#include <QStandardPaths>
+#include <QKeySequence>
+#include <QMenuBar>
+#include <QTimer>
+#include <QIcon>
+#include <QMessageBox>
+#include <QStatusBar>
+#include <QDir>
 
 // KDE includes
 
+#include <klocalizedstring.h>
+#include <kactioncollection.h>
+#include <ktoolbar.h>
+#include <ktoolbarpopupaction.h>
+#include <kwindowsystem.h>
 #include <kselectaction.h>
 
 // Local includes
 
 #include "digikam_config.h"
+#include "digikam_debug.h"
 #include "albummanager.h"
 #include "applicationsettings.h"
 #include "cameralist.h"
+#include "cameratype.h"
+#include "cameranamehelper.h"
 #include "dsplashscreen.h"
 #include "dzoombar.h"
-#include "digikamview.h"
+#include "itemiconview.h"
 #include "metadatastatusbar.h"
+#include "itempropertiestab.h"
+#include "importui.h"
+#include "setup.h"
+#include "actioncategorizedview.h"
+#include "drawdecoder.h"
+#include "dlayoutbox.h"
+#include "album.h"
+#include "coredb.h"
+#include "albummodel.h"
+#include "albumselectdialog.h"
+#include "albumthumbnailloader.h"
+#include "dbinfoiface.h"
+#include "itemgps.h"
+#include "categorizeditemmodel.h"
+#include "collectionscanner.h"
+#include "collectionmanager.h"
+#include "componentsinfodlg.h"
+#include "coredbthumbinfoprovider.h"
+#include "dio.h"
+#include "dlogoaction.h"
+#include "fileactionmngr.h"
+#include "filterstatusbar.h"
+#include "iccsettings.h"
+#include "itemattributeswatch.h"
+#include "iteminfo.h"
+#include "imagewindow.h"
+#include "lighttablewindow.h"
+#include "queuemgrwindow.h"
+#include "loadingcache.h"
+#include "loadingcacheinterface.h"
+#include "loadsavethread.h"
+#include "metaengine_rotation.h"
+#include "scancontroller.h"
+#include "setupeditor.h"
+#include "setupicc.h"
+#include "thememanager.h"
+#include "thumbnailloadthread.h"
+#include "thumbnailsize.h"
+#include "dmetadata.h"
+#include "tagscache.h"
+#include "tagsactionmngr.h"
+#include "databaseserverstarter.h"
+#include "metaenginesettings.h"
+#include "statusbarprogresswidget.h"
+#include "dbmigrationdlg.h"
+#include "progressmanager.h"
+#include "progressview.h"
+#include "maintenancedlg.h"
+#include "maintenancemngr.h"
+#include "newitemsfinder.h"
+#include "dbcleaner.h"
+#include "tagsmanager.h"
+#include "itemsortsettings.h"
+#include "metadatahubmngr.h"
+#include "metadataedit.h"
+#include "dfiledialog.h"
+#include "dpluginloader.h"
+
+#ifdef HAVE_MARBLE
+#   include "geolocationedit.h"
+#endif
+
+#ifdef HAVE_DBUS
+#   include "digikamadaptor.h"
+#endif
+
+#ifdef HAVE_KFILEMETADATA
+#   include "baloowrap.h"
+#endif
 
 class KToolBarPopupAction;
 
 namespace Digikam
 {
 
-class ImportUI;
 class SearchTextBar;
 class FilterStatusBar;
 class TagsActionMngr;
 class DAdjustableLabel;
 
-class ProgressEntry
+class Q_DECL_HIDDEN ProgressEntry
 {
 public:
 
-    ProgressEntry()
-        : progress(0),
-          canCancel(false)
+    explicit ProgressEntry()
+      : progress(0),
+        canCancel(false)
     {
     }
 
@@ -78,12 +165,12 @@ public:
 
 // ------------------------------------------------------------------------------
 
-class DigikamApp::Private
+class Q_DECL_HIDDEN DigikamApp::Private
 {
 public:
 
-    Private() :
-        autoShowZoomToolTip(false),
+    explicit Private()
+      : autoShowZoomToolTip(false),
         validIccPath(true),
         cameraMenu(0),
         usbMediaMenu(0),
@@ -126,6 +213,7 @@ public:
         imageViewAction(0),
         imageWriteMetadataAction(0),
         imageReadMetadataAction(0),
+        imageScanForFacesAction(0),
         imageFindSimilarAction(0),
         imageSetExifOrientation1Action(0),
         imageSetExifOrientation2Action(0),
@@ -248,6 +336,7 @@ public:
     QAction*                            imageViewAction;
     QAction*                            imageWriteMetadataAction;
     QAction*                            imageReadMetadataAction;
+    QAction*                            imageScanForFacesAction;
     QAction*                            imageFindSimilarAction;
     QAction*                            imageSetExifOrientation1Action;
     QAction*                            imageSetExifOrientation2Action;
@@ -320,15 +409,15 @@ public:
     MetadataStatusBar*                  metadataStatusBar;
     FilterStatusBar*                    filterStatusBar;
     DSplashScreen*                      splashScreen;
-    DigikamView*                        view;
+    ItemIconView*                        view;
     CameraList*                         cameraList;
     TagsActionMngr*                     tagsActionManager;
     DZoomBar*                           zoomBar;
     DAdjustableLabel*                   statusLabel;
 
-    DigikamModelCollection*             modelCollection;
+    DModelFactory*                      modelCollection;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
 #endif // DIGIKAM_APP_PRIVATE_H
