@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2002-07-28
  * Description : main program from digiKam
  *
  * Copyright (C) 2002-2006 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2002-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2002-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,6 @@
  *
  * ============================================================ */
 
-#include "digikam_config.h"
-
 // Qt includes
 
 #include <QFile>
@@ -44,8 +42,11 @@
 
 // Local includes
 
-#include "metaengine.h"
+#include "digikam_config.h"
 #include "digikam_debug.h"
+#include "digikam_version.h"
+#include "digikam_globals.h"
+#include "metaengine.h"
 #include "dmessagebox.h"
 #include "albummanager.h"
 #include "firstrundlg.h"
@@ -59,26 +60,37 @@
 #include "thumbsdbaccess.h"
 #include "facedbaccess.h"
 #include "dxmlguiwindow.h"
-#include "digikam_version.h"
 #include "applicationsettings.h"
+#include "similaritydbaccess.h"
+
+#ifdef Q_OS_WIN
+#   include <windows.h>
+#   include <shellapi.h>
+#   include <objbase.h>
+#endif
 
 using namespace Digikam;
 
-
 int main(int argc, char* argv[])
 {
     QApplication app(argc, argv);
 
+    tryInitDrMingw();
+
+#ifdef Q_OS_LINUX
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
+
     // if we have some local breeze icon resource, prefer it
     DXmlGuiWindow::setupIconTheme();
 
     KLocalizedString::setApplicationDomain("digikam");
 
-    KAboutData aboutData(QString::fromLatin1("digikam"), // component name
-                         i18n("digiKam"),                // display name
+    KAboutData aboutData(QLatin1String("digikam"), // component name
+                         i18n("digiKam"),          // display name
                          digiKamVersion());
 
-    aboutData.setShortDescription(DAboutData::digiKamSlogan());;
+    aboutData.setShortDescription(QString::fromUtf8("%1 - %2").arg(DAboutData::digiKamSlogan()).arg(DAboutData::digiKamFamily()));
     aboutData.setLicense(KAboutLicense::GPL);
     aboutData.setCopyrightStatement(DAboutData::copyright());
     aboutData.setOtherText(additionalInformation());
@@ -163,8 +175,8 @@ int main(int argc, char* argv[])
         QString configFilename = parser.value(QLatin1String("config"));
         QFileInfo configFile(configFilename);
 
-        if (configFile.isDir() || !configFile.dir().exists()
-                || !configFile.isReadable() || !configFile.isWritable())
+        if (configFile.isDir() || !configFile.dir().exists() ||
+            !configFile.isReadable() || !configFile.isWritable())
         {
             QMessageBox::critical(qApp->activeWindow(),
                                   qApp->applicationName(),
@@ -179,8 +191,8 @@ int main(int argc, char* argv[])
             return 1;
         }
     }
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("General Settings"));
     QString version           = group.readEntry(QLatin1String("Version"), QString());
     QString iconTheme         = group.readEntry(QLatin1String("Icon Theme"), QString());
@@ -230,6 +242,7 @@ int main(int argc, char* argv[])
         CoreDbAccess::cleanUpDatabase();
         ThumbsDbAccess::cleanUpDatabase();
         FaceDbAccess::cleanUpDatabase();
+        SimilarityDbAccess::cleanUpDatabase();
         MetaEngine::cleanupExiv2();
         return 0;
     }
@@ -239,6 +252,11 @@ int main(int argc, char* argv[])
         QIcon::setThemeName(iconTheme);
     }
 
+#ifdef Q_OS_WIN
+    // Necessary to open native open with dialog on windows
+    CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
+#endif
+
     // create main window
     DigikamApp* const digikam = new DigikamApp();
 
@@ -280,14 +298,18 @@ int main(int argc, char* argv[])
         digikam->autoDetect();
     }
 
-
-
     int ret = app.exec();
 
     CoreDbAccess::cleanUpDatabase();
     ThumbsDbAccess::cleanUpDatabase();
     FaceDbAccess::cleanUpDatabase();
+    SimilarityDbAccess::cleanUpDatabase();
     MetaEngine::cleanupExiv2();
 
+#ifdef Q_OS_WIN
+    // Necessary to open native open with dialog on windows
+    CoUninitialize();
+#endif
+
     return ret;
 }
