@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-02-11
  * Description : Table view
@@ -39,11 +39,12 @@
 
 #include "advancedrenamedialog.h"
 #include "advancedrenameprocessdialog.h"
+#include "applicationsettings.h"
 #include "contextmenuhelper.h"
 #include "digikam_debug.h"
 #include "fileactionmngr.h"
 #include "album.h"
-#include "imageviewutilities.h"
+#include "itemviewutilities.h"
 #include "tableview_columnfactory.h"
 #include "tableview_model.h"
 #include "tableview_selection_model_syncer.h"
@@ -53,14 +54,14 @@
 namespace Digikam
 {
 
-class ImageAlbumModel;
-class ImageFilterModel;
+class ItemAlbumModel;
+class ItemFilterModel;
 
-class TableView::Private
+class Q_DECL_HIDDEN TableView::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : columnProfiles(),
         thumbnailSize(),
         imageViewUtilities(0)
@@ -69,7 +70,7 @@ public:
 
     QList<TableViewColumnProfile> columnProfiles;
     ThumbnailSize                 thumbnailSize;
-    ImageViewUtilities*           imageViewUtilities;
+    ItemViewUtilities*           imageViewUtilities;
 };
 
 TableView::TableView(QItemSelectionModel* const selectionModel,
@@ -83,8 +84,8 @@ TableView::TableView(QItemSelectionModel* const selectionModel,
     s->isActive                      = false;
     s->tableView                     = this;
     s->thumbnailLoadThread           = new ThumbnailLoadThread(this);
-    s->imageFilterModel              = dynamic_cast<ImageFilterModel*>(imageFilterModel);
-    s->imageModel                    = dynamic_cast<ImageModel*>(imageFilterModel->sourceModel());
+    s->imageFilterModel              = dynamic_cast<ItemFilterModel*>(imageFilterModel);
+    s->imageModel                    = dynamic_cast<ItemModel*>(imageFilterModel->sourceModel());
     s->imageFilterSelectionModel     = selectionModel;
     s->columnFactory                 = new TableViewColumnFactory(s.data(), this);
 
@@ -95,7 +96,7 @@ TableView::TableView(QItemSelectionModel* const selectionModel,
     s->treeView                      = new TableViewTreeView(s.data(), this);
     s->treeView->installEventFilter(this);
 
-    d->imageViewUtilities            = new ImageViewUtilities(this);
+    d->imageViewUtilities            = new ItemViewUtilities(this);
 
     connect(s->treeView, SIGNAL(activated(QModelIndex)),
             this, SLOT(slotItemActivated(QModelIndex)));
@@ -128,6 +129,7 @@ TableView::TableView(QItemSelectionModel* const selectionModel,
             this, SIGNAL(signalItemsChanged()));
 
     vbox1->addWidget(s->treeView);
+    vbox1->setContentsMargins(QMargins());
 
     setLayout(vbox1);
 }
@@ -168,7 +170,7 @@ void TableView::doSaveState()
 
 void TableView::slotItemActivated(const QModelIndex& tableViewIndex)
 {
-    const ImageInfo info = s->tableViewModel->imageInfo(tableViewIndex);
+    const ItemInfo info = s->tableViewModel->imageInfo(tableViewIndex);
 
     if (info.isNull())
     {
@@ -183,12 +185,12 @@ void TableView::slotItemActivated(const QModelIndex& tableViewIndex)
         }
         else
         {
-            d->imageViewUtilities->openInfos(info, allInfo(), currentAlbum());
+            d->imageViewUtilities->openInfos(info, allItemInfos(), currentAlbum());
         }
     }
     else
     {
-        d->imageViewUtilities->openInfosWithDefaultApplication(QList<ImageInfo>() << info);
+        d->imageViewUtilities->openInfosWithDefaultApplication(QList<ItemInfo>() << info);
     }
 }
 
@@ -225,7 +227,7 @@ void TableView::setThumbnailSize(const ThumbnailSize& size)
     d->thumbnailSize                            = size;
     const QList<TableViewColumn*> columnObjects = s->tableViewModel->getColumnObjects();
 
-    Q_FOREACH(TableViewColumn* const iColumn, columnObjects)
+    foreach(TableViewColumn* const iColumn, columnObjects)
     {
         iColumn->updateThumbnailSize();
     }
@@ -238,7 +240,7 @@ ThumbnailSize TableView::getThumbnailSize() const
 
 Album* TableView::currentAlbum() const
 {
-    ImageAlbumModel* const albumModel = qobject_cast<ImageAlbumModel*>(s->imageModel);
+    ItemAlbumModel* const albumModel = qobject_cast<ItemAlbumModel*>(s->imageModel);
 
     if (!albumModel)
     {
@@ -259,24 +261,34 @@ void TableView::slotPaste()
     dragDropViewImplementation->paste();
 }
 
-ImageInfo TableView::currentInfo() const
+ItemInfo TableView::currentInfo() const
 {
     return s->tableViewModel->imageInfo(s->tableViewSelectionModel->currentIndex());
 }
 
-ImageInfoList TableView::allInfo(bool grouping) const
+ItemInfoList TableView::allItemInfos(bool grouping) const
 {
     if (grouping)
     {
-        return resolveGrouping(s->tableViewModel->allImageInfo());
+        return s->treeView->resolveGrouping(ItemInfoList(s->tableViewModel->allItemInfo()));
     }
 
-    return s->tableViewModel->allImageInfo();
+    return ItemInfoList(s->tableViewModel->allItemInfo());
 }
 
-void TableView::slotDeleteSelected(const ImageViewUtilities::DeleteMode deleteMode)
+bool TableView::allNeedGroupResolving(const ApplicationSettings::OperationType type) const
 {
-    const ImageInfoList infoList = selectedImageInfos(true);
+    return s->treeView->needGroupResolving(type, allItemInfos());
+}
+
+bool TableView::selectedNeedGroupResolving(const ApplicationSettings::OperationType type) const
+{
+    return s->treeView->needGroupResolving(type, selectedItemInfos());
+}
+
+void TableView::slotDeleteSelected(const ItemViewUtilities::DeleteMode deleteMode)
+{
+    const ItemInfoList infoList = selectedItemInfos(true);
 
     /// @todo Update parameter naming for deleteImages
     if (d->imageViewUtilities->deleteImages(infoList, deleteMode))
@@ -285,9 +297,9 @@ void TableView::slotDeleteSelected(const ImageViewUtilities::DeleteMode deleteMo
     }
 }
 
-void TableView::slotDeleteSelectedWithoutConfirmation(const ImageViewUtilities::DeleteMode deleteMode)
+void TableView::slotDeleteSelectedWithoutConfirmation(const ItemViewUtilities::DeleteMode deleteMode)
 {
-    const ImageInfoList infoList = selectedImageInfos(true);
+    const ItemInfoList infoList = selectedItemInfos(true);
 
     d->imageViewUtilities->deleteImagesDirectly(infoList, deleteMode);
     slotAwayFromSelection();
@@ -345,19 +357,6 @@ void TableView::slotGroupingModeActionTriggered()
     s->tableViewModel->setGroupingMode(newGroupingMode);
 }
 
-QList<QUrl> TableView::allUrls(bool grouping) const
-{
-    const ImageInfoList infos = allInfo(grouping);
-    QList<QUrl> resultList;
-
-    Q_FOREACH(const ImageInfo& info, infos)
-    {
-        resultList << info.fileUrl();
-    }
-
-    return resultList;
-}
-
 int TableView::numberOfSelectedItems() const
 {
     return s->tableViewSelectionModel->selectedRows().count();
@@ -384,7 +383,7 @@ void TableView::slotGoToRow(const int rowNumber, const bool relativeMove)
     }
 }
 
-ImageInfo TableView::deepRowImageInfo(const int rowNumber, const bool relative) const
+ItemInfo TableView::deepRowItemInfo(const int rowNumber, const bool relative) const
 {
     int targetRowNumber = rowNumber;
 
@@ -394,7 +393,7 @@ ImageInfo TableView::deepRowImageInfo(const int rowNumber, const bool relative)
 
         if (!currentTableViewIndex.isValid())
         {
-            return ImageInfo();
+            return ItemInfo();
         }
 
         const int currentDeepRowNumber = s->tableViewModel->indexToDeepRowNumber(currentTableViewIndex);
@@ -405,7 +404,7 @@ ImageInfo TableView::deepRowImageInfo(const int rowNumber, const bool relative)
     return s->tableViewModel->imageInfo(targetIndex);
 }
 
-ImageInfo TableView::nextInfo() const
+ItemInfo TableView::nextInfo() const
 {
     const QModelIndex cIndex       = s->tableViewSelectionModel->currentIndex();
     const int currentDeepRowNumber = s->tableViewModel->indexToDeepRowNumber(cIndex);
@@ -413,14 +412,14 @@ ImageInfo TableView::nextInfo() const
 
     if (nextDeepRowNumber>=s->tableViewModel->deepRowCount())
     {
-        return ImageInfo();
+        return ItemInfo();
     }
 
     const QModelIndex nextDeepRowIndex = s->tableViewModel->deepRowIndex(nextDeepRowNumber);
     return s->tableViewModel->imageInfo(nextDeepRowIndex);
 }
 
-ImageInfo TableView::previousInfo() const
+ItemInfo TableView::previousInfo() const
 {
     const QModelIndex cIndex        = s->tableViewSelectionModel->currentIndex();
     const int currentDeepRowNumber  = s->tableViewModel->indexToDeepRowNumber(cIndex);
@@ -428,7 +427,7 @@ ImageInfo TableView::previousInfo() const
 
     if (previousDeepRowNumber < 0)
     {
-        return ImageInfo();
+        return ItemInfo();
     }
 
     const QModelIndex previousDeepRowIndex = s->tableViewModel->deepRowIndex(previousDeepRowNumber);
@@ -543,7 +542,7 @@ void TableView::invertSelection()
 
     s->tableViewSelectionModel->clearSelection();
 
-    Q_FOREACH(const int i, rowsToSelect)
+    foreach(const int i, rowsToSelect)
     {
         const QModelIndex iIndex = s->tableViewModel->deepRowIndex(i);
         const QItemSelection is  = s->tableViewSelectionModelSyncer->targetIndexToRowItemSelection(iIndex);
@@ -567,20 +566,19 @@ void TableView::slotSetActive(const bool isActive)
     }
 }
 
-ImageInfoList TableView::selectedImageInfos(bool grouping) const
+ItemInfoList TableView::selectedItemInfos(bool grouping) const
 {
-    if (grouping) {
-        return resolveGrouping(s->tableViewSelectionModel->selectedRows());
+    ItemInfoList infos = ItemInfoList(s->tableViewModel->imageInfos(s->tableViewSelectionModel->selectedRows()));
+
+    if (grouping)
+    {
+        return s->treeView->resolveGrouping(infos);
     }
-    return s->tableViewModel->imageInfos(s->tableViewSelectionModel->selectedRows());
+
+    return infos;
 }
 
-ImageInfoList TableView::selectedImageInfos(ApplicationSettings::OperationType type) const
-{
-    return selectedImageInfos(needGroupResolving(type));
-}
-
-QModelIndexList TableView::selectedIndexesCurrentFirst() const
+ItemInfoList TableView::selectedItemInfosCurrentFirst(bool grouping) const
 {
     QModelIndexList indexes   = s->tableViewSelectionModel->selectedRows();
     const QModelIndex current = s->tableViewModel->toCol0(s->tableViewSelectionModel->currentIndex());
@@ -596,121 +594,63 @@ QModelIndexList TableView::selectedIndexesCurrentFirst() const
         }
     }
 
-    return indexes;
-}
-
-ImageInfoList TableView::selectedImageInfosCurrentFirst(bool grouping) const
-{
-    if (grouping) {
-        return resolveGrouping(selectedIndexesCurrentFirst());
-    }
-    return s->tableViewModel->imageInfos(selectedIndexesCurrentFirst());
-}
-
-QList<qlonglong> TableView::selectedImageIdsCurrentFirst(bool grouping) const
-{
-    return selectedImageInfosCurrentFirst(grouping).toImageIdList();
-}
-
-QList<QUrl> TableView::selectedUrls(bool grouping) const
-{
-    return selectedImageInfos(grouping).toImageUrlList();
-}
-
-ImageInfoList TableView::resolveGrouping(const QList<QModelIndex>& indexes) const
-{
-    return resolveGrouping(s->tableViewModel->imageInfos(indexes));
-}
-
-ImageInfoList TableView::resolveGrouping(const ImageInfoList& infos) const
-{
-    ImageInfoList out;
-
-    foreach(const ImageInfo& info, infos)
+    if (grouping)
     {
-        QModelIndex index = s->tableViewModel->indexFromImageId(info.id(), 0);
-
-        out << info;
-
-        if (info.hasGroupedImages()
-            && (s->tableViewModel->groupingMode() == s->tableViewModel->GroupingMode::GroupingHideGrouped
-                || (s->tableViewModel->groupingMode() == s->tableViewModel->GroupingMode::GroupingShowSubItems
-                    && !s->treeView->isExpanded(index))))
-        {
-            out << info.groupedImages();
-        }
+        return s->treeView->resolveGrouping(ItemInfoList(s->tableViewModel->imageInfos(indexes)));
     }
 
-    return out;
-}
-
-bool TableView::needGroupResolving(ApplicationSettings::OperationType type, bool all) const
-{
-    ApplicationSettings::ApplyToEntireGroup applyAll =
-            ApplicationSettings::instance()->getGroupingOperateOnAll(type);
-
-    if (applyAll == ApplicationSettings::No)
-    {
-        return false;
-    }
-    else if (applyAll == ApplicationSettings::Yes)
-    {
-        return true;
-    }
-
-    ImageInfoList infos;
-
-    if (all)
-    {
-        infos = s->tableViewModel->allImageInfo();
-    }
-    else
-    {
-        infos = s->tableViewModel->imageInfos(s->tableViewSelectionModel->selectedRows());
-    }
-
-    foreach(const ImageInfo& info, infos)
-    {
-        QModelIndex index = s->tableViewModel->indexFromImageId(info.id(), 0);
-
-        if (info.hasGroupedImages()
-            && (s->tableViewModel->groupingMode() == s->tableViewModel->GroupingMode::GroupingHideGrouped
-                || (s->tableViewModel->groupingMode() == s->tableViewModel->GroupingMode::GroupingShowSubItems
-                    && !s->treeView->isExpanded(index))))
-        {
-            // Ask whether should be performed on all and return info if no
-            return ApplicationSettings::instance()->askGroupingOperateOnAll(type);
-        }
-    }
-
-    return false;
+    return ItemInfoList(s->tableViewModel->imageInfos(indexes));
 }
 
 void TableView::rename()
 {
-    bool grouping     = needGroupResolving(ApplicationSettings::Rename);
-    QList<QUrl>  urls = selectedUrls(grouping);
+    ItemInfoList infos = selectedItemInfos();
+
+    if (s->treeView->needGroupResolving(ApplicationSettings::Rename, infos))
+    {
+        infos = s->treeView->resolveGrouping(infos);
+    }
+
+    QList<QUrl> urls = infos.toImageUrlList();
+    bool loop        = false;
     NewNamesList newNamesList;
 
-    qCDebug(DIGIKAM_GENERAL_LOG) << "Selected URLs to rename: " << urls;
-
-    QPointer<AdvancedRenameDialog> dlg = new AdvancedRenameDialog(this);
-    dlg->slotAddImages(urls);
-
-    if (dlg->exec() == QDialog::Accepted)
+    do
     {
+        qCDebug(DIGIKAM_GENERAL_LOG) << "Selected URLs to rename: " << urls;
+
+        QPointer<AdvancedRenameDialog> dlg = new AdvancedRenameDialog(this);
+        dlg->slotAddImages(urls);
+
+        if (dlg->exec() != QDialog::Accepted)
+        {
+            delete dlg;
+            break;
+        }
+
+        if (!loop)
+        {
+            slotAwayFromSelection();
+            loop = true;
+        }
+
         newNamesList = dlg->newNames();
-
-        slotAwayFromSelection();
-    }
-
-    delete dlg;
-
-    if (!newNamesList.isEmpty())
-    {
-        QPointer<AdvancedRenameProcessDialog> dlg = new AdvancedRenameProcessDialog(newNamesList);
-        dlg->exec();
         delete dlg;
+
+        setFocus();
+        qApp->processEvents();
+
+        if (!newNamesList.isEmpty())
+        {
+            QPointer<AdvancedRenameProcessDialog> dlg = new AdvancedRenameProcessDialog(newNamesList, this);
+            dlg->exec();
+
+            s->tableViewModel->scheduleResort();
+            urls = dlg->failedUrls();
+            delete dlg;
+        }
     }
+    while (!urls.isEmpty() && !newNamesList.isEmpty());
 }
+
 } // namespace Digikam
