@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-03-02
  * Description : Table view: Column configuration dialog
@@ -43,14 +43,14 @@
 namespace Digikam
 {
 
-class ImageAlbumModel;
-class ImageFilterModel;
+class ItemAlbumModel;
+class ItemFilterModel;
 
-class TableViewConfigurationDialog::Private
+class Q_DECL_HIDDEN TableViewConfigurationDialog::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : columnIndex(0),
         buttons(0),
         columnObject(0),
