@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-02-25
  * Description : Table view column helpers: Item properties
@@ -20,8 +20,8 @@
  *
  * ============================================================ */
 
-#ifndef TABLEVIEW_COLUMN_ITEM_H
-#define TABLEVIEW_COLUMN_ITEM_H
+#ifndef DIGIKAM_TABLE_VIEW_COLUMN_ITEM_H
+#define DIGIKAM_TABLE_VIEW_COLUMN_ITEM_H
 
 // Qt includes
 
@@ -79,8 +79,8 @@ private:
     SubColumn subColumn;
 };
 
-} /* namespace TableViewColumns */
+} // namespace TableViewColumns
 
-} /* namespace Digikam */
+} // namespace Digikam
 
-#endif // TABLEVIEW_COLUMN_ITEM_H
+#endif // DIGIKAM_TABLE_VIEW_COLUMN_ITEM_H
