@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-02-12
  * Description : Table view column helpers
@@ -20,8 +20,8 @@
  *
  * ============================================================ */
 
-#ifndef TABLEVIEW_COLUMNFACTORY_H
-#define TABLEVIEW_COLUMNFACTORY_H
+#ifndef DIGIKAM_TABLE_VIEW_COLUMNFACTORY_H
+#define DIGIKAM_TABLE_VIEW_COLUMNFACTORY_H
 
 // Qt includes
 
@@ -44,7 +44,7 @@ class QStyleOptionViewItem;
 namespace Digikam
 {
 
-class ImageInfo;
+class ItemInfo;
 class ThumbnailSize;
 
 class TableViewColumnConfiguration
@@ -300,7 +300,7 @@ class TableViewColumnFactory : public QObject
 
 public:
 
-    explicit TableViewColumnFactory(TableViewShared* const tableViewShared, QObject* parent = 0);
+    explicit TableViewColumnFactory(TableViewShared* const tableViewShared, QObject* const parent = 0);
 
     static QList<TableViewColumnDescription> getColumnDescriptionList();
     TableViewColumn* getColumn(const TableViewColumnConfiguration& columnConfiguration);
@@ -329,12 +329,12 @@ public:
     QByteArray                          headerState;
 };
 
-} /* namespace Digikam */
+} // namespace Digikam
 
 Q_DECLARE_METATYPE(Digikam::TableViewColumnDescription)
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::TableViewColumn::ColumnFlags)
 
-#endif // TABLEVIEW_COLUMNFACTORY_H
+#endif // DIGIKAM_TABLE_VIEW_COLUMNFACTORY_H
 
 
