@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-02-12
  * Description : Wrapper model for table view
@@ -20,8 +20,8 @@
  *
  * ============================================================ */
 
-#ifndef TABLEVIEW_MODEL_H
-#define TABLEVIEW_MODEL_H
+#ifndef DIGIKAM_TABLE_VIEW_MODEL_H
+#define DIGIKAM_TABLE_VIEW_MODEL_H
 
 // Qt includes
 
@@ -39,10 +39,10 @@ namespace Digikam
 {
 
 class ImageChangeset;
-class ImageFilterModel;
-class ImageFilterSettings;
-class ImageInfo;
-class ImageInfoList;
+class ItemFilterModel;
+class ItemFilterSettings;
+class ItemInfo;
+class ItemInfoList;
 class TableViewColumn;
 class TableViewColumnConfiguration;
 class TableViewColumnDescription;
@@ -87,7 +87,7 @@ public:
 
 public:
 
-    explicit TableViewModel(TableViewShared* const sharedObject, QObject* parent = 0);
+    explicit TableViewModel(TableViewShared* const sharedObject, QObject* const parent = 0);
     virtual ~TableViewModel();
 
     void                    addColumnAt(const TableViewColumnDescription& description, const int targetColumn = -1);
@@ -95,10 +95,10 @@ public:
     void                    removeColumnAt(const int columnIndex);
     TableViewColumn*        getColumnObject(const int columnIndex);
     QList<TableViewColumn*> getColumnObjects();
-    QModelIndex             fromImageFilterModelIndex(const QModelIndex& imageFilterModelIndex);
-    QModelIndex             fromImageModelIndex(const QModelIndex& imageModelIndex);
-    QModelIndex             toImageFilterModelIndex(const QModelIndex& i) const;
-    QModelIndex             toImageModelIndex(const QModelIndex& i) const;
+    QModelIndex             fromItemFilterModelIndex(const QModelIndex& imageFilterModelIndex);
+    QModelIndex             fromItemModelIndex(const QModelIndex& imageModelIndex);
+    QModelIndex             toItemFilterModelIndex(const QModelIndex& i) const;
+    QModelIndex             toItemModelIndex(const QModelIndex& i) const;
     void                    loadColumnProfile(const TableViewColumnProfile& columnProfile);
     TableViewColumnProfile  getColumnProfile() const;
 
@@ -112,17 +112,17 @@ public:
     QModelIndex   indexFromImageId(const qlonglong imageId, const int columnIndex) const;
     Item*         itemFromImageId(const qlonglong imageId) const;
     Item*         itemFromIndex(const QModelIndex& i) const;
-    ImageInfo     infoFromItem(Item* const item) const;
-    ImageInfoList infosFromItems(QList<Item*> const items) const;
+    ItemInfo     infoFromItem(Item* const item) const;
+    ItemInfoList infosFromItems(QList<Item*> const items) const;
 
     QVariant              itemDatabaseFieldRaw(Item* const item, const DatabaseFields::Set requestedField);
     DatabaseFieldsHashRaw itemDatabaseFieldsRaw(Item* const item, const DatabaseFields::Set requestedSet);
 
     qlonglong        imageId(const QModelIndex& anIndex) const;
     QList<qlonglong> imageIds(const QModelIndexList& indexList) const;
-    QList<ImageInfo> imageInfos(const QModelIndexList& indexList) const;
-    ImageInfo        imageInfo(const QModelIndex& index) const;
-    QList<ImageInfo> allImageInfo() const;
+    QList<ItemInfo> imageInfos(const QModelIndexList& indexList) const;
+    ItemInfo        imageInfo(const QModelIndex& index) const;
+    QList<ItemInfo> allItemInfo() const;
 
     QList<Item*> sortItems(const QList<Item*> itemList);
     class LessThan;
@@ -177,7 +177,7 @@ private Q_SLOTS:
 
     void slotDatabaseImageChanged(const ImageChangeset& imageChangeset);
 
-    void slotFilterSettingsChanged(const ImageFilterSettings& settings);
+    void slotFilterSettingsChanged(const ItemFilterSettings& settings);
     void slotResortModel();
     void slotClearModel(const bool sendNotifications);
 
@@ -205,4 +205,4 @@ private:
 
 Q_DECLARE_METATYPE(Digikam::TableViewModel::GroupingMode)
 
-#endif // TABLEVIEW_MODEL_H
+#endif // DIGIKAM_TABLE_VIEW_MODEL_H
