@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-03-02
  * Description : Table view: Tree view subelement
@@ -34,8 +34,8 @@
 
 #include "digikam_debug.h"
 #include "contextmenuhelper.h"
-#include "imageinfo.h"
-#include "imagemodel.h"
+#include "iteminfo.h"
+#include "itemmodel.h"
 #include "tableview_column_configuration_dialog.h"
 #include "tableview_columnfactory.h"
 #include "tableview_model.h"
@@ -46,11 +46,11 @@
 namespace Digikam
 {
 
-class TableViewTreeView::Private
+class Q_DECL_HIDDEN TableViewTreeView::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : headerContextMenuActiveColumn(-1),
         actionHeaderContextMenuRemoveColumn(0),
         actionHeaderContextMenuConfigureColumn(0),
@@ -246,11 +246,11 @@ AbstractItemDragDropHandler* TableViewTreeView::dragDropHandler() const
 QModelIndex TableViewTreeView::mapIndexForDragDrop(const QModelIndex& index) const
 {
     // "index" is a TableViewModel index.
-    // We are using the drag-drop-handler of ImageModel, thus
-    // we have to convert it to an index of ImageModel.
+    // We are using the drag-drop-handler of ItemModel, thus
+    // we have to convert it to an index of ItemModel.
 
-    // map to ImageModel
-    const QModelIndex imageModelIndex = s->tableViewModel->toImageModelIndex(index);
+    // map to ItemModel
+    const QModelIndex imageModelIndex = s->tableViewModel->toItemModelIndex(index);
 
     return imageModelIndex;
 }
@@ -258,12 +258,12 @@ QModelIndex TableViewTreeView::mapIndexForDragDrop(const QModelIndex& index) con
 QPixmap TableViewTreeView::pixmapForDrag(const QList< QModelIndex >& indexes) const
 {
     const QModelIndex& firstIndex = indexes.at(0);
-    const ImageInfo info          = s->tableViewModel->imageInfo(firstIndex);
+    const ItemInfo info          = s->tableViewModel->imageInfo(firstIndex);
     const QString path            = info.filePath();
 
     QPixmap thumbnailPixmap;
     /// @todo The first thumbnail load always fails. We have to add thumbnail pre-generation
-    ///       like in ImageModel. Getting thumbnails from ImageModel does not help, because it
+    ///       like in ItemModel. Getting thumbnails from ItemModel does not help, because it
     ///       does not necessarily prepare them the same way.
     /// @todo Make a central drag-drop thumbnail generator?
     if (!s->thumbnailLoadThread->find(info.thumbnailIdentifier(), thumbnailPixmap, d->dragDropThumbnailSize.size()))
@@ -277,15 +277,15 @@ QPixmap TableViewTreeView::pixmapForDrag(const QList< QModelIndex >& indexes) co
     return thumbnailPixmap;
 
 //     const QModelIndex& firstIndex = indexes.at(0);
-//     const QModelIndex& imageModelIndex = s->sortModel->toImageModelIndex(firstIndex);
-//     ImageModel* const imageModel = s->imageFilterModel->sourceImageModel();
+//     const QModelIndex& imageModelIndex = s->sortModel->toItemModelIndex(firstIndex);
+//     ItemModel* const imageModel = s->imageFilterModel->sourceItemModel();
 //
 //     /// @todo Determine how other views choose the size
 //     const QSize thumbnailSize(60, 60);
 //
-//     imageModel->setData(imageModelIndex, qMax(thumbnailSize.width(), thumbnailSize.height()), ImageModel::ThumbnailRole);
-//     QVariant thumbnailData = imageModel->data(imageModelIndex, ImageModel::ThumbnailRole);
-//     imageModel->setData(imageModelIndex, QVariant(), ImageModel::ThumbnailRole);
+//     imageModel->setData(imageModelIndex, qMax(thumbnailSize.width(), thumbnailSize.height()), ItemModel::ThumbnailRole);
+//     QVariant thumbnailData = imageModel->data(imageModelIndex, ItemModel::ThumbnailRole);
+//     imageModel->setData(imageModelIndex, QVariant(), ItemModel::ThumbnailRole);
 //
 //     QPixmap thumbnailPixmap = thumbnailData.value<QPixmap>();
 //
@@ -297,11 +297,11 @@ Album* TableViewTreeView::albumAt(const QPoint& pos) const
 {
     Q_UNUSED(pos)
 
-    ImageAlbumModel* const albumModel = qobject_cast<ImageAlbumModel*>(s->imageModel);
+    ItemAlbumModel* const albumModel = qobject_cast<ItemAlbumModel*>(s->imageModel);
 
     if (albumModel)
     {
-        if(!(albumModel->currentAlbums().isEmpty()))
+        if (!(albumModel->currentAlbums().isEmpty()))
             return albumModel->currentAlbums().first();
     }
 
@@ -330,9 +330,17 @@ void TableViewTreeView::wheelEvent(QWheelEvent* event)
     QTreeView::wheelEvent(event);
 }
 
+bool TableViewTreeView::hasHiddenGroupedImages(const ItemInfo& info) const
+{
+        return (info.hasGroupedImages()
+            && (s->tableViewModel->groupingMode() == s->tableViewModel->GroupingMode::GroupingHideGrouped
+                || (s->tableViewModel->groupingMode() == s->tableViewModel->GroupingMode::GroupingShowSubItems
+                    && !s->treeView->isExpanded(s->tableViewModel->indexFromImageId(info.id(), 0)))));
+}
+
 void TableViewTreeView::slotModelGroupingModeChanged()
 {
     setRootIsDecorated(s->tableViewModel->groupingMode()==TableViewModel::GroupingShowSubItems);
 }
 
-} /* namespace Digikam */
+} // namespace Digikam
