@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-03-02
  * Description : Table view: Tree view subelement
@@ -20,8 +20,8 @@
  *
  * ============================================================ */
 
-#ifndef TABLEVIEW_TREEVIEW_DELEGATE_H
-#define TABLEVIEW_TREEVIEW_DELEGATE_H
+#ifndef DIGIKAM_TABLE_VIEW_TREEVIEW_DELEGATE_H
+#define DIGIKAM_TABLE_VIEW_TREEVIEW_DELEGATE_H
 
 // Qt includes
 
@@ -31,8 +31,8 @@
 // Local includes
 
 #include "digikam_export.h"
-#include "imagealbummodel.h"
-#include "imagefiltermodel.h"
+#include "itemalbummodel.h"
+#include "itemfiltermodel.h"
 #include "statesavingobject.h"
 #include "tableview_columnfactory.h"
 #include "tableview_shared.h"
@@ -61,6 +61,6 @@ private:
     TableViewShared* const s;
 };
 
-} /* namespace Digikam */
+} // namespace Digikam
 
-#endif // TABLEVIEW_TREEVIEW_DELEGATE_H
+#endif // DIGIKAM_TABLE_VIEW_TREEVIEW_DELEGATE_H
