@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-06-18
  * Description : Core database interface.
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef _CORE_DATABASE_H_
-#define _CORE_DATABASE_H_
+#ifndef DIGIKAM_CORE_DB_H
+#define DIGIKAM_CORE_DB_H
 
 // Qt includes
 
@@ -161,6 +161,13 @@ public:
      */
     void setAlbumRootLabel(int rootId, const QString& newLabel);
 
+    /**
+     * Changes the specificPath of the specified album root
+     * @param rootId the id of the album root
+     * @param newPath new path for the album root
+     */
+    void setAlbumRootPath(int rootId, const QString& newPath);
+
     /**
      * Sets the type of the specified album root to a new value.
      */
@@ -583,22 +590,28 @@ public:
     QList<qlonglong> getImageIds(DatabaseItem::Status status);
 
     /**
-     * Get the imageId fitting to the information given for the item
+     * Returns all image ids with the given status and category.
+     * @param status The status.
+     * @param category The category.
+     * @return The ids of the images that have the given status.
+     */
+    QList<qlonglong> getImageIds(DatabaseItem::Status status, DatabaseItem::Category category);
+
+    /**
+     * Find the imageId fitting to the information given for the item
      * @param albumID the albumID of the item (-1 means NULL)
      * @param name the name of the item
      * @param status the status of the item
      * @param category the category of the item
-     * @param modificationDate the modification date
      * @param fileSize the file size
      * @param uniqueHash the unique hash
      * @return the ImageId for the item, or -1 if no matching or more than one infos were found.
      */
-    qlonglong getImageId(int albumID, const QString& name,
-                      DatabaseItem::Status status,
-                      DatabaseItem::Category category,
-                      const QDateTime& modificationDate,
-                      qlonglong fileSize,
-                      const QString& uniqueHash);
+    qlonglong findImageId(int albumID, const QString& name,
+                          DatabaseItem::Status status,
+                          DatabaseItem::Category category,
+                          qlonglong fileSize,
+                          const QString& uniqueHash);
 
     enum ItemSortOrder
     {
@@ -749,6 +762,22 @@ public:
      */
     void setItemAlbum(qlonglong imageID, qlonglong albumId);
 
+    /**
+     * Updates the manualOrder field for the item.
+     */
+    void setItemManualOrder(qlonglong imageID, qlonglong value);
+
+    /**
+     * Updates the modification date field for the item.
+     */
+    void setItemModificationDate(qlonglong imageID, const QDateTime& modificationDate);
+
+    /**
+     * Rename the item.
+     * Note: we not use here ImageChangeset.
+     */
+    void renameItem(qlonglong imageID, const QString& newName);
+
     /**
      * Returns the requested fields from the Images table.
      * Choose the fields with the mask.
@@ -764,7 +793,7 @@ public:
     QVariantList getImagesFields(qlonglong imageID, DatabaseFields::Images imagesFields);
 
     /**
-     * Add (or replace) the ImageInformation of the specified item.
+     * Add (or replace) the ItemInformation of the specified item.
      * If there is already an entry, it will be discarded.
      * The QVariantList shall have 9 entries, of types in this order:
      * 0) Int       rating
@@ -778,25 +807,25 @@ public:
      * 8) Int       colorModel
      * ( (*) You can provide the date also as a string in the format Qt::IsoDate)
      * You can leave out entries from this list, which will then be filled with null values.
-     * Indicate the values that you have passed in the ImageInformation flag in the third parameters.
+     * Indicate the values that you have passed in the ItemInformation flag in the third parameters.
      */
-    void addImageInformation(qlonglong imageID, const QVariantList& infos,
-                             DatabaseFields::ImageInformation fields = DatabaseFields::ImageInformationAll);
+    void addItemInformation(qlonglong imageID, const QVariantList& infos,
+                             DatabaseFields::ItemInformation fields = DatabaseFields::ItemInformationAll);
 
     /**
      * Change the indicated fields of the image information for the specified item.
      * Fields not indicated by the fields parameter will not be touched.
-     * This method does nothing if the item does not yet have an entry in the ImageInformation table.
+     * This method does nothing if the item does not yet have an entry in the ItemInformation table.
      * The parameters are as for the method above.
      */
-    void changeImageInformation(qlonglong imageID, const QVariantList& infos,
-                                DatabaseFields::ImageInformation fields = DatabaseFields::ImageInformationAll);
+    void changeItemInformation(qlonglong imageID, const QVariantList& infos,
+                                DatabaseFields::ItemInformation fields = DatabaseFields::ItemInformationAll);
 
     /**
      * Read image information. Parameters as above.
      */
-    QVariantList getImageInformation(qlonglong imageID,
-                                     DatabaseFields::ImageInformation infoFields = DatabaseFields::ImageInformationAll);
+    QVariantList getItemInformation(qlonglong imageID,
+                                     DatabaseFields::ItemInformation infoFields = DatabaseFields::ItemInformationAll);
 
     /**
      * Add (or replace) the ImageMetadata of the specified item.
@@ -827,7 +856,7 @@ public:
 
     /**
      * Change the indicated fields of the image information for the specified item.
-     * This method does nothing if the item does not yet have an entry in the ImageInformation table.
+     * This method does nothing if the item does not yet have an entry in the ItemInformation table.
      * The parameters are as for the method above.
      */
     void changeImageMetadata(qlonglong imageID, const QVariantList& infos,
@@ -846,7 +875,7 @@ public:
      * 0) String    AspectRatio
      * 1) String    AudioBitRate
      * 2) String    AudioChannelType
-     * 3) String    AudioCompressor
+     * 3) String    AudioCodec
      * 4) String    Duration
      * 5) String    FrameRate
      * 6) String    VideoCodec
@@ -858,7 +887,7 @@ public:
 
     /**
      * Change the indicated fields of the video information for the specified item.
-     * This method does nothing if the item does not yet have an entry in the ImageInformation table.
+     * This method does nothing if the item does not yet have an entry in the ItemInformation table.
      * The parameters are as for the method above.
      */
     void changeVideoMetadata(qlonglong imageID, const QVariantList& infos,
@@ -871,7 +900,7 @@ public:
                                   DatabaseFields::VideoMetadata metadataFields = DatabaseFields::VideoMetadataAll);
 
     /**
-     * Add (or replace) the ImagePosition of the specified item.
+     * Add (or replace) the ItemPosition of the specified item.
      * If there is already an entry, it will be discarded.
      * The QVariantList shall have at most 10 entries, of types in this order:
      * 0) String    Latitude
@@ -885,41 +914,41 @@ public:
      * 8) Double    Accuracy
      * 9) String    Description
      * You can leave out entries from this list. Indicate the values that you have
-     * passed in the ImageInfo flag in the third parameters.
+     * passed in the ItemInfo flag in the third parameters.
      */
-    void addImagePosition(qlonglong imageID, const QVariantList& infos,
-                          DatabaseFields::ImagePositions fields = DatabaseFields::ImagePositionsAll);
+    void addItemPosition(qlonglong imageID, const QVariantList& infos,
+                          DatabaseFields::ItemPositions fields = DatabaseFields::ItemPositionsAll);
 
     /**
      * Change the indicated fields of the image information for the specified item.
-     * This method does nothing if the item does not yet have an entry in the ImageInformation table.
+     * This method does nothing if the item does not yet have an entry in the ItemInformation table.
      * The parameters are as for the method above.
      */
-    void changeImagePosition(qlonglong imageID, const QVariantList& infos,
-                             DatabaseFields::ImagePositions fields = DatabaseFields::ImagePositionsAll);
+    void changeItemPosition(qlonglong imageID, const QVariantList& infos,
+                             DatabaseFields::ItemPositions fields = DatabaseFields::ItemPositionsAll);
 
     /**
      * Read image metadata. Parameters as above.
      */
-    QVariantList getImagePosition(qlonglong imageID,
-                                  DatabaseFields::ImagePositions positionFields = DatabaseFields::ImagePositionsAll);
+    QVariantList getItemPosition(qlonglong imageID,
+                                  DatabaseFields::ItemPositions positionFields = DatabaseFields::ItemPositionsAll);
 
-    QVariantList getImagePositions(QList<qlonglong> imageIDs, DatabaseFields::ImagePositions fields);
+    QVariantList getItemPositions(QList<qlonglong> imageIDs, DatabaseFields::ItemPositions fields);
 
     /**
-     * Remove the entry in ImagePositions for the given image
+     * Remove the entry in ItemPositions for the given image
      */
-    void removeImagePosition(qlonglong imageid);
+    void removeItemPosition(qlonglong imageid);
 
     /**
-     * Remove the altitude in ImagePositions for the given image
+     * Remove the altitude in ItemPositions for the given image
      */
-    void removeImagePositionAltitude(qlonglong imageid);
+    void removeItemPositionAltitude(qlonglong imageid);
 
     /**
      * Retrieves all available comments for the specified item.
      */
-    QList<CommentInfo> getImageComments(qlonglong imageID);
+    QList<CommentInfo> getItemComments(qlonglong imageID);
 
     /**
      * Sets the comments for the image. A comment for the image with the same
@@ -950,10 +979,10 @@ public:
      * 4) String    Comment
      */
     void changeImageComment(int commentId, qlonglong imageID, const QVariantList& infos,
-                            DatabaseFields::ImageComments fields = DatabaseFields::ImageCommentsAll);
+                            DatabaseFields::ItemComments fields = DatabaseFields::ItemCommentsAll);
 
     /**
-     * Remove the specified entry in ImageComments
+     * Remove the specified entry in ItemComments
      */
     void removeImageComment(int commentId, qlonglong imageid);
 
@@ -973,7 +1002,7 @@ public:
      * Returns the copyright properties of the specified image.
      * If property is not null, only the given property is returned.
      */
-    QList<CopyrightInfo> getImageCopyright(qlonglong imageID, const QString& property = QString());
+    QList<CopyrightInfo> getItemCopyright(qlonglong imageID, const QString& property = QString());
 
     enum CopyrightPropertyUnique
     {
@@ -985,7 +1014,7 @@ public:
     /**
      * Sets the property with the given name for the given image to the specified value and extraValue
      */
-    void setImageCopyrightProperty(qlonglong imageID, const QString& property,
+    void setItemCopyrightProperty(qlonglong imageID, const QString& property,
                                    const QString& value, const QString& extraValue = QString(),
                                    CopyrightPropertyUnique uniqueness = PropertyUnique);
 
@@ -994,7 +1023,7 @@ public:
      *  extraValue; or property, extraValue and value).
      *  Note that extraValue is ordered before value in this method!
      */
-    void removeImageCopyrightProperties(qlonglong imageID, const QString& property = QString(),
+    void removeItemCopyrightProperties(qlonglong imageID, const QString& property = QString(),
                                         const QString& extraValue = QString(),
                                         const QString& value = QString() /* NOTE parameter order */);
 
@@ -1006,7 +1035,7 @@ public:
     /**
      * Retrieves the history entry for the given image.
      */
-    ImageHistoryEntry getImageHistory(qlonglong imageId);
+    ImageHistoryEntry getItemHistory(qlonglong imageId);
 
     /**
      * Retrieves the image UUID
@@ -1021,7 +1050,7 @@ public:
     /**
      * Changes (adds or updates) the image history
      */
-    void setImageHistory(qlonglong imageId, const QString& history);
+    void setItemHistory(qlonglong imageId, const QString& history);
     void setImageUuid(qlonglong imageId, const QString& uuid);
 
     /**
@@ -1084,19 +1113,9 @@ public:
                                             DatabaseRelation::Type type = DatabaseRelation::UndefinedType);
 
     /**
-     * Returns if there are valid entries in the ImageHaarMatrix table.
-     * Returns false if the table is empty.
+     * Retrieves all images that related to (retrieves objects) by given type.
      */
-    bool hasHaarFingerprints() const;
-
-    /**
-     * Returns a list of all images where the Haar fingerprint has either not been generated
-     * yet, or is outdated because the file is identified as changed since
-     * the generation of the fingerprint.
-     * Return image ids or item URLs.
-     */
-    QList<qlonglong> getDirtyOrMissingFingerprints();
-    QStringList getDirtyOrMissingFingerprintURLs();
+    QList<qlonglong> getRelatedImagesToByType(DatabaseRelation::Type type);
 
     /**
      * Returns a list of all images where the Faces have either not been detected
@@ -1121,7 +1140,7 @@ public:
      * Returns a list of all images where tagId is assigned
      * Return item URLs.
      */
-     QStringList getItemsURLsWithTag(int tagId);
+    QStringList getItemsURLsWithTag(int tagId);
 
     // ----------- Items and their tags -----------
 
@@ -1254,7 +1273,7 @@ public:
     QList<qlonglong> getImagesWithImageTagProperty(int tagId, const QString& property);
 
     /**
-     * Returns a QMap<QString,int> of ImageInformation.format
+     * Returns a QMap<QString,int> of ItemInformation.format
      * -> count of items with that format.
      */
     QMap<QString, int> getFormatStatistics();
@@ -1296,11 +1315,19 @@ public:
      */
     void copyImageAttributes(qlonglong srcId, qlonglong destId);
 
-    /// Copies all entries in the ImageProperties table
+    // Copies all entries in the ImageProperties table
     void copyImageProperties(qlonglong srcId, qlonglong dstId);
-    /// Copies all entries in the ImageTags table
+    // Copies all entries in the ImageTags table
     void copyImageTags(qlonglong srcId, qlonglong dstId);
 
+    // ------------ Clear all Item Metadata -----------
+
+    /**
+     * Clear all metadata of an item
+     * @param  imageID the ID of the item
+     */
+    void clearMetadataFromImage(qlonglong imageID);
+
     // ----------- Download history methods -----------
 
     /**
@@ -1315,7 +1342,7 @@ public:
      */
     int addToDownloadHistory(const QString& identifier, const QString& name, qlonglong fileSize, const QDateTime& date);
 
-    QList<QVariant> getImageIdsFromArea(qreal lat1, qreal lng1, qreal lat2, qreal lng2, int sortMode, const QString& sortBy);
+    QList<QVariant> getImageIdsFromArea(qreal lat1, qreal lat2, qreal lng1, qreal lng2, int sortMode, const QString& sortBy);
 
     // ----------- Database shrinking methods ----------
 
@@ -1332,11 +1359,11 @@ public:
     // ----------- Static helper methods for constructing SQL queries -----------
 
     static QStringList imagesFieldList(DatabaseFields::Images fields);
-    static QStringList imageInformationFieldList(DatabaseFields::ImageInformation fields);
+    static QStringList imageInformationFieldList(DatabaseFields::ItemInformation fields);
     static QStringList videoMetadataFieldList(DatabaseFields::VideoMetadata fields);
     static QStringList imageMetadataFieldList(DatabaseFields::ImageMetadata fields);
-    static QStringList imagePositionsFieldList(DatabaseFields::ImagePositions fields);
-    static QStringList imageCommentsFieldList(DatabaseFields::ImageComments fields);
+    static QStringList imagePositionsFieldList(DatabaseFields::ItemPositions fields);
+    static QStringList imageCommentsFieldList(DatabaseFields::ItemComments fields);
     static void addBoundValuePlaceholders(QString& query, int count);
 
 public:
@@ -1360,6 +1387,8 @@ protected:
 
 private:
 
+    CoreDB(const CoreDB&); // Disable
+
     void readSettings();
     void writeSettings();
 
@@ -1371,4 +1400,4 @@ private:
 
 } // namespace Digikam
 
-#endif // _CORE_DATABASE_H_
+#endif // DIGIKAM_CORE_DB_H
