@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-18
  * Description : Core database access wrapper.
  *
  * Copyright (C) 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -40,8 +40,8 @@
 #include "digikam_debug.h"
 #include "coredb.h"
 #include "collectionscannerobserver.h"
-#include "imageinfodata.h"
-#include "imageinfocache.h"
+#include "iteminfodata.h"
+#include "iteminfocache.h"
 #include "coredbschemaupdater.h"
 #include "collectionmanager.h"
 #include "coredbwatch.h"
@@ -54,7 +54,7 @@
 namespace Digikam
 {
 
-class CoreDbAccessStaticPriv
+class Q_DECL_HIDDEN CoreDbAccessStaticPriv
 {
 public:
 
@@ -85,7 +85,7 @@ public:
     bool                initializing;
 };
 
-class CoreDbAccessMutexLocker : public QMutexLocker
+class Q_DECL_HIDDEN CoreDbAccessMutexLocker : public QMutexLocker
 {
 public:
 
@@ -236,7 +236,7 @@ void CoreDbAccess::setParameters(const DbEngineParameters& parameters, Applicati
         }
     }
 
-    ImageInfoStatic::create();
+    ItemInfoStatic::create();
 
     if (!d->backend || !d->backend->isCompatible(parameters))
     {
@@ -249,7 +249,7 @@ void CoreDbAccess::setParameters(const DbEngineParameters& parameters, Applicati
     }
 
     d->databaseWatch->sendDatabaseChanged();
-    ImageInfoStatic::cache()->invalidate();
+    ItemInfoStatic::cache()->invalidate();
     TagsCache::instance()->invalidate();
     d->databaseWatch->setDatabaseIdentifier(QString());
     CollectionManager::instance()->clear_locked();
@@ -352,7 +352,7 @@ void CoreDbAccess::cleanUpDatabase()
         }
     }
 
-    ImageInfoStatic::destroy();
+    ItemInfoStatic::destroy();
     delete d;
     d = 0;
 }
@@ -410,4 +410,4 @@ CoreDbAccessUnlock::~CoreDbAccessUnlock()
     CoreDbAccess::d->lock.lockCount += count;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
