@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-07
  * Description : Core database abstract backend.
  *
  * Copyright (C) 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef COREDATABASEBACKEND_P_H
-#define COREDATABASEBACKEND_P_H
+#ifndef DIGIKAM_CORE_DB_BACKEND_PRIVATE_H
+#define DIGIKAM_CORE_DB_BACKEND_PRIVATE_H
 
 // Local includes
 
@@ -35,7 +35,7 @@ namespace Digikam
 
 class CoreDbWatch;
 
-class CoreDbBackendPrivate : public BdEngineBackendPrivate
+class Q_DECL_HIDDEN CoreDbBackendPrivate : public BdEngineBackendPrivate
 {
 public:
 
@@ -88,11 +88,11 @@ public:
     }
 
     template <class T>
-    class ChangesetContainer
+    class Q_DECL_HIDDEN ChangesetContainer
     {
     public:
 
-        explicit ChangesetContainer(CoreDbBackendPrivate* d)
+        explicit ChangesetContainer(CoreDbBackendPrivate* const d)
             : d(d)
         {
         }
@@ -120,7 +120,7 @@ public:
 
     public:
 
-        QList<T>                      changesets;
+        QList<T>                    changesets;
         CoreDbBackendPrivate* const d;
     };
 
@@ -150,6 +150,6 @@ public:
     }
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // COREDATABASEBACKEND_P_H
+#endif // DIGIKAM_CORE_DB_BACKEND_PRIVATE_H
