@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-09-22
  * Description : Core database field enumerations.
  *
  * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef COREDATABASEFIELDS_H
-#define COREDATABASEFIELDS_H
+#ifndef DIGIKAM_CORE_DB_FIELDS_H
+#define DIGIKAM_CORE_DB_FIELDS_H
 
 #include "digikam_config.h"
 
@@ -61,21 +61,24 @@ enum ImagesField
     ModificationDate   = 1 << 4,
     FileSize           = 1 << 5,
     UniqueHash         = 1 << 6,
+    ManualOrder        = 1 << 7,
     ImagesAll          = Album            |
                          Name             |
                          Status           |
                          Category         |
                          ModificationDate |
                          FileSize         |
-                         UniqueHash,
+                         UniqueHash       |
+                         ManualOrder,
     ImagesFirst        = Album,
-    ImagesLast         = UniqueHash
+    ImagesLast         = ManualOrder
 };
+
 typedef uint8_t ImagesMinSizeType;
 
-enum ImageInformationField
+enum ItemInformationField
 {
-    ImageInformationNone  = 0,
+    ItemInformationNone  = 0,
     Rating                = 1 << 0,
     CreationDate          = 1 << 1,
     DigitizationDate      = 1 << 2,
@@ -87,7 +90,7 @@ enum ImageInformationField
     ColorModel            = 1 << 8,
     ColorLabel            = 1 << 9,
     PickLabel             = 1 << 10,
-    ImageInformationAll   = Rating           |
+    ItemInformationAll   = Rating           |
                             CreationDate     |
                             DigitizationDate |
                             Orientation      |
@@ -98,10 +101,11 @@ enum ImageInformationField
                             ColorModel       |
                             ColorLabel       |
                             PickLabel,
-    ImageInformationFirst = Rating,
-    ImageInformationLast  = PickLabel
+    ItemInformationFirst = Rating,
+    ItemInformationLast  = PickLabel
 };
-typedef uint16_t ImageInformationMinSizeType;
+
+typedef uint16_t ItemInformationMinSizeType;
 
 enum ImageMetadataField
 {
@@ -141,11 +145,12 @@ enum ImageMetadataField
     ImageMetadataFirst           = Make,
     ImageMetadataLast            = SubjectDistanceCategory
 };
+
 typedef uint16_t ImageMetadataMinSizeType;
 
-enum ImagePositionsField
+enum ItemPositionsField
 {
-    ImagePositionsNone  = 0,
+    ItemPositionsNone  = 0,
     Latitude            = 1 << 0,
     LatitudeNumber      = 1 << 1,
     Longitude           = 1 << 2,
@@ -156,7 +161,7 @@ enum ImagePositionsField
     PositionRoll        = 1 << 7,
     PositionAccuracy    = 1 << 8,
     PositionDescription = 1 << 9,
-    ImagePositionsAll   = Latitude            |
+    ItemPositionsAll   = Latitude            |
                           LatitudeNumber      |
                           Longitude           |
                           LongitudeNumber     |
@@ -166,28 +171,30 @@ enum ImagePositionsField
                           PositionTilt        |
                           PositionAccuracy    |
                           PositionDescription,
-    ImagePositionsFirst = Latitude,
-    ImagePositionsLast  = PositionDescription
+    ItemPositionsFirst = Latitude,
+    ItemPositionsLast  = PositionDescription
 };
-typedef uint16_t ImagePositionsMinSizeType;
 
-enum ImageCommentsField
+typedef uint16_t ItemPositionsMinSizeType;
+
+enum ItemCommentsField
 {
-    ImageCommentsNone  = 0,
+    ItemCommentsNone  = 0,
     CommentType        = 1 << 0,
     CommentLanguage    = 1 << 1,
     CommentAuthor      = 1 << 2,
     CommentDate        = 1 << 3,
     Comment            = 1 << 4,
-    ImageCommentsAll   = CommentType     |
+    ItemCommentsAll   = CommentType     |
                          CommentAuthor   |
                          CommentLanguage |
                          CommentDate     |
                          Comment,
-    ImageCommentsFirst = CommentType,
-    ImageCommentsLast  = Comment
+    ItemCommentsFirst = CommentType,
+    ItemCommentsLast  = Comment
 };
-typedef uint8_t ImageCommentsMinSizeType;
+
+typedef uint8_t ItemCommentsMinSizeType;
 
 enum ImageHistoryInfoField
 {
@@ -201,6 +208,7 @@ enum ImageHistoryInfoField
     ImageHistoryInfoFirst = ImageUUID,
     ImageHistoryInfoLast  = ImageRelations
 };
+
 typedef uint8_t ImageHistoryInfoMinSizeType;
 
 enum VideoMetadataField
@@ -209,27 +217,28 @@ enum VideoMetadataField
     AspectRatio                  = 1 << 0,
     AudioBitRate                 = 1 << 1,
     AudioChannelType             = 1 << 2,
-    AudioCompressor              = 1 << 3,
+    AudioCodec                   = 1 << 3,
     Duration                     = 1 << 4,
     FrameRate                    = 1 << 5,
     VideoCodec                   = 1 << 6,
     VideoMetadataAll             = AspectRatio      |
                                    AudioBitRate     |
                                    AudioChannelType |
-                                   AudioCompressor  |
+                                   AudioCodec       |
                                    Duration         |
                                    FrameRate        |
                                    VideoCodec,
     VideoMetadataFirst           = AspectRatio,
     VideoMetadataLast            = VideoCodec
 };
+
 typedef uint8_t VideoMetadataMinSizeType;
 
 Q_DECLARE_FLAGS(Images,           ImagesField)
-Q_DECLARE_FLAGS(ImageInformation, ImageInformationField)
+Q_DECLARE_FLAGS(ItemInformation, ItemInformationField)
 Q_DECLARE_FLAGS(ImageMetadata,    ImageMetadataField)
-Q_DECLARE_FLAGS(ImageComments,    ImageCommentsField)
-Q_DECLARE_FLAGS(ImagePositions,   ImagePositionsField)
+Q_DECLARE_FLAGS(ItemComments,    ItemCommentsField)
+Q_DECLARE_FLAGS(ItemPositions,   ItemPositionsField)
 Q_DECLARE_FLAGS(ImageHistoryInfo, ImageHistoryInfoField)
 Q_DECLARE_FLAGS(VideoMetadata,    VideoMetadataField)
 
@@ -249,19 +258,18 @@ template<typename FieldName> class FieldMetaInfo
     };
 
 DECLARE_FIELDMETAINFO(Images)
-DECLARE_FIELDMETAINFO(ImageInformation)
+DECLARE_FIELDMETAINFO(ItemInformation)
 DECLARE_FIELDMETAINFO(ImageMetadata)
-DECLARE_FIELDMETAINFO(ImageComments)
-DECLARE_FIELDMETAINFO(ImagePositions)
+DECLARE_FIELDMETAINFO(ItemComments)
+DECLARE_FIELDMETAINFO(ItemPositions)
 DECLARE_FIELDMETAINFO(ImageHistoryInfo)
 DECLARE_FIELDMETAINFO(VideoMetadata)
 
 /**
  * You can iterate over each of the Enumerations defined above:
  * ImagesIterator, ImageMetadataIterator etc.
- * for (ImagesIterator it; !it.atEnd(); ++it) {}
+ * for (ImagesIterator it ; !it.atEnd() ; ++it) {...}
  */
-
 template<typename FieldName> class DatabaseFieldsEnumIterator
 {
 
@@ -297,10 +305,9 @@ private:
  */
 template<typename FieldName> class DatabaseFieldsEnumIteratorSetOnly
 {
-
 public:
 
-    DatabaseFieldsEnumIteratorSetOnly(const FieldName setValues)
+    explicit DatabaseFieldsEnumIteratorSetOnly(const FieldName setValues)
       : i(),
         values(setValues)
     {
@@ -344,11 +351,11 @@ private:
     typedef DatabaseFieldsEnumIteratorSetOnly<Flag> Flag##IteratorSetOnly;
 
 DATABASEFIELDS_ENUM_ITERATOR(Images)
-DATABASEFIELDS_ENUM_ITERATOR(ImageInformation)
+DATABASEFIELDS_ENUM_ITERATOR(ItemInformation)
 DATABASEFIELDS_ENUM_ITERATOR(ImageMetadata)
 DATABASEFIELDS_ENUM_ITERATOR(VideoMetadata)
-DATABASEFIELDS_ENUM_ITERATOR(ImagePositions)
-DATABASEFIELDS_ENUM_ITERATOR(ImageComments)
+DATABASEFIELDS_ENUM_ITERATOR(ItemPositions)
+DATABASEFIELDS_ENUM_ITERATOR(ItemComments)
 DATABASEFIELDS_ENUM_ITERATOR(ImageHistoryInfo)
 
 /**
@@ -361,8 +368,8 @@ enum CustomEnumFlags
 Q_DECLARE_FLAGS(CustomEnum, CustomEnumFlags)
 
 #define DATABASEFIELDS_SET_DECLARE_METHODS(Flag, variable)                     \
-    Set(const Flag& f)                      { initialize(); variable = f;    } \
-    Set(const Flag##Field& f)               { initialize(); variable = f;    } \
+    explicit Set(const Flag& f)             { initialize(); variable = f;    } \
+    explicit Set(const Flag##Field& f)      { initialize(); variable = f;    } \
     inline Flag& operator=(const Flag& f)   { return variable.operator=(f);  } \
     inline Flag& operator|=(Flag f)         { return variable.operator|=(f); } \
     inline Flag& operator^=(Flag f)         { return variable.operator^=(f); } \
@@ -374,7 +381,7 @@ Q_DECLARE_FLAGS(CustomEnum, CustomEnumFlags)
     inline Flag get##Flag() const           { return variable;               }
 
 /**
- * This class provides a set of all DatabasFields enums,
+ * This class provides a set of all DatabaseFields enums,
  * without resorting to a QSet.
  */
 class Set
@@ -389,10 +396,10 @@ public:
     void initialize()
     {
         images           = ImagesNone;
-        imageInformation = ImageInformationNone;
+        imageInformation = ItemInformationNone;
         imageMetadata    = ImageMetadataNone;
-        imageComments    = ImageCommentsNone;
-        imagePositions   = ImagePositionsNone;
+        imageComments    = ItemCommentsNone;
+        imagePositions   = ItemPositionsNone;
         imageHistory     = ImageHistoryInfoNone;
         videoMetadata    = VideoMetadataNone;
         customEnum       = (CustomEnum)0;
@@ -401,37 +408,37 @@ public:
 public:
 
     DATABASEFIELDS_SET_DECLARE_METHODS(Images,           images)
-    DATABASEFIELDS_SET_DECLARE_METHODS(ImageInformation, imageInformation)
+    DATABASEFIELDS_SET_DECLARE_METHODS(ItemInformation, imageInformation)
     DATABASEFIELDS_SET_DECLARE_METHODS(VideoMetadata,    videoMetadata)
     DATABASEFIELDS_SET_DECLARE_METHODS(ImageMetadata,    imageMetadata)
-    DATABASEFIELDS_SET_DECLARE_METHODS(ImageComments,    imageComments)
-    DATABASEFIELDS_SET_DECLARE_METHODS(ImagePositions,   imagePositions)
+    DATABASEFIELDS_SET_DECLARE_METHODS(ItemComments,    imageComments)
+    DATABASEFIELDS_SET_DECLARE_METHODS(ItemPositions,   imagePositions)
     DATABASEFIELDS_SET_DECLARE_METHODS(ImageHistoryInfo, imageHistory)
 
     inline bool operator&(const Set& other)
     {
-        return (images & other.images)                     ||
+        return (images           & other.images)           ||
                (imageInformation & other.imageInformation) ||
-               (imageMetadata & other.imageMetadata)       ||
-               (imageComments & other.imageComments)       ||
-               (imagePositions & other.imagePositions)     ||
-               (imageHistory & other.imageHistory)         ||
-               (customEnum & other.customEnum)             ||
-               (videoMetadata & other.videoMetadata);
+               (imageMetadata    & other.imageMetadata)    ||
+               (imageComments    & other.imageComments)    ||
+               (imagePositions   & other.imagePositions)   ||
+               (imageHistory     & other.imageHistory)     ||
+               (customEnum       & other.customEnum)       ||
+               (videoMetadata    & other.videoMetadata);
     }
 
     // overloading operator|= creates ambiguity with the database fields'
     // operator|=, therefore we give it another name.
     inline Set& setFields(const Set& otherSet)
     {
-        images|= otherSet.images;
-        imageInformation|= otherSet.imageInformation;
-        imageMetadata|= otherSet.imageMetadata;
-        imageComments|= otherSet.imageComments;
-        imagePositions|= otherSet.imagePositions;
-        imageHistory|= otherSet.imageHistory;
-        customEnum|= otherSet.customEnum;
-        videoMetadata|= otherSet.videoMetadata;
+        images           |= otherSet.images;
+        imageInformation |= otherSet.imageInformation;
+        imageMetadata    |= otherSet.imageMetadata;
+        imageComments    |= otherSet.imageComments;
+        imagePositions   |= otherSet.imagePositions;
+        imageHistory     |= otherSet.imageHistory;
+        customEnum       |= otherSet.customEnum;
+        videoMetadata    |= otherSet.videoMetadata;
 
         return *this;
     }
@@ -475,11 +482,11 @@ public:
 private:
 
     Images           images;
-    ImageInformation imageInformation;
+    ItemInformation imageInformation;
     ImageMetadata    imageMetadata;
     VideoMetadata    videoMetadata;
-    ImageComments    imageComments;
-    ImagePositions   imagePositions;
+    ItemComments    imageComments;
+    ItemPositions   imagePositions;
     ImageHistoryInfo imageHistory;
     CustomEnum       customEnum;
 };
@@ -490,7 +497,7 @@ private:
     int removeAllFields(const Key& key)                                                                                             \
     {                                                                                                                               \
         int removedCount = 0;                                                                                                       \
-        for (DatabaseFieldsEnumIteratorSetOnly<Key> it(key); !it.atEnd(); ++it)                                                     \
+        for (DatabaseFieldsEnumIteratorSetOnly<Key> it(key) ; !it.atEnd() ; ++it)                                                   \
         {                                                                                                                           \
             removedCount+=remove(*it);                                                                                              \
         }                                                                                                                           \
@@ -530,7 +537,7 @@ public:
         return (int)f | (0 << 26);
     }
 
-    static inline unsigned int uniqueKey(ImageInformation f)
+    static inline unsigned int uniqueKey(ItemInformation f)
     {
         return (int)f | (1 << 26);
     }
@@ -540,12 +547,12 @@ public:
         return (int)f | (2 << 26);
     }
 
-    static inline unsigned int uniqueKey(ImageComments f)
+    static inline unsigned int uniqueKey(ItemComments f)
     {
         return (int)f | (3 << 26);
     }
 
-    static inline unsigned int uniqueKey(ImagePositions f)
+    static inline unsigned int uniqueKey(ItemPositions f)
     {
         return (int)f | (4 << 26);
     }
@@ -566,27 +573,27 @@ public:
     }
 
     // override relevant methods from QHash
-    DATABASEFIELDS_HASH_DECLARE_METHODS(Images, uniqueKey);
-    DATABASEFIELDS_HASH_DECLARE_METHODS(ImageInformation, uniqueKey);
-    DATABASEFIELDS_HASH_DECLARE_METHODS(ImageMetadata, uniqueKey);
-    DATABASEFIELDS_HASH_DECLARE_METHODS(VideoMetadata, uniqueKey);
-    DATABASEFIELDS_HASH_DECLARE_METHODS(ImageComments, uniqueKey);
-    DATABASEFIELDS_HASH_DECLARE_METHODS(ImagePositions, uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(Images,           uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(ItemInformation, uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(ImageMetadata,    uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(VideoMetadata,    uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(ItemComments,    uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(ItemPositions,   uniqueKey);
     DATABASEFIELDS_HASH_DECLARE_METHODS(ImageHistoryInfo, uniqueKey);
-    DATABASEFIELDS_HASH_DECLARE_METHODS(CustomEnum, uniqueKey);
+    DATABASEFIELDS_HASH_DECLARE_METHODS(CustomEnum,       uniqueKey);
 };
 
-} // end of namespace DatabaseFields
+} // namespace DatabaseFields
 
-} // end of namespace Digikam
+} // namespace Digikam
 
-// must be outside the namespace!
+// NOTE: must be outside the namespace!
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::Images)
-Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ImageInformation)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ItemInformation)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ImageMetadata)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::VideoMetadata)
-Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ImageComments)
-Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ImagePositions)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ItemComments)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ItemPositions)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ImageHistoryInfo)
 
-#endif // COREDATABASEFIELDS_H
+#endif // DIGIKAM_CORE_DB_FIELDS_H
