@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-04-16
  * Description : Core database Schema updater
  *
  * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,7 +47,7 @@
 #include "collectionmanager.h"
 #include "collectionlocation.h"
 #include "collectionscanner.h"
-#include "imagequerybuilder.h"
+#include "itemquerybuilder.h"
 #include "collectionscannerobserver.h"
 #include "digikam_config.h"
 
@@ -56,12 +56,12 @@ namespace Digikam
 
 int CoreDbSchemaUpdater::schemaVersion()
 {
-    return 9;
+    return 10;
 }
 
 int CoreDbSchemaUpdater::filterSettingsVersion()
 {
-    return 6;
+    return 8;
 }
 
 int CoreDbSchemaUpdater::uniqueHashVersion()
@@ -76,18 +76,18 @@ bool CoreDbSchemaUpdater::isUniqueHashUpToDate()
 
 // --------------------------------------------------------------------------------------
 
-class CoreDbSchemaUpdater::Private
+class Q_DECL_HIDDEN CoreDbSchemaUpdater::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
+      : setError(false),
+        backend(0),
+        albumDB(0),
+        dbAccess(0),
+        observer(0)
     {
-        setError = false;
-        backend  = 0;
-        albumDB  = 0;
-        access   = 0;
-        observer = 0;
     }
 
     bool                    setError;
@@ -100,13 +100,15 @@ public:
     DbEngineParameters      parameters;
 
     // legacy
-    CoreDbAccess*           access;
+    CoreDbAccess*           dbAccess;
 
     QString                 lastErrorMessage;
     InitializationObserver* observer;
 };
 
-CoreDbSchemaUpdater::CoreDbSchemaUpdater(CoreDB* const albumDB, CoreDbBackend* const backend, DbEngineParameters parameters)
+CoreDbSchemaUpdater::CoreDbSchemaUpdater(CoreDB* const albumDB,
+                                         CoreDbBackend* const backend,
+                                         DbEngineParameters parameters)
     : d(new Private)
 {
     d->backend    = backend;
@@ -119,9 +121,9 @@ CoreDbSchemaUpdater::~CoreDbSchemaUpdater()
     delete d;
 }
 
-void CoreDbSchemaUpdater::setCoreDbAccess(CoreDbAccess* const access)
+void CoreDbSchemaUpdater::setCoreDbAccess(CoreDbAccess* const dbAccess)
 {
-    d->access = access;
+    d->dbAccess = dbAccess;
 }
 
 const QString CoreDbSchemaUpdater::getLastErrorMessage()
@@ -162,12 +164,14 @@ void CoreDbSchemaUpdater::setVersionSettings()
 {
     if (d->currentVersion.isValid())
     {
-        d->albumDB->setSetting(QLatin1String("DBVersion"), QString::number(d->currentVersion.toInt()));
+        d->albumDB->setSetting(QLatin1String("DBVersion"),
+                               QString::number(d->currentVersion.toInt()));
     }
 
     if (d->currentRequiredVersion.isValid())
     {
-        d->albumDB->setSetting(QLatin1String("DBVersionRequired"), QString::number(d->currentRequiredVersion.toInt()));
+        d->albumDB->setSetting(QLatin1String("DBVersionRequired"),
+                               QString::number(d->currentRequiredVersion.toInt()));
     }
 }
 
@@ -209,9 +213,7 @@ bool CoreDbSchemaUpdater::startUpdates()
             QString errorMsg = i18n("You have insufficient privileges on the database.\n"
                                     "Following privileges are not assigned to you:\n %1\n"
                                     "Check your privileges on the database and restart digiKam.",
-                                    insufficientRights.join(QLatin1String(",\n"))
-                                   );
-
+                                    insufficientRights.join(QLatin1String(",\n")));
             d->lastErrorMessage = errorMsg;
 
             if (d->observer)
@@ -242,8 +244,7 @@ bool CoreDbSchemaUpdater::startUpdates()
             QString errorMsg = i18n("The database is not valid: "
                                     "the \"DBVersion\" setting does not exist. "
                                     "The current database schema version cannot be verified. "
-                                    "Try to start with an empty database. "
-                                   );
+                                    "Try to start with an empty database. ");
             d->lastErrorMessage=errorMsg;
 
             if (d->observer)
@@ -352,8 +353,8 @@ bool CoreDbSchemaUpdater::beginWrapSchemaUpdateStep()
         QString errorMsg = i18n("Failed to open a database transaction on your database file \"%1\". "
                                 "This is unusual. Please check that you can access the file and no "
                                 "other process has currently locked the file. "
-                                "If the problem persists you can get help from the digikam-devel@kde.org "
-                                "mailing list. As well, please have a look at what digiKam prints on the console. ",
+                                "If the problem persists you can get help from the digikam developers mailing list (see www.digikam.org/support). "
+                                "As well, please have a look at what digiKam prints on the console. ",
                                 QDir::toNativeSeparators(currentDBFile.filePath()));
         d->observer->error(errorMsg);
         d->observer->finishedSchemaUpdate(InitializationObserver::UpdateErrorMustAbort);
@@ -411,8 +412,8 @@ bool CoreDbSchemaUpdater::makeUpdates()
                                     "You can try to discard your old database and start with an empty one. "
                                     "(In this case, please move the database files "
                                     "\"%1\" and \"%2\" from the directory \"%3\"). "
-                                    "More probably you will want to report this error to the digikam-devel@kde.org "
-                                    "mailing list. As well, please have a look at what digiKam prints on the console. ",
+                                    "More probably you will want to report this error to the digikam developers mailing list (see www.digikam.org/support). "
+                                    "As well, please have a look at what digiKam prints on the console. ",
                                     QLatin1String("digikam3.db"),
                                     QLatin1String("digikam4.db"),
                                     QDir::toNativeSeparators(currentDBFile.dir().path()));
@@ -429,7 +430,7 @@ bool CoreDbSchemaUpdater::makeUpdates()
         }
 
         // Incremental updates, starting from version 5
-        for (int v = d->currentVersion.toInt(); v < schemaVersion(); v++)
+        for (int v = d->currentVersion.toInt() ; v < schemaVersion() ; ++v)
         {
             int targetVersion = v + 1;
 
@@ -458,21 +459,33 @@ bool CoreDbSchemaUpdater::makeUpdates()
     return true;
 }
 
-void CoreDbSchemaUpdater::defaultFilterSettings(QStringList& defaultImageFilter, QStringList& defaultVideoFilter,
+void CoreDbSchemaUpdater::defaultFilterSettings(QStringList& defaultItemFilter, QStringList& defaultVideoFilter,
                                                 QStringList& defaultAudioFilter)
 {
     //NOTE for updating:
     //When changing anything here, just increment filterSettingsVersion() so that the changes take effect
 
-    defaultImageFilter << QLatin1String("jpg") << QLatin1String("jpeg") << QLatin1String("jpe")                                                 // JPEG
+    // https://en.wikipedia.org/wiki/Image_file_formats
+
+    defaultItemFilter << QLatin1String("jpg") << QLatin1String("jpeg") << QLatin1String("jpe")                                                 // JPEG
                        << QLatin1String("jp2") << QLatin1String("j2k")  << QLatin1String("jpx") << QLatin1String("jpc") << QLatin1String("pgx") // JPEG-2000
                        << QLatin1String("tif") << QLatin1String("tiff")                                                                         // TIFF
                        << QLatin1String("png")                                                                                                  // PNG
                        << QLatin1String("gif") << QLatin1String("xpm")  << QLatin1String("ppm") << QLatin1String("pnm") << QLatin1String("pgf")
-                       << QLatin1String("bmp") << QLatin1String("xcf")  << QLatin1String("pcx")
+                       << QLatin1String("bmp") << QLatin1String("pcx")
                        << QLatin1String("webp");
 
-    defaultImageFilter << DRawDecoder::rawFilesList();
+    // Raster graphics editor containers: https://en.wikipedia.org/wiki/Raster_graphics_editor
+
+    defaultItemFilter << QLatin1String("xcf")
+                       << QLatin1String("psd") << QLatin1String("psb")
+                       << QLatin1String("kra") << QLatin1String("ora");
+
+    // Raw images: https://en.wikipedia.org/wiki/Raw_image_format
+
+    defaultItemFilter << DRawDecoder::rawFilesList();
+
+    // Video files: https://en.wikipedia.org/wiki/Video_file_format
 
     defaultVideoFilter << QLatin1String("mpeg") << QLatin1String("mpg")  << QLatin1String("mpo") << QLatin1String("mpe") << QLatin1String("mts") << QLatin1String("vob")    // MPEG
                        << QLatin1String("avi")  << QLatin1String("divx")                                                                                                    // RIFF
@@ -481,24 +494,31 @@ void CoreDbSchemaUpdater::defaultFilterSettings(QStringList& defaultImageFilter,
                        << QLatin1String("mkv")  << QLatin1String("webm")                                                                                                    // Matroska
                        << QLatin1String("mng");                                                                                                                             // Animated PNG image
 
-    defaultAudioFilter << QLatin1String("ogg") << QLatin1String("mp3") << QLatin1String("wma") << QLatin1String("wav");                                                                                                                             // Animated PNG image
+    // Audio files: https://en.wikipedia.org/wiki/Audio_file_format
+
+    defaultAudioFilter << QLatin1String("ogg") << QLatin1String("oga") << QLatin1String("flac") << QLatin1String("wv")  << QLatin1String("ape") // Linux audio
+                       << QLatin1String("mpc") << QLatin1String("au")                                                                           // Linux audio
+                       << QLatin1String("m4b") << QLatin1String("aax") << QLatin1String("aa")                                                   // Book audio
+                       << QLatin1String("mp3") << QLatin1String("aac")                                                                          // MPEG based audio
+                       << QLatin1String("m4a") << QLatin1String("m4p") << QLatin1String("caf") << QLatin1String("aiff")                         // Apple audio
+                       << QLatin1String("wma") << QLatin1String("wav");                                                                         // Windows audio
 }
 
 void CoreDbSchemaUpdater::defaultIgnoreDirectoryFilterSettings(QStringList& defaultIgnoreDirectoryFilter)
 {
-    //NOTE for updating:
-    //When changing anything here, just increment filterSettingsVersion() so that the changes take effect
+    // NOTE: when update this section,
+    // just increment filterSettingsVersion() so that the changes take effect
 
     defaultIgnoreDirectoryFilter << QLatin1String("@eaDir");
 }
 
 bool CoreDbSchemaUpdater::createFilterSettings()
 {
-    QStringList defaultImageFilter, defaultVideoFilter, defaultAudioFilter, defaultIgnoreDirectoryFilter;
-    defaultFilterSettings(defaultImageFilter, defaultVideoFilter, defaultAudioFilter);
+    QStringList defaultItemFilter, defaultVideoFilter, defaultAudioFilter, defaultIgnoreDirectoryFilter;
+    defaultFilterSettings(defaultItemFilter, defaultVideoFilter, defaultAudioFilter);
     defaultIgnoreDirectoryFilterSettings(defaultIgnoreDirectoryFilter);
 
-    d->albumDB->setFilterSettings(defaultImageFilter, defaultVideoFilter, defaultAudioFilter);
+    d->albumDB->setFilterSettings(defaultItemFilter, defaultVideoFilter, defaultAudioFilter);
     d->albumDB->setIgnoreDirectoryFilterSettings(defaultIgnoreDirectoryFilter);
     d->albumDB->setSetting(QLatin1String("FilterSettingsVersion"),      QString::number(filterSettingsVersion()));
     d->albumDB->setSetting(QLatin1String("DcrawFilterSettingsVersion"), QString::number(DRawDecoder::rawFilesVersion()));
@@ -659,14 +679,17 @@ bool CoreDbSchemaUpdater::updateToVersion(int targetVersion)
         case 7:
             // Digikam for database version 5 and 6 can work with version 7, though not using the support for video files.
             return performUpdateToVersion(QLatin1String("UpdateSchemaFromV6ToV7"), 7, 5);
-        // NOTE: If you add a new update step, please check the d->currentVersion at the bottom of updateV4toV7
-            // If the update already comes with createTables, createTriggers, we dont need the extra update here
+            // NOTE: If you add a new update step, please check the d->currentVersion at the bottom of updateV4toV7
+            // If the update already comes with createTables, createTriggers, we don't need the extra update here
         case 8:
             // Digikam for database version 7 can work with version 8, now using COLLATE utf8_general_ci for MySQL.
             return performUpdateToVersion(QLatin1String("UpdateSchemaFromV7ToV9"), 8, 5);
         case 9:
             // Digikam for database version 8 can work with version 9, now using COLLATE utf8_general_ci for MySQL.
             return performUpdateToVersion(QLatin1String("UpdateSchemaFromV7ToV9"), 9, 5);
+        case 10:
+            // Digikam for database version 9 can work with version 10, remove ImageHaarMatrix table and add manualOrder column.
+            return performUpdateToVersion(QLatin1String("UpdateSchemaFromV9ToV10"), 10, 5);
         default:
             qCDebug(DIGIKAM_COREDB_LOG) << "Core database: unsupported update to version" << targetVersion;
             return false;
@@ -890,7 +913,7 @@ bool CoreDbSchemaUpdater::updateV4toV7()
                                    "with a storage volume of your system. "
                                    "This problem may indicate that there is a problem with your installation. "
                                    "If you are working on Linux, check that HAL is installed and running. "
-                                   "In any case, you can seek advice from the digikam-devel@kde.org mailing list. "
+                                   "In any case, you can seek advice from the digikam developers mailing list (see www.digikam.org/support). "
                                    "The database updating process will now be aborted because we do not want "
                                    "to create a new database based on false assumptions from a broken installation.",
                                    albumLibraryPath);
@@ -958,7 +981,7 @@ bool CoreDbSchemaUpdater::updateV4toV7()
         return false;
     }
 
-    if (!d->access->backend()->execSql(QString::fromUtf8(
+    if (!d->dbAccess->backend()->execSql(QString::fromUtf8(
                                           "REPLACE INTO ImageInformation (imageId) SELECT id FROM Images;"))
        )
     {
@@ -999,7 +1022,7 @@ bool CoreDbSchemaUpdater::updateV4toV7()
     {
         QUrl url((*it).query);
 
-        ImageQueryBuilder builder;
+        ItemQueryBuilder builder;
         QString query = builder.convertFromUrlToXml(url);
         QString name  = (*it).name;
 
@@ -1037,23 +1060,23 @@ bool CoreDbSchemaUpdater::updateV4toV7()
 
     // --- Set user settings from config ---
 
-    QStringList defaultImageFilter, defaultVideoFilter, defaultAudioFilter;
-    defaultFilterSettings(defaultImageFilter, defaultVideoFilter, defaultAudioFilter);
+    QStringList defaultItemFilter, defaultVideoFilter, defaultAudioFilter;
+    defaultFilterSettings(defaultItemFilter, defaultVideoFilter, defaultAudioFilter);
 
-    QSet<QString> configImageFilter, configVideoFilter, configAudioFilter;
+    QSet<QString> configItemFilter, configVideoFilter, configAudioFilter;
 
-    configImageFilter   = cleanUserFilterString(group.readEntry(QLatin1String("File Filter"),       QString())).toSet();
-    configImageFilter  += cleanUserFilterString(group.readEntry(QLatin1String("Raw File Filter"),   QString())).toSet();
+    configItemFilter   = cleanUserFilterString(group.readEntry(QLatin1String("File Filter"),       QString())).toSet();
+    configItemFilter  += cleanUserFilterString(group.readEntry(QLatin1String("Raw File Filter"),   QString())).toSet();
     configVideoFilter   = cleanUserFilterString(group.readEntry(QLatin1String("Movie File Filter"), QString())).toSet();
     configAudioFilter   = cleanUserFilterString(group.readEntry(QLatin1String("Audio File Filter"), QString())).toSet();
 
     // remove those that are included in the default filter
-    configImageFilter.subtract(defaultImageFilter.toSet());
+    configItemFilter.subtract(defaultItemFilter.toSet());
     configVideoFilter.subtract(defaultVideoFilter.toSet());
     configAudioFilter.subtract(defaultAudioFilter.toSet());
 
-    d->albumDB->setUserFilterSettings(configImageFilter.toList(), configVideoFilter.toList(), configAudioFilter.toList());
-    qCDebug(DIGIKAM_COREDB_LOG) << "Core database: set initial filter settings with user settings" << configImageFilter;
+    d->albumDB->setUserFilterSettings(configItemFilter.toList(), configVideoFilter.toList(), configAudioFilter.toList());
+    qCDebug(DIGIKAM_COREDB_LOG) << "Core database: set initial filter settings with user settings" << configItemFilter;
 
     if (d->observer)
     {
@@ -1110,7 +1133,7 @@ bool CoreDbSchemaUpdater::updateV4toV7()
         d->observer->schemaUpdateProgress(i18n("Imported creation dates"));
     }
 
-    // Port ImagesV3.comment to ImageComments
+    // Port ImagesV3.comment to ItemComments
 
     // An author of NULL will inhibt the UNIQUE restriction to take effect (but #189080). Work around.
     d->backend->execSql(QString::fromUtf8(
@@ -1140,7 +1163,7 @@ bool CoreDbSchemaUpdater::updateV4toV7()
         d->observer->schemaUpdateProgress(i18n("Imported comments"));
     }
 
-    // Port rating storage in ImageProperties to ImageInformation
+    // Port rating storage in ImageProperties to ItemInformation
     if (!d->backend->execSql(QString::fromUtf8(
                                 "UPDATE ImageInformation SET "
                                 " rating=(SELECT value FROM ImageProperties "
@@ -1234,7 +1257,7 @@ void CoreDbSchemaUpdater::preAlpha010Update1()
     {
         QUrl url((*it).query);
 
-        ImageQueryBuilder builder;
+        ItemQueryBuilder builder;
         QString query = builder.convertFromUrlToXml(url);
 
         if (QUrlQuery(url).queryItemValue(QLatin1String("type")) == QLatin1String("datesearch"))
@@ -1265,7 +1288,7 @@ void CoreDbSchemaUpdater::preAlpha010Update2()
         return;
     }
 
-    if (!d->backend->execSql(QString::fromUtf8("ALTER TABLE ImagePositions RENAME TO ImagePositionsTemp;")))
+    if (!d->backend->execSql(QString::fromUtf8("ALTER TABLE ImagePositions RENAME TO ItemPositionsTemp;")))
     {
         return;
     }
@@ -1276,7 +1299,7 @@ void CoreDbSchemaUpdater::preAlpha010Update2()
     }
 
     d->backend->execSql(
-        QString::fromUtf8("CREATE TABLE ImagePositions\n"
+        QString::fromUtf8("CREATE TABLE ItemPositions\n"
                           " (imageid INTEGER PRIMARY KEY,\n"
                           "  latitude TEXT,\n"
                           "  latitudeNumber REAL,\n"
@@ -1294,7 +1317,7 @@ void CoreDbSchemaUpdater::preAlpha010Update2()
                                           "  altitude, orientation, tilt, roll, accuracy, description) "
                                           "SELECT imageid, latitude, latitudeNumber, longitude, longitudeNumber, "
                                           "  altitude, orientation, tilt, roll, 0, description "
-                                          " FROM ImagePositionsTemp;"));
+                                          " FROM ItemPositionsTemp;"));
 
     d->backend->execSql(
         QString::fromUtf8("CREATE TABLE ImageMetadata\n"
@@ -1325,7 +1348,7 @@ void CoreDbSchemaUpdater::preAlpha010Update2()
                                            "  whiteBalanceColorTemperature, meteringMode, subjectDistance, subjectDistanceCategory "
                                            "FROM ImageMetadataTemp;"));
 
-    d->backend->execSql(QString::fromUtf8("DROP TABLE ImagePositionsTemp;"));
+    d->backend->execSql(QString::fromUtf8("DROP TABLE ItemPositionsTemp;"));
     d->backend->execSql(QString::fromUtf8("DROP TABLE ImageMetadataTemp;"));
 
     d->albumDB->setSetting(QLatin1String("preAlpha010Update2"), QLatin1String("true"));
@@ -1340,8 +1363,8 @@ void CoreDbSchemaUpdater::preAlpha010Update3()
         return;
     }
 
-    d->backend->execSql(QString::fromUtf8("DROP TABLE ImageCopyright;"));
-    d->backend->execSql(QString::fromUtf8("CREATE TABLE ImageCopyright\n"
+    d->backend->execSql(QString::fromUtf8("DROP TABLE ItemCopyright;"));
+    d->backend->execSql(QString::fromUtf8("CREATE TABLE ItemCopyright\n"
                                           " (imageid INTEGER,\n"
                                           "  property TEXT,\n"
                                           "  value TEXT,\n"
@@ -1369,15 +1392,15 @@ void CoreDbSchemaUpdater::beta010Update1()
                                           "    WHERE imageid=OLD.id;\n"
                                           "  DELETE From ImageHaarMatrix\n "
                                           "    WHERE imageid=OLD.id;\n"
-                                          "  DELETE From ImageInformation\n "
+                                          "  DELETE From ItemInformation\n "
                                           "    WHERE imageid=OLD.id;\n"
                                           "  DELETE From ImageMetadata\n "
                                           "    WHERE imageid=OLD.id;\n"
-                                          "  DELETE From ImagePositions\n "
+                                          "  DELETE From ItemPositions\n "
                                           "    WHERE imageid=OLD.id;\n"
-                                          "  DELETE From ImageComments\n "
+                                          "  DELETE From ItemComments\n "
                                           "    WHERE imageid=OLD.id;\n"
-                                          "  DELETE From ImageCopyright\n "
+                                          "  DELETE From ItemCopyright\n "
                                           "    WHERE imageid=OLD.id;\n"
                                           "  DELETE From ImageProperties\n "
                                           "    WHERE imageid=OLD.id;\n"
@@ -1565,4 +1588,4 @@ bool CoreDbSchemaUpdater::createTablesV3()
     return true;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
