@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2000-06-08
  * Description : Core database <-> thumbnail database interface
  *
  * Copyright (C) 2009      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,7 +34,7 @@
 #include "collectionmanager.h"
 #include "collectionlocation.h"
 #include "coredbaccess.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "thumbnailcreator.h"
 
 namespace Digikam
@@ -43,15 +43,15 @@ namespace Digikam
 ThumbnailInfo ThumbsDbInfoProvider::thumbnailInfo(const ThumbnailIdentifier& identifier)
 {
     // If code here proves to be a bottleneck we can add custom queries to albumdb to retrieve info all-in-one
-    ImageInfo imageinfo;
+    ItemInfo imageinfo;
 
     if (identifier.id)
     {
-        imageinfo = ImageInfo(identifier.id);
+        imageinfo = ItemInfo(identifier.id);
     }
     else
     {
-        imageinfo = ImageInfo::fromLocalFile(identifier.filePath);
+        imageinfo = ItemInfo::fromLocalFile(identifier.filePath);
     }
 
     if (imageinfo.isNull())
@@ -64,8 +64,8 @@ ThumbnailInfo ThumbsDbInfoProvider::thumbnailInfo(const ThumbnailIdentifier& ide
 
 int DatabaseLoadSaveFileInfoProvider::orientationHint(const QString& path)
 {
-    ImageInfo info = ImageInfo::fromLocalFile(path);
+    ItemInfo info = ItemInfo::fromLocalFile(path);
     return info.orientation();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
