@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-23
  * Description : Core database image properties synchronizer
  *
  * Copyright (C) 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef COREDATABASEWATCH_H
-#define COREDATABASEWATCH_H
+#ifndef DIGIKAM_CORE_DB_WATCH_H
+#define DIGIKAM_CORE_DB_WATCH_H
 
 #include "digikam_config.h"
 
@@ -192,4 +192,4 @@ private:
 
 } // namespace Digikam
 
-#endif // COREDATABASEWATCH_H
+#endif // DIGIKAM_CORE_DB_WATCH_H
