@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-06-01
  * Description : DB Jobs for listing and scanning
  *
- * Copyright (C) 2015 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,14 +21,14 @@
  *
  * ============================================================ */
 
-#ifndef DBJOB_H
-#define DBJOB_H
+#ifndef DIGIKAM_DB_JOB_H
+#define DIGIKAM_DB_JOB_H
 
 // Local includes
 
 #include "dbjobinfo.h"
 #include "dbjobsthread.h"
-#include "imagelisterrecord.h"
+#include "itemlisterrecord.h"
 #include "duplicatesprogressobserver.h"
 #include "actionthreadbase.h"
 #include "digikam_export.h"
@@ -44,12 +44,12 @@ class DIGIKAM_DATABASE_EXPORT DBJob : public ActionJob
 
 protected:
 
-    DBJob();
+    explicit DBJob();
     ~DBJob();
 
 Q_SIGNALS:
 
-    void data(const QList<ImageListerRecord>& records);
+    void data(const QList<ItemListerRecord>& records);
     void error(const QString& err);
 };
 
@@ -61,7 +61,7 @@ class DIGIKAM_DATABASE_EXPORT AlbumsJob : public DBJob
 
 public:
 
-    AlbumsJob(const AlbumsDBJobInfo& jobInfo);
+    explicit AlbumsJob(const AlbumsDBJobInfo& jobInfo);
     ~AlbumsJob();
 
 protected:
@@ -85,7 +85,7 @@ class DIGIKAM_DATABASE_EXPORT DatesJob : public DBJob
 
 public:
 
-    DatesJob(const DatesDBJobInfo& jobInfo);
+    explicit DatesJob(const DatesDBJobInfo& jobInfo);
     ~DatesJob();
 
 protected:
@@ -109,7 +109,7 @@ class DIGIKAM_DATABASE_EXPORT GPSJob : public DBJob
 
 public:
 
-    GPSJob(const GPSDBJobInfo& jobInfo);
+    explicit GPSJob(const GPSDBJobInfo& jobInfo);
     ~GPSJob();
 
 protected:
@@ -133,7 +133,7 @@ class DIGIKAM_DATABASE_EXPORT TagsJob : public DBJob
 
 public:
 
-    TagsJob(const TagsDBJobInfo& jobInfo);
+    explicit TagsJob(const TagsDBJobInfo& jobInfo);
     ~TagsJob();
 
 protected:
@@ -142,7 +142,7 @@ protected:
 
 Q_SIGNALS:
 
-    void foldersData(const QMap<int, int> & data);
+    void foldersData(const QMap<int, int>& data);
     void faceFoldersData(const QMap<QString, QMap<int, int> >& data);
 
 private:
@@ -158,7 +158,7 @@ class DIGIKAM_DATABASE_EXPORT SearchesJob : public DBJob
 
 public:
 
-    SearchesJob(const SearchesDBJobInfo& jobInfo);
+    explicit SearchesJob(const SearchesDBJobInfo& jobInfo);
     ~SearchesJob();
 
     bool isCanceled();
@@ -179,4 +179,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DBJOB_H
+#endif // DIGIKAM_DB_JOB_H
