@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-04-15
  * Description : Database engine abstract database backend
  *
  * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -80,7 +80,8 @@ DbEngineThreadData::~DbEngineThreadData()
 {
     if (transactionCount)
     {
-        qCDebug(DIGIKAM_DBENGINE_LOG) << "WARNING !!! Transaction count is" << transactionCount << "when destroying database!!!";
+        qCDebug(DIGIKAM_DBENGINE_LOG) << "WARNING !!! Transaction count is"
+                                      << transactionCount << "when destroying database!!!";
     }
 
     closeDatabase();
@@ -97,7 +98,6 @@ void DbEngineThreadData::closeDatabase()
 
     // Destroy object
     database         = QSqlDatabase();
-
     valid            = 0;
     transactionCount = 0;
     lastError        = QSqlError();
@@ -173,7 +173,8 @@ QSqlDatabase BdEngineBackendPrivate::databaseForThread()
         }
         else
         {
-            qCDebug(DIGIKAM_DBENGINE_LOG) << "Error while opening the database. Error was" << threadData->database.lastError();
+            qCDebug(DIGIKAM_DBENGINE_LOG) << "Error while opening the database. Error was"
+                                          << threadData->database.lastError();
         }
     }
 
@@ -198,7 +199,7 @@ QSqlDatabase BdEngineBackendPrivate::createDatabaseConnection()
             connectOptions += QLatin1Char(';');
         }
 
-        connectOptions += toAdd.join(QLatin1String(";"));
+        connectOptions += toAdd.join(QLatin1Char(';'));
     }
 
     db.setDatabaseName(parameters.databaseNameCore);
@@ -277,12 +278,14 @@ bool BdEngineBackendPrivate::reconnectOnError() const
 bool BdEngineBackendPrivate::isSQLiteLockError(const DbEngineSqlQuery& query) const
 {
     return parameters.isSQLite() &&
-           (query.lastError().number() == 5 /*SQLITE_BUSY*/ || query.lastError().number() == 6/*SQLITE_LOCKED*/);
+           (query.lastError().number() == 5 /*SQLITE_BUSY*/  ||
+            query.lastError().number() == 6 /*SQLITE_LOCKED*/);
 }
 
 bool BdEngineBackendPrivate::isSQLiteLockTransactionError(const QSqlError& lastError) const
 {
-    return (parameters.isSQLite()                                   &&
+    return (
+            parameters.isSQLite()                                   &&
             lastError.type()         == QSqlError::TransactionError &&
             lastError.databaseText() == QLatin1String("database is locked")
            );
@@ -298,7 +301,8 @@ bool BdEngineBackendPrivate::isConnectionError(const DbEngineSqlQuery& query) co
         return false;
     }
 
-    return (query.lastError().type()   == QSqlError::ConnectionError ||
+    return (
+            query.lastError().type()   == QSqlError::ConnectionError ||
             query.lastError().number() == 2006
            );
 }
@@ -498,7 +502,7 @@ BdEngineBackendPrivate::AbstractUnlocker::AbstractUnlocker(BdEngineBackendPrivat
     d->lock->lockCount = 0;
 
     // unlock
-    for (int i=0; i<count; ++i)
+    for (int i = 0 ; i < count ; ++i)
     {
         d->lock->mutex.unlock();
     }
@@ -515,7 +519,7 @@ void BdEngineBackendPrivate::AbstractUnlocker::finishAcquire()
 BdEngineBackendPrivate::AbstractUnlocker::~AbstractUnlocker()
 {
     // lock main mutex as often as it was locked before
-    for (int i=0; i<count; ++i)
+    for (int i = 0 ; i < count ; ++i)
     {
         d->lock->mutex.lock();
     }
@@ -569,13 +573,16 @@ void BdEngineBackendPrivate::ErrorLocker::wait()
 
 // -----------------------------------------------------------------------------------------
 
-BdEngineBackend::BdEngineBackend(const QString& backendName, DbEngineLocking* const locking)
+BdEngineBackend::BdEngineBackend(const QString& backendName,
+                                 DbEngineLocking* const locking)
     : d_ptr(new BdEngineBackendPrivate(this))
 {
     d_ptr->init(backendName, locking);
 }
 
-BdEngineBackend::BdEngineBackend(const QString& backendName, DbEngineLocking* const locking, BdEngineBackendPrivate& dd)
+BdEngineBackend::BdEngineBackend(const QString& backendName,
+                                 DbEngineLocking* const locking,
+                                 BdEngineBackendPrivate& dd)
     : d_ptr(&dd)
 {
     d_ptr->init(backendName, locking);
@@ -616,36 +623,40 @@ BdEngineBackend::DbType BdEngineBackend::databaseType() const
     return d->parameters.isSQLite() ? DbType::SQLite : DbType::MySQL;
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execDBAction(const DbEngineAction& action, QList<QVariant>* const values,
+BdEngineBackend::QueryState BdEngineBackend::execDBAction(const DbEngineAction& action,
+                                                          QList<QVariant>* const values,
                                                           QVariant* const lastInsertId)
 {
     return execDBAction(action, QMap<QString, QVariant>(), values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execDBAction(const QString& action, QList<QVariant>* const values,
+BdEngineBackend::QueryState BdEngineBackend::execDBAction(const QString& action,
+                                                          QList<QVariant>* const values,
                                                           QVariant* const lastInsertId)
 {
     return execDBAction(getDBAction(action), QMap<QString, QVariant>(), values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execDBAction(const QString& action, const QMap<QString, QVariant>& bindingMap,
+BdEngineBackend::QueryState BdEngineBackend::execDBAction(const QString& action,
+                                                          const QMap<QString, QVariant>& bindingMap,
                                                           QList<QVariant>* const values, QVariant* const lastInsertId)
 {
     return execDBAction(getDBAction(action), bindingMap, values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execDBAction(const DbEngineAction& action, const QMap<QString, QVariant>& bindingMap,
+BdEngineBackend::QueryState BdEngineBackend::execDBAction(const DbEngineAction& action,
+                                                          const QMap<QString, QVariant>& bindingMap,
                                                           QList<QVariant>* const values, QVariant* const lastInsertId)
 {
     Q_D(BdEngineBackend);
 
-    BdEngineBackend::QueryState returnResult = BdEngineBackend::NoErrors;
+    BdEngineBackend::QueryState returnResult = BdEngineBackend::QueryState(BdEngineBackend::NoErrors);
     QSqlDatabase db                          = d->databaseForThread();
 
     if (action.name.isNull())
     {
         qCWarning(DIGIKAM_DBENGINE_LOG) << "Attempt to execute null action";
-        return BdEngineBackend::SQLError;
+        return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
     }
 
     //qCDebug(DIGIKAM_DBENGINE_LOG) << "Executing DBAction ["<<  action.name  <<"]";
@@ -707,7 +718,9 @@ BdEngineBackend::QueryState BdEngineBackend::execDBAction(const DbEngineAction&
     return returnResult;
 }
 
-QSqlQuery BdEngineBackend::execDBActionQuery(const QString& action, const QMap<QString, QVariant>& bindingMap)
+QSqlQuery BdEngineBackend::execDBActionQuery(const QString& action,
+                                             const QMap<QString,
+                                             QVariant>& bindingMap)
 {
     return execDBActionQuery(getDBAction(action), bindingMap);
 }
@@ -722,7 +735,7 @@ QSqlQuery BdEngineBackend::execDBActionQuery(const DbEngineAction& action, const
 
     QSqlQuery result;
 
-    foreach(const DbEngineActionElement& actionElement, action.dbActionElements)
+    foreach (const DbEngineActionElement& actionElement, action.dbActionElements)
     {
         if (actionElement.mode == QLatin1String("query"))
         {
@@ -792,6 +805,7 @@ bool BdEngineBackend::open(const DbEngineParameters& parameters)
     }
 
     d->status = Open;
+
     return true;
 }
 
@@ -840,7 +854,7 @@ QList<QVariant> BdEngineBackend::readToList(DbEngineSqlQuery& query)
 
     while (query.next())
     {
-        for (int i=0; i<count; ++i)
+        for (int i = 0 ; i < count ; ++i)
         {
             list << query.value(i);
         }
@@ -851,17 +865,19 @@ QList<QVariant> BdEngineBackend::readToList(DbEngineSqlQuery& query)
     return list;
 }
 
-BdEngineBackend::QueryState BdEngineBackend::handleQueryResult(DbEngineSqlQuery& query, QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::handleQueryResult(DbEngineSqlQuery& query,
+                                                               QList<QVariant>* const values,
+                                                               QVariant* const lastInsertId)
 {
     if (!query.isActive())
     {
         if (query.lastError().type() == QSqlError::ConnectionError)
         {
-            return BdEngineBackend::ConnectionError;
+            return BdEngineBackend::QueryState(BdEngineBackend::ConnectionError);
         }
         else
         {
-            return BdEngineBackend::SQLError;
+            return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
         }
     }
 
@@ -875,35 +891,46 @@ BdEngineBackend::QueryState BdEngineBackend::handleQueryResult(DbEngineSqlQuery&
         (*values) = readToList(query);
     }
 
-    return BdEngineBackend::NoErrors;
+    return BdEngineBackend::QueryState(BdEngineBackend::NoErrors);
 }
 
 // -------------------------------------------------------------------------------------
 
-BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql, QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql);
+
     return handleQueryResult(query, values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql, const QVariant& boundValue1,
-                                                     QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
+                                                     const QVariant& boundValue1,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql, boundValue1);
+
     return handleQueryResult(query, values, lastInsertId);
 }
 
 BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
-                                                     const QVariant& boundValue1, const QVariant& boundValue2,
-                                                     QList<QVariant>* const values, QVariant* const lastInsertId)
+                                                     const QVariant& boundValue1,
+                                                     const QVariant& boundValue2,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql, boundValue1, boundValue2);
+
     return handleQueryResult(query, values, lastInsertId);
 }
 
 BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
-                                                     const QVariant& boundValue1, const QVariant& boundValue2,
-                                                     const QVariant& boundValue3, QList<QVariant>* const values,
+                                                     const QVariant& boundValue1,
+                                                     const QVariant& boundValue2,
+                                                     const QVariant& boundValue3,
+                                                     QList<QVariant>* const values,
                                                      QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql, boundValue1, boundValue2, boundValue3);
@@ -911,18 +938,25 @@ BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
 }
 
 BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
-                                                     const QVariant& boundValue1, const QVariant& boundValue2,
-                                                     const QVariant& boundValue3, const QVariant& boundValue4,
-                                                     QList<QVariant>* const values, QVariant* const lastInsertId)
+                                                     const QVariant& boundValue1,
+                                                     const QVariant& boundValue2,
+                                                     const QVariant& boundValue3,
+                                                     const QVariant& boundValue4,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql, boundValue1, boundValue2, boundValue3, boundValue4);
+
     return handleQueryResult(query, values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql, const QList<QVariant>& boundValues,
-                                                     QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql,
+                                                     const QList<QVariant>& boundValues,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql, boundValues);
+
     return handleQueryResult(query, values, lastInsertId);
 }
 
@@ -930,52 +964,71 @@ BdEngineBackend::QueryState BdEngineBackend::execSql(const QString& sql, const Q
                                                      QList<QVariant>* const values, QVariant* const lastInsertId)
 {
     DbEngineSqlQuery query = execQuery(sql, bindingMap);
+
     return handleQueryResult(query, values, lastInsertId);
 }
 
 // -------------------------------------------------------------------------------------
 
-BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery, QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     exec(preparedQuery);
+
     return handleQueryResult(preparedQuery, values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery, const QVariant& boundValue1,
-        QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery,
+                                                     const QVariant& boundValue1,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     execQuery(preparedQuery, boundValue1);
+
     return handleQueryResult(preparedQuery, values, lastInsertId);
 }
 
 BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery,
-        const QVariant& boundValue1, const QVariant& boundValue2,
-        QList<QVariant>* const values, QVariant* const lastInsertId)
+                                                     const QVariant& boundValue1,
+                                                     const QVariant& boundValue2,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     execQuery(preparedQuery, boundValue1, boundValue2);
+
     return handleQueryResult(preparedQuery, values, lastInsertId);
 }
 
 BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery,
-        const QVariant& boundValue1, const QVariant& boundValue2,
-        const QVariant& boundValue3, QList<QVariant>* const values,
-        QVariant* const lastInsertId)
+                                                     const QVariant& boundValue1,
+                                                     const QVariant& boundValue2,
+                                                     const QVariant& boundValue3,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     execQuery(preparedQuery, boundValue1, boundValue2, boundValue3);
+
     return handleQueryResult(preparedQuery, values, lastInsertId);
 }
 
 BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery,
-        const QVariant& boundValue1, const QVariant& boundValue2,
-        const QVariant& boundValue3, const QVariant& boundValue4,
-        QList<QVariant>* const values, QVariant* const lastInsertId)
+                                                     const QVariant& boundValue1,
+                                                     const QVariant& boundValue2,
+                                                     const QVariant& boundValue3,
+                                                     const QVariant& boundValue4,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     execQuery(preparedQuery, boundValue1, boundValue2, boundValue3, boundValue4);
+
     return handleQueryResult(preparedQuery, values, lastInsertId);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery, const QList<QVariant>& boundValues,
-        QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execSql(DbEngineSqlQuery& preparedQuery,
+                                                     const QList<QVariant>& boundValues,
+                                                     QList<QVariant>* const values,
+                                                     QVariant* const lastInsertId)
 {
     execQuery(preparedQuery, boundValues);
     return handleQueryResult(preparedQuery, values, lastInsertId);
@@ -990,38 +1043,49 @@ DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql, const QVariant&
 //    qCDebug(DIGIKAM_DBENGINE_LOG) << "Trying to sql ["<< sql <<"] query ["<<query.lastQuery()<<"]";
 
     execQuery(query, boundValue1);
+
     return query;
 }
 
 DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql,
-                                        const QVariant& boundValue1, const QVariant& boundValue2)
+                                            const QVariant& boundValue1,
+                                            const QVariant& boundValue2)
 {
     DbEngineSqlQuery query = prepareQuery(sql);
     execQuery(query, boundValue1, boundValue2);
+
     return query;
 }
 
 DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql,
-                                        const QVariant& boundValue1, const QVariant& boundValue2, const QVariant& boundValue3)
+                                            const QVariant& boundValue1,
+                                            const QVariant& boundValue2,
+                                            const QVariant& boundValue3)
 {
     DbEngineSqlQuery query = prepareQuery(sql);
     execQuery(query, boundValue1, boundValue2, boundValue3);
+
     return query;
 }
 
 DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql,
-                                        const QVariant& boundValue1, const QVariant& boundValue2,
-                                        const QVariant& boundValue3, const QVariant& boundValue4)
+                                            const QVariant& boundValue1,
+                                            const QVariant& boundValue2,
+                                            const QVariant& boundValue3,
+                                            const QVariant& boundValue4)
 {
     DbEngineSqlQuery query = prepareQuery(sql);
     execQuery(query, boundValue1, boundValue2, boundValue3, boundValue4);
+
     return query;
 }
 
-DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql, const QList<QVariant>& boundValues)
+DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql,
+                                            const QList<QVariant>& boundValues)
 {
     DbEngineSqlQuery query = prepareQuery(sql);
     execQuery(query, boundValues);
+
     return query;
 }
 
@@ -1032,6 +1096,7 @@ DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql)
 //    qCDebug(DIGIKAM_DBENGINE_LOG)<<"execQuery: Using statement ["<< query.lastQuery() <<"]";
 
     exec(query);
+
     return query;
 }
 
@@ -1044,7 +1109,8 @@ void BdEngineBackend::execQuery(DbEngineSqlQuery& query, const QVariant& boundVa
 }
 
 void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
-                                    const QVariant& boundValue1, const QVariant& boundValue2)
+                                const QVariant& boundValue1,
+                                const QVariant& boundValue2)
 {
     query.bindValue(0, boundValue1);
     query.bindValue(1, boundValue2);
@@ -1052,8 +1118,9 @@ void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
 }
 
 void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
-                                    const QVariant& boundValue1, const QVariant& boundValue2,
-                                    const QVariant& boundValue3)
+                                const QVariant& boundValue1,
+                                const QVariant& boundValue2,
+                                const QVariant& boundValue3)
 {
     query.bindValue(0, boundValue1);
     query.bindValue(1, boundValue2);
@@ -1062,8 +1129,10 @@ void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
 }
 
 void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
-                                    const QVariant& boundValue1, const QVariant& boundValue2,
-                                    const QVariant& boundValue3, const QVariant& boundValue4)
+                                const QVariant& boundValue1,
+                                const QVariant& boundValue2,
+                                const QVariant& boundValue3,
+                                const QVariant& boundValue4)
 {
     query.bindValue(0, boundValue1);
     query.bindValue(1, boundValue2);
@@ -1072,9 +1141,10 @@ void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
     exec(query);
 }
 
-void BdEngineBackend::execQuery(DbEngineSqlQuery& query, const QList<QVariant>& boundValues)
+void BdEngineBackend::execQuery(DbEngineSqlQuery& query,
+                                const QList<QVariant>& boundValues)
 {
-    for (int i=0; i<boundValues.size(); ++i)
+    for (int i = 0 ; i < boundValues.size() ; ++i)
     {
         query.bindValue(i, boundValues.at(i));
     }
@@ -1213,7 +1283,7 @@ DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql, const QMap<QStri
             }
 
             preparedString = preparedString.replace(pos, identifierRegExp.matchedLength(), replaceStr);
-            pos=0; // reset pos
+            pos            = 0; // reset pos
         }
     }
 
@@ -1221,7 +1291,7 @@ DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql, const QMap<QStri
 
     DbEngineSqlQuery query = prepareQuery(preparedString);
 
-    for (int i=0; i < valuesToBind.size(); ++i)
+    for (int i = 0 ; i < valuesToBind.size() ; ++i)
     {
         query.bindValue(i, valuesToBind.at(i));
     }
@@ -1230,13 +1300,15 @@ DbEngineSqlQuery BdEngineBackend::execQuery(const QString& sql, const QMap<QStri
     return query;
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execUpsertDBAction(const DbEngineAction& action, const QVariant& id,
-                                                                        const QStringList fieldNames, const QList<QVariant>& values)
+BdEngineBackend::QueryState BdEngineBackend::execUpsertDBAction(const DbEngineAction& action,
+                                                                const QVariant& id,
+                                                                const QStringList fieldNames,
+                                                                const QList<QVariant>& values)
 {
     QMap<QString, QVariant> parameters;
     QMap<QString, QVariant> fieldValueMap;
 
-    for (int i = 0; i < fieldNames.size(); ++i)
+    for (int i = 0 ; i < fieldNames.size() ; ++i)
     {
         fieldValueMap.insert(fieldNames.at(i), values.at(i));
     }
@@ -1253,8 +1325,10 @@ BdEngineBackend::QueryState BdEngineBackend::execUpsertDBAction(const DbEngineAc
     return execDBAction(action, parameters);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execUpsertDBAction(const QString& action, const QVariant& id,
-                                                                        const QStringList fieldNames, const QList<QVariant>& values)
+BdEngineBackend::QueryState BdEngineBackend::execUpsertDBAction(const QString& action,
+                                                                const QVariant& id,
+                                                                const QStringList fieldNames,
+                                                                const QList<QVariant>& values)
 {
     return execUpsertDBAction(getDBAction(action), id, fieldNames, values);
 }
@@ -1351,11 +1425,11 @@ BdEngineBackend::QueryState BdEngineBackend::execDirectSql(const QString& sql)
 
     if (!d->checkOperationStatus())
     {
-        return BdEngineBackend::SQLError;
+        return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
     }
 
     DbEngineSqlQuery query = getQuery();
-    int retries    = 0;
+    int retries            = 0;
 
     forever
     {
@@ -1371,25 +1445,27 @@ BdEngineBackend::QueryState BdEngineBackend::execDirectSql(const QString& sql)
             }
             else
             {
-                return BdEngineBackend::SQLError;
+                return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
             }
         }
     }
 
-    return BdEngineBackend::NoErrors;
+    return BdEngineBackend::QueryState(BdEngineBackend::NoErrors);
 }
 
-BdEngineBackend::QueryState BdEngineBackend::execDirectSqlWithResult(const QString& sql, QList<QVariant>* const values, QVariant* const lastInsertId)
+BdEngineBackend::QueryState BdEngineBackend::execDirectSqlWithResult(const QString& sql,
+                                                                     QList<QVariant>* const values,
+                                                                     QVariant* const lastInsertId)
 {
     Q_D(BdEngineBackend);
 
     if (!d->checkOperationStatus())
     {
-        return BdEngineBackend::SQLError;
+        return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
     }
 
     DbEngineSqlQuery query = getQuery();
-    int retries    = 0;
+    int retries            = 0;
 
     forever
     {
@@ -1406,12 +1482,12 @@ BdEngineBackend::QueryState BdEngineBackend::execDirectSqlWithResult(const QStri
             }
             else
             {
-                return BdEngineBackend::SQLError;
+                return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
             }
         }
     }
 
-    return BdEngineBackend::NoErrors;
+    return BdEngineBackend::QueryState(BdEngineBackend::NoErrors);
 }
 
 bool BdEngineBackend::exec(DbEngineSqlQuery& query)
@@ -1427,9 +1503,15 @@ bool BdEngineBackend::exec(DbEngineSqlQuery& query)
 
     forever
     {
-//        qCDebug(DIGIKAM_DBENGINE_LOG) << "Trying to query [" << query.lastQuery() << "] values [" << query.boundValues() << "]";
+/*
+        qCDebug(DIGIKAM_DBENGINE_LOG) << "Trying to query ["
+                                      << query.lastQuery()
+                                      << "] values ["
+                                      << query.boundValues()
+                                      << "]";
+*/
 
-        if (query.exec())
+        if (query.exec())   // krazy:exclude=crashy
         {
             break;
         }
@@ -1522,7 +1604,7 @@ DbEngineSqlQuery BdEngineBackend::copyQuery(const DbEngineSqlQuery& old)
     // only for positional binding
     QList<QVariant> boundValues = old.boundValues().values();
 
-    foreach(const QVariant& value, boundValues)
+    foreach (const QVariant& value, boundValues)
     {
 //        qCDebug(DIGIKAM_DBENGINE_LOG) << "Bind value to query ["<<value<<"]";
 
@@ -1539,6 +1621,7 @@ DbEngineSqlQuery BdEngineBackend::getQuery()
 
     DbEngineSqlQuery query(db);
     query.setForwardOnly(true);
+
     return query;
 }
 
@@ -1571,11 +1654,11 @@ BdEngineBackend::QueryState BdEngineBackend::beginTransaction()
 
                     if (db.lastError().type() == QSqlError::ConnectionError)
                     {
-                        return BdEngineBackend::ConnectionError;
+                        return BdEngineBackend::QueryState(BdEngineBackend::ConnectionError);
                     }
                     else
                     {
-                        return BdEngineBackend::SQLError;
+                        return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
                     }
                 }
             }
@@ -1584,7 +1667,7 @@ BdEngineBackend::QueryState BdEngineBackend::beginTransaction()
         d->isInTransaction = true;
     }
 
-    return BdEngineBackend::NoErrors;
+    return BdEngineBackend::QueryState(BdEngineBackend::NoErrors);
 }
 
 BdEngineBackend::QueryState BdEngineBackend::commitTransaction()
@@ -1617,11 +1700,11 @@ BdEngineBackend::QueryState BdEngineBackend::commitTransaction()
 
                     if (lastError.type() == QSqlError::ConnectionError)
                     {
-                        return BdEngineBackend::ConnectionError;
+                        return BdEngineBackend::QueryState(BdEngineBackend::ConnectionError);
                     }
                     else
                     {
-                        return BdEngineBackend::SQLError;
+                        return BdEngineBackend::QueryState(BdEngineBackend::SQLError);
                     }
                 }
             }
@@ -1631,7 +1714,7 @@ BdEngineBackend::QueryState BdEngineBackend::commitTransaction()
         d->transactionFinished();
     }
 
-    return BdEngineBackend::NoErrors;
+    return BdEngineBackend::QueryState(BdEngineBackend::NoErrors);
 }
 
 bool BdEngineBackend::isInTransaction() const
@@ -1696,4 +1779,4 @@ void BdEngineBackend::setForeignKeyChecks(bool check)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
