@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-06-07
  * Description : Database engine abstract database backend
  *
  * Copyright (C) 2007-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DATABASE_ENGINE_BACKEND_H
-#define DATABASE_ENGINE_BACKEND_H
+#ifndef DIGIKAM_DB_ENGINE_BACKEND_H
+#define DIGIKAM_DB_ENGINE_BACKEND_H
 
 // Qt includes
 
@@ -52,7 +52,7 @@ class DIGIKAM_EXPORT DbEngineLocking
 {
 public:
 
-    DbEngineLocking();
+    explicit DbEngineLocking();
 
 public:
 
@@ -93,6 +93,7 @@ public:
          * opened yet or because of an error condition.
          */
         Unavailable,
+
         /**
          * The database is open. It has not been verified that
          * the schema is up to date.
@@ -101,6 +102,7 @@ public:
          * by a master process.
          */
         Open,
+
         /**
          * The database is open, and it has been verified that the schema is up to
          * date, or the schema has been updated.
@@ -115,18 +117,20 @@ public:
         AbortQueries
     };
 
-    enum DbType{
+    enum DbType
+    {
         SQLite,
         MySQL
     };
 
 public:
 
-    /** Creates a database backend. The backend name is an arbitrary string that
-     *  shall be unique for this backend object.
-     *  It will be used to create unique connection names per backend and thread.
+    /**
+     * Creates a database backend. The backend name is an arbitrary string that
+     * shall be unique for this backend object.
+     * It will be used to create unique connection names per backend and thread.
      */
-    BdEngineBackend(const QString& backendName, DbEngineLocking* const locking);
+    explicit BdEngineBackend(const QString& backendName, DbEngineLocking* const locking);
     BdEngineBackend(const QString& backendName, DbEngineLocking* const locking, BdEngineBackendPrivate& dd);
     ~BdEngineBackend();
 
@@ -158,7 +162,7 @@ public:
         {
         }
 
-        QueryState(const QueryStateEnum value)
+        explicit QueryState(const QueryStateEnum value)    // krazy:exclude=explicit
             : value(value)
         {
         }
@@ -187,12 +191,12 @@ public:
 
     bool isOpen() const
     {
-        return status() > Unavailable;
+        return (status() > Unavailable);
     }
 
     bool isReady() const
     {
-        return status() == OpenSchemaChecked;
+        return (status() == OpenSchemaChecked);
     }
 
     /**
@@ -230,7 +234,7 @@ public:
     /**
      * Performs the database action on the current database.
      * Queries by the specified parameters can have named parameters which are
-     * substituded with values from the bindingMap parameter.
+     * substituted with values from the bindingMap parameter.
      * The result values (if any) are stored within the values list.
      */
     QueryState execDBAction(const DbEngineAction& action, const QMap<QString, QVariant>& bindingMap,
@@ -255,7 +259,7 @@ public:
     /**
      * Performs the database action on the current database.
      * Queries by the specified parameters can have named parameters which are
-     * substituded with values from the bindingMap parameter.
+     * substituted with values from the bindingMap parameter.
      * The result values (if any) are stored within the values list.
      * This method returns the last query, which is used to handle special cases.
      */
@@ -423,6 +427,7 @@ public:
      * Rollback the current database transaction
      */
     void rollbackTransaction();
+
     /**
      * Returns if the database is in a different thread in a transaction.
      * Note that a transaction does not require holding CoreDbAccess.
@@ -500,4 +505,4 @@ private:
 
 Q_DECLARE_METATYPE(QSqlError)
 
-#endif // DATABASE_ENGINE_BACKEND_H
+#endif // DIGIKAM_DB_ENGINE_BACKEND_H
