@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-04-15
  * Description : Database engine abstract database backend
  *
  * Copyright (C) 2007-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DATABASE_ENGINE_BACKEND_P_H
-#define DATABASE_ENGINE_BACKEND_P_H
+#ifndef DIGIKAM_DB_ENGINE_BACKEND_PRIVATE_H
+#define DIGIKAM_DB_ENGINE_BACKEND_PRIVATE_H
 
 // Qt includes
 
@@ -42,11 +42,11 @@
 namespace Digikam
 {
 
-class DbEngineThreadData
+class Q_DECL_HIDDEN DbEngineThreadData
 {
 public:
 
-    DbEngineThreadData();
+    explicit DbEngineThreadData();
     ~DbEngineThreadData();
 
     void closeDatabase();
@@ -130,7 +130,7 @@ public:
 
 public:
 
-    class AbstractUnlocker
+    class Q_DECL_HIDDEN AbstractUnlocker
     {
     public:
 
@@ -149,11 +149,13 @@ public:
 
     // ------------------------------------------------------------------
 
-    class AbstractWaitingUnlocker : public AbstractUnlocker
+    class Q_DECL_HIDDEN AbstractWaitingUnlocker : public AbstractUnlocker
     {
     public:
 
-        AbstractWaitingUnlocker(BdEngineBackendPrivate* const d, QMutex* const mutex, QWaitCondition* const condVar);
+        explicit AbstractWaitingUnlocker(BdEngineBackendPrivate* const d,
+                                         QMutex* const mutex,
+                                         QWaitCondition* const condVar);
         ~AbstractWaitingUnlocker();
 
         bool wait(unsigned long time = ULONG_MAX);
@@ -166,7 +168,7 @@ public:
 
     // ------------------------------------------------------------------
 
-    class ErrorLocker : public AbstractWaitingUnlocker
+    class Q_DECL_HIDDEN ErrorLocker : public AbstractWaitingUnlocker
     {
     public:
 
@@ -176,18 +178,18 @@ public:
 
     // ------------------------------------------------------------------
 
-    class BusyWaiter : public AbstractWaitingUnlocker
+    class Q_DECL_HIDDEN BusyWaiter : public AbstractWaitingUnlocker
     {
     public:
 
         explicit BusyWaiter(BdEngineBackendPrivate* const d);
     };
 
-public :
+public:
 
     BdEngineBackend* const q;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DATABASE_ENGINE_BACKEND_P_H
+#endif // DIGIKAM_DB_ENGINE_BACKEND_PRIVATE_H
