@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-09-05
  * Description : Database engine gui error handler
  *
  * Copyright (C) 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -48,12 +48,12 @@
 namespace Digikam
 {
 
-class DbEngineConnectionChecker::Private
+class Q_DECL_HIDDEN DbEngineConnectionChecker::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         stop    = false;
         success = false;
@@ -83,7 +83,7 @@ void DbEngineConnectionChecker::run()
 {
     QString databaseID(QLatin1String("ConnectionTest"));
 
-    // NOTE: wrap this code into bracket to prevent QtQSL plugin warning. See bug #339074 for details.
+    // NOTE: wrap this code into bracket to prevent QtSQL plugin warning. See bug #339074 for details.
     {
         QSqlDatabase databaseHandler = QSqlDatabase::addDatabase(d->parameters.databaseType, databaseID);
 
@@ -140,12 +140,12 @@ bool DbEngineConnectionChecker::checkSuccessful() const
 
 // ---------------------------------------------------------------------------------------
 
-class DbEngineGuiErrorHandler::Private
+class Q_DECL_HIDDEN DbEngineGuiErrorHandler::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         checker = 0;
     }
@@ -239,4 +239,4 @@ void DbEngineGuiErrorHandler::consultUserForError(DbEngineErrorAnswer* answer, c
     answer->connectionErrorAbortQueries();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
