@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-14
  * Description : Mysql internal database server
  *
  * Copyright (C) 2009-2011 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2016 by Swati Lodha <swatilodha27 at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2016      by Swati Lodha <swatilodha27 at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DATABASE_SERVER_H_
-#define DATABASE_SERVER_H_
+#ifndef DIGIKAM_DATABASE_SERVER_H
+#define DIGIKAM_DATABASE_SERVER_H
 
 // QT includes
 
@@ -60,7 +60,8 @@ public:
 
 public:
 
-    explicit DatabaseServer(const DbEngineParameters& params, DatabaseServerStarter* const parent = DatabaseServerStarter::instance());
+    explicit DatabaseServer(const DbEngineParameters& params,
+                            DatabaseServerStarter* const parent = DatabaseServerStarter::instance());
     virtual ~DatabaseServer();
 
     /**
@@ -143,4 +144,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* DATABASE_SERVER_H_ */
+#endif // DIGIKAM_DATABASE_SERVER_H
