@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-04-02
  * Description : Cache for Tag information
  *
  * Copyright (C) 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,7 +39,7 @@
 #include "coredbaccess.h"
 #include "coredbwatch.h"
 #include "digikam_globals.h"
-#include "imagepropertiestab.h"
+#include "itempropertiestab.h"
 #include "tagproperties.h"
 
 namespace Digikam
@@ -60,12 +60,12 @@ typedef QPair<TagPropertiesConstIterator, TagPropertiesConstIterator> TagPropert
 
 // ------------------------------------------------------------------------------------------
 
-class TagsCache::Private
+class Q_DECL_HIDDEN TagsCache::Private
 {
 public:
 
-    explicit Private(TagsCache* const q) :
-        initialized(false),
+    explicit Private(TagsCache* const q)
+      : initialized(false),
         needUpdateInfos(true),
         needUpdateHash(true),
         needUpdateProperties(true),
@@ -118,7 +118,7 @@ public:
             QWriteLocker locker(&lock);
             nameHash.clear();
 
-            foreach(const TagShortInfo& info, infos)
+            foreach (const TagShortInfo& info, infos)
             {
                 nameHash.insert(info.name, info.id);
             }
@@ -142,7 +142,7 @@ public:
 
             QLatin1String internalProp = TagsCache::propertyNameDigikamInternalTag();
 
-            foreach(const TagProperty& property, tagProperties)
+            foreach (const TagProperty& property, tagProperties)
             {
                 if (property.property == internalProp)
                 {
@@ -177,7 +177,7 @@ public:
         // increment iterator until the next tagid is reached
         int currentId = it->tagId;
 
-        for (++it; it != tagProperties.end(); ++it)
+        for (++it ; it != tagProperties.end() ; ++it)
         {
             if (it->tagId != currentId)
             {
@@ -241,7 +241,7 @@ public:
 
 // ------------------------------------------------------------------------------------------
 
-class ChangingDB
+class Q_DECL_HIDDEN ChangingDB
 {
 public:
 
@@ -260,7 +260,7 @@ public:
 
 // ------------------------------------------------------------------------------------------
 
-class TagsCacheCreator
+class Q_DECL_HIDDEN TagsCacheCreator
 {
 public:
 
@@ -353,7 +353,7 @@ QStringList TagsCache::tagNames(const QList<int>& ids, HiddenTagsPolicy hiddenTa
 
     if (!ids.isEmpty())
     {
-        foreach(int id, ids)
+        foreach (int id, ids)
         {
             if (hiddenTagsPolicy == IncludeHiddenTags || !isInternalTag(id))
             {
@@ -373,7 +373,7 @@ QString TagsCache::tagPath(int id, LeadingSlashPolicy slashPolicy) const
     QReadLocker locker(&d->lock);
     QList<TagShortInfo>::const_iterator it;
 
-    for (it = d->find(id); it != d->infos.constEnd(); it = d->find(it->pid))
+    for (it = d->find(id) ; it != d->infos.constEnd() ; it = d->find(it->pid))
     {
         if (path.isNull())
         {
@@ -394,7 +394,7 @@ QString TagsCache::tagPath(int id, LeadingSlashPolicy slashPolicy) const
 
     if (slashPolicy == IncludeLeadingSlash)
     {
-        path.prepend(QLatin1String("/"));
+        path.prepend(QLatin1Char('/'));
     }
 
     return path;
@@ -407,7 +407,7 @@ QStringList TagsCache::tagPaths(const QList<int>& ids, LeadingSlashPolicy slashP
 
     if (!ids.isEmpty())
     {
-        foreach(int id, ids)
+        foreach (int id, ids)
         {
             if (hiddenTagsPolicy == IncludeHiddenTags || !isInternalTag(id))
             {
@@ -429,7 +429,7 @@ QList<int> TagsCache::tagsForName(const QString& tagName, HiddenTagsPolicy hidde
         QList<int> ids;
         QMultiHash<QString, int>::const_iterator it;
 
-        for (it = d->nameHash.constFind(tagName); it != d->nameHash.constEnd() && it.key() == tagName; ++it)
+        for (it = d->nameHash.constFind(tagName) ; it != d->nameHash.constEnd() && it.key() == tagName ; ++it)
         {
             if (!d->internalTags.contains(it.value()))
             {
@@ -452,7 +452,7 @@ int TagsCache::tagForName(const QString& tagName, int parentId) const
 
     QList<TagShortInfo>::const_iterator tag;
 
-    foreach(int id, d->nameHash.values(tagName))
+    foreach (int id, d->nameHash.values(tagName))
     {
         tag = d->find(id);
 
@@ -503,7 +503,7 @@ QList<int> TagsCache::parentTags(int id) const
          it != d->infos.constEnd() && it->pid;
          it = d->find(it->pid))
     {
-        if((it->pid)!= 0)
+        if ((it->pid) != 0)
             ids.prepend(it->pid);
     }
 
@@ -524,14 +524,14 @@ int TagsCache::tagForPath(const QString& tagPath) const
 
     // last entry in list is the actual tag name
     int tagID       = 0;
-    QString tagName = tagHierarchy.back();
-    tagHierarchy.pop_back();
+    QString tagName = tagHierarchy.last();
+    tagHierarchy.removeLast();
     QList<TagShortInfo>::const_iterator tag, parentTag;
 
     QReadLocker locker(&d->lock);
     // There might be multiple tags with the same name, but in different
     // hierarchies. We must check them all until we find the correct hierarchy
-    foreach(int id, d->nameHash.values(tagName))
+    foreach (int id, d->nameHash.values(tagName))
     {
         tag = d->find(id);
 
@@ -555,8 +555,8 @@ int TagsCache::tagForPath(const QString& tagPath) const
             parentTag = d->find(parentID);
 
             // check if the parent is found and has the name we need
-            if ( parentTag != d->infos.constEnd() &&
-                 parentTag->name == (*parentTagName) )
+            if (parentTag != d->infos.constEnd() &&
+                parentTag->name == (*parentTagName))
             {
                 parentID       = parentTag->pid;
                 foundParentTag = true;
@@ -585,7 +585,7 @@ QList<int> TagsCache::tagsForPaths(const QStringList& tagPaths) const
 
     if (!tagPaths.isEmpty())
     {
-        foreach(const QString& tagPath, tagPaths)
+        foreach (const QString& tagPath, tagPaths)
         {
             ids << tagForPath(tagPath);
         }
@@ -616,7 +616,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
         QReadLocker locker(&d->lock);
 
         // Traverse hierarchy from top to bottom
-        foreach(const QString& tagName, tagHierarchy)
+        foreach (const QString& tagName, tagHierarchy)
         {
             tagID = 0;
 
@@ -627,7 +627,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
                 // find the tag with tag name according to tagHierarchy,
                 // and parent ID identical to the ID of the tag we found in
                 // the previous run.
-                foreach(int id, d->nameHash.values(tagName))
+                foreach (int id, d->nameHash.values(tagName))
                 {
                     tag = d->find(id);
 
@@ -664,7 +664,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
     {
         CoreDbAccess access;
 
-        foreach(const QString& tagName, tagsToCreate)
+        foreach (const QString& tagName, tagsToCreate)
         {
             tagID = access.db()->addTag(parentTagIDForCreation, tagName, QString(), 0);
 
@@ -692,7 +692,7 @@ QList<int> TagsCache::createTags(const QStringList& tagPaths)
 
     if (!tagPaths.isEmpty())
     {
-        foreach(const QString& tagPath, tagPaths)
+        foreach (const QString& tagPath, tagPaths)
         {
             ids << createTag(tagPath);
         }
@@ -707,7 +707,7 @@ QList<int> TagsCache::getOrCreateTags(const QStringList& tagPaths)
 
     if (!tagPaths.isEmpty())
     {
-        foreach(const QString& tagPath, tagPaths)
+        foreach (const QString& tagPath, tagPaths)
         {
             ids << getOrCreateTag(tagPath);
         }
@@ -755,7 +755,7 @@ bool TagsCache::hasProperty(int tagId, const QString& property, const QString& v
     QReadLocker locker(&d->lock);
     TagPropertiesRange range = d->findProperties(tagId);
 
-    for (TagPropertiesConstIterator it = range.first; it != range.second; ++it)
+    for (TagPropertiesConstIterator it = range.first ; it != range.second ; ++it)
     {
         if (d->compareProperty(it, property, value))
         {
@@ -772,7 +772,7 @@ QString TagsCache::propertyValue(int tagId, const QString& property) const
     QReadLocker locker(&d->lock);
     TagPropertiesRange range = d->findProperties(tagId);
 
-    for (TagPropertiesConstIterator it = range.first; it != range.second; ++it)
+    for (TagPropertiesConstIterator it = range.first ; it != range.second ; ++it)
     {
         if (it->property == property)
         {
@@ -790,12 +790,12 @@ QStringList TagsCache::propertyValues(int tagId, const QString& property) const
     TagPropertiesRange range = d->findProperties(tagId);
     QStringList values;
 
-    for (TagPropertiesConstIterator it = range.first; it != range.second; ++it)
+    for (TagPropertiesConstIterator it = range.first ; it != range.second ; ++it)
     {
         if (it->property == property)
         {
             // the list is ordered by property, after id
-            for (; it != range.second && it->property == property; ++it)
+            for (; it != range.second && it->property == property ; ++it)
             {
                 values << it->value;
             }
@@ -815,7 +815,7 @@ QMap<QString, QString> TagsCache::properties(int tagId) const
     TagPropertiesRange range = d->findProperties(tagId);
     QStringList values;
 
-    for (TagPropertiesConstIterator it = range.first; it != range.second; ++it)
+    for (TagPropertiesConstIterator it = range.first ; it != range.second ; ++it)
     {
         map[it->property] = it->value;
     }
@@ -829,7 +829,7 @@ QList<int> TagsCache::tagsWithProperty(const QString& property, const QString& v
     QReadLocker locker(&d->lock);
     QList<int>  ids;
 
-    for (TagPropertiesConstIterator it = d->tagProperties.constBegin(); it != d->tagProperties.constEnd(); )
+    for (TagPropertiesConstIterator it = d->tagProperties.constBegin() ; it != d->tagProperties.constEnd() ;)
     {
         // sort out invalid entries, see bug #277169
         if (it->tagId <= 0)
@@ -890,7 +890,7 @@ QList<int> TagsCache::publicTags(const QList<int>& tagIds) const
 
     QList<int>::const_iterator it, it2;
 
-    for (it = tagIds.begin(); it != tagIds.end(); ++it)
+    for (it = tagIds.begin() ; it != tagIds.end() ; ++it)
     {
         if (d->internalTags.contains(*it))
         {
@@ -907,13 +907,13 @@ QList<int> TagsCache::publicTags(const QList<int>& tagIds) const
     publicIds.reserve(it - tagIds.begin());
 
     // copy to the point of the first internal tag
-    for (it2 = tagIds.begin(); it2 != it; ++it2)
+    for (it2 = tagIds.begin() ; it2 != it ; ++it2)
     {
         publicIds << *it2;
     }
 
     // continue filtering
-    for (; it2 != tagIds.end(); ++it2)
+    for (; it2 != tagIds.end() ; ++it2)
     {
         if (!d->internalTags.contains(*it2))
         {
@@ -929,7 +929,7 @@ bool TagsCache::containsPublicTags(const QList<int>& tagIds) const
     d->checkProperties();
     QReadLocker locker(&d->lock);
 
-    foreach(int id, tagIds)
+    foreach (int id, tagIds)
     {
         if (!d->internalTags.contains(id))
         {
@@ -968,7 +968,7 @@ int TagsCache::getOrCreateInternalTag(const QString& tagName)
 
 void TagsCache::slotTagChanged(const TagChangeset& changeset)
 {
-    if(changeset.operation() == TagChangeset::Deleted)
+    if (changeset.operation() == TagChangeset::Deleted)
     {
         QString name = this->tagName(changeset.tagId());
         emit tagAboutToBeDeleted(name);
@@ -1018,9 +1018,9 @@ int TagsCache::colorLabelFromTags(QList<int> tagIds)
     d->checkLabelTags();
     QReadLocker locker(&d->lock);
 
-    foreach(int tagId, tagIds)
+    foreach (int tagId, tagIds)
     {
-        for (int i=FirstColorLabel; i<=LastColorLabel; i++)
+        for (int i = FirstColorLabel ; i <= LastColorLabel ; ++i)
         {
             if (d->colorLabelsTags[i] == tagId)
             {
@@ -1061,9 +1061,9 @@ int TagsCache::pickLabelFromTags(QList<int> tagIds)
     d->checkLabelTags();
     QReadLocker locker(&d->lock);
 
-    foreach(int tagId, tagIds)
+    foreach (int tagId, tagIds)
     {
-        for (int i=FirstPickLabel; i<=LastPickLabel; i++)
+        for (int i = FirstPickLabel ; i <= LastPickLabel ; ++i)
         {
             if (d->pickLabelsTags[i] == tagId)
             {
@@ -1082,7 +1082,7 @@ QStringList TagsCache::shortenedTagPaths(const QList<int>& ids, QList<int>* sort
     QList<QVariant> variantIds;
 
     // duplicates tagPath(), but we need the additional list of tag ids
-    foreach(int id, ids)
+    foreach (int id, ids)
     {
         if (hiddenTagsPolicy == IncludeHiddenTags || !isInternalTag(id))
         {
@@ -1092,9 +1092,9 @@ QStringList TagsCache::shortenedTagPaths(const QList<int>& ids, QList<int>* sort
     }
 
     // The code is needed in libdigikamcore, so it cannot be moved here. TODO: Find a good place
-    QStringList shortenedPaths = ImagePropertiesTab::shortenedTagPaths(paths, &variantIds);
+    QStringList shortenedPaths = ItemPropertiesTab::shortenedTagPaths(paths, &variantIds);
 
-    foreach(const QVariant& var, variantIds)
+    foreach (const QVariant& var, variantIds)
     {
         (*sortedIds) << var.toInt();
     }
@@ -1105,7 +1105,7 @@ QStringList TagsCache::shortenedTagPaths(const QList<int>& ids, QList<int>* sort
 QStringList TagsCache::shortenedTagPaths(const QList<int>& ids,
                                          LeadingSlashPolicy slashPolicy, HiddenTagsPolicy hiddenTagsPolicy) const
 {
-    return ImagePropertiesTab::shortenedTagPaths(tagPaths(ids, slashPolicy, hiddenTagsPolicy));
+    return ItemPropertiesTab::shortenedTagPaths(tagPaths(ids, slashPolicy, hiddenTagsPolicy));
 }
 
 QList<int> TagsCache::Private::tagsForFragment(bool (QString::*stringFunction)(const QString&, Qt::CaseSensitivity cs) const,
@@ -1114,7 +1114,7 @@ QList<int> TagsCache::Private::tagsForFragment(bool (QString::*stringFunction)(c
                                                      HiddenTagsPolicy hiddenTagsPolicy)
 {
     checkNameHash();
-    QList<int> ids;
+    QMultiMap<QString, int> idsMap;
     QMultiHash<QString, int>::const_iterator it;
     const bool excludeHiddenTags = hiddenTagsPolicy == NoHiddenTags;
 
@@ -1125,25 +1125,25 @@ QList<int> TagsCache::Private::tagsForFragment(bool (QString::*stringFunction)(c
 
     QReadLocker locker(&lock);
 
-    for (it = nameHash.constBegin(); it != nameHash.constEnd(); ++it)
+    for (it = nameHash.constBegin() ; it != nameHash.constEnd() ; ++it)
     {
-        if ( (!excludeHiddenTags || !internalTags.contains(it.value())) && (it.key().*stringFunction)(fragment, caseSensitivity))
+        if ((!excludeHiddenTags || !internalTags.contains(it.value())) && (it.key().*stringFunction)(fragment, caseSensitivity))
         {
-            ids << it.value();
+            idsMap.insert(it.key(), it.value());
         }
     }
 
-    return ids;
+    return idsMap.values();
 }
 
 QList<int> TagsCache::tagsStartingWith(const QString& fragment, Qt::CaseSensitivity caseSensitivity,
-                                      HiddenTagsPolicy hiddenTagsPolicy)
+                                       HiddenTagsPolicy hiddenTagsPolicy)
 {
     return d->tagsForFragment(&QString::startsWith, fragment, caseSensitivity, hiddenTagsPolicy);
 }
 
 QList<int> TagsCache::tagsContaining(const QString& fragment, Qt::CaseSensitivity caseSensitivity,
-                                      HiddenTagsPolicy hiddenTagsPolicy)
+                                     HiddenTagsPolicy hiddenTagsPolicy)
 {
     return d->tagsForFragment(&QString::contains, fragment, caseSensitivity, hiddenTagsPolicy);
 }
