@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-29
  * Description : Thumbnails database interface.
  *
  * Copyright (C)      2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,26 +26,22 @@
 
 // Qt includes
 
-#include <QFile>
-#include <QFileInfo>
-#include <QDir>
+#include <QMap>
 
 // Local includes
 
 #include "digikam_debug.h"
-#include "collectionmanager.h"
-#include "collectionlocation.h"
 
 namespace Digikam
 {
 
-class ThumbsDb::Private
+class Q_DECL_HIDDEN ThumbsDb::Private
 {
 
 public:
 
-    Private() :
-        db(0)
+    explicit Private()
+      : db(0)
     {
     }
 
@@ -68,7 +64,8 @@ bool ThumbsDb::setSetting(const QString& keyword, const QString& value )
     QMap<QString, QVariant> parameters;
     parameters.insert(QLatin1String(":keyword"), keyword);
     parameters.insert(QLatin1String(":value"), value);
-    BdEngineBackend::QueryState queryStateResult = d->db->execDBAction(d->db->getDBAction(QLatin1String("ReplaceThumbnailSetting")), parameters);
+    BdEngineBackend::QueryState queryStateResult = d->db->execDBAction(d->db->getDBAction(QLatin1String("ReplaceThumbnailSetting")),
+                                                                       parameters);
 
     return (queryStateResult == BdEngineBackend::NoErrors);
 }
@@ -79,17 +76,18 @@ QString ThumbsDb::getSetting(const QString& keyword)
     parameters.insert(QLatin1String(":keyword"), keyword);
     QList<QVariant> values;
     // TODO Should really check return status here
-    BdEngineBackend::QueryState queryStateResult = d->db->execDBAction(d->db->getDBAction(QLatin1String("SelectThumbnailSetting")), parameters, &values);
-    qCDebug(DIGIKAM_THUMBSDB_LOG) << "ThumbDB SelectThumbnailSetting val ret = " << (BdEngineBackend::QueryStateEnum)queryStateResult;
+    BdEngineBackend::QueryState queryStateResult = d->db->execDBAction(d->db->getDBAction(QLatin1String("SelectThumbnailSetting")),
+                                                                       parameters, &values);
 
-    if (values.isEmpty())
-    {
-        return QString();
-    }
-    else
+    qCDebug(DIGIKAM_THUMBSDB_LOG) << "ThumbDB SelectThumbnailSetting val ret = "
+                                  << (BdEngineBackend::QueryStateEnum)queryStateResult;
+
+    if (!values.isEmpty())
     {
         return values.first().toString();
     }
+
+    return QString();
 }
 
 QString ThumbsDb::getLegacySetting(const QString& keyword)
@@ -98,62 +96,60 @@ QString ThumbsDb::getLegacySetting(const QString& keyword)
     parameters.insert(QLatin1String(":keyword"), keyword);
     QList<QVariant> values;
     // TODO Should really check return status here
-    BdEngineBackend::QueryState queryStateResult = d->db->execDBAction(d->db->getDBAction(QLatin1String("SelectThumbnailLegacySetting")), parameters, &values);
-    qCDebug(DIGIKAM_THUMBSDB_LOG) << "ThumbDB SelectThumbnailLegacySetting val ret = " << (BdEngineBackend::QueryStateEnum)queryStateResult;
+    BdEngineBackend::QueryState queryStateResult = d->db->execDBAction(d->db->getDBAction(QLatin1String("SelectThumbnailLegacySetting")),
+                                                                       parameters, &values);
 
-    if (values.isEmpty())
-    {
-        return QString();
-    }
-    else
+    qCDebug(DIGIKAM_THUMBSDB_LOG) << "ThumbDB SelectThumbnailLegacySetting val ret = "
+                                  << (BdEngineBackend::QueryStateEnum)queryStateResult;
+
+    if (!values.isEmpty())
     {
         return values.first().toString();
     }
+
+    return QString();
 }
 
-static void fillThumbnailInfo(const QList<QVariant> &values, ThumbsDbInfo& info)
+ThumbsDbInfo ThumbsDb::fillThumbnailInfo(const QList<QVariant>& values)
 {
     if (values.isEmpty())
     {
-        return;
+        return ThumbsDbInfo();
     }
 
+    ThumbsDbInfo info;
+
     info.id               = values.at(0).toInt();
     info.type             = (DatabaseThumbnail::Type)values.at(1).toInt();
-    info.modificationDate = values.at(2).isNull() ? QDateTime() : QDateTime::fromString(values.at(2).toString(), Qt::ISODate);
+    info.modificationDate = values.at(2).toDateTime();
     info.orientationHint  = values.at(3).toInt();
     info.data             = values.at(4).toByteArray();
+
+    return info;
 }
 
 ThumbsDbInfo ThumbsDb::findByHash(const QString& uniqueHash, qlonglong fileSize)
 {
     QList<QVariant> values;
     d->db->execSql(QLatin1String("SELECT id, type, modificationDate, orientationHint, data "
-                                 "FROM UniqueHashes "
-                                 "   INNER JOIN Thumbnails ON thumbId = id "
-                                 "WHERE uniqueHash=? AND fileSize=?;"),
-                   uniqueHash, fileSize,
-                   &values );
+                                 "FROM Thumbnails "
+                                 " INNER JOIN UniqueHashes ON id = thumbId "
+                                 "  WHERE uniqueHash=? AND fileSize=?;"),
+                   uniqueHash, fileSize, &values);
 
-    ThumbsDbInfo info;
-    fillThumbnailInfo(values, info);
-    return info;
+    return fillThumbnailInfo(values);
 }
 
 ThumbsDbInfo ThumbsDb::findByFilePath(const QString& path)
 {
     QList<QVariant> values;
     d->db->execSql(QLatin1String("SELECT id, type, modificationDate, orientationHint, data "
-                                 "FROM FilePaths "
-                                 "   INNER JOIN Thumbnails ON thumbId = id "
-                                 "WHERE path=?;"),
-                   path,
-                   &values );
+                                 "FROM Thumbnails "
+                                 " INNER JOIN FilePaths ON id = thumbId "
+                                 "  WHERE path=?;"),
+                   path, &values);
 
-    ThumbsDbInfo info;
-    fillThumbnailInfo(values, info);
-
-    return info;
+    return fillThumbnailInfo(values);
 }
 
 ThumbsDbInfo ThumbsDb::findByFilePath(const QString& path, const QString& uniqueHash)
@@ -179,56 +175,54 @@ ThumbsDbInfo ThumbsDb::findByFilePath(const QString& path, const QString& unique
     {
         return info;
     }
-    else
-    {
-        foreach(const QVariant& hash, values)
-        {
-            if (hash == uniqueHash)
-            {
-                return info;
-            }
-        }
 
-        return ThumbsDbInfo();
+    foreach (const QVariant& hash, values)
+    {
+        if (hash == uniqueHash)
+        {
+            return info;
+        }
     }
+
+    return ThumbsDbInfo();
 }
 
 ThumbsDbInfo ThumbsDb::findByCustomIdentifier(const QString& id)
 {
     QList<QVariant> values;
     d->db->execSql(QLatin1String("SELECT id, type, modificationDate, orientationHint, data "
-                                 "FROM CustomIdentifiers "
-                                 "   INNER JOIN Thumbnails ON thumbId = id "
-                                 "WHERE identifier=?;"),
-                   id,
-                   &values);
+                                 "FROM Thumbnails "
+                                 " INNER JOIN CustomIdentifiers ON id = thumbId "
+                                 "  WHERE identifier=?;"),
+                   id, &values);
 
-    ThumbsDbInfo info;
-    fillThumbnailInfo(values, info);
-    return info;
+    return fillThumbnailInfo(values);
 }
 
 QList<int> ThumbsDb::findAll()
 {
     QList<QVariant> values;
-    d->db->execSql(QLatin1String("SELECT id FROM Thumbnails;"),&values);
+    d->db->execSql(QLatin1String("SELECT id FROM Thumbnails;"),
+                   &values);
 
     QList<int> thumbIds;
-    foreach (QVariant object, values)
+
+    foreach (const QVariant& object, values)
     {
         thumbIds << object.toInt();
     }
+
     return thumbIds;
 }
 
 QHash<QString, int> ThumbsDb::getFilePathsWithThumbnail()
 {
-    DbEngineSqlQuery query = d->db->prepareQuery(QString::fromLatin1("SELECT path, id "
-                                                             "FROM FilePaths "
-                                                             "   INNER JOIN Thumbnails ON FilePaths.thumbId=Thumbnails.id "
-                                                             "WHERE type BETWEEN %1 AND %2;")
-                                         .arg(DatabaseThumbnail::PGF)
-                                         .arg(DatabaseThumbnail::PNG));
+    DbEngineSqlQuery query = d->db->prepareQuery(QString::fromLatin1("SELECT path, thumbId "
+                                                        "FROM FilePaths "
+                                                        " INNER JOIN Thumbnails ON thumbId = id "
+                                                        "  WHERE type BETWEEN %1 AND %2;")
+                                                 .arg(DatabaseThumbnail::PGF)
+                                                 .arg(DatabaseThumbnail::PNG));
 
     if (!d->db->exec(query))
     {
@@ -275,7 +269,8 @@ BdEngineBackend::QueryState ThumbsDb::removeByUniqueHash(const QString& uniqueHa
     parameters.insert(QLatin1String(":uniqueHash"), uniqueHash);
     parameters.insert(QLatin1String(":filesize"),   fileSize);
 
-    return d->db->execDBAction(d->db->getDBAction(QLatin1String("Delete_Thumbnail_ByUniqueHashId")), parameters);
+    return d->db->execDBAction(d->db->getDBAction(QLatin1String("Delete_Thumbnail_ByUniqueHashId")),
+                               parameters);
 }
 
 BdEngineBackend::QueryState ThumbsDb::removeByFilePath(const QString& path)
@@ -284,7 +279,8 @@ BdEngineBackend::QueryState ThumbsDb::removeByFilePath(const QString& path)
     QMap<QString, QVariant> parameters;
     parameters.insert(QLatin1String(":path"), path);
 
-    return d->db->execDBAction(d->db->getDBAction(QLatin1String("Delete_Thumbnail_ByPath")), parameters);
+    return d->db->execDBAction(d->db->getDBAction(QLatin1String("Delete_Thumbnail_ByPath")),
+                               parameters);
 }
 
 BdEngineBackend::QueryState ThumbsDb::removeByCustomIdentifier(const QString& id)
@@ -293,7 +289,8 @@ BdEngineBackend::QueryState ThumbsDb::removeByCustomIdentifier(const QString& id
     QMap<QString, QVariant> parameters;
     parameters.insert(QLatin1String(":identifier"), id);
 
-    return d->db->execDBAction(d->db->getDBAction(QLatin1String("Delete_Thumbnail_ByCustomIdentifier")), parameters);
+    return d->db->execDBAction(d->db->getDBAction(QLatin1String("Delete_Thumbnail_ByCustomIdentifier")),
+                               parameters);
 }
 
 BdEngineBackend::QueryState ThumbsDb::insertThumbnail(const ThumbsDbInfo& info, QVariant* const lastInsertId)
@@ -301,21 +298,26 @@ BdEngineBackend::QueryState ThumbsDb::insertThumbnail(const ThumbsDbInfo& info,
     QVariant id;
     BdEngineBackend::QueryState lastQueryState;
     lastQueryState = d->db->execSql(QLatin1String("INSERT INTO Thumbnails (type, modificationDate, orientationHint, data) VALUES (?, ?, ?, ?);"),
-                                    info.type, info.modificationDate, info.orientationHint, info.data,
-                                    0, &id);
+                                    info.type, info.modificationDate, info.orientationHint, info.data, 0, &id);
 
     if (BdEngineBackend::NoErrors == lastQueryState)
     {
-        *lastInsertId=id.toInt();
+        *lastInsertId = id.toInt();
     }
     else
     {
-        *lastInsertId=-1;
+        *lastInsertId = -1;
     }
 
     return lastQueryState;
 }
 
+BdEngineBackend::QueryState ThumbsDb::renameByFilePath(const QString& oldPath, const QString& newPath)
+{
+    return d->db->execSql(QLatin1String("UPDATE FilePaths SET path=? WHERE path=?;"),
+                          newPath, oldPath);
+}
+
 BdEngineBackend::QueryState ThumbsDb::replaceThumbnail(const ThumbsDbInfo& info)
 {
     return d->db->execSql(QLatin1String("REPLACE INTO Thumbnails (id, type, modificationDate, orientationHint, data) VALUES(?, ?, ?, ?, ?);"),
@@ -324,7 +326,8 @@ BdEngineBackend::QueryState ThumbsDb::replaceThumbnail(const ThumbsDbInfo& info)
 
 BdEngineBackend::QueryState ThumbsDb::updateModificationDate(int thumbId, const QDateTime& modificationDate)
 {
-    return d->db->execSql(QLatin1String("UPDATE Thumbnails SET modificationDate=? WHERE id=?;"), modificationDate, thumbId);
+    return d->db->execSql(QLatin1String("UPDATE Thumbnails SET modificationDate=? WHERE id=?;"),
+                          modificationDate, thumbId);
 }
 
 void ThumbsDb::replaceUniqueHash(const QString& oldUniqueHash, int oldFileSize,
@@ -337,7 +340,9 @@ void ThumbsDb::replaceUniqueHash(const QString& oldUniqueHash, int oldFileSize,
 bool ThumbsDb::integrityCheck()
 {
     QList<QVariant> values;
-    d->db->execDBAction(d->db->getDBAction(QString::fromUtf8("checkThumbnailsDbIntegrity")), &values);
+    d->db->execDBAction(d->db->getDBAction(QString::fromUtf8("checkThumbnailsDbIntegrity")),
+                        &values);
+
     switch (d->db->databaseType())
     {
         case BdEngineBackend::DbType::SQLite:
@@ -347,12 +352,12 @@ bool ThumbsDb::integrityCheck()
             // For MySQL, for every checked table, the table name, operation (check), message type (status) and the message text (ok on success)
             // are returned. So we check if there are four elements and if yes, whether the fourth element is "ok".
             //qCDebug(DIGIKAM_DATABASE_LOG) << "MySQL check returned " << values.size() << " rows";
-            if ( (values.size() % 4) != 0)
+            if ((values.size() % 4) != 0)
             {
                 return false;
             }
 
-            for (QList<QVariant>::iterator it = values.begin(); it != values.end(); )
+            for (QList<QVariant>::iterator it = values.begin() ; it != values.end() ;)
             {
                 QString tableName   = (*it).toString();
                 ++it;
@@ -365,7 +370,8 @@ bool ThumbsDb::integrityCheck()
 
                 if (messageText.toLower().compare(QLatin1String("ok")) != 0)
                 {
-                    qCDebug(DIGIKAM_DATABASE_LOG) << "Failed integrity check for table " << tableName << ". Reason:" << messageText;
+                    qCDebug(DIGIKAM_DATABASE_LOG) << "Failed integrity check for table " << tableName
+                                                  << ". Reason:" << messageText;
                     return false;
                 }
                 else
@@ -385,4 +391,4 @@ void ThumbsDb::vacuum()
     d->db->execDBAction(d->db->getDBAction(QString::fromUtf8("vacuumThumbnailsDB")));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
