@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-29
  * Description : Thumbnails database interface.
  *
  * Copyright (C)      2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,18 +22,15 @@
  *
  * ============================================================ */
 
-#ifndef THUMBNAILS_DATABASE_H
-#define THUMBNAILS_DATABASE_H
+#ifndef DIGIKAM_THUMBS_DB_H
+#define DIGIKAM_THUMBS_DB_H
 
 // Qt includes
 
-#include <QString>
-#include <QList>
-#include <QStringList>
 #include <QDateTime>
-#include <QPair>
-#include <QMap>
+#include <QString>
 #include <QHash>
+#include <QList>
 
 // Local includes
 
@@ -66,7 +63,7 @@ class DIGIKAM_EXPORT ThumbsDbInfo
 
 public:
 
-    ThumbsDbInfo()
+    explicit ThumbsDbInfo()
         : id(-1),
           type(DatabaseThumbnail::UndefinedType),
           orientationHint(0)
@@ -117,6 +114,8 @@ public:
     BdEngineBackend::QueryState removeByFilePath(const QString& path);
     BdEngineBackend::QueryState removeByCustomIdentifier(const QString& id);
 
+    BdEngineBackend::QueryState renameByFilePath(const QString& oldPath, const QString& newPath);
+
     BdEngineBackend::QueryState insertThumbnail(const ThumbsDbInfo& info, QVariant* const lastInsertId = 0);
     BdEngineBackend::QueryState replaceThumbnail(const ThumbsDbInfo& info);
 
@@ -125,8 +124,6 @@ public:
     void replaceUniqueHash(const QString& oldUniqueHash, int oldFileSize, const QString& newUniqueHash, int newFileSize);
     BdEngineBackend::QueryState updateModificationDate(int thumbId, const QDateTime& modificationDate);
 
-    //QStringList getAllThumbnailPaths();
-
     // ----------- Database shrinking methods ----------
 
     /**
@@ -144,14 +141,18 @@ private:
     explicit ThumbsDb(ThumbsDbBackend* const backend);
     ~ThumbsDb();
 
+    ThumbsDbInfo fillThumbnailInfo(const QList<QVariant>& values);
+
 private:
 
+    ThumbsDb(const ThumbsDb&); // Disable
+
     class Private;
     Private* const d;
 
     friend class ThumbsDbAccess;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* THUMBNAILS_DATABASE_H */
+#endif // DIGIKAM_THUMBS_DB_H
