@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-18
  * Description : Database access wrapper.
  *
  * Copyright (C) 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,18 +38,18 @@
 #include "digikam_debug.h"
 #include "thumbsdbbackend.h"
 #include "thumbsdb.h"
-#include "thumbsdbchemaupdater.h"
+#include "thumbsdbschemaupdater.h"
 #include "dbengineparameters.h"
 #include "dbengineaccess.h"
 
 namespace Digikam
 {
 
-class ThumbsDbAccessStaticPriv
+class Q_DECL_HIDDEN ThumbsDbAccessStaticPriv
 {
 public:
 
-    ThumbsDbAccessStaticPriv()
+    explicit ThumbsDbAccessStaticPriv()
         : backend(0),
           db(0),
           initializing(false)
@@ -73,7 +73,7 @@ ThumbsDbAccessStaticPriv* ThumbsDbAccess::d = 0;
 
 // -----------------------------------------------------------------------------
 
-class ThumbsDbAccessMutexLocker : public QMutexLocker
+class Q_DECL_HIDDEN ThumbsDbAccessMutexLocker : public QMutexLocker
 {
 public:
 
@@ -279,4 +279,4 @@ void ThumbsDbAccess::cleanUpDatabase()
     d = 0;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
