@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Matthias Kretz <kretz at kde dot org>
  *
  * This program is free software; you can redistribute it
@@ -61,12 +61,11 @@ DConfigDlgModel::~DConfigDlgModel()
 
 // ----------------------------------------------------------------------------------
 
-
-class DConfigDlgWdgItem::Private
+class Q_DECL_HIDDEN DConfigDlgWdgItem::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : checkable(false),
           checked(false),
           enabled(true)
@@ -303,7 +302,7 @@ void PageItem::dump(int indent)
 
     for (int i = 0; i < indent; ++i)
     {
-        prefix.append(QLatin1String(" "));
+        prefix.append(QLatin1Char(' '));
     }
 
     const QString name = (mPageWidgetItem ? mPageWidgetItem->name() : QLatin1String("root"));
@@ -317,7 +316,7 @@ void PageItem::dump(int indent)
 
 // ---------------------------------------------------------------------------------
 
-DConfigDlgWdgModel::DConfigDlgWdgModel(QObject* parent)
+DConfigDlgWdgModel::DConfigDlgWdgModel(QObject* const parent)
     : DConfigDlgModel(*new DConfigDlgWdgModelPrivate, parent)
 {
 }
@@ -701,6 +700,6 @@ QModelIndex DConfigDlgWdgModel::index(const DConfigDlgWdgItem* item) const
     return createIndex(pageItem->row(), 0, (void*)pageItem);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
 
 #include "moc_dconfigdlgmodels.cpp"
