@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006      by Tobias Koenig <tokoe at kde dot org>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DBCONFIGDLG_VIEW_H
-#define DBCONFIGDLG_VIEW_H
+#ifndef DIGIKAM_DCONFIG_DLG_VIEW_H
+#define DIGIKAM_DCONFIG_DLG_VIEW_H
 
 // Qt includes
 
@@ -31,6 +31,8 @@
 
 // Local includes
 
+#include "digikam_export.h"
+
 class QAbstractItemDelegate;
 class QAbstractItemView;
 class QModelIndex;
@@ -53,7 +55,7 @@ class DConfigDlgModel;
  * types are available. @see DConfigDlgWdg
  *
  */
-class DConfigDlgView : public QWidget
+class DIGIKAM_EXPORT DConfigDlgView : public QWidget
 {
     Q_OBJECT
     Q_ENUMS(FaceType)
@@ -201,6 +203,6 @@ private:
     Q_PRIVATE_SLOT(d_func(), void _k_dataChanged(const QModelIndex&, const QModelIndex&))
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DBCONFIGDLG_VIEW_H
+#endif // DIGIKAM_DCONFIG_DLG_VIEW_H
