@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Rafael Fernández López <ereslibre at kde dot org>
  * Copyright (C) 2006      by Tobias Koenig <tokoe at kde dot org>
  *
@@ -223,7 +223,7 @@ DConfigDlgTabbedView::DConfigDlgTabbedView(QWidget* const parent)
     setFrameShape(NoFrame);
 
     QVBoxLayout* const layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     mTabWidget = new QTabWidget(this);
 
@@ -546,7 +546,7 @@ void DConfigDlgListViewDelegate::drawFocus(QPainter* painter, const QStyleOption
         QPalette::ColorGroup cg  = (option.state & QStyle::State_Enabled)
                                    ? QPalette::Normal : QPalette::Disabled;
         o.backgroundColor        = option.palette.color(cg, (option.state & QStyle::State_Selected)
-                                   ? QPalette::Highlight : QPalette::Background);
+                                   ? QPalette::Highlight : QPalette::Window);
 
         QApplication::style()->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter);
     }
@@ -707,4 +707,4 @@ void SelectionModel::select(const QItemSelection& selection, QItemSelectionModel
     QItemSelectionModel::select(selection, command);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
