@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006      by Tobias Koenig <tokoe at kde dot org>
  *
  * This program is free software; you can redistribute it
@@ -109,7 +109,7 @@ DConfigDlgWdgItem* DConfigDlgWdg::addPage(QWidget* widget, const QString& name)
     // force layout margin to zero so that it aligns well with title widget
     if (widget->layout())
     {
-        widget->layout()->setMargin(0);
+        widget->layout()->setContentsMargins(0, 0, 0, 0);
     }
 
     return d_func()->model()->addPage(widget, name);
@@ -142,7 +142,7 @@ void DConfigDlgWdg::addSubPage(DConfigDlgWdgItem* parent, DConfigDlgWdgItem* ite
 
 void DConfigDlgWdg::removePage(DConfigDlgWdgItem* item)
 {
-    emit pageRemoved(item); // Q_EMIT signal before we remove it, because the item will be deleted in the model
+    emit pageRemoved(item); // Emit signal before we remove it, because the item will be deleted in the model
     d_func()->model()->removePage(item);
 }
 
@@ -208,7 +208,7 @@ DConfigDlgTitle::DConfigDlgTitle(QWidget* const parent)
 
     QVBoxLayout* const mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(titleFrame);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     setLayout(mainLayout);
 }
 
@@ -376,6 +376,6 @@ void DConfigDlgTitle::showEvent(QShowEvent* event)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
 
 #include "moc_dconfigdlgwidgets.cpp"
