@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006      by Tobias Koenig <tokoe at kde dot org>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DBCONFIGDLG_WIDGETS_H
-#define DBCONFIGDLG_WIDGETS_H
+#ifndef DIGIKAM_DCONFIG_DLG_WIDGETS_H
+#define DIGIKAM_DCONFIG_DLG_WIDGETS_H
 
 // Qt includes
 
@@ -39,6 +39,7 @@ namespace Digikam
 {
 
 class DConfigDlgWdgPrivate;
+
 /**
  * @short Page widget with many layouts (faces).
  * @see DConfigDlgView with hierarchical page model.
@@ -143,7 +144,7 @@ Q_SIGNALS:
     /**
      * This signal is emitted whenever the current page has changed.
      *
-     * @param item The new current page or 0 if no current page is available.
+     * @param current The new current page or 0 if no current page is available.
      */
     void currentPageChanged(DConfigDlgWdgItem* current, DConfigDlgWdgItem* before);
 
@@ -217,7 +218,7 @@ public:
 public:
 
     /**
-     * Constructs a title widget with the given @param parent.
+     * Constructs a title widget with the given @param parent .
      */
     explicit DConfigDlgTitle(QWidget* const parent = 0);
 
@@ -336,6 +337,6 @@ private:
     Q_DISABLE_COPY(DConfigDlgTitle)
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DBCONFIGDLG_WIDGETS_H
+#endif // DIGIKAM_DCONFIG_DLG_WIDGETS_H
