@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Matthias Kretz <kretz at kde dot org>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DBCONFIGDLG_WIDGETS_P_H
-#define DBCONFIGDLG_WIDGETS_P_H
+#ifndef DIGIKAM_DCONFIG_DLG_WIDGETS_PRIVATE_H
+#define DIGIKAM_DCONFIG_DLG_WIDGETS_PRIVATE_H
 
 #include "dconfigdlgwidgets.h"
 #include "dconfigdlgview_p.h"
@@ -38,13 +38,13 @@ namespace Digikam
 
 class DConfigDlgWdgModel;
 
-class DConfigDlgWdgPrivate : public DConfigDlgViewPrivate
+class Q_DECL_HIDDEN DConfigDlgWdgPrivate : public DConfigDlgViewPrivate
 {
     Q_DECLARE_PUBLIC(DConfigDlgWdg)
 
 protected:
 
-    DConfigDlgWdgPrivate(DConfigDlgWdg* const q);
+    explicit DConfigDlgWdgPrivate(DConfigDlgWdg* const q);
 
     DConfigDlgWdgModel* model() const
     {
@@ -56,11 +56,11 @@ protected:
 
 // -----------------------------------------------------------------------------------
 
-class DConfigDlgTitle::Private
+class Q_DECL_HIDDEN DConfigDlgTitle::Private
 {
 public:
 
-    Private(DConfigDlgTitle* const parent)
+    explicit Private(DConfigDlgTitle* const parent)
         : q(parent),
           headerLayout(0),
           imageLabel(0),
@@ -145,6 +145,6 @@ public:
     MessageType      messageType;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DBCONFIGDLG_WIDGETS_P_H
+#endif // DIGIKAM_DCONFIG_DLG_WIDGETS_PRIVATE_H
