@@ -1,16 +1,16 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-07
  * Description : a dialog to delete item.
  *
- * Copyright (C) 2004      by Michael Pyne <michael.pyne@kdemail.net>
- * Copyright (C) 2006      by Ian Monroe <ian@monroe.nu>
+ * Copyright (C) 2004      by Michael Pyne <michael dot pyne at kdemail dot net>
+ * Copyright (C) 2006      by Ian Monroe <ian at monroe dot nu>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -58,12 +58,12 @@
 namespace Digikam
 {
 
-class DeleteItem::Private
+class Q_DECL_HIDDEN DeleteItem::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         hasThumb = false;
     }
@@ -151,12 +151,12 @@ void DeleteItem::setThumb(const QPixmap& pix, bool hasThumb)
 
 //----------------------------------------------------------------------------
 
-class DeleteItemList::Private
+class Q_DECL_HIDDEN DeleteItemList::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
         : iconSize(64)
     {
         thumbLoadThread = 0;
@@ -229,11 +229,11 @@ void DeleteItemList::drawRow(QPainter* p, const QStyleOptionViewItem& opt, const
 
 //----------------------------------------------------------------------------
 
-class DeleteWidget::Private
+class Q_DECL_HIDDEN DeleteWidget::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         checkBoxStack   = 0;
         warningIcon     = 0;
@@ -462,11 +462,11 @@ void DeleteWidget::updateText()
 
 //----------------------------------------------------------------------------
 
-class DeleteDialog::Private
+class Q_DECL_HIDDEN DeleteDialog::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         saveShouldDeleteUserPreference = true;
         saveDoNotShowAgainTrash        = false;
@@ -654,7 +654,7 @@ void DeleteDialog::setListMode(DeleteDialogMode::ListMode mode)
 
 void DeleteDialog::keyPressEvent(QKeyEvent* e)
 {
-    if ( e->modifiers() == 0 )
+    if (e->modifiers() == 0)
     {
         if (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Return)
         {
