@@ -1,16 +1,16 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-07
  * Description : a dialog to delete item.
  *
- * Copyright (C) 2004      by Michael Pyne <michael.pyne@kdemail.net>
- * Copyright (C) 2006      by Ian Monroe <ian@monroe.nu>
+ * Copyright (C) 2004      by Michael Pyne <michael dot pyne at kdemail dot net>
+ * Copyright (C) 2006      by Ian Monroe <ian at monroe dot nu>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,8 +25,8 @@
  *
  * ============================================================ */
 
-#ifndef DELETEDIALOG_H
-#define DELETEDIALOG_H
+#ifndef DIGIKAM_DELETE_DIALOG_H
+#define DIGIKAM_DELETE_DIALOG_H
 
 // Qt includes
 
@@ -71,7 +71,7 @@ class DeleteItem : public QTreeWidgetItem
 
 public:
 
-    DeleteItem(QTreeWidget* const parent, const QUrl& url);
+    explicit DeleteItem(QTreeWidget* const parent, const QUrl& url);
     virtual ~DeleteItem();
 
     bool    hasValidThumbnail() const;
@@ -188,4 +188,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DELETEDIALOG_H
+#endif // DIGIKAM_DELETE_DIALOG_H
