@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-30-08
  * Description : a progress dialog for digiKam
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DPROGRESSDLG_H
-#define DPROGRESSDLG_H
+#ifndef DIGIKAM_DPROGRESS_DLG_H
+#define DIGIKAM_DPROGRESS_DLG_H
 
 // Qt includes
 
@@ -75,6 +75,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif  // DPROGRESSDLG_H
+#endif // DIGIKAM_DPROGRESS_DLG_H
