@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-03-13
  * Description : image files selector dialog.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,12 +54,12 @@
 namespace Digikam
 {
 
-class ImageDialogPreview::Private
+class Q_DECL_HIDDEN ImageDialogPreview::Private
 {
 public:
 
-    Private() :
-        imageLabel(0),
+    explicit Private()
+      : imageLabel(0),
         infoLabel(0),
         thumbLoadThread(0)
     {
@@ -142,9 +142,9 @@ void ImageDialogPreview::slotShowPreview(const QUrl& url)
         if (!info.isEmpty())
         {
             DToolTipStyleSheet cnt;
-            QString identify = QString::fromLatin1("<qt><center>");
+            QString identify = QLatin1String("<qt><center>");
             QString make, model, dateTime, aperture, focalLength, exposureTime, sensitivity;
-            QString aspectRatio, audioBitRate, audioChannelType, audioCompressor, duration, frameRate, videoCodec;
+            QString aspectRatio, audioBitRate, audioChannelType, audioCodec, duration, frameRate, videoCodec;
 
             if (info.make.isEmpty())
             {
@@ -236,13 +236,13 @@ void ImageDialogPreview::slotShowPreview(const QUrl& url)
                 audioChannelType = videoInfo.audioChannelType;
             }
 
-            if (videoInfo.audioCompressor.isEmpty())
+            if (videoInfo.audioCodec.isEmpty())
             {
-                audioCompressor = cnt.unavailable;
+                audioCodec = cnt.unavailable;
             }
             else
             {
-                audioCompressor = videoInfo.audioCompressor;
+                audioCodec = videoInfo.audioCodec;
             }
 
             if (videoInfo.duration.isEmpty())
@@ -272,7 +272,7 @@ void ImageDialogPreview::slotShowPreview(const QUrl& url)
                 videoCodec = videoInfo.videoCodec;
             }
 
-            identify += QString::fromLatin1("<table cellspacing=0 cellpadding=0>");
+            identify += QLatin1String("<table cellspacing=0 cellpadding=0>");
             identify += cnt.cellBeg + i18n("<i>Make:</i>")              + cnt.cellMid + make                + cnt.cellEnd;
             identify += cnt.cellBeg + i18n("<i>Model:</i>")             + cnt.cellMid + model               + cnt.cellEnd;
             identify += cnt.cellBeg + i18n("<i>Created:</i>")           + cnt.cellMid + dateTime            + cnt.cellEnd;
@@ -286,13 +286,13 @@ void ImageDialogPreview::slotShowPreview(const QUrl& url)
                 identify += cnt.cellBeg + i18n("<i>AspectRatio:</i>")       + cnt.cellMid + aspectRatio         + cnt.cellEnd;
                 identify += cnt.cellBeg + i18n("<i>AudioBitRate:</i>")      + cnt.cellMid + audioBitRate        + cnt.cellEnd;
                 identify += cnt.cellBeg + i18n("<i>AudioChannelType:</i>")  + cnt.cellMid + audioChannelType    + cnt.cellEnd;
-                identify += cnt.cellBeg + i18n("<i>AudioCompressor:</i>")   + cnt.cellMid + audioCompressor     + cnt.cellEnd;
+                identify += cnt.cellBeg + i18n("<i>AudioCodec:</i>")   + cnt.cellMid + audioCodec     + cnt.cellEnd;
                 identify += cnt.cellBeg + i18n("<i>Duration:</i>")          + cnt.cellMid + duration            + cnt.cellEnd;
                 identify += cnt.cellBeg + i18n("<i>FrameRate:</i>")         + cnt.cellMid + frameRate           + cnt.cellEnd;
                 identify += cnt.cellBeg + i18n("<i>VideoCodec:</i>")        + cnt.cellMid + videoCodec          + cnt.cellEnd;
             }
 
-            identify += QString::fromLatin1("</table></center></qt>");
+            identify += QLatin1String("</table></center></qt>");
 
             d->infoLabel->setText(identify);
         }
@@ -394,12 +394,12 @@ QIcon DFileIconProvider::icon(const QFileInfo& info) const
 */
 // ------------------------------------------------------------------------
 
-class ImageDialog::Private
+class Q_DECL_HIDDEN ImageDialog::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
@@ -421,8 +421,8 @@ ImageDialog::ImageDialog(QWidget* const parent, const QUrl& url, bool singleSele
     dlg->setIconProvider(provider);
     dlg->setNameFilters(d->fileFormats);
     dlg->selectNameFilter(d->fileFormats.last());
-    dlg->setAcceptMode(DFileDialog::AcceptOpen);
-    dlg->setFileMode(singleSelect ? DFileDialog::ExistingFile : DFileDialog::ExistingFiles);
+    dlg->setAcceptMode(QFileDialog::AcceptOpen);
+    dlg->setFileMode(singleSelect ? QFileDialog::ExistingFile : QFileDialog::ExistingFiles);
 
     dlg->exec();
     d->urls = dlg->selectedUrls();
