@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-03-13
  * Description : image files selector dialog.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEDIALOG_H
-#define IMAGEDIALOG_H
+#ifndef DIGIKAM_IMAGE_DIALOG_H
+#define DIGIKAM_IMAGE_DIALOG_H
 
 // Qt includes
 
@@ -99,7 +99,10 @@ class DIGIKAM_EXPORT ImageDialog
 
 public:
 
-    ImageDialog(QWidget* const parent, const QUrl& url, bool singleSelect=false, const QString& caption=QString());
+    explicit ImageDialog(QWidget* const parent,
+                         const QUrl& url,
+                         bool singleSelect=false,
+                         const QString& caption=QString());
     ~ImageDialog();
 
     QUrl        url()         const;
@@ -111,10 +114,12 @@ public:
 
 private:
 
+    ImageDialog(const ImageDialog&); // Disable
+
     class Private;
     Private* const d;
 };
 
 } // namespace Digikam
 
-#endif /* IMAGEDIALOG_H */
+#endif // DIGIKAM_IMAGE_DIALOG_H
