@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-07-11
  * Description : general info list dialog
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -53,11 +53,11 @@
 namespace Digikam
 {
 
-class InfoDlg::Private
+class Q_DECL_HIDDEN InfoDlg::Private
 {
 public:
 
-    Private() :
+    explicit Private() :
         listView(0),
         page(0)
     {
@@ -99,10 +99,11 @@ InfoDlg::InfoDlg(QWidget* const parent)
     QLabel* const header    = new QLabel(d->page);
     header->setWordWrap(true);
     header->setText(i18n("<font size=\"5\">%1</font><br/><b>Version %2</b>"
-                         "<p>%3</p>",
+                         "<p>%3</p><p><i>%4</i></p>",
                          QApplication::applicationName(),
                          QApplication::applicationVersion(),
-                         DAboutData::digiKamSlogan()));
+                         DAboutData::digiKamSlogan(),
+                         DAboutData::digiKamFamily()));
 
     // --------------------------------------------------------
 
@@ -175,7 +176,7 @@ void InfoDlg::slotCopy2ClipBoard()
     textInfo.append(QApplication::applicationName());
     textInfo.append(QLatin1String(" version "));
     textInfo.append(QApplication::applicationVersion());
-    textInfo.append(QLatin1String("\n"));
+    textInfo.append(QLatin1Char('\n'));
 
     QTreeWidgetItemIterator it(d->listView);
 
@@ -184,7 +185,7 @@ void InfoDlg::slotCopy2ClipBoard()
         textInfo.append((*it)->text(0));
         textInfo.append(QLatin1String(": "));
         textInfo.append((*it)->text(1));
-        textInfo.append(QLatin1String("\n"));
+        textInfo.append(QLatin1Char('\n'));
         ++it;
     }
 
@@ -198,4 +199,4 @@ void InfoDlg::slotHelp()
     DXmlGuiWindow::openHandbook();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
