@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-07-11
  * Description : shared libraries list dialog
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,13 +45,17 @@
 #include "metaengine.h"
 
 #ifdef HAVE_LENSFUN
-#include "lensfuniface.h"
+#   include "lensfuniface.h"
 #endif // HAVE_LENSFUN
 
 #ifdef HAVE_MARBLE
-#include "mapwidget.h"
+#   include "mapwidget.h"
 #endif // HAVE_MARBLE
 
+#ifdef HAVE_IMAGE_MAGICK
+#   include <Magick++.h>
+#endif
+
 // C ANSI includes
 
 #ifndef Q_OS_WIN
@@ -60,7 +64,7 @@ extern "C"
 #endif
 
 #ifdef HAVE_JASPER
-#include <jasper/jas_version.h>
+#   include <jasper/jas_version.h>
 #endif // HAVE_JASPER
 
 #include <png.h>
@@ -103,6 +107,12 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
     list.insert(i18nc(CONTEXT, "Eigen support"),               SUPPORTED_NO);
 #endif // HAVE_EIGEN3
 
+#ifdef HAVE_QWEBENGINE
+    list.insert(i18nc(CONTEXT, "Qt WebEngine support"),        SUPPORTED_YES);
+#else
+    list.insert(i18nc(CONTEXT, "Qt Webkit support"),           SUPPORTED_YES);
+#endif
+
     list.insert(i18nc(CONTEXT, "Exiv2"),                       MetaEngine::Exiv2Version());
     list.insert(i18nc(CONTEXT, "Exiv2 supports XMP metadata"), MetaEngine::supportXmp() ?
                 i18n("Yes") : i18n("No"));
@@ -129,6 +139,18 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
     list.insert(i18nc(CONTEXT, "LibLqr support"),              SUPPORTED_NO);
 #endif // HAVE_LIBLQR_1
 
+#ifdef HAVE_VKONTAKTE
+    list.insert(i18nc(CONTEXT, "VKontakte support"),           SUPPORTED_YES);
+#else
+    list.insert(i18nc(CONTEXT, "VKontakte support"),           SUPPORTED_NO);
+#endif // HAVE_VKONTAKTE
+
+#ifdef HAVE_IMAGE_MAGICK
+    list.insert(i18nc(CONTEXT, "ImageMagick codecs"),          QLatin1String(MagickLibVersionText));
+#else
+    list.insert(i18nc(CONTEXT, "ImageMagick codecs support"),  SUPPORTED_NO);
+#endif // HAVE_IMAGE_MAGICK
+
     QString tiffver = QLatin1String(TIFFLIB_VERSION_STR);
     tiffver         = tiffver.left(tiffver.indexOf(QLatin1Char('\n')));
     tiffver         = tiffver.section(QLatin1Char(' '), 2, 2);
@@ -180,4 +202,4 @@ QString LibsInfoDlg::checkTriState(int value) const
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
