@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-04-07
  * Description : Raw camera list dialog
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,12 +44,12 @@
 namespace Digikam
 {
 
-class RawCameraDlg::Private
+class Q_DECL_HIDDEN RawCameraDlg::Private
 {
 public:
 
-    Private() :
-        header(0),
+    explicit Private()
+      : header(0),
         searchBar(0)
     {
     }
@@ -136,9 +136,9 @@ void RawCameraDlg::updateHeader(int results)
     if (!results)
     {
         d->header->setText(i18np("Using LibRaw version %2<br/>"
-                                 "1 model on the list</p>",
+                                 "1 model on the list",
                                  "Using LibRaw version %2<br/>"
-                                 "%1 models on the list</p>",
+                                 "%1 models on the list",
                                  list.count(),
                                  librawVer
                                  ));
@@ -146,13 +146,13 @@ void RawCameraDlg::updateHeader(int results)
     else
     {
         d->header->setText(i18np("Using LibRaw version %2<br/>"
-                                 "1 model on the list (found: %3)</p>",
+                                 "1 model on the list (found: %3)",
                                  "Using LibRaw version %2<br/>"
-                                 "%1 models on the list (found: %3)</p>",
+                                 "%1 models on the list (found: %3)",
                                  list.count(),
                                  librawVer,
                                  results));
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
