@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-06-21
  * Description : a simple web browser dialog based on Qt WebEngine.
  *
- * Copyright (C) 2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2017-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,6 +22,7 @@
  * ============================================================ */
 
 #include "webbrowserdlg.h"
+#include "digikam_config.h"
 
 // Qt includes
 
@@ -29,11 +30,17 @@
 #include <QApplication>
 #include <QStyle>
 #include <QIcon>
-#include <QWebView>
 #include <QToolBar>
 #include <QDesktopServices>
 #include <QDebug>
 
+#ifdef HAVE_QWEBENGINE
+#   include <QWebEngineView>
+#   include <QWebEnginePage>
+#else
+#   include <qwebview.h>
+#endif
+
 // KDE includes
 
 #include <klocalizedstring.h>
@@ -48,11 +55,11 @@
 namespace Digikam
 {
 
-class WebBrowserDlg::Private
+class Q_DECL_HIDDEN WebBrowserDlg::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         browser     = 0;
         toolbar     = 0;
@@ -63,7 +70,13 @@ public:
 public:
 
     QUrl               home;
+
+#ifdef HAVE_QWEBENGINE
+    QWebEngineView*    browser;
+#else
     QWebView*          browser;
+#endif
+
     QToolBar*          toolbar;
     StatusProgressBar* progressbar;
     SearchTextBar*     searchbar;
@@ -75,16 +88,29 @@ WebBrowserDlg::WebBrowserDlg(const QUrl& url, QWidget* const parent)
 {
     setModal(false);
     d->home    = url;
+
+#ifdef HAVE_QWEBENGINE
+    d->browser = new QWebEngineView(this);
+#else
     d->browser = new QWebView(this);
+#endif
 
     // --------------------------
 
     d->toolbar = new QToolBar(this);
     d->toolbar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+
+#ifdef HAVE_QWEBENGINE
+    d->toolbar->addAction(d->browser->pageAction(QWebEnginePage::Back));
+    d->toolbar->addAction(d->browser->pageAction(QWebEnginePage::Forward));
+    d->toolbar->addAction(d->browser->pageAction(QWebEnginePage::Reload));
+    d->toolbar->addAction(d->browser->pageAction(QWebEnginePage::Stop));
+#else
     d->toolbar->addAction(d->browser->pageAction(QWebPage::Back));
     d->toolbar->addAction(d->browser->pageAction(QWebPage::Forward));
     d->toolbar->addAction(d->browser->pageAction(QWebPage::Reload));
     d->toolbar->addAction(d->browser->pageAction(QWebPage::Stop));
+#endif
 
     QAction* const gohome  = new QAction(QIcon::fromTheme(QLatin1String("go-home")),
                                          i18n("Home"), this);
@@ -125,11 +151,11 @@ WebBrowserDlg::WebBrowserDlg(const QUrl& url, QWidget* const parent)
             this, SLOT(slotIconChanged(const QIcon&)));
 #endif
 */
-    connect(d->browser, SIGNAL(titleChanged(const QString&)),
-            this, SLOT(slotTitleChanged(const QString&)));
+    connect(d->browser, SIGNAL(titleChanged(QString)),
+            this, SLOT(slotTitleChanged(QString)));
 
-    connect(d->browser, SIGNAL(urlChanged(const QUrl&)),
-            this, SLOT(slotUrlChanged(const QUrl&)));
+    connect(d->browser, SIGNAL(urlChanged(QUrl)),
+            this, SLOT(slotUrlChanged(QUrl)));
 
     connect(d->browser, SIGNAL(loadStarted()),
             this, SLOT(slotLoadingStarted()));
@@ -137,8 +163,8 @@ WebBrowserDlg::WebBrowserDlg(const QUrl& url, QWidget* const parent)
     connect(d->browser, SIGNAL(loadFinished(bool)),
             this, SLOT(slotLoadingFinished(bool)));
 
-    connect(d->searchbar, SIGNAL(signalSearchTextSettings(const SearchTextSettings&)),
-            this, SLOT(slotSearchTextChanged(const SearchTextSettings&)));
+    connect(d->searchbar, SIGNAL(signalSearchTextSettings(SearchTextSettings)),
+            this, SLOT(slotSearchTextChanged(SearchTextSettings)));
 
     connect(d->browser, SIGNAL(loadProgress(int)),
             d->progressbar, SLOT(setProgressValue(int)));
@@ -208,11 +234,18 @@ void WebBrowserDlg::slotLoadingFinished(bool b)
 
 void WebBrowserDlg::slotSearchTextChanged(const SearchTextSettings& settings)
 {
+#ifdef HAVE_QWEBENGINE
+    d->browser->findText(settings.text,
+                         (settings.caseSensitive == Qt::CaseSensitive) ? QWebEnginePage::FindCaseSensitively
+                                                                       : QWebEnginePage::FindFlags(),
+                         [this](bool found) { d->searchbar->slotSearchResult(found); });
+#else
     bool found = d->browser->findText(
                     settings.text,
                     (settings.caseSensitive == Qt::CaseInsensitive) ? QWebPage::FindCaseSensitively 
                                                                     : QWebPage::FindFlags());
     d->searchbar->slotSearchResult(found);
+#endif
 }
 
 void WebBrowserDlg::slotGoHome()
