@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-06-21
  * Description : a simple web browser dialog based on Qt WebEngine.
  *
- * Copyright (C) 2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2017-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef WEB_BROWSER_DLG_H
-#define WEB_BROWSER_DLG_H
+#ifndef DIGIKAM_WEB_BROWSER_DLG_H
+#define DIGIKAM_WEB_BROWSER_DLG_H
 
 // Qt include
 
@@ -73,4 +73,4 @@ private:
 
 } // namespace Digikam
 
-#endif // WEB_BROWSER_DLG_H
+#endif // DIGIKAM_WEB_BROWSER_DLG_H
