@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : digiKam 8/16 bits image management API
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -50,7 +50,6 @@ extern "C"
 #include <QFileInfo>
 #include <QImage>
 #include <QImageReader>
-#include <QMap>
 #include <QPaintEngine>
 #include <QPainter>
 #include <QPixmap>
@@ -80,11 +79,11 @@ extern "C"
 #include "digikam_debug.h"
 
 #ifdef HAVE_JASPER
-#include "jp2kloader.h"
+#   include "jp2kloader.h"
 #endif // HAVE_JASPER
 
-typedef uint64_t ullong;
-typedef int64_t  llong;
+typedef uint64_t ullong;    // krazy:exclude=typedefs
+typedef int64_t  llong;     // krazy:exclude=typedefs
 
 namespace Digikam
 {
@@ -94,14 +93,16 @@ DImg::DImg()
 {
 }
 
-DImg::DImg(const QByteArray& filePath, DImgLoaderObserver* const observer,
+DImg::DImg(const QByteArray& filePath,
+           DImgLoaderObserver* const observer,
            const DRawDecoding& rawDecodingSettings)
     : m_priv(new Private)
 {
     load(QString::fromUtf8(filePath), observer, rawDecodingSettings);
 }
 
-DImg::DImg(const QString& filePath, DImgLoaderObserver* const observer,
+DImg::DImg(const QString& filePath,
+           DImgLoaderObserver* const observer,
            const DRawDecoding& rawDecodingSettings)
     : m_priv(new Private)
 {
@@ -311,7 +312,9 @@ size_t DImg::allocateData()
 
     if (!m_priv->data)
     {
-        m_priv->null = true;
+        m_priv->null   = true;
+        m_priv->width  = 0;
+        m_priv->height = 0;
         return 0;
     }
 
@@ -338,9 +341,9 @@ void DImg::setImageData(bool null, uint width, uint height, bool sixteenBit, boo
 //---------------------------------------------------------------------------------------------------
 // load and save
 
-bool DImg::loadImageInfo(const QString& filePath, bool loadMetadata, bool loadICCData, bool loadUniqueHash, bool loadImageHistory)
+bool DImg::loadItemInfo(const QString& filePath, bool loadMetadata, bool loadICCData, bool loadUniqueHash, bool loadImageHistory)
 {
-    DImgLoader::LoadFlags loadFlags = DImgLoader::LoadImageInfo;
+    DImgLoader::LoadFlags loadFlags = DImgLoader::LoadItemInfo;
 
     if (loadMetadata)
     {
@@ -373,7 +376,7 @@ bool DImg::load(const QString& filePath, DImgLoaderObserver* const observer, con
 bool DImg::load(const QString& filePath, bool loadMetadata, bool loadICCData, bool loadUniqueHash, bool loadImageHistory,
                 DImgLoaderObserver* const observer, const DRawDecoding& rawDecodingSettings)
 {
-    DImgLoader::LoadFlags loadFlags = DImgLoader::LoadImageInfo | DImgLoader::LoadImageData;
+    DImgLoader::LoadFlags loadFlags = DImgLoader::LoadItemInfo | DImgLoader::LoadImageData;
 
     if (loadMetadata)
     {
@@ -696,7 +699,11 @@ bool DImg::save(const QString& filePath, const QString& format, DImgLoaderObserv
     }
 
 #ifdef HAVE_JASPER
-    else if (frm == QLatin1String("JP2") || frm == QLatin1String("J2K") || frm == QLatin1String("JPX") || frm == QLatin1String("JPC") || frm == QLatin1String("PGX"))
+    else if (frm == QLatin1String("JP2") ||
+             frm == QLatin1String("J2K") ||
+             frm == QLatin1String("JPX") ||
+             frm == QLatin1String("JPC") ||
+             frm == QLatin1String("PGX"))
     {
         JP2KLoader loader(this);
         setAttribute(QLatin1String("savedformat-isreadonly"), loader.isReadOnly());
@@ -795,7 +802,7 @@ DImg::FORMAT DImg::fileFormat(const QString& filePath)
 
     fclose(f);
 
-    RawInfo dcrawIdentify;
+    DRawInfo dcrawIdentify;
     uchar jpegID[2]    = { 0xFF, 0xD8 };
     uchar tiffBigID[2] = { 0x4D, 0x4D };
     uchar tiffLilID[2] = { 0x49, 0x49 };
@@ -1098,7 +1105,7 @@ QVariant DImg::fileOriginData() const
 {
     QVariantMap map;
 
-    foreach(const QString& key, m_priv->fileOriginAttributes())
+    foreach (const QString& key, m_priv->fileOriginAttributes())
     {
         QVariant attr = attribute(key);
 
@@ -1156,7 +1163,7 @@ void DImg::setFileOriginData(const QVariant& data)
 {
     QVariantMap map = data.toMap();
 
-    foreach(const QString& key, m_priv->fileOriginAttributes())
+    foreach (const QString& key, m_priv->fileOriginAttributes())
     {
         removeAttribute(key);
         QVariant attr = map.value(key);
@@ -1951,7 +1958,7 @@ QImage DImg::copyQImage(int x, int y, int w, int h) const
 
 // --------------------------------------------------------------------------------------
 
-class PixmapPaintEngineDetector
+class Q_DECL_HIDDEN PixmapPaintEngineDetector
 {
 public:
 
@@ -2687,8 +2694,8 @@ bool DImg::reverseRotateAndFlip(int orientation)
             break;
 
         case DMetadata::ORIENTATION_ROT_90_HFLIP:
-            rotate(DImg::ROT270);
             flip(DImg::HORIZONTAL);
+            rotate(DImg::ROT270);
             rotatedOrFlipped = true;
             break;
 
@@ -2698,8 +2705,8 @@ bool DImg::reverseRotateAndFlip(int orientation)
             break;
 
         case DMetadata::ORIENTATION_ROT_90_VFLIP:
-            rotate(DImg::ROT270);
             flip(DImg::VERTICAL);
+            rotate(DImg::ROT270);
             rotatedOrFlipped = true;
             break;
 
@@ -2930,6 +2937,7 @@ QByteArray DImg::getUniqueHashV2() const
     }
 
     FileReadLocker lock(filePath);
+
     return DImgLoader::uniqueHashV2(filePath, this);
 }
 
@@ -2943,6 +2951,7 @@ QByteArray DImg::createImageUniqueId() const
     NonDeterministicRandomData randomData(16);
     QByteArray imageUUID = randomData.toHex();
     imageUUID           += getUniqueHashV2();
+
     return imageUUID;
 }
 
@@ -3059,7 +3068,7 @@ void DImg::prepareMetadataToSave(const QString& intendedDestPath, const QString&
            )
         {
             // Non JPEG file, we update IPTC preview
-            meta.setImagePreview(preview);
+            meta.setItemPreview(preview);
         }
 
         if (destMimeType.toUpper() == QLatin1String("TIFF") || destMimeType.toUpper() == QLatin1String("TIF"))
@@ -3078,7 +3087,7 @@ void DImg::prepareMetadataToSave(const QString& intendedDestPath, const QString&
     }
 
     // Update Exif Image dimensions.
-    meta.setImageDimensions(size());
+    meta.setItemDimensions(size());
 
     // Update Exif Document Name tag with the original file name.
     if (!originalFileName.isEmpty())
@@ -3089,7 +3098,7 @@ void DImg::prepareMetadataToSave(const QString& intendedDestPath, const QString&
     // Update Exif Orientation tag if necessary.
     if (flags & ResetExifOrientationTag)
     {
-        meta.setImageOrientation(DMetadata::ORIENTATION_NORMAL);
+        meta.setItemOrientation(DMetadata::ORIENTATION_NORMAL);
     }
 
     if (!m_priv->imageHistory.isEmpty())
@@ -3107,12 +3116,12 @@ void DImg::prepareMetadataToSave(const QString& intendedDestPath, const QString&
         }
 
         QString imageHistoryXml = forSaving.toXml();
-        meta.setImageHistory(imageHistoryXml);
+        meta.setItemHistory(imageHistoryXml);
     }
 
     if (flags & CreateNewImageHistoryUUID)
     {
-        meta.setImageUniqueId(QString::fromUtf8(createImageUniqueId()));
+        meta.setItemUniqueId(QString::fromUtf8(createImageUniqueId()));
     }
 
     // Store new Exif/IPTC/XMP data into image.
@@ -3123,6 +3132,7 @@ HistoryImageId DImg::createHistoryImageId(const QString& filePath, HistoryImageI
 {
     HistoryImageId id = DImgLoader::createHistoryImageId(filePath, *this, DMetadata(getMetadata()));
     id.setType(type);
+
     return id;
 }
 
@@ -3131,6 +3141,7 @@ HistoryImageId DImg::addAsReferredImage(const QString& filePath, HistoryImageId:
     HistoryImageId id = createHistoryImageId(filePath, type);
     m_priv->imageHistory.purgePathFromReferredImages(id.path(), id.fileName());
     addAsReferredImage(id);
+
     return id;
 }
 
@@ -3154,17 +3165,17 @@ void DImg::addFilterAction(const Digikam::FilterAction& action)
     m_priv->imageHistory << action;
 }
 
-const DImageHistory& DImg::getImageHistory() const
+const DImageHistory& DImg::getItemHistory() const
 {
     return m_priv->imageHistory;
 }
 
-DImageHistory& DImg::getImageHistory()
+DImageHistory& DImg::getItemHistory()
 {
     return m_priv->imageHistory;
 }
 
-void DImg::setImageHistory(const DImageHistory& history)
+void DImg::setItemHistory(const DImageHistory& history)
 {
     m_priv->imageHistory = history;
 }
@@ -3263,4 +3274,4 @@ bool DImg::isAnimatedImage(const QString& filePath)
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
