@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : digiKam 8/16 bits image management API
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DIMG_H
-#define DIMG_H
+#ifndef DIGIKAM_DIMG_H
+#define DIGIKAM_DIMG_H
 
 // Qt includes
 
@@ -224,7 +224,7 @@ public:
         If loadMetadata is true, the metadata will be available with getComments, getExif, getIptc, getXmp .
         If loadICCData is true, the ICC profile will be available with getICCProfile.
      */
-    bool        loadImageInfo(const QString& filePath, bool loadMetadata = true,
+    bool        loadItemInfo(const QString& filePath, bool loadMetadata = true,
                               bool loadICCData = true, bool loadUniqueHash = true,
                               bool loadImageHistory = true);
 
@@ -342,9 +342,9 @@ public:
     void       setEmbeddedText(const QString& key, const QString& text);
     QString    embeddedText(const QString& key) const;
 
-    const DImageHistory& getImageHistory() const;
-    DImageHistory&       getImageHistory();
-    void                 setImageHistory(const DImageHistory& history);
+    const DImageHistory& getItemHistory() const;
+    DImageHistory&       getItemHistory();
+    void                 setItemHistory(const DImageHistory& history);
     bool                 hasImageHistory() const;
     DImageHistory        getOriginalImageHistory() const;
     void                 addFilterAction(const FilterAction& action);
@@ -608,7 +608,7 @@ public:
 
         If you already have a DImg object of the file, use the member method.
         The object does not need to have the full image data loaded, but it shall at least
-        have been loaded with loadImageInfo with loadMetadata = true, or have the metadata
+        have been loaded with loadItemInfo with loadMetadata = true, or have the metadata
         set later with setComments, setExif, setIptc, setXmp.
         If the object does not have the metadata loaded, a non-null, but invalid hash will
         be returned! In this case, use the static method.
@@ -689,8 +689,8 @@ private:
     friend class DImgLoader;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DImg::PrepareMetadataFlags)
 
-#endif /* DIMG_H */
+#endif // DIGIKAM_DIMG_H
