@@ -1,16 +1,16 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : This is the normal smoothscale method,
  *               based on Imlib2's smoothscale. Added
  *               smoothScaleSection - Scaling only of a
- *               section of a image. Added 16bit image support
+ *               section of a image. Added 16 bits image support
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Ported to C++/QImage by Daniel M. Duley
  * Following modification are (C) Daniel M. Duley
@@ -53,8 +53,8 @@ extern "C"
 #include "dimg.h"
 #include "dimg_p.h"
 
-typedef uint64_t ullong;
-typedef int64_t  llong;
+typedef uint64_t ullong;    // krazy:exclude=typedefs
+typedef int64_t  llong;     // krazy:exclude=typedefs
 
 namespace Digikam
 {
@@ -62,14 +62,14 @@ namespace Digikam
 namespace DImgScale
 {
 
-class DImgScaleInfo
+class Q_DECL_HIDDEN DImgScaleInfo
 {
 public:
 
     DImgScaleInfo()
     {
-        xpoints = 0;
-        ypoints = 0;
+        xpoints   = 0;
+        ypoints   = 0;
         ypoints16 = 0;
         xapoints  = 0;
         yapoints  = 0;
@@ -177,7 +177,7 @@ DImg DImg::smoothScale(const QSize& destSize, Qt::AspectRatioMode aspectRatioMod
         return DImg();
     }
 
-    return smoothScaleClipped(scaleSize, QRect(QPoint(0,0), scaleSize));
+    return smoothScaleClipped(scaleSize, QRect(QPoint(0, 0), scaleSize));
 }
 
 DImg DImg::smoothScale(int dw, int dh, Qt::AspectRatioMode aspectRatioMode) const
@@ -193,7 +193,7 @@ DImg DImg::smoothScaleClipped(const QSize& destSize, const QRect& clip) const
 
 DImg DImg::smoothScaleClipped(int dw, int dh, int clipx, int clipy, int clipw, int cliph) const
 {
-    if (dw <= 0 || dh <= 0 || clipw <=0 || cliph <=0 || isNull())
+    if (dw <= 0 || dh <= 0 || clipw <= 0 || cliph <= 0 || isNull())
     {
         return DImg();
     }
@@ -404,12 +404,11 @@ uint** DImgScale::dimgCalcYPoints(uint* const src, int sw, int sh, int dh)
     int i, j = 0;
     ullong val, inc;
 
-    p = new uint* [dh+1];
-
+    p   = new uint* [dh+1];
     val = 0;
     inc = (((ullong)sh) << 16) / dh;
 
-    for (i = 0; i < dh; ++i)
+    for (i = 0 ; i < dh ; ++i)
     {
         p[j++] = src + ((val >> 16) * sw);
         val += inc;
@@ -424,15 +423,14 @@ ullong** DImgScale::dimgCalcYPoints16(ullong* const src, int sw, int sh, int dh)
     int i, j   = 0;
     ullong val, inc;
 
-    p = new ullong*[(dh+1)];
-
+    p   = new ullong*[(dh+1)];
     val = 0;
     inc = (((ullong)sh) << 16) / dh;
 
-    for (i = 0; i < dh; ++i)
+    for (i = 0 ; i < dh ; ++i)
     {
         p[j++] = src + ((val >> 16) * sw);
-        val += inc;
+        val   += inc;
     }
 
     return p;
@@ -443,15 +441,14 @@ int* DImgScale::dimgCalcXPoints(int sw, int dw)
     int* p=0, i, j = 0;
     ullong val, inc;
 
-    p = new int[dw+1];
-
+    p   = new int[dw+1];
     val = 0;
     inc = (((ullong)sw) << 16) / dw;
 
-    for (i = 0; i < dw; ++i)
+    for (i = 0 ; i < dw ; ++i)
     {
         p[j++] = (val >> 16);
-        val    += inc;
+        val   += inc;
     }
 
     return(p);
@@ -471,7 +468,7 @@ int* DImgScale::dimgCalcApoints(int s, int d, int up)
         val = 0;
         inc = (((ullong)s) << 16) / d;
 
-        for (i = 0; i < d; ++i)
+        for (i = 0 ; i < d ; ++i)
         {
             p[j++] = (val >> 8) - ((val >> 8) & 0xffffff00);
 
@@ -492,7 +489,7 @@ int* DImgScale::dimgCalcApoints(int s, int d, int up)
         inc = (((ullong)s) << 16) / d;
         Cp  = ((d << 14) / s) + 1;
 
-        for (i = 0; i < d; ++i)
+        for (i = 0 ; i < d ; ++i)
         {
             ap   = ((0x100 - ((val >> 8) & 0xff)) * Cp) >> 8;
             p[j] = ap | (Cp << 16);
@@ -574,8 +571,8 @@ void DImgScale::dimgSampleRGBA(DImgScaleInfo* const isi, uint* const dest,
     uint* sptr=0;
     uint* dptr=0;
     int x, y;
-    uint** ypoints = isi->ypoints;
-    int* xpoints   = isi->xpoints;
+    uint** ypoints    = isi->ypoints;
+    int* xpoints      = isi->xpoints;
 
     const int x_begin = dxx + clip_dx;     // no clip set = dxx
     const int x_end   = x_begin + clip_dw; // no clip set = dxx + dw
@@ -614,8 +611,8 @@ void DImgScale::dimgSampleRGBA16(DImgScaleInfo* const isi, ullong* const dest,
     ullong* sptr=0;
     ullong* dptr=0;
     int x, y;
-    ullong** ypoints = isi->ypoints16;
-    int* xpoints   = isi->xpoints;
+    ullong** ypoints  = isi->ypoints16;
+    int* xpoints      = isi->xpoints;
 
     const int x_begin = dxx + clip_dx;     // no clip set = dxx
     const int x_end   = x_begin + clip_dw; // no clip set = dxx + dw
@@ -643,7 +640,7 @@ void DImgScale::dimgSampleRGBA16(DImgScaleInfo* const isi, ullong* const dest,
 /**
 dimgScaleAARGBA : scale by area sampling. Arguments:
   DImgScaleInfo* isi,              // scaleinfo
-  uint*  dest,             // destination img data
+  uint*  dest,                     // destination img data
   int            dxx,              // destination x location corresponding to start x of src section
   int            dyy,              // destination y location corresponding to start y of src section
   int            dw,               // destination width
@@ -675,10 +672,10 @@ void DImgScale::dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
     uint* sptr=0;
     uint* dptr=0;
     int x, y;
-    uint** ypoints = isi->ypoints;
-    int* xpoints           = isi->xpoints;
-    int* xapoints          = isi->xapoints;
-    int* yapoints          = isi->yapoints;
+    uint** ypoints    = isi->ypoints;
+    int* xpoints      = isi->xpoints;
+    int* xapoints     = isi->xapoints;
+    int* yapoints     = isi->yapoints;
 
     const int x_begin = dxx + clip_dx;     // no clip set = dxx
     const int x_end   = x_begin + clip_dw; // no clip set = dxx + dw
@@ -1082,8 +1079,10 @@ void DImgScale::dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
 
                 if (j > 0)
                 {
-                    pix  = sptr;
+                    pix   = sptr;
                     sptr += sow;
+                    (void)sptr;    // disable clang warning.
+
                     rx   = (R_VAL(pix) * xap) >> 9;
                     gx   = (G_VAL(pix) * xap) >> 9;
                     bx   = (B_VAL(pix) * xap) >> 9;
@@ -1146,10 +1145,10 @@ void DImgScale::dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
     uint* sptr=0;
     uint* dptr=0;
     int x, y;
-    uint** ypoints = isi->ypoints;
-    int* xpoints           = isi->xpoints;
-    int* xapoints          = isi->xapoints;
-    int* yapoints          = isi->yapoints;
+    uint** ypoints    = isi->ypoints;
+    int* xpoints      = isi->xpoints;
+    int* xapoints     = isi->xapoints;
+    int* yapoints     = isi->yapoints;
 
     const int x_begin = dxx + clip_dx;     // no clip set = dxx
     const int x_end   = x_begin + clip_dw; // no clip set = dxx + dw
@@ -1514,6 +1513,8 @@ void DImgScale::dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
                 {
                     pix  = sptr;
                     sptr += sow;
+                    (void)sptr;    // disable clang warning.
+
                     rx   = (R_VAL(pix) * xap) >> 9;
                     gx   = (G_VAL(pix) * xap) >> 9;
                     bx   = (B_VAL(pix) * xap) >> 9;
@@ -1941,6 +1942,8 @@ void DImgScale::dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
                 {
                     pix  = sptr;
                     sptr += sow;
+                    (void)sptr;    // disable clang warning.
+
                     rx   = (R_VAL16(pix) * xap) >> 9;
                     gx   = (G_VAL16(pix) * xap) >> 9;
                     bx   = (B_VAL16(pix) * xap) >> 9;
@@ -1999,10 +2002,10 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
     ullong* sptr=0;
     ullong* dptr=0;
     int x, y;
-    ullong** ypoints = isi->ypoints16;
-    int* xpoints     = isi->xpoints;
-    int* xapoints    = isi->xapoints;
-    int* yapoints    = isi->yapoints;
+    ullong** ypoints  = isi->ypoints16;
+    int* xpoints      = isi->xpoints;
+    int* xapoints     = isi->xapoints;
+    int* yapoints     = isi->yapoints;
 
     const int x_begin = dxx + clip_dx;     // no clip set = dxx
     const int x_end   = x_begin + clip_dw; // no clip set = dxx + dw
@@ -2406,6 +2409,8 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
                 {
                     pix  = sptr;
                     sptr += sow;
+                    (void)sptr;    // disable clang warning.
+
                     rx   = (R_VAL16(pix) * xap) >> 9;
                     gx   = (G_VAL16(pix) * xap) >> 9;
                     bx   = (B_VAL16(pix) * xap) >> 9;
@@ -2445,4 +2450,4 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
