@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-06
  * Description : Raw decoding settings for digiKam:
  *               standard RawEngine parameters plus
  *               few customized for post processing.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DRAW_DECODING_H
-#define DRAW_DECODING_H
+#ifndef DIGIKAM_DRAW_DECODING_H
+#define DIGIKAM_DRAW_DECODING_H
 
 // Qt includes
 
@@ -111,8 +111,8 @@ public:
     CurvesContainer     curvesAdjust;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
 Q_DECLARE_METATYPE(Digikam::DRawDecoding)
 
-#endif /* DRAW_DECODING_H */
+#endif // DIGIKAM_DRAW_DECODING_H
