@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-15-02
  * Description : auto exposure image filter.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef AUTOEXPOFILTER_H
-#define AUTOEXPOFILTER_H
+#ifndef DIGIKAM_AUTO_EXPO_FILTER_H
+#define DIGIKAM_AUTO_EXPO_FILTER_H
 
 // Local includes
 
@@ -85,4 +85,4 @@ private:
 
 } // namespace Digikam
 
-#endif // AUTOEXPOFILTER_H
+#endif // DIGIKAM_AUTO_EXPO_FILTER_H
