@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-24-01
  * Description : auto levels image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef AUTOLEVELSFILTER_H
-#define AUTOLEVELSFILTER_H
+#ifndef DIGIKAM_AUTO_LEVELS_FILTER_H
+#define DIGIKAM_AUTO_LEVELS_FILTER_H
 
 // Local includes
 
@@ -84,4 +84,4 @@ private:
 
 } // namespace Digikam
 
-#endif // AUTOLEVELSFILTER_H
+#endif // DIGIKAM_AUTO_LEVELS_FILTER_H
