@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-24-01
  * Description : equalize image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef EQUALIZEFILTER_H
-#define EQUALIZEFILTER_H
+#ifndef DIGIKAM_EQUALIZE_FILTER_H
+#define DIGIKAM_EQUALIZE_FILTER_H
 
 // Local includes
 
@@ -39,6 +39,7 @@ class DIGIKAM_EXPORT EqualizeFilter : public DImgThreadedFilter
 {
 
 public:
+
     explicit EqualizeFilter(QObject* const parent = 0);
     EqualizeFilter(DImg* const orgImage, const DImg* const refImage, QObject* const parent=0);
     virtual ~EqualizeFilter();
@@ -81,6 +82,14 @@ private:
 
     struct double_packet
     {
+        double_packet()
+            : red(0.0),
+              green(0.0),
+              blue(0.0),
+              alpha(0.0)
+        {
+        }
+
         double red;
         double green;
         double blue;
@@ -89,6 +98,14 @@ private:
 
     struct int_packet
     {
+       int_packet()
+            : red(0),
+              green(0),
+              blue(0),
+              alpha(0)
+        {
+        }
+
         unsigned int red;
         unsigned int green;
         unsigned int blue;
@@ -100,4 +117,4 @@ private:
 
 } // namespace Digikam
 
-#endif // EQUALIZEFILTER_H
+#endif // DIGIKAM_EQUALIZE_FILTER_H
