@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-03-06
  * Description : a Brightness/Contrast/Gamma image filter.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -78,11 +78,11 @@ BCGContainer BCGContainer::fromFilterAction(const FilterAction& action, const QS
 
 // -----------------------------------------------------------------------------------------------
 
-class BCGFilter::Private
+class Q_DECL_HIDDEN BCGFilter::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         memset(map,   0, sizeof(map));
         memset(map16, 0, sizeof(map16));
@@ -305,4 +305,4 @@ void BCGFilter::applyBCG(uchar* const bits, uint width, uint height, bool sixtee
 
 }
 
-}  // namespace Digikam
+} // namespace Digikam
