@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-03-06
  * Description : a Brightness/Contrast/Gamma image filter.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef BCGFILTER_H
-#define BCGFILTER_H
+#ifndef DIGIKAM_BCG_FILTER_H
+#define DIGIKAM_BCG_FILTER_H
 
 // Local includes
 
@@ -95,6 +95,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* BCGFILTER_H */
+#endif // DIGIKAM_BCG_FILTER_H
