@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-03-06
  * Description : black and white image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010 by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -38,12 +38,12 @@
 namespace Digikam
 {
 
-class BWSepiaFilter::Private
+class Q_DECL_HIDDEN BWSepiaFilter::Private
 {
 public:
 
-    Private() :
-        redAttn(0.0),
+    explicit Private()
+      : redAttn(0.0),
         greenAttn(0.0),
         blueAttn(0.0),
         redMult(0.0),
@@ -532,4 +532,4 @@ void BWSepiaFilter::readParameters(const FilterAction& action)
 }
 
 
-}  // namespace Digikam
+} // namespace Digikam
