@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-23
  * Description : black and white settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -57,7 +57,7 @@
 namespace Digikam
 {
 
-class BWSepiaSettings::Private
+class Q_DECL_HIDDEN BWSepiaSettings::Private
 {
 
 public:
@@ -72,7 +72,7 @@ public:
 
 public:
 
-    Private() :
+    explicit Private() :
         bwFilters(0),
         bwFilm(0),
         bwTone(0),
@@ -139,7 +139,10 @@ BWSepiaSettings::BWSepiaSettings(QWidget* const parent, DImg* const img)
     }
     else
     {
-        d->thumbImage = DImg(QIcon::fromTheme(QLatin1String("view-preview")).pixmap(128).toImage());
+        QString backGround = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                    QLatin1String("digikam/about/images/body-background.jpg"));
+
+        d->thumbImage      = DImg(backGround).smoothScale(128, 128, Qt::KeepAspectRatio);
     }
 
     const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
@@ -648,4 +651,4 @@ void BWSepiaSettings::setScaleType(HistogramScale scale)
     d->curvesBox->setScale(scale);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
