@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date   : 2005-05-25
  * Description : Infrared threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2010 by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef INFRAREDFILTER_H
-#define INFRAREDFILTER_H
+#ifndef DIGIKAM_INFRARED_FILTER_H
+#define DIGIKAM_INFRARED_FILTER_H
 
 // Local includes
 
@@ -39,15 +39,17 @@ class DIGIKAM_EXPORT InfraredContainer
 
 public:
 
-    InfraredContainer()
+    explicit InfraredContainer()
     {
+        sensibility = 200;
         redGain     = 0.4;
         greenGain   = 2.1;
         blueGain    = -0.8;
-        sensibility = 200;
     };
 
-    ~InfraredContainer() {};
+    ~InfraredContainer()
+    {
+    };
 
 public:
 
@@ -66,8 +68,10 @@ class DIGIKAM_EXPORT InfraredFilter : public DImgThreadedFilter
 
 public:
 
-    explicit InfraredFilter(QObject* parent = 0);
-    explicit InfraredFilter(DImg* orgImage, QObject* parent=0, const InfraredContainer& settings=InfraredContainer());
+    explicit InfraredFilter(QObject* const parent = 0);
+    explicit InfraredFilter(DImg* const orgImage,
+                            QObject* const parent=0, 
+                            const InfraredContainer& settings=InfraredContainer());
     ~InfraredFilter();
 
     static QString          FilterIdentifier()
@@ -110,6 +114,6 @@ private:
     InfraredContainer m_settings;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* INFRAREDFILTER_H */
+#endif // DIGIKAM_INFRARED_FILTER_H
