@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-24-01
  * Description : Chanels mixer filter
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010 by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef MIXERFILTER_H
-#define MIXERFILTER_H
+#ifndef DIGIKAM_MIXER_FILTER_H
+#define DIGIKAM_MIXER_FILTER_H
 
 // Local includes
 
@@ -41,7 +41,7 @@ class DIGIKAM_EXPORT MixerContainer
 
 public:
 
-    MixerContainer()
+    explicit MixerContainer()
     {
         bPreserveLum   = true;
         bMonochrome    = false;
@@ -93,7 +93,9 @@ class DIGIKAM_EXPORT MixerFilter : public DImgThreadedFilter
 public:
 
     explicit MixerFilter(QObject* const parent = 0);
-    explicit MixerFilter(DImg* const orgImage, QObject* const parent=0, const MixerContainer& settings=MixerContainer());
+    explicit MixerFilter(DImg* const orgImage,
+                         QObject* const parent=0,
+                         const MixerContainer& settings=MixerContainer());
     virtual ~MixerFilter();
 
     static QString          FilterIdentifier()
@@ -139,6 +141,6 @@ private:
     MixerContainer m_settings;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* MIXERFILTER_H */
+#endif // DIGIKAM_MIXER_FILTER_H
