@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-02-18
  * Description : Channel mixer settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,11 +54,11 @@
 namespace Digikam
 {
 
-class MixerSettings::Private
+class Q_DECL_HIDDEN MixerSettings::Private
 {
 public:
 
-    Private() :
+    explicit Private() :
         currentChannel(RedChannel),
         monochromeTips(0),
         totalPercents(0),
@@ -704,4 +704,4 @@ void MixerSettings::saveAsSettings()
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
