@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-24-01
  * Description : Change tonality image filter
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010 by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef TONALITYFILTER_H
-#define TONALITYFILTER_H
+#ifndef DIGIKAM_TONALITY_FILTER_H
+#define DIGIKAM_TONALITY_FILTER_H
 
 // Local includes
 
@@ -41,7 +41,7 @@ class DIGIKAM_EXPORT TonalityContainer
 
 public:
 
-    TonalityContainer()
+    explicit TonalityContainer()
     {
         redMask   = 0;
         greenMask = 0;
@@ -67,7 +67,9 @@ class DIGIKAM_EXPORT TonalityFilter : public DImgThreadedFilter
 public:
 
     explicit TonalityFilter(QObject* const parent = 0);
-    explicit TonalityFilter(DImg* const orgImage, QObject* const parent=0, const TonalityContainer& settings=TonalityContainer());
+    explicit TonalityFilter(DImg* const orgImage,
+                            QObject* const parent=0,
+                            const TonalityContainer& settings=TonalityContainer());
     virtual ~TonalityFilter();
 
     static QString          FilterIdentifier()
@@ -109,4 +111,4 @@ private:
 
 } // namespace Digikam
 
-#endif // TONALITYFILTER_H
+#endif // DIGIKAM_TONALITY_FILTER_H
