@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-18
  * Description : color balance filter
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef CBFILTER_H
-#define CBFILTER_H
+#ifndef DIGIKAM_CB_FILTER_H
+#define DIGIKAM_CB_FILTER_H
 
 // Local includes
 
@@ -41,7 +41,7 @@ class DIGIKAM_EXPORT CBContainer
 
 public:
 
-    CBContainer()
+    explicit CBContainer()
     {
         red   = 1.0;
         green = 1.0;
@@ -50,7 +50,9 @@ public:
         gamma = 1.0;
     };
 
-    ~CBContainer() {};
+    ~CBContainer()
+    {
+    };
 
 public:
 
@@ -69,9 +71,15 @@ class DIGIKAM_EXPORT CBFilter : public DImgThreadedFilter
 public:
 
     explicit CBFilter(QObject* const parent = 0);
-    explicit CBFilter(DImg* const orgImage, QObject* const parent=0, const CBContainer& settings=CBContainer());
-    explicit CBFilter(const CBContainer& settings, DImgThreadedFilter* const master,
-                      const DImg& orgImage, DImg& destImage, int progressBegin=0, int progressEnd=100);
+    explicit CBFilter(DImg* const orgImage,
+                      QObject* const parent=0,
+                      const CBContainer& settings=CBContainer());
+    explicit CBFilter(const CBContainer& settings,
+                      DImgThreadedFilter* const master,
+                      const DImg& orgImage,
+                      DImg& destImage,
+                      int progressBegin=0,
+                      int progressEnd=100);
     virtual ~CBFilter();
 
     static QString          FilterIdentifier()
@@ -122,4 +130,4 @@ private:
 
 } // namespace Digikam
 
-#endif // CBFILTER_H
+#endif // DIGIKAM_CB_FILTER_H
