@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-11
  * Description : Color Balance settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,17 +45,15 @@
 #include "dnuminput.h"
 #include "digikam_debug.h"
 
-
-
 namespace Digikam
 {
 
-class CBSettings::Private
+class Q_DECL_HIDDEN CBSettings::Private
 {
 public:
 
-    Private() :
-        rInput(0),
+    explicit Private()
+      : rInput(0),
         gInput(0),
         bInput(0)
     {
@@ -80,19 +78,19 @@ CBSettings::CBSettings(QWidget* const parent)
     : QWidget(parent),
       d(new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing       = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     QGridLayout* const grid = new QGridLayout(parent);
 
     QLabel* const labelCyan = new QLabel(i18n("Cyan"));
     labelCyan->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
-    d->rInput = new DIntNumInput();
+    d->rInput               = new DIntNumInput();
     d->rInput->setRange(-100, 100, 1);
     d->rInput->setDefaultValue(0);
     d->rInput->setWhatsThis(i18n("Set here the cyan/red color adjustment of the image."));
 
-    QLabel* const labelRed = new QLabel(i18n("Red"));
+    QLabel* const labelRed     = new QLabel(i18n("Red"));
     labelRed->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
     // -------------------------------------------------------------
@@ -105,7 +103,7 @@ CBSettings::CBSettings(QWidget* const parent)
     d->gInput->setDefaultValue(0);
     d->gInput->setWhatsThis(i18n("Set here the magenta/green color adjustment of the image."));
 
-    QLabel* const labelGreen = new QLabel(i18n("Green"));
+    QLabel* const labelGreen  = new QLabel(i18n("Green"));
     labelGreen->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
     // -------------------------------------------------------------
@@ -113,10 +111,10 @@ CBSettings::CBSettings(QWidget* const parent)
     QLabel* const labelYellow = new QLabel(i18n("Yellow"));
     labelYellow->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
-    QLabel* const labelBlue = new QLabel(i18n("Blue"));
+    QLabel* const labelBlue   = new QLabel(i18n("Blue"));
     labelBlue->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
-    d->bInput = new DIntNumInput();
+    d->bInput                 = new DIntNumInput();
     d->bInput->setRange(-100, 100, 1);
     d->bInput->setDefaultValue(0);
     d->bInput->setWhatsThis(i18n("Set here the yellow/blue color adjustment of the image."));
@@ -214,4 +212,4 @@ void CBSettings::writeSettings(KConfigGroup& group)
     group.writeEntry(d->configBlueAdjustmentEntry,  prm.blue);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
