@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-14
  * Description : a curves widget with additional control elements
  *
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -36,6 +36,7 @@
 #include <QApplication>
 #include <QStyle>
 #include <QStandardPaths>
+#include <QMenu>
 
 // KDE includes
 
@@ -56,12 +57,12 @@
 namespace Digikam
 {
 
-class CurvesBox::Private
+class Q_DECL_HIDDEN CurvesBox::Private
 {
 public:
 
-    Private() :
-        sixteenBit(false),
+    explicit Private()
+      : sixteenBit(false),
         channel(LuminosityChannel),
         curveFree(0),
         curveSmooth(0),
@@ -72,6 +73,8 @@ public:
         pickerType(0),
         pickerBox(0),
         resetButton(0),
+        resetChannelAction(0),
+        resetChannelsAction(0),
         curvesWidget(0),
         hGradient(0),
         vGradient(0)
@@ -94,13 +97,17 @@ public:
 
     QPushButton*         resetButton;
 
+    QAction*             resetChannelAction;
+    QAction*             resetChannelsAction;
+
     CurvesWidget*        curvesWidget;
     ColorGradientWidget* hGradient;
     ColorGradientWidget* vGradient;
 };
 
 CurvesBox::CurvesBox(int w, int h, QWidget* const parent, bool readOnly)
-    : QWidget(parent), d(new Private)
+    : QWidget(parent),
+      d(new Private)
 {
     d->curvesWidget = new CurvesWidget(w, h, this, readOnly);
     setup();
@@ -119,15 +126,15 @@ CurvesBox::CurvesBox(int w, int h, const DImg& img, QWidget* const parent, bool
 
 void CurvesBox::setup()
 {
-    QWidget* curveBox = new QWidget();
+    QWidget* const curveBox           = new QWidget();
 
-    d->vGradient = new ColorGradientWidget(Qt::Vertical, 10);
+    d->vGradient                      = new ColorGradientWidget(Qt::Vertical, 10);
     d->vGradient->setColors(QColor("white"), QColor("black"));
 
-    d->hGradient = new ColorGradientWidget(Qt::Horizontal, 10);
+    d->hGradient                      = new ColorGradientWidget(Qt::Horizontal, 10);
     d->hGradient->setColors(QColor("black"), QColor("white"));
 
-    QGridLayout* curveBoxLayout = new QGridLayout;
+    QGridLayout* const curveBoxLayout = new QGridLayout;
     curveBoxLayout->addWidget(d->vGradient,    0, 0, 1, 1);
     curveBoxLayout->addWidget(d->curvesWidget, 0, 2, 1, 1);
     curveBoxLayout->addWidget(d->hGradient,    2, 2, 1, 1);
@@ -139,30 +146,30 @@ void CurvesBox::setup()
 
     // -------------------------------------------------------------
 
-    QWidget* typeBox = new QWidget();
+    QWidget* const typeBox          = new QWidget();
 
-    d->curveFree = new QToolButton;
+    d->curveFree                    = new QToolButton;
     d->curveFree->setIcon(QPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/curvefree.png"))));
     d->curveFree->setCheckable(true);
     d->curveFree->setToolTip(i18n("Curve free mode"));
     d->curveFree->setWhatsThis(i18n("With this button, you can draw your curve free-hand "
                                     "with the mouse."));
 
-    d->curveSmooth = new QToolButton;
+    d->curveSmooth                  = new QToolButton;
     d->curveSmooth->setIcon(QPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/curvemooth.png"))));
     d->curveSmooth->setCheckable(true);
     d->curveSmooth->setToolTip(i18n("Curve smooth mode"));
     d->curveSmooth->setWhatsThis(i18n("With this button, the curve type is constrained to "
                                       "be a smooth line with tension."));
 
-    d->curveType = new QButtonGroup(typeBox);
+    d->curveType                     = new QButtonGroup(typeBox);
     d->curveType->addButton(d->curveFree,   FreeDrawing);
     d->curveType->addButton(d->curveSmooth, SmoothDrawing);
 
     d->curveType->setExclusive(true);
     d->curveSmooth->setChecked(true);
 
-    QHBoxLayout* typeBoxLayout = new QHBoxLayout;
+    QHBoxLayout* const typeBoxLayout = new QHBoxLayout;
     typeBoxLayout->addWidget(d->curveFree);
     typeBoxLayout->addWidget(d->curveSmooth);
     typeBoxLayout->setContentsMargins(QMargins());
@@ -171,9 +178,9 @@ void CurvesBox::setup()
 
     // -------------------------------------------------------------
 
-    d->pickerBox = new QWidget();
+    d->pickerBox                       = new QWidget();
 
-    d->pickBlack = new QToolButton;
+    d->pickBlack                       = new QToolButton;
     d->pickBlack->setIcon(QIcon::fromTheme(QLatin1String("color-picker-black")));
     d->pickBlack->setCheckable(true);
     d->pickBlack->setToolTip(i18n("All channels shadow tone color picker"));
@@ -181,7 +188,7 @@ void CurvesBox::setup()
                                     "image used to set <b>Shadow Tone</b> "
                                     "smooth curves point on Red, Green, Blue, and Luminosity channels."));
 
-    d->pickGray = new QToolButton;
+    d->pickGray                        = new QToolButton;
     d->pickGray->setIcon(QIcon::fromTheme(QLatin1String("color-picker-grey")));
     d->pickGray->setCheckable(true);
     d->pickGray->setToolTip(i18n("All channels middle tone color picker"));
@@ -189,7 +196,7 @@ void CurvesBox::setup()
                                    "image used to set <b>Middle Tone</b> "
                                    "smooth curves point on Red, Green, Blue, and Luminosity channels."));
 
-    d->pickWhite = new QToolButton;
+    d->pickWhite                       = new QToolButton;
     d->pickWhite->setIcon(QIcon::fromTheme(QLatin1String("color-picker-white")));
     d->pickWhite->setCheckable(true);
     d->pickWhite->setToolTip(i18n("All channels highlight tone color picker"));
@@ -197,7 +204,7 @@ void CurvesBox::setup()
                                     "image used to set <b>Highlight Tone</b> "
                                     "smooth curves point on Red, Green, Blue, and Luminosity channels."));
 
-    d->pickerType = new QButtonGroup(d->pickerBox);
+    d->pickerType                      = new QButtonGroup(d->pickerBox);
     d->pickerType->addButton(d->pickBlack, BlackTonal);
     d->pickerType->addButton(d->pickGray,  GrayTonal);
     d->pickerType->addButton(d->pickWhite, WhiteTonal);
@@ -214,14 +221,22 @@ void CurvesBox::setup()
 
     // -------------------------------------------------------------
 
-    d->resetButton = new QPushButton(i18n("&Reset"));
+    d->resetButton            = new QPushButton(i18n("&Reset"));
     d->resetButton->setIcon(QIcon::fromTheme(QLatin1String("document-revert")));
-    d->resetButton->setToolTip(i18n("Reset current channel curves' values."));
-    d->resetButton->setWhatsThis(i18n("If you press this button, all curves' values "
-                                      "from the currently selected channel "
-                                      "will be reset to the default values."));
+    d->resetButton->setToolTip(i18n("Resets channel/channels curves' values."));
+    d->resetButton->setWhatsThis(i18n("If you press this button, custom menu will appear: "
+                                      "First option will reset current channel. "
+                                      "Second option will reset all channels."));
 
-    QHBoxLayout* const l3 = new QHBoxLayout();
+    QMenu* const resetMenu    = new QMenu(i18n("&Reset"), d->resetButton);
+    d->resetChannelAction     = new QAction(i18n("Reset &Channel"));
+    d->resetChannelsAction    = new QAction(i18n("Reset &All"));
+    resetMenu->addAction(d->resetChannelAction);
+    resetMenu->addAction(d->resetChannelsAction);
+
+    d->resetButton->setMenu(resetMenu);
+
+    QHBoxLayout* const l3     = new QHBoxLayout();
     l3->addWidget(typeBox);
     l3->addWidget(d->pickerBox);
     l3->addStretch(10);
@@ -250,11 +265,14 @@ void CurvesBox::setup()
     connect(d->pickerType, SIGNAL(buttonReleased(int)),
             this, SIGNAL(signalPickerChanged(int)));
 
-    connect(d->resetButton, SIGNAL(clicked()),
-            this, SLOT(slotResetChannel()));
-
     connect(d->curveType, SIGNAL(buttonClicked(int)),
             this, SLOT(slotCurveTypeChanged(int)));
+
+    connect(d->resetChannelAction, SIGNAL(triggered()), 
+            this, SLOT(slotResetChannel()));
+
+    connect(d->resetChannelsAction, SIGNAL(triggered()), 
+            this, SLOT(slotResetChannels()));
 }
 
 CurvesBox::~CurvesBox()
@@ -397,15 +415,17 @@ void CurvesBox::slotResetChannel()
 void CurvesBox::slotResetChannels()
 {
     resetChannels();
+    resetPickers();
 }
 
 void CurvesBox::resetChannels()
 {
-    for (int channel = 0; channel < ImageCurves::NUM_CHANNELS; ++channel)
+    for (int channel = 0 ; channel < ImageCurves::NUM_CHANNELS ; ++channel)
     {
-        d->curvesWidget->curves()->curvesChannelReset(channel);
+        resetChannel(channel);
     }
 
+    emit signalChannelReset(d->channel);
     reset();
 }
 
