@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-14
  * Description : a curves widget with additional control elements
  *
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef CURVESBOX_H
-#define CURVESBOX_H
+#ifndef DIGIKAM_CURVES_BOX_H
+#define DIGIKAM_CURVES_BOX_H
 
 // Qt includes
 
@@ -126,4 +126,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* CURVESBOX_H */
+#endif // DIGIKAM_CURVES_BOX_H
