@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-25-02
  * Description : Curves image filter
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -38,19 +38,31 @@ CurvesFilter::CurvesFilter(QObject* const parent)
     initFilter();
 }
 
-CurvesFilter::CurvesFilter(DImg* const orgImage, QObject* const parent, const CurvesContainer& settings)
-    : DImgThreadedFilter(orgImage, parent, QLatin1String("CurvesFilter"))
+CurvesFilter::CurvesFilter(DImg* const orgImage,
+                           QObject* const parent,
+                           const CurvesContainer& settings)
+    : DImgThreadedFilter(orgImage,
+                         parent,
+                         QLatin1String("CurvesFilter")),
+      m_settings(settings)
 {
-    m_settings = settings;
     initFilter();
 }
 
-CurvesFilter::CurvesFilter(const CurvesContainer& settings, DImgThreadedFilter* const master,
-                           const DImg& orgImage, DImg& destImage, int progressBegin, int progressEnd)
-    : DImgThreadedFilter(master, orgImage, destImage, progressBegin, progressEnd, QLatin1String("CurvesFilter"))
+CurvesFilter::CurvesFilter(const CurvesContainer& settings,
+                           DImgThreadedFilter* const master,
+                           const DImg& orgImage,
+                           DImg& destImage,
+                           int progressBegin,
+                           int progressEnd)
+    : DImgThreadedFilter(master,
+                         orgImage,
+                         destImage,
+                         progressBegin,
+                         progressEnd,
+                         QLatin1String("CurvesFilter")),
+      m_settings(settings)
 {
-    m_settings = settings;
-
     // cannot operate in-place, so allocate dest image
     initFilter();
     destImage = m_destImage;
@@ -101,4 +113,4 @@ void CurvesFilter::readParameters(const FilterAction& action)
     m_settings = CurvesContainer::fromFilterAction(action);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
