@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-25-02
  * Description : Curves image filter
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef CURVESFILTER_H
-#define CURVESFILTER_H
+#ifndef DIGIKAM_CURVES_FILTER_H
+#define DIGIKAM_CURVES_FILTER_H
 
 // Qt includes
 
@@ -47,9 +47,15 @@ class DIGIKAM_EXPORT CurvesFilter : public DImgThreadedFilter
 public:
 
     explicit CurvesFilter(QObject* const parent = 0);
-    explicit CurvesFilter(DImg* const orgImage, QObject* const parent=0, const CurvesContainer& settings=CurvesContainer());
-    explicit CurvesFilter(const CurvesContainer& settings, DImgThreadedFilter* const master,
-                          const DImg& orgImage, DImg& destImage, int progressBegin=0, int progressEnd=100);
+    explicit CurvesFilter(DImg* const orgImage,
+                          QObject* const parent=0,
+                          const CurvesContainer& settings=CurvesContainer());
+    explicit CurvesFilter(const CurvesContainer& settings,
+                           DImgThreadedFilter* const master,
+                          const DImg& orgImage,
+                          DImg& destImage,
+                          int progressBegin=0,
+                          int progressEnd=100);
     virtual ~CurvesFilter();
 
     static QString          FilterIdentifier()
@@ -91,4 +97,4 @@ private:
 
 } // namespace Digikam
 
-#endif // CURVESFILTER_H
+#endif // DIGIKAM_CURVES_FILTER_H
