@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-01
  * Description : Curves settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -61,15 +61,16 @@
 namespace Digikam
 {
 
-class CurvesSettings::Private
+class Q_DECL_HIDDEN CurvesSettings::Private
 {
 
 public:
 
-    Private() :
-        histoSegments(0),
+    explicit Private()
+      : histoSegments(0),
         curvesBox(0)
-    {}
+    {
+    }
 
     static const QString configCurveEntry;
 
@@ -287,4 +288,4 @@ int CurvesSettings::curvesLeftOffset() const
     return d->curvesBox->curvesLeftOffset();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
