@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-01
  * Description : Curves settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef CURVESSETTINGS_H
-#define CURVESSETTINGS_H
+#ifndef DIGIKAM_CURVES_SETTINGS_H
+#define DIGIKAM_CURVES_SETTINGS_H
 
 // Local includes
 
@@ -49,7 +49,7 @@ class DIGIKAM_EXPORT CurvesSettings : public QWidget
 
 public:
 
-    CurvesSettings(QWidget* const parent, DImg* const img);
+    explicit CurvesSettings(QWidget* const parent, DImg* const img);
     ~CurvesSettings();
 
     CurvesContainer defaultSettings() const;
@@ -86,6 +86,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* CURVESSETTINGS_H */
+#endif // DIGIKAM_CURVES_SETTINGS_H
