@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-12-01
  * Description : a widget to draw histogram curves
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef CURVESWIDGET_H
-#define CURVESWIDGET_H
+#ifndef DIGIKAM_CURVES_WIDGET_H
+#define DIGIKAM_CURVES_WIDGET_H
 
 // Qt includes
 
@@ -53,7 +53,7 @@ class DIGIKAM_EXPORT CurvesWidget : public QWidget
 
 public:
 
-    CurvesWidget(int w, int h, QWidget* const parent, bool readOnly=false);
+    explicit CurvesWidget(int w, int h, QWidget* const parent, bool readOnly=false);
     ~CurvesWidget();
 
     void setup(int w, int h, bool readOnly);
@@ -135,6 +135,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* CURVESWIDGET_H */
+#endif // DIGIKAM_CURVES_WIDGET_H
