@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : border threaded image filter.
  *
- * Copyright 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
@@ -45,12 +45,12 @@
 namespace Digikam
 {
 
-class BorderFilter::Private
+class Q_DECL_HIDDEN BorderFilter::Private
 {
 public:
 
-    Private() :
-        borderMainWidth(0),
+    explicit Private()
+      : borderMainWidth(0),
         border2ndWidth(0),
         orgRatio(0.0f)
     {
@@ -99,14 +99,14 @@ void BorderFilter::Private::setup(const DImg& m_orgImage)
     }
 }
 
-BorderFilter::BorderFilter(QObject* parent)
+BorderFilter::BorderFilter(QObject* const parent)
     : DImgThreadedFilter(parent),
       d(new Private)
 {
     initFilter();
 }
 
-BorderFilter::BorderFilter(DImg* image, QObject* parent, const BorderContainer& settings)
+BorderFilter::BorderFilter(DImg* image, QObject* const parent, const BorderContainer& settings)
     : DImgThreadedFilter(image, parent, QLatin1String("Border")),
       d(new Private)
 {
@@ -562,4 +562,4 @@ void BorderFilter::readParameters(const FilterAction& action)
     d->settings.decorativeSecondColor = stringToColor(action.parameter(QLatin1String("decorativeSecondColor")).toString());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
