@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : border threaded image filter.
  *
- * Copyright 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright 2010 by Martin Klapetek <martin dot klapetek at gmail dot com>
+ * Copyright 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef BORDERFILTER_H
-#define BORDERFILTER_H
+#ifndef DIGIKAM_BORDER_FILTER_H
+#define DIGIKAM_BORDER_FILTER_H
 
 // Qt includes
 
@@ -72,7 +72,7 @@ public:
 
 public:
 
-    BorderContainer()
+    explicit BorderContainer()
     {
         preserveAspectRatio   = true;
         orgWidth              = 0;
@@ -128,8 +128,8 @@ public:
 
     /** Constructor using settings to preserve aspect ratio of image.
      */
-    explicit BorderFilter(QObject* parent = 0);
-    explicit BorderFilter(DImg* orgImage, QObject* parent=0, const BorderContainer& settings = BorderContainer());
+    explicit BorderFilter(QObject* const parent = 0);
+    explicit BorderFilter(DImg* orgImage, QObject* const parent=0, const BorderContainer& settings = BorderContainer());
     virtual ~BorderFilter();
 
     static QString          FilterIdentifier()
@@ -184,6 +184,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* BORDERFILTER_H */
+#endif // DIGIKAM_BORDER_FILTER_H
