@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-17
  * Description : Border settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef BORDERSETTINGS_H
-#define BORDERSETTINGS_H
+#ifndef DIGIKAM_BORDER_SETTINGS_H
+#define DIGIKAM_BORDER_SETTINGS_H
 
 // Local includes
 
@@ -41,8 +41,6 @@
 namespace Digikam
 {
 
-class Private;
-
 class DIGIKAM_EXPORT BorderSettings : public QWidget
 {
     Q_OBJECT
@@ -80,9 +78,10 @@ private:
 
 private:
 
+    class Private;
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* BORDERSETTINGS_H */
+#endif // DIGIKAM_BORDER_SETTINGS_H
