@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : TextureFilter threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef TEXTUREFILTER_H
-#define TEXTUREFILTER_H
+#ifndef DIGIKAM_TEXTURE_FILTER_H
+#define DIGIKAM_TEXTURE_FILTER_H
 
 // Qt includes
 
@@ -44,7 +44,9 @@ class DIGIKAM_EXPORT TextureFilter : public DImgThreadedFilter
 public:
 
     explicit TextureFilter(QObject* const parent = 0);
-    explicit TextureFilter(DImg* const orgImage, QObject* const parent=0, int blendGain=200,
+    explicit TextureFilter(DImg* const orgImage,
+                           QObject* const parent=0,
+                           int blendGain=200,
                            const QString& texturePath=QString());
 
     ~TextureFilter();
@@ -88,6 +90,6 @@ private:
     QString m_texturePath;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* TEXTUREFILTER_H */
+#endif // DIGIKAM_TEXTURE_FILTER_H
