@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-06-24
  * Description : manager for filters (registering, creating etc)
@@ -101,11 +101,11 @@ namespace Digikam
 {
 typedef QSharedPointer<DImgFilterGenerator> ImgFilterPtr;
 
-class DImgFilterManager::Private
+class Q_DECL_HIDDEN DImgFilterManager::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : mutex(QMutex::Recursive)
     {
     }
@@ -257,7 +257,7 @@ void DImgFilterManager::Private::addGenerator(const ImgFilterPtr& generator)
 
 // -----------------------------------------------------------------------------------------
 
-class DImgFilterManagerCreator
+class Q_DECL_HIDDEN DImgFilterManagerCreator
 {
 public:
 
