@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-02-05
  * Description : film color negative inverter filter
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef FILMFILTER_H_
-#define FILMFILTER_H_
+#ifndef DIGIKAM_FILM_FILTER_H
+#define DIGIKAM_FILM_FILTER_H
 
 // Qt includes
 
@@ -83,7 +83,7 @@ public:
     {
     public:
 
-        ListItem(const QString& text, QListWidget* const parent, CNFilmProfile type)
+        explicit ListItem(const QString& text, QListWidget* const parent, CNFilmProfile type)
             : QListWidgetItem(text, parent, type + QListWidgetItem::UserType)
         {
         }
@@ -178,4 +178,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* FILMFILTER_H_ */
+#endif // DIGIKAM_FILM_FILTER_H
