@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Charcoal threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef CHARCOALFILTER_H
-#define CHARCOALFILTER_H
+#ifndef DIGIKAM_CHARCOAL_FILTER_H
+#define DIGIKAM_CHARCOAL_FILTER_H
 
 // Local includes
 
@@ -40,7 +40,10 @@ class DIGIKAM_EXPORT CharcoalFilter : public DImgThreadedFilter
 public:
 
     explicit CharcoalFilter(QObject* const parent = 0);
-    explicit CharcoalFilter(DImg* const orgImage, QObject* const parent=0, double pencil=5.0, double smooth=10.0);
+    explicit CharcoalFilter(DImg* const orgImage,
+                            QObject* const parent=0,
+                            double pencil=5.0,
+                            double smooth=10.0);
     ~CharcoalFilter();
 
     static QString          FilterIdentifier()
@@ -84,6 +87,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* CHARCOALFILTER_H */
+#endif // DIGIKAM_CHARCOAL_FILTER_H
