@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-02-14
  * Description : Color FX threaded image filter.
  *
- * Copyright 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  * Copyright 2015      by Andrej Krutak <dev at andree dot sk>
@@ -55,13 +55,14 @@ ColorFXFilter::ColorFXFilter(QObject* const parent)
     initFilter();
 }
 
-ColorFXFilter::ColorFXFilter(DImg* const orgImage, QObject* const parent, const ColorFXContainer& settings)
+ColorFXFilter::ColorFXFilter(DImg* const orgImage,
+                             QObject* const parent,
+                             const ColorFXContainer& settings)
     : DImgThreadedFilter(orgImage, parent, QLatin1String("ColorFX")),
+      m_settings(settings),
       m_lutTable(0),
       m_lutTableSize(0)
 {
-    m_settings = settings;
-
     loadLut3D(m_settings.path);
 
     initFilter();
@@ -284,7 +285,7 @@ void ColorFXFilter::neon(DImg* const orgImage, DImg* const destImage, int Intens
  * BW               => Border Width
  *
  * Theory           => Wow, another Photoshop filter (FindEdges). Do you understand
- *                     Neon effect ? This is the same engine, but is inversed with
+ *                     Neon effect ? This is the same engine, but is inverted with
  *                     255 - color.
  */
 void ColorFXFilter::findEdges(DImg* const orgImage, DImg* const destImage, int Intensity, int BW)
@@ -322,7 +323,7 @@ void ColorFXFilter::neonFindEdges(DImg* const orgImage, DImg* const destImage, b
     Intensity = (Intensity < 0) ? 0 : (Intensity > 5) ? 5 : Intensity;
     BW        = (BW < 1) ? 1 : (BW > 5) ? 5 : BW;
 
-    uchar* ptr, *ptr1, *ptr2;
+    uchar* ptr=0, *ptr1=0, *ptr2=0;
 
     // these must be uint, we need full 2^32 range for 16 bit
     uint color_1, color_2, colorPoint, colorOther1, colorOther2;
@@ -332,9 +333,9 @@ void ColorFXFilter::neonFindEdges(DImg* const orgImage, DImg* const destImage, b
 
     double intensityFactor = qSqrt(1 << Intensity);
 
-    for (int h = 0; h < Height; ++h)
+    for (int h = 0 ; h < Height ; ++h)
     {
-        for (int w = 0; w < Width; ++w)
+        for (int w = 0 ; w < Width ; ++w)
         {
             ptr  = pResBits + getOffset(Width, w, h, bytesDepth);
             ptr1 = pResBits + getOffset(Width, w + Lim_Max(w, BW, Width), h, bytesDepth);
@@ -342,7 +343,7 @@ void ColorFXFilter::neonFindEdges(DImg* const orgImage, DImg* const destImage, b
 
             if (sixteenBit)
             {
-                for (int k = 0; k <= 2; ++k)
+                for (int k = 0 ; k <= 2 ; ++k)
                 {
                     colorPoint  = reinterpret_cast<unsigned short*>(ptr)[k];
                     colorOther1 = reinterpret_cast<unsigned short*>(ptr1)[k];
@@ -366,7 +367,7 @@ void ColorFXFilter::neonFindEdges(DImg* const orgImage, DImg* const destImage, b
             }
             else
             {
-                for (int k = 0; k <= 2; ++k)
+                for (int k = 0 ; k <= 2 ; ++k)
                 {
                     colorPoint  = ptr[k];
                     colorOther1 = ptr1[k];
@@ -388,7 +389,7 @@ void ColorFXFilter::neonFindEdges(DImg* const orgImage, DImg* const destImage, b
     }
 }
 
-#define Lut3DSetPixel(table, w, x, y, p) \
+#define Lut3DSetPixel(table, w, x, y, p)                        \
     table[((y) * (w) + (x)) * 4 + 0] = qRed(p)   * 65535 / 255; \
     table[((y) * (w) + (x)) * 4 + 1] = qGreen(p) * 65535 / 255; \
     table[((y) * (w) + (x)) * 4 + 2] = qBlue(p)  * 65535 / 255;
@@ -401,7 +402,7 @@ void ColorFXFilter::loadLut3D(const QString& path)
 
     if (fi.suffix().toLower() == QLatin1String("cube"))
     {
-        qCDebug(DIGIKAM_DIMG_LOG) << "Can't yet process Cube LUTs";
+        qCDebug(DIGIKAM_DIMG_LOG) << "Ca not yet process Cube LUTs";
         // TODO: Adobe Cube LUT http://wwwimages.adobe.com/content/dam/Adobe/en/products/speedgrade/cc/pdfs/cube-lut-specification-1.0.pdf
     }
     else
@@ -417,7 +418,7 @@ void ColorFXFilter::loadLut3D(const QString& path)
         if (img.width() == img.height())
         {
             // HALD LUT (Like imagemagick creates)
-            int w = img.width();
+            int w          = img.width();
 
             m_lutTableSize = int(pow(pow(w, 1 / 3.0), 2) + 0.1);
 
@@ -449,17 +450,17 @@ void ColorFXFilter::loadLut3D(const QString& path)
             int iRow        = 0, iCol;
             const int zSize = w / m_lutTableSize;
 
-            for (oz = 0; oz < m_lutTableSize; oz++)
+            for (oz = 0 ; oz < m_lutTableSize ; ++oz)
             {
                 xOff = oz * m_lutTableSize;
 
-                for (y1 = 0; y1 < zSize; y1++)
+                for (y1 = 0 ; y1 < zSize ; ++y1)
                 {
                     iCol = 0;
 
-                    for (y2 = 0; y2 < zSize; y2++)
+                    for (y2 = 0 ; y2 < zSize ; ++y2)
                     {
-                        for (x = 0; x < m_lutTableSize; x++, iCol++)
+                        for (x = 0 ; x < m_lutTableSize ; ++x, ++iCol)
                         {
                             QRgb p = img.pixel(iCol, iRow);
                             Lut3DSetPixel(m_lutTable,
@@ -470,7 +471,7 @@ void ColorFXFilter::loadLut3D(const QString& path)
                         }
                     }
 
-                    iRow++;
+                    ++iRow;
                 }
             }
         }
@@ -482,9 +483,9 @@ void ColorFXFilter::loadLut3D(const QString& path)
             m_lutTable     = new quint16[img.width() * img.height() * 4];
             w              = img.width();
 
-            for (y = 0; y < m_lutTableSize; y++)
+            for (y = 0 ; y < m_lutTableSize ; ++y)
             {
-                for (x = 0; x < w; x++)
+                for (x = 0 ; x < w ; ++x)
                 {
                     QRgb p = img.pixel(x, y);
                     Lut3DSetPixel(m_lutTable, w, x, y, p);
@@ -529,7 +530,7 @@ static __inline__ int clamp(int from, int maxVal)
 }
 
 template<typename T>
-static void ImageFilterFx(const quint16* lutrgb, int lutTableSize,
+static void ItemFilterFx(const quint16* lutrgb, int lutTableSize,
                           T* rgb, uint start, uint end, int maxVal, int intensity)
 {
     int lutdim_r  = lutTableSize;
@@ -538,7 +539,7 @@ static void ImageFilterFx(const quint16* lutrgb, int lutTableSize,
     int STEP      = 4;
     const int RED = 2, GREEN = 1, BLUE = 0;
 
-    int off[8] =
+    int off[8]    =
     {
             0,
             STEP*1,
@@ -553,15 +554,13 @@ static void ImageFilterFx(const quint16* lutrgb, int lutTableSize,
     float scale_R = (lutdim_r-1.f)/(maxVal + 1);
     float scale_G = (lutdim_g-1.f)/(maxVal + 1);
     float scale_B = (lutdim_b-1.f)/(maxVal + 1);
+    rgb          += 4 * start;
 
-    uint i;
-    rgb += 4 * start;
-
-    for (i = start; i < end; i++)
+    for (uint i = start ; i < end ; ++i)
     {
-        int r      = rgb[RED], rn;
+        int r      = rgb[RED],   rn;
         int g      = rgb[GREEN], gn;
-        int b      = rgb[BLUE], bn;
+        int b      = rgb[BLUE],  bn;
 
         float fb   = b*scale_B;
         float fg   = g*scale_G;
@@ -599,19 +598,19 @@ void ColorFXFilter::applyLut3D()
     maxI  = m_orgImage.width() * m_orgImage.height();
     stepI = maxI / steps;
 
-    for (progress = 0, i = 0;
-         runningFlag() && (i < maxI);
+    for (progress = 0, i = 0 ;
+         runningFlag() && (i < maxI) ;
          i += stepI, progress += (100 / steps))
     {
         if (!m_orgImage.sixteenBit())
         {
-            ImageFilterFx(m_lutTable, m_lutTableSize, m_orgImage.bits(),
+            ItemFilterFx(m_lutTable, m_lutTableSize, m_orgImage.bits(),
                           i, min(i + stepI, maxI),
                           255, m_settings.intensity);
         }
         else
         {
-            ImageFilterFx(m_lutTable, m_lutTableSize, reinterpret_cast<unsigned short*>(m_orgImage.bits()),
+            ItemFilterFx(m_lutTable, m_lutTableSize, reinterpret_cast<unsigned short*>(m_orgImage.bits()),
                           i, min(i + stepI, maxI),
                           65535, m_settings.intensity);
         }
@@ -643,4 +642,4 @@ void ColorFXFilter::readParameters(const FilterAction& action)
     m_settings.intensity   = action.parameter(QLatin1String("intensity")).toInt();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
