@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Color FX threaded image filter.
  *
- * Copyright 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  * Copyright 2015      by Andrej Krutak <dev at andree dot sk>
@@ -27,8 +27,8 @@
  *
  * ============================================================ */
 
-#ifndef COLORFXFILTER_H
-#define COLORFXFILTER_H
+#ifndef DIGIKAM_COLOR_FX_FILTER_H
+#define DIGIKAM_COLOR_FX_FILTER_H
 
 // Local includes
 
@@ -44,7 +44,7 @@ class DIGIKAM_EXPORT ColorFXContainer
 
 public:
 
-    ColorFXContainer()
+    explicit ColorFXContainer()
     {
         colorFXType = 0; // ColorFXFilter::Solarize
         level       = 0;
@@ -85,7 +85,9 @@ public:
 public:
 
     explicit ColorFXFilter(QObject* const parent = 0);
-    explicit ColorFXFilter(DImg* const orgImage, QObject* const parent, const ColorFXContainer& settings=ColorFXContainer());
+    explicit ColorFXFilter(DImg* const orgImage,
+                           QObject* const parent,
+                           const ColorFXContainer& settings=ColorFXContainer());
     ~ColorFXFilter();
 
     static QString          FilterIdentifier()
@@ -136,6 +138,6 @@ private:
     int              m_lutTableSize; // all axis are of this size
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* COLORFXFILTER_H */
+#endif // DIGIKAM_COLOR_FX_FILTER_H
