@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-11-08
  * Description : Color effects settings view.
@@ -46,19 +46,20 @@
 namespace Digikam
 {
 
-class ColorFXSettings::Private
+class Q_DECL_HIDDEN ColorFXSettings::Private
 {
 public:
 
-    Private() :
-        stack(0),
+    explicit Private()
+      : stack(0),
         effectType(0),
         levelInput(0),
         iterationInput(0),
         intensityInput(0),
         iterationLabel(0),
         correctionTools(0)
-    {}
+    {
+    }
 
     static const QString configEffectTypeEntry;
     static const QString configLevelAdjustmentEntry;
@@ -99,7 +100,10 @@ ColorFXSettings::ColorFXSettings(QWidget* const parent, bool useGenericImg)
 
     if (useGenericImg)
     {
-        thumbImage = DImg(QIcon::fromTheme(QLatin1String("view-preview")).pixmap(128).toImage());
+        QString backGround = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                    QLatin1String("digikam/about/images/body-background.jpg"));
+
+        thumbImage         = DImg(backGround).smoothScale(128, 128, Qt::KeepAspectRatio);
     }
     else
     {
@@ -175,7 +179,7 @@ ColorFXSettings::ColorFXSettings(QWidget* const parent, bool useGenericImg)
 
     d->correctionTools           = new PreviewList(lut3DSettings);
 
-    for (int idx = 0; idx < d->luts.count(); idx++)
+    for (int idx = 0 ; idx < d->luts.count() ; ++idx)
     {
         ColorFXContainer prm;
         prm.colorFXType = ColorFXFilter::Lut3D;
@@ -421,4 +425,4 @@ QString ColorFXSettings::translateLuts(const QString& name) const
     return name;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
