@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-07-18
  * Description : Distortion FX threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -26,8 +26,8 @@
  *
  * ============================================================ */
 
-#ifndef DISTORTION_FX_FILTER_H
-#define DISTORTION_FX_FILTER_H
+#ifndef DIGIKAM_DISTORTION_FX_FILTER_H
+#define DIGIKAM_DISTORTION_FX_FILTER_H
 
 // Local includes
 
@@ -209,6 +209,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* DISTORTION_FX_FILTER_H */
+#endif // DIGIKAM_DISTORTION_FX_FILTER_H
