@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Emboss threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -26,8 +26,8 @@
  *
  * ============================================================ */
 
-#ifndef EMBOSSFILTER_H
-#define EMBOSSFILTER_H
+#ifndef DIGIKAM_EMBOSS_FILTER_H
+#define DIGIKAM_EMBOSS_FILTER_H
 
 // Local includes
 
@@ -88,6 +88,6 @@ private:
     int m_depth;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* EMBOSSFILTER_H */
+#endif // DIGIKAM_EMBOSS_FILTER_H
