@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-10
  * Description : Film Grain settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,12 +50,12 @@
 namespace Digikam
 {
 
-class FilmGrainSettings::Private
+class Q_DECL_HIDDEN FilmGrainSettings::Private
 {
 public:
 
-    Private() :
-        sizeLabel(0),
+    explicit Private()
+      : sizeLabel(0),
         label1(0),
         label2(0),
         label3(0),
@@ -565,4 +565,4 @@ void FilmGrainSettings::writeSettings(KConfigGroup& group)
     group.writeEntry(d->configHighlightsChromaRedAdjustmentEntry,  prm.chromaRedHighlights);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
