@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-17-07
  * Description : An invert image threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef INVERTFILTER_H
-#define INVERTFILTER_H
+#ifndef DIGIKAM_INVERT_FILTER_H
+#define DIGIKAM_INVERT_FILTER_H
 
 // Local includes
 
@@ -82,6 +82,6 @@ private:
     void filterImage();
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* INVERTFILTER_H */
+#endif // DIGIKAM_INVERT_FILTER_H
