@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Oil Painting threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -35,7 +35,7 @@
 
 // Qt includes
 
-#include <QtConcurrent>
+#include <QtConcurrent>    // krazy:exclude=includes
 #include <QMutex>
 
 // Local includes
@@ -45,12 +45,12 @@
 namespace Digikam
 {
 
-class OilPaintFilter::Private
+class Q_DECL_HIDDEN OilPaintFilter::Private
 {
 public:
 
-    Private() :
-        brushSize(1),
+    explicit Private()
+      : brushSize(1),
         smoothness(30),
         globalProgress(0)
     {
@@ -267,4 +267,4 @@ void OilPaintFilter::readParameters(const Digikam::FilterAction& action)
     d->smoothness = action.parameter(QLatin1String("smoothness")).toInt();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
