@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Raindrop threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef RAINDROPFILTER_H
-#define RAINDROPFILTER_H
+#ifndef DIGIKAM_RAIN_DROP_FILTER_H
+#define DIGIKAM_RAIN_DROP_FILTER_H
 
 // Local includes
 
@@ -44,8 +44,12 @@ class DIGIKAM_EXPORT RainDropFilter : public DImgThreadedFilter
 public:
 
     explicit RainDropFilter(QObject* const parent = 0);
-    explicit RainDropFilter(DImg* const orgImage, QObject* const parent=0, int drop=80,
-                            int amount=150, int coeff=30, const QRect& selection=QRect(0, 0, 0, 0));
+    explicit RainDropFilter(DImg* const orgImage,
+                            QObject* const parent=0,
+                            int drop=80,
+                            int amount=150,
+                            int coeff=30,
+                            const QRect& selection=QRect(0, 0, 0, 0));
     ~RainDropFilter();
 
     static QString          FilterIdentifier()
@@ -126,6 +130,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* RAINDROPFILTER_H */
+#endif // DIGIKAM_RAIN_DROP_FILTER_H
