@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-12-03
  * Description : Greycstoration interface.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GREYCSTORATIONFILTER_H
-#define GREYCSTORATIONFILTER_H
+#ifndef DIGIKAM_GREY_CSTORATION_FILTER_H
+#define DIGIKAM_GREY_CSTORATION_FILTER_H
 
 // Qt includes
 
@@ -54,7 +54,7 @@ public:
 
 public:
 
-    GreycstorationContainer()
+    explicit GreycstorationContainer()
     {
         setRestorationDefaultSettings();
     };
@@ -229,11 +229,10 @@ private:
 
 private:
 
-
     class Private;
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* GREYCSTORATIONFILTER_H */
+#endif // DIGIKAM_GREY_CSTORATION_FILTER_H
