@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-09-13
  * Description : Greycstoration settings widgets
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,13 +46,13 @@
 namespace Digikam
 {
 
-class GreycstorationSettings::GreycstorationSettingsPriv
+class Q_DECL_HIDDEN GreycstorationSettings::Private
 {
 
 public:
 
-    GreycstorationSettingsPriv() :
-        alphaLabel(0),
+    explicit Private()
+      : alphaLabel(0),
         amplitudeLabel(0),
         anisotropyLabel(0),
         btileLabel(0),
@@ -119,18 +119,17 @@ public:
     DIntNumInput*    tileInput;
 };
 
-GreycstorationSettings::GreycstorationSettings(QTabWidget* parent)
+GreycstorationSettings::GreycstorationSettings(QTabWidget* const parent)
     : QObject(static_cast<QObject*>(parent)),
-      d(new GreycstorationSettingsPriv)
+      d(new Private)
 {
-    d->parent = parent;
-
+    d->parent         = parent;
     const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     // -------------------------------------------------------------
 
-    d->generalPage     = new QWidget(parent);
-    QGridLayout* grid1 = new QGridLayout(d->generalPage);
+    d->generalPage           = new QWidget(parent);
+    QGridLayout* const grid1 = new QGridLayout(d->generalPage);
     parent->addTab(d->generalPage, i18n("General"));
 
     d->sharpnessLabel = new QLabel(i18n("Detail preservation:"), d->generalPage);
@@ -193,8 +192,8 @@ GreycstorationSettings::GreycstorationSettings(QTabWidget* parent)
 
     // -------------------------------------------------------------
 
-    d->advancedPage    = new QWidget(parent);
-    QGridLayout* grid2 = new QGridLayout(d->advancedPage);
+    d->advancedPage          = new QWidget(parent);
+    QGridLayout* const grid2 = new QGridLayout(d->advancedPage);
     parent->addTab(d->advancedPage, i18n("Advanced Settings"));
 
     d->daLabel = new QLabel(i18n("Angular step:"), d->advancedPage);
