@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-03-06
  * Description : Hue/Saturation/Lightness image filter.
  *
- * Copyright (C) 2005-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -21,8 +21,8 @@
  * GNU General Public License for more details.
  * ============================================================ */
 
-#ifndef HSLFILTER_H
-#define HSLFILTER_H
+#ifndef DIGIKAM_HSL_FILTER_H
+#define DIGIKAM_HSL_FILTER_H
 
 // Local includes
 
@@ -40,7 +40,7 @@ class DIGIKAM_EXPORT HSLContainer
 
 public:
 
-    HSLContainer()
+    explicit HSLContainer()
     {
         hue        = 0.0;
         saturation = 0.0;
@@ -48,7 +48,9 @@ public:
         lightness  = 0.0;
     };
 
-    ~HSLContainer() {};
+    ~HSLContainer()
+    {
+    };
 
 public:
 
@@ -117,4 +119,4 @@ private:
 
 } // namespace Digikam
 
-#endif // HSLFILTER_H
+#endif // DIGIKAM_HSL_FILTER_H
