@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-11
  * Description : HSL settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Julien Narboux <julien at narboux dot fr>
  *
  * This program is free software; you can redistribute it
@@ -47,12 +47,12 @@
 namespace Digikam
 {
 
-class HSLSettings::Private
+class Q_DECL_HIDDEN HSLSettings::Private
 {
 public:
 
-    Private() :
-        HSSelector(0),
+    explicit Private()
+      : HSSelector(0),
         hInput(0),
         sInput(0),
         vInput(0),
@@ -87,15 +87,14 @@ HSLSettings::HSLSettings(QWidget* const parent)
     : QWidget(parent),
       d(new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-
+    const int spacing       = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
     QGridLayout* const grid = new QGridLayout(parent);
 
     d->HSSelector = new DHueSaturationSelector();
     d->HSSelector->setWhatsThis(i18n("Select the hue and saturation adjustments of the image."));
     d->HSSelector->setMinimumSize(256, 142);
 
-    d->HSPreview = new HSPreviewWidget();
+    d->HSPreview  = new HSPreviewWidget();
     d->HSPreview->setWhatsThis(i18n("You can see here a color preview of the hue and "
                                     "saturation adjustments."));
     d->HSPreview->setMinimumSize(256, 15);
@@ -289,4 +288,4 @@ void HSLSettings::writeSettings(KConfigGroup& group)
     group.writeEntry(d->configLighnessAdjustmentEntry,   prm.lightness);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
