@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-01-08
  * Description : Hue/Saturation preview widget
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef HSPREVIEWWIDGET_H
-#define HSPREVIEWWIDGET_H
+#ifndef DIGIKAM_HS_PREVIEW_WIDGET_H
+#define DIGIKAM_HS_PREVIEW_WIDGET_H
 
 // Qt includes
 
@@ -63,6 +63,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* HSPREVIEWWIDGET_H */
+#endif // DIGIKAM_HS_PREVIEW_WIDGET_H
