@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-12
  * Description : methods that implement color management tasks
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCMANAGER_H
-#define ICCMANAGER_H
+#ifndef DIGIKAM_ICC_MANAGER_H
+#define DIGIKAM_ICC_MANAGER_H
 
 // Local includes
 
@@ -138,10 +138,12 @@ protected:
 
 private:
 
+    IccManager(const IccManager&); // Disable
+
     class Private;
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif   // ICCMANAGER_H
+#endif // DIGIKAM_ICC_MANAGER_H
