@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-07
  * Description : a wrapper class for an ICC color profile
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -42,17 +42,17 @@
 namespace Digikam
 {
 
-class IccProfile::Private : public QSharedData
+class Q_DECL_HIDDEN IccProfile::Private : public QSharedData
 {
 public:
 
-    Private() :
-        type(IccProfile::InvalidType),
+    explicit Private()
+      : type(IccProfile::InvalidType),
         handle(0)
     {
     }
 
-    Private(const Private& other)
+    explicit Private(const Private& other)
         : QSharedData(other)
     {
         handle   = 0;
@@ -98,7 +98,7 @@ public:
 
 // ----------------------------------------------------------------------------------
 
-class IccProfileStatic
+class Q_DECL_HIDDEN IccProfileStatic
 {
 public:
 
@@ -292,6 +292,7 @@ QByteArray IccProfile::data()
 
         d->data = file.readAll();
         file.close();
+
         return d->data;
     }
 
@@ -381,7 +382,7 @@ QString IccProfile::description()
 
     LcmsLock lock;
 
-    if ( !QString(dkCmsTakeProductDesc(d->handle)).isEmpty() )
+    if (!QString(dkCmsTakeProductDesc(d->handle)).isEmpty())
     {
         d->description = QString(dkCmsTakeProductDesc(d->handle)).replace(QLatin1Char('\n'), QLatin1Char(' '));
     }
@@ -507,7 +508,7 @@ QStringList IccProfile::defaultSearchPaths()
     candidates << QDir::homePath() + QLatin1String("/Library/ColorSync/Profiles");
 
     // MacPorts installs for KDE, so we include the XDG data dirs, including /usr/share/color/icc
-    QStringList dataDirs = QString::fromLocal8Bit(getenv("XDG_DATA_DIRS")).split(QLatin1Char(':'), QString::SkipEmptyParts);
+    QStringList dataDirs = QString::fromLocal8Bit(qgetenv("XDG_DATA_DIRS")).split(QLatin1Char(':'), QString::SkipEmptyParts);
 
     if (!dataDirs.contains(QLatin1String("/opt/local/share")))
     {
@@ -525,7 +526,7 @@ QStringList IccProfile::defaultSearchPaths()
     }
 
     // XDG_DATA_HOME
-    QString dataHomeDir = QString::fromLocal8Bit(getenv("XDG_DATA_HOME"));
+    QString dataHomeDir = QString::fromLocal8Bit(qgetenv("XDG_DATA_HOME"));
 
     if (!dataHomeDir.isEmpty())
     {
@@ -541,7 +542,7 @@ QStringList IccProfile::defaultSearchPaths()
 #else // LINUX
 
     // XDG data dirs, including /usr/share/color/icc
-    QStringList dataDirs = QString::fromLocal8Bit(getenv("XDG_DATA_DIRS")).split(QLatin1Char(':'), QString::SkipEmptyParts);
+    QStringList dataDirs = QString::fromLocal8Bit(qgetenv("XDG_DATA_DIRS")).split(QLatin1Char(':'), QString::SkipEmptyParts);
 
     if (!dataDirs.contains(QLatin1String("/usr/share")))
     {
@@ -559,7 +560,7 @@ QStringList IccProfile::defaultSearchPaths()
     }
 
     // XDG_DATA_HOME
-    QString dataHomeDir = QString::fromLocal8Bit(getenv("XDG_DATA_HOME"));
+    QString dataHomeDir = QString::fromLocal8Bit(qgetenv("XDG_DATA_HOME"));
 
     if (!dataHomeDir.isEmpty())
     {
@@ -606,6 +607,7 @@ void IccProfile::considerOriginalAdobeRGB(const QString& filePath)
     {
         QCryptographicHash md5(QCryptographicHash::Md5);
         md5.addData(&file);
+        file.close();
 
         if (md5.result().toHex() == QByteArray("dea88382d899d5f6e573b432473ae138"))
         {
@@ -615,4 +617,4 @@ void IccProfile::considerOriginalAdobeRGB(const QString& filePath)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
