@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-17
  * Description : Icc profile settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,12 +49,12 @@
 namespace Digikam
 {
 
-class IccProfilesSettings::Private
+class Q_DECL_HIDDEN IccProfilesSettings::Private
 {
 public:
 
-    Private() :
-        profilesBox(0)
+    explicit Private()
+      : profilesBox(0)
     {
         favoriteProfiles.setMaxCost(10);
     }
@@ -156,4 +156,4 @@ QStringList IccProfilesSettings::favoriteProfiles(KConfigGroup& group)
     return group.readPathEntry(d.configRecentlyUsedProfilesEntry, QStringList());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
