@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-09
  * Description : central place for ICC settings
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -54,17 +54,18 @@
 #   include <X11/Xlib.h>
 #   include <X11/Xatom.h>
 #   include <QX11Info>
-#endif /* HAVE_X11 */
+#endif // HAVE_X11
 
 namespace Digikam
 {
 
-class IccSettings::Private
+class Q_DECL_HIDDEN IccSettings::Private
 {
 public:
 
-    Private()
-        : configGroup(QLatin1String("Color Management"))
+    explicit Private()
+        : settings(ICCSettingsContainer()),
+          configGroup(QLatin1String("Color Management"))
     {
     }
 
@@ -92,7 +93,7 @@ public:
 
 // -----------------------------------------------------------------------------------------------
 
-class IccSettingsCreator
+class Q_DECL_HIDDEN IccSettingsCreator
 {
 public:
 
@@ -142,7 +143,7 @@ IccProfile IccSettings::monitorProfile(QWidget* const widget)
 
     if (!d->settings.monitorProfile.isNull())
     {
-        return d->settings.monitorProfile;
+        return IccProfile(d->settings.monitorProfile);
     }
     else
     {
@@ -181,11 +182,11 @@ bool IccSettings::monitorProfileFromSystem() const
 
 /*
  * From koffice/libs/pigment/colorprofiles/KoLcmsColorProfileContainer.cpp
- * Copyright (C) 2000 Matthias Elter <elter@kde.org>
+ * Copyright (C) 2000 Matthias Elter <elter at kde dot org>
  *               2001 John Califf
- *               2004 Boudewijn Rempt <boud@valdyas.org>
- * Copyright (C) 2007 Thomas Zander <zander@kde.org>
- * Copyright (C) 2007 Adrian Page <adrian@pagenet.plus.com>
+ *               2004 Boudewijn Rempt <boud at valdyas dot org>
+ * Copyright (C) 2007 Thomas Zander <zander at kde dot org>
+ * Copyright (C) 2007 Adrian Page <adrian at pagenet dot plus dot com>
 */
 IccProfile IccSettings::Private::profileFromWindowSystem(QWidget* const widget)
 {
@@ -251,7 +252,7 @@ IccProfile IccSettings::Private::profileFromWindowSystem(QWidget* const widget)
 
         if (!bytes.isEmpty())
         {
-            profile = bytes;
+            profile = IccProfile(bytes);
         }
 
         qCDebug(DIGIKAM_DIMG_LOG) << "Found X.org XICC monitor profile " << profile.description();
@@ -615,4 +616,4 @@ void IccSettings::loadAllProfilesProperties()
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
