@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-09
  * Description : central place for ICC settings
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCSETTINGS_H
-#define ICCSETTINGS_H
+#ifndef DIGIKAM_ICC_SETTINGS_H
+#define DIGIKAM_ICC_SETTINGS_H
 
 // Qt includes
 
@@ -116,7 +116,7 @@ Q_SIGNALS:
 
 private:
 
-    IccSettings();
+    explicit IccSettings();
     ~IccSettings();
 
     void readFromConfig();
@@ -130,6 +130,6 @@ private:
     friend class IccSettingsCreator;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif   // ICCSETTINGS_H
+#endif // DIGIKAM_ICC_SETTINGS_H
