@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-11-18
  * Description : a class to apply ICC color correction to image.
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
  * Copyright (C) 2009      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,7 +46,7 @@
 namespace Digikam
 {
 
-class TransformDescription
+class Q_DECL_HIDDEN TransformDescription
 {
 public:
 
@@ -83,11 +83,11 @@ public:
     int        proofIntent;
 };
 
-class IccTransform::Private : public QSharedData
+class Q_DECL_HIDDEN IccTransform::Private : public QSharedData
 {
 public:
 
-    Private()
+    explicit Private()
     {
         intent          = IccTransform::Perceptual;
         proofIntent     = IccTransform::AbsoluteColorimetric;
@@ -98,7 +98,7 @@ public:
         handle          = 0;
     }
 
-    Private(const Private& other)
+    explicit Private(const Private& other)
         : QSharedData(other)
     {
         handle = 0;
@@ -785,4 +785,4 @@ void IccTransform::closeProfiles()
 }
 */
 
-}  // namespace Digikam
+} // namespace Digikam
