@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-11-18
  * Description : a class to apply ICC color correction to image.
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
  * Copyright (C) 2009      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCTRANSFORM_H
-#define ICCTRANSFORM_H
+#ifndef DIGIKAM_ICC_TRANSFORM_H
+#define DIGIKAM_ICC_TRANSFORM_H
 
 // Qt includes
 
@@ -59,7 +59,7 @@ public:
 
 public:
 
-    IccTransform();
+    explicit IccTransform();
     ~IccTransform();
 
     IccTransform(const IccTransform& other);
@@ -164,8 +164,8 @@ private:
     QSharedDataPointer<Private> d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
 Q_DECLARE_METATYPE(Digikam::IccTransform)
 
-#endif   // ICCTRANSFORM_H
+#endif // DIGIKAM_ICC_TRANSFORM_H
