@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-09-19
  * Description : ICC Transform threaded image filter.
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCTRANSFORMFILTER_H
-#define ICCTRANSFORMFILTER_H
+#ifndef DIGIKAM_ICC_TRANSFORM_FILTER_H
+#define DIGIKAM_ICC_TRANSFORM_FILTER_H
 
 // Local includes
 
@@ -76,7 +76,7 @@ public:
 
 protected:
 
-    virtual void progressInfo(const DImg* const, float progress);
+    virtual void progressInfo(DImg* const img, float progress);
     virtual void filterImage();
 
 private:
@@ -84,6 +84,6 @@ private:
     IccTransform m_transform;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* DIMGREFOCUS_H */
+#endif // DIGIKAM_ICC_TRANSFORM_FILTER_H
