@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-09
  * Description : Enhance image with local contrasts (as human eye does).
@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009      by Nasca Octavian Paul <zynaddsubfx at yahoo dot com>
  * Copyright (C) 2009      by Julien Pontabry <julien dot pontabry at gmail dot com>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -30,7 +30,7 @@
 // Qt includes
 
 #include <QtMath>
-#include <QtConcurrent>
+#include <QtConcurrent>    // krazy:exclude=includes
 
 // Local includes
 
@@ -40,11 +40,11 @@
 namespace Digikam
 {
 
-class LocalContrastFilter::Private
+class Q_DECL_HIDDEN LocalContrastFilter::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         current_process_power_value = 20.0;
     }
@@ -526,7 +526,7 @@ void LocalContrastFilter::stretchContrast(float* const data, int datasize)
         histogram[m]++;
     }
 
-    // I want to strip the lowest and upper 0.1 procents (in the histogram) of the pixels
+    // I want to strip the lowest and upper 0.1 percents (in the histogram) of the pixels
     int          min         = 0;
     int          max         = 255;
     unsigned int desired_sum = datasize / 1000;
