@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-09
  * Description : Enhance image with local contrasts (as human eye does).
  *               LDR ToneMapper <http://zynaddsubfx.sourceforge.net/other/tonemapping>
  *
  * Copyright (C) 2009      by Julien Pontabry <julien dot pontabry at gmail dot com>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef LOCALCONTRASTFILTER_H
-#define LOCALCONTRASTFILTER_H
+#ifndef DIGIKAM_LOCAL_CONTRAST_FILTER_H
+#define DIGIKAM_LOCAL_CONTRAST_FILTER_H
 
 // Qt includes
 
@@ -123,4 +123,4 @@ private:
 
 } // namespace Digikam
 
-#endif // LOCALCONTRASTFILTER_H
+#endif // DIGIKAM_LOCAL_CONTRAST_FILTER_H
