@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-09
  * Description : Local Contrast settings view.
  *               LDR ToneMapper <http://zynaddsubfx.sourceforge.net/other/tonemapping>
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -60,13 +60,13 @@
 namespace Digikam
 {
 
-class LocalContrastSettings::Private
+class Q_DECL_HIDDEN LocalContrastSettings::Private
 {
 
 public:
 
-    Private() :
-        stretchContrastCheck(0),
+    explicit Private()
+      : stretchContrastCheck(0),
         label4(0),
         label5(0),
         label6(0),
@@ -711,22 +711,22 @@ void LocalContrastSettings::saveAsSettings()
         QTextStream stream(&file);
         stream << QLatin1String("# Photograph Local Contrast Configuration File\n");
 
-        stream << d->stretchContrastCheck->isChecked() << QLatin1String("\n");
-        stream << d->expanderBox->isChecked(1) << QLatin1String("\n");
-        stream << d->expanderBox->isChecked(2) << QLatin1String("\n");
-        stream << d->expanderBox->isChecked(3) << QLatin1String("\n");
-        stream << d->expanderBox->isChecked(4) << QLatin1String("\n");
-        stream << d->lowSaturationInput->value() << QLatin1String("\n");
-        stream << d->highSaturationInput->value() << QLatin1String("\n");
-        stream << d->functionInput->currentIndex() << QLatin1String("\n");
-        stream << d->powerInput1->value() << QLatin1String("\n");
-        stream << d->blurInput1->value() << QLatin1String("\n");
-        stream << d->powerInput2->value() << QLatin1String("\n");
-        stream << d->blurInput2->value() << QLatin1String("\n");
-        stream << d->powerInput3->value() << QLatin1String("\n");
-        stream << d->blurInput3->value() << QLatin1String("\n");
-        stream << d->powerInput4->value() << QLatin1String("\n");
-        stream << d->blurInput4->value() << QLatin1String("\n");
+        stream << d->stretchContrastCheck->isChecked() << QLatin1Char('\n');
+        stream << d->expanderBox->isChecked(1) << QLatin1Char('\n');
+        stream << d->expanderBox->isChecked(2) << QLatin1Char('\n');
+        stream << d->expanderBox->isChecked(3) << QLatin1Char('\n');
+        stream << d->expanderBox->isChecked(4) << QLatin1Char('\n');
+        stream << d->lowSaturationInput->value() << QLatin1Char('\n');
+        stream << d->highSaturationInput->value() << QLatin1Char('\n');
+        stream << d->functionInput->currentIndex() << QLatin1Char('\n');
+        stream << d->powerInput1->value() << QLatin1Char('\n');
+        stream << d->blurInput1->value() << QLatin1Char('\n');
+        stream << d->powerInput2->value() << QLatin1Char('\n');
+        stream << d->blurInput2->value() << QLatin1Char('\n');
+        stream << d->powerInput3->value() << QLatin1Char('\n');
+        stream << d->blurInput3->value() << QLatin1Char('\n');
+        stream << d->powerInput4->value() << QLatin1Char('\n');
+        stream << d->blurInput4->value() << QLatin1Char('\n');
     }
     else
     {
@@ -737,4 +737,4 @@ void LocalContrastSettings::saveAsSettings()
     file.close();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
