@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Antivignetting threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef ANTIVIGNETTINGFILTER_H
-#define ANTIVIGNETTINGFILTER_H
+#ifndef DIGIKAM_ANTI_VIGNETTING_FILTER_H
+#define DIGIKAM_ANTI_VIGNETTING_FILTER_H
 
 // Local includes
 
@@ -38,7 +38,7 @@ class DIGIKAM_EXPORT AntiVignettingContainer
 
 public:
 
-    AntiVignettingContainer()
+    explicit AntiVignettingContainer()
     {
         addvignetting = true;
         density       = 2.0;
@@ -123,6 +123,6 @@ private:
     AntiVignettingContainer m_settings;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* ANTIVIGNETTINGFILTER_H */
+#endif // DIGIKAM_ANTI_VIGNETTING_FILTER_H
