@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-15
  * Description : Anti vignetting settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,22 +44,19 @@
 // Local includes
 
 #include "dlayoutbox.h"
-#include "digikam_debug.h"
 #include "dexpanderbox.h"
 #include "dnuminput.h"
 #include "digikam_debug.h"
 
-
-
 namespace Digikam
 {
 
-class AntiVignettingSettings::Private
+class Q_DECL_HIDDEN AntiVignettingSettings::Private
 {
 public:
 
-    Private() :
-        addVignettingCheck(0),
+    explicit Private()
+      : addVignettingCheck(0),
         maskPreviewLabel(0),
         densityInput(0),
         powerInput(0),
@@ -326,4 +323,4 @@ void AntiVignettingSettings::slotSettingsChanged()
     emit signalSettingsChanged();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
