@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,20 +39,18 @@
 
 #include "dlayoutbox.h"
 #include "digikam_debug.h"
-#include "dcombobox.h"
+#include "squeezedcombobox.h"
 #include "dnuminput.h"
 #include "dexpanderbox.h"
 
-
-
 namespace Digikam
 {
 
-class LensFunCameraSelector::Private
+class Q_DECL_HIDDEN LensFunCameraSelector::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : configUseMetadata(QLatin1String("UseMetadata")),
           configCameraModel(QLatin1String("CameraModel")),
           configCameraMake(QLatin1String("CameraMake")),
@@ -109,13 +107,13 @@ public:
     const QString       orangeStyle;
     const QString       greenStyle;
 
-    DAdjustableLabel* lensDescription;
-    DAdjustableLabel* makeDescription;
-    DAdjustableLabel* modelDescription;
+    DAdjustableLabel*   lensDescription;
+    DAdjustableLabel*   makeDescription;
+    DAdjustableLabel*   modelDescription;
 
-    DComboBox*          make;
-    DComboBox*          model;
-    DComboBox*          lens;
+    SqueezedComboBox*   make;
+    SqueezedComboBox*   model;
+    SqueezedComboBox*   lens;
 
     DDoubleNumInput*    focal;
     DDoubleNumInput*    aperture;
@@ -147,8 +145,8 @@ LensFunCameraSelector::LensFunCameraSelector(QWidget* const parent)
     d->makeDescription->setWhatsThis(i18n("This is the camera maker description string found in image meta-data. "
                                           "This one is used to query and find relevant camera device information from Lensfun database."));
 
-    d->make              = new DComboBox(this);
-    d->make->setDefaultIndex(0);
+    d->make              = new SqueezedComboBox(this);
+    d->make->setCurrentIndex(0);
 
     DHBox* const hbox2   = new DHBox(this);
     d->modelLabel        = new QLabel(i18nc("camera model", "Model:"), hbox2);
@@ -159,8 +157,8 @@ LensFunCameraSelector::LensFunCameraSelector(QWidget* const parent)
     d->modelDescription->setWhatsThis(i18n("This is the camera model description string found in image meta-data. "
                                            "This one is used to query and found relevant camera device information from Lensfun database."));
 
-    d->model             = new DComboBox(this);
-    d->model->setDefaultIndex(0);
+    d->model             = new SqueezedComboBox(this);
+    d->model->setCurrentIndex(0);
 
     DHBox* const hbox3   = new DHBox(this);
     d->lensLabel         = new QLabel(i18nc("camera lens",  "Lens:"),  hbox3);
@@ -171,8 +169,8 @@ LensFunCameraSelector::LensFunCameraSelector(QWidget* const parent)
                                           "This one is used to query and found relevant lens information from Lensfun database."));
     hbox3->setStretchFactor(space3, 10);
 
-    d->lens              = new DComboBox(this);
-    d->lens->setDefaultIndex(0);
+    d->lens              = new SqueezedComboBox(this);
+    d->lens->setCurrentIndex(0);
 
     d->metadataUsage->setEnabled(false);
     d->metadataUsage->setCheckState(Qt::Unchecked);
@@ -234,9 +232,6 @@ LensFunCameraSelector::LensFunCameraSelector(QWidget* const parent)
 
     connect(d->distance, SIGNAL(valueChanged(double)),
             this, SLOT(slotDistanceChanged()));
-
-    populateDeviceCombos();
-    populateLensCombo();
 }
 
 LensFunCameraSelector::~LensFunCameraSelector()
@@ -331,17 +326,6 @@ void LensFunCameraSelector::writeSettings(KConfigGroup& group)
 void LensFunCameraSelector::setMetadata(const DMetadata& meta)
 {
     d->metadata = meta;
-
-    if (d->metadata.isEmpty())
-    {
-        d->metadataUsage->setCheckState(Qt::Unchecked);
-        setEnabledUseMetadata(false);
-    }
-    else
-    {
-        setEnabledUseMetadata(true);
-        findFromMetadata();
-    }
 }
 
 void LensFunCameraSelector::setEnabledUseMetadata(bool b)
@@ -456,16 +440,16 @@ void LensFunCameraSelector::refreshSettingsView()
 
     if (d->iface->usedCamera())
     {
-        makerIdx = d->make->combo()->findText(d->iface->settings().cameraMake);
+        makerIdx = d->make->findText(d->iface->settings().cameraMake);
         qCDebug(DIGIKAM_DIMG_LOG) << "makerIdx: " << makerIdx << " (" << d->iface->settings().cameraMake << ")";
     }
     else
     {
-        int i = d->make->combo()->findText(d->iface->makeDescription());
+        int i = d->make->findText(d->iface->makeDescription());
 
         if (i == -1)
         {
-            i = d->make->combo()->findText(QLatin1String("Generic"));
+            i = d->make->findText(QLatin1String("Generic"));
         }
 
         if (i >= 0)
@@ -504,7 +488,7 @@ void LensFunCameraSelector::refreshSettingsView()
 
     if (d->iface->usedCamera())
     {
-        modelIdx = d->model->combo()->findText(d->iface->settings().cameraModel);
+        modelIdx = d->model->findText(d->iface->settings().cameraModel);
         qCDebug(DIGIKAM_DIMG_LOG) << "modelIdx: " << modelIdx << " (" << d->iface->settings().cameraModel << ")";
     }
 
@@ -539,7 +523,7 @@ void LensFunCameraSelector::refreshSettingsView()
 
     if (d->iface->usedLens())
     {
-        lensIdx = d->lens->combo()->findText(d->iface->settings().lensModel);
+        lensIdx = d->lens->findText(d->iface->settings().lensModel);
         qCDebug(DIGIKAM_DIMG_LOG) << "lensIdx: " << lensIdx << " (" << d->iface->settings().lensModel << ")";
     }
 
@@ -631,11 +615,11 @@ void LensFunCameraSelector::populateDeviceCombos()
     const lfCamera* const* it = d->iface->lensFunCameras();
 
     // reset box
-    d->model->combo()->clear();
+    d->model->clear();
 
     bool firstRun = false;
 
-    if (d->make->combo()->count() == 0)
+    if (d->make->count() == 0)
     {
         firstRun = true;
     }
@@ -647,28 +631,28 @@ void LensFunCameraSelector::populateDeviceCombos()
             // Maker DB does not change, so we fill it only once.
             if ((*it)->Maker)
             {
-                QString t = QString::fromLatin1((*it)->Maker);
+                QString t = QLatin1String((*it)->Maker);
 
-                if (d->make->combo()->findText(t, Qt::MatchExactly) < 0)
+                if (d->make->findText(t, Qt::MatchExactly) < 0)
                 {
-                    d->make->addItem(t);
+                    d->make->addSqueezedItem(t);
                 }
             }
         }
 
         // Fill models for current selected maker
-        if ((*it)->Model && QString::fromLatin1((*it)->Maker) == d->make->combo()->currentText())
+        if ((*it)->Model && QLatin1String((*it)->Maker) == d->make->itemHighlighted())
         {
             LensFunIface::DevicePtr dev = *it;
             QVariant b                  = qVariantFromValue(dev);
-            d->model->combo()->addItem(QString::fromLatin1(dev->Model), b);
+            d->model->addSqueezedItem(QLatin1String(dev->Model), b);
         }
 
         ++it;
     }
 
-    d->make->combo()->model()->sort(0,  Qt::AscendingOrder);
-    d->model->combo()->model()->sort(0, Qt::AscendingOrder);
+    //d->make->model()->sort(0,  Qt::AscendingOrder);
+    //d->model->model()->sort(0, Qt::AscendingOrder);
 
     d->make->blockSignals(false);
     d->model->blockSignals(false);
@@ -677,10 +661,10 @@ void LensFunCameraSelector::populateDeviceCombos()
 void LensFunCameraSelector::populateLensCombo()
 {
     d->lens->blockSignals(true);
-    d->lens->combo()->clear();
+    d->lens->clear();
     d->lens->blockSignals(false);
 
-    QVariant v = d->model->combo()->itemData(d->model->currentIndex());
+    QVariant v = d->model->itemData(d->model->currentIndex());
 
     if (!v.isValid() || v.isNull())
     {
@@ -706,15 +690,24 @@ void LensFunCameraSelector::populateLensCombo()
     settings.cropFactor       = dev ? dev->CropFactor : -1.0;
     d->iface->setSettings(settings);
 
+    QMultiMap<QString, QVariant> lensMap;
+
     while (lenses && *lenses)
     {
         LensFunIface::LensPtr lens = *lenses;
         QVariant b                 = qVariantFromValue(lens);
-        d->lens->combo()->addItem(QString::fromLatin1(lens->Model), b);
+        lensMap.insert(QLatin1String(lens->Model), b);
         ++lenses;
     }
 
-    d->lens->combo()->model()->sort(0, Qt::AscendingOrder);
+    QMultiMap<QString, QVariant>::ConstIterator it = lensMap.constBegin();
+
+    for ( ; it != lensMap.constEnd() ; ++it)
+    {
+        d->lens->addSqueezedItem(it.key(), it.value());
+    }
+
+    //d->lens->model()->sort(0, Qt::AscendingOrder);
     d->lens->blockSignals(false);
 }
 
@@ -736,7 +729,7 @@ void LensFunCameraSelector::slotModelChanged()
 
 void LensFunCameraSelector::slotModelSelected()
 {
-    QVariant v = d->model->combo()->itemData(d->model->currentIndex());
+    QVariant v = d->model->itemData(d->model->currentIndex());
     d->iface->setUsedCamera(d->metadataUsage->isChecked() && d->passiveMetadataUsage ? 0 :
                             v.value<LensFunIface::DevicePtr>());
     emit signalLensSettingsChanged();
@@ -744,7 +737,7 @@ void LensFunCameraSelector::slotModelSelected()
 
 void LensFunCameraSelector::slotLensSelected()
 {
-    QVariant v = d->lens->combo()->itemData(d->lens->currentIndex());
+    QVariant v = d->lens->itemData(d->lens->currentIndex());
     d->iface->setUsedLens(d->metadataUsage->isChecked() && d->passiveMetadataUsage ? 0 :
                           v.value<LensFunIface::LensPtr>());
 
@@ -753,7 +746,8 @@ void LensFunCameraSelector::slotLensSelected()
     if (d->iface->usedLens() &&
         settings.cropFactor <= 0.0) // this should not happen
     {
-        qCDebug(DIGIKAM_DIMG_LOG) << "No crop factor is set for camera, using lens calibration data: " << d->iface->usedLens()->CropFactor;
+        qCDebug(DIGIKAM_DIMG_LOG) << "No crop factor is set for camera, using lens calibration data: "
+                                  << d->iface->usedLens()->CropFactor;
         settings.cropFactor = d->iface->usedLens()->CropFactor;
     }
 
@@ -788,4 +782,23 @@ void LensFunCameraSelector::slotDistanceChanged()
     emit signalLensSettingsChanged();
 }
 
-}  // namespace Digikam
+void LensFunCameraSelector::showEvent(QShowEvent* event)
+{
+    QWidget::showEvent(event);
+
+    populateDeviceCombos();
+    populateLensCombo();
+
+    if (d->metadata.isEmpty())
+    {
+        d->metadataUsage->setCheckState(Qt::Unchecked);
+        setEnabledUseMetadata(false);
+    }
+    else
+    {
+        setEnabledUseMetadata(true);
+        findFromMetadata();
+    }
+}
+
+} // namespace Digikam
