@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -19,8 +19,8 @@
  *
  * ============================================================ */
 
-#ifndef LENSFUNCAMERASELECTOR_H
-#define LENSFUNCAMERASELECTOR_H
+#ifndef DIGIKAM_LENS_FUN_CAMERA_SELECTOR_H
+#define DIGIKAM_LENS_FUN_CAMERA_SELECTOR_H
 
 // Qt includes
 
@@ -92,12 +92,16 @@ private:
     void populateDeviceCombos();
     void populateLensCombo();
 
+protected:
+
+    void showEvent(QShowEvent* event);
+
 private:
 
     class Private;
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* LENSFUNCAMERASELECTOR_H */
+#endif // DIGIKAM_LENS_FUN_CAMERA_SELECTOR_H
