@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,7 +25,7 @@
 #include <QByteArray>
 #include <QCheckBox>
 #include <QString>
-#include <QtConcurrent>
+#include <QtConcurrent>    // krazy:exclude=includes
 
 // Local includes
 
@@ -36,11 +36,11 @@
 namespace Digikam
 {
 
-class LensFunFilter::Private
+class Q_DECL_HIDDEN LensFunFilter::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         iface    = 0;
         modifier = 0;
@@ -235,7 +235,7 @@ void LensFunFilter::filterImage()
 
     QList<int> vals = multithreadedSteps(m_destImage.height());
 
-    // Stage 1: Chromatic Aberation Corrections
+    // Stage 1: Chromatic Aberration Corrections
 
     if (d->iface->settings().filterCCA)
     {
@@ -254,7 +254,7 @@ void LensFunFilter::filterImage()
         foreach(QFuture<void> t, tasks)
             t.waitForFinished();
 
-        qCDebug(DIGIKAM_DIMG_LOG) << "Chromatic Aberation Corrections applied.";
+        qCDebug(DIGIKAM_DIMG_LOG) << "Chromatic Aberration Corrections applied.";
     }
 
     postProgress(30);
@@ -327,28 +327,28 @@ bool LensFunFilter::registerSettingsToXmp(MetaEngineData& data) const
     LensFunContainer prm = d->iface->settings();
 
     str.append(i18n("Camera: %1-%2",        prm.cameraMake, prm.cameraModel));
-    str.append(QLatin1String("\n"));
+    str.append(QLatin1Char('\n'));
     str.append(i18n("Lens: %1",             prm.lensModel));
-    str.append(QLatin1String("\n"));
-    str.append(i18n("Subject Distance: %1", QString::number(prm.subjectDistance)));
-    str.append(QLatin1String("\n"));
-    str.append(i18n("Aperture: %1",         QString::number(prm.aperture)));
-    str.append(QLatin1String("\n"));
-    str.append(i18n("Focal Length: %1",     QString::number(prm.focalLength)));
-    str.append(QLatin1String("\n"));
-    str.append(i18n("Crop Factor: %1",      QString::number(prm.cropFactor)));
-    str.append(QLatin1String("\n"));
+    str.append(QLatin1Char('\n'));
+    str.append(i18n("Subject Distance: <numid>%1</numid>", prm.subjectDistance));
+    str.append(QLatin1Char('\n'));
+    str.append(i18n("Aperture: <numid>%1</numid>",         prm.aperture));
+    str.append(QLatin1Char('\n'));
+    str.append(i18n("Focal Length: <numid>%1</numid>",     prm.focalLength));
+    str.append(QLatin1Char('\n'));
+    str.append(i18n("Crop Factor: <numid>%1</numid>",      prm.cropFactor));
+    str.append(QLatin1Char('\n'));
     str.append(i18n("CCA Correction: %1",   prm.filterCCA  && d->iface->supportsCCA()       ? i18n("enabled") : i18n("disabled")));
-    str.append(QLatin1String("\n"));
+    str.append(QLatin1Char('\n'));
     str.append(i18n("VIG Correction: %1",   prm.filterVIG  && d->iface->supportsVig()       ? i18n("enabled") : i18n("disabled")));
-    str.append(QLatin1String("\n"));
+    str.append(QLatin1Char('\n'));
     str.append(i18n("DST Correction: %1",   prm.filterDST && d->iface->supportsDistortion() ? i18n("enabled") : i18n("disabled")));
-    str.append(QLatin1String("\n"));
+    str.append(QLatin1Char('\n'));
     str.append(i18n("GEO Correction: %1",   prm.filterGEO && d->iface->supportsGeometry()   ? i18n("enabled") : i18n("disabled")));
 
     DMetadata meta(data);
     bool ret = meta.setXmpTagString("Xmp.digiKam.LensCorrectionSettings",
-                                    str.replace(QLatin1Char('\n'), QLatin1String(" ; ")), false);
+                                    str.replace(QLatin1Char('\n'), QLatin1String(" ; ")));
     data     = meta.data();
 
     return ret;
@@ -392,4 +392,4 @@ void LensFunFilter::readParameters(const Digikam::FilterAction& action)
     d->iface->setSettings(prm);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
