@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -33,11 +33,11 @@
 namespace Digikam
 {
 
-class LensFunIface::Private
+class Q_DECL_HIDDEN LensFunIface::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         usedLens   = 0;
         usedCamera = 0;
@@ -65,22 +65,32 @@ LensFunIface::LensFunIface()
 {
     d->lfDb          = lf_db_new();
 
+    // Lensfun host XML files in a dedicated sub-directory.
     QString lensPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                               QLatin1String("lensfun"),
                                               QStandardPaths::LocateDirectory);
 
-    qCDebug(DIGIKAM_DIMG_LOG) << "Root lens database dir: " << lensPath;
+    QDir lensDir;
 
-    // For older Lensfun versions.
-    QDir lensDir(lensPath, QLatin1String("*.xml"));
+    // In first try to use last Lensfun version data dir.
+    lensDir = QDir(lensPath + QLatin1String("/version_2"), QLatin1String("*.xml"));
 
     if (lensDir.entryList().isEmpty())
     {
-        // More Lensfun recent versions use a sub-directory to host XML files.
+        // Fail-back to revision 1.
+
         lensDir = QDir(lensPath + QLatin1String("/version_1"), QLatin1String("*.xml"));
+
+        if (lensDir.entryList().isEmpty())
+        {
+           // Fail-back to revision 0 which host XML data in root data directory.
+           lensDir = QDir(lensPath, QLatin1String("*.xml"));
+        }
     }
 
-    foreach(const QString& lens, lensDir.entryList())
+    qCDebug(DIGIKAM_DIMG_LOG) << "Using root lens database dir: " << lensPath;
+
+    foreach (const QString& lens, lensDir.entryList())
     {
         qCDebug(DIGIKAM_DIMG_LOG) << "Load lens database file: " << lens;
         d->lfDb->Load(QFile::encodeName(lensDir.absoluteFilePath(lens)).constData());
@@ -342,7 +352,7 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(const DMetadata& meta
                 else
                 {
                     // Best case for an exact match is to have only one item returned by Lensfun searches.
-                    if(lensMatches.count() == 1)
+                    if (lensMatches.count() == 1)
                     {
                         setUsedLens(lensMatches.first());
                         qCDebug(DIGIKAM_DIMG_LOG) << "Lens found     : " << d->settings.lensModel;
@@ -353,16 +363,16 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(const DMetadata& meta
                         qCDebug(DIGIKAM_DIMG_LOG) << "lens matches   : more than one...";
                         const lfLens* exact = 0;
 
-                        Q_FOREACH(const lfLens* const l, lensMatches)
+                        foreach (const lfLens* const l, lensMatches)
                         {
-                            if(QLatin1String(l->Model) == d->lensDescription)
+                            if (QLatin1String(l->Model) == d->lensDescription)
                             {
-                                qCDebug(DIGIKAM_DIMG_LOG) << "found exact match from" << lensMatches.count() << "possitibilites:" << l->Model;
+                                qCDebug(DIGIKAM_DIMG_LOG) << "found exact match from" << lensMatches.count() << "possibilities:" << l->Model;
                                 exact = l;
                             }
                         }
 
-                        if(exact)
+                        if (exact)
                         {
                             setUsedLens(exact);
                         }
@@ -547,4 +557,4 @@ QString LensFunIface::lensFunVersion()
     return QString::fromLatin1("%1.%2.%3-%4").arg(LF_VERSION_MAJOR).arg(LF_VERSION_MINOR).arg(LF_VERSION_MICRO).arg(LF_VERSION_BUGFIX);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
