@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-12-27
  * Description : access pixels method for lens distortion algorithm.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef PIXEL_ACCESS_H
-#define PIXEL_ACCESS_H
+#ifndef DIGIKAM_PIXEL_ACCESS_H
+#define DIGIKAM_PIXEL_ACCESS_H
 
 #define PixelAccessRegions 20
 #define PixelAccessWidth   40
@@ -90,6 +90,6 @@ private:
     int   m_tileMaxY[PixelAccessRegions];
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* PIXEL_ACCESS_H */
+#endif // DIGIKAM_PIXEL_ACCESS_H
