@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-09-30
  * Description : a widget to display an image histogram and its control widgets
  *
  * Copyright (C) 2008-2009 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,12 +54,11 @@
 namespace Digikam
 {
 
-class HistogramBox::Private
+class Q_DECL_HIDDEN HistogramBox::Private
 {
-
 public:
 
-    Private()
+    explicit Private()
     {
         scaleBG         = 0;
         linHistoButton  = 0;
@@ -83,7 +82,8 @@ public:
 };
 
 HistogramBox::HistogramBox(QWidget* const parent, HistogramBoxType type, bool selectMode)
-    : QWidget(parent), d(new Private)
+    : QWidget(parent),
+      d(new Private)
 {
     d->channelCB               = new QComboBox(this);
     QLabel* const channelLabel = new QLabel(i18n("Channel:"), this);
@@ -272,24 +272,24 @@ void HistogramBox::setHistogramType(HistogramBoxType type)
     typedef QPair<QString, QString> ChannelPair;
 
     ChannelPair luminosityPair(i18nc("The luminosity channel", "Luminosity"), i18n(
-                                   "<b>Luminosity</b>: display the image's luminosity values."));
+                                     "<b>Luminosity</b>: display the image's luminosity values."));
 
     ChannelPair redPair(i18nc("The red channel", "Red"), i18n(
-                            "<b>Red</b>: display the red image-channel values."));
+                              "<b>Red</b>: display the red image-channel values."));
 
     ChannelPair greenPair(i18nc("The green channel", "Green"), i18n(
-                              "<b>Green</b>: display the green image-channel values."));
+                                "<b>Green</b>: display the green image-channel values."));
 
     ChannelPair bluePair(i18nc("The blue channel", "Blue"), i18n(
-                             "<b>Blue</b>: display the blue image-channel values."));
+                               "<b>Blue</b>: display the blue image-channel values."));
 
     ChannelPair colorsPair(i18nc("The colors channel", "Colors"), i18n(
-                               "<b>Colors</b>: Display all color channel values at the same time."));
+                                 "<b>Colors</b>: Display all color channel values at the same time."));
 
     ChannelPair alphaPair(i18nc("The alpha channel", "Alpha"), i18n(
-                              "<b>Alpha</b>: display the alpha image-channel values. "
-                              "This channel corresponds to the transparency value and "
-                              "is supported by some image formats, such as PNG or TIF."));
+                                "<b>Alpha</b>: display the alpha image-channel values. "
+                                "This channel corresponds to the transparency value and "
+                                "is supported by some image formats, such as PNG or TIF."));
 
     channelDescMap.insert(LuminosityChannel, luminosityPair);
     channelDescMap.insert(RedChannel, redPair);
