@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-09-30
  * Description : a widget to display an image histogram and its control widgets
  *
  * Copyright (C) 2008-2009 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef HISTOGRAMBOX_H
-#define HISTOGRAMBOX_H
+#ifndef DIGIKAM_HISTOGRAM_BOX_H
+#define DIGIKAM_HISTOGRAM_BOX_H
 
 // Qt includes
 
@@ -48,7 +48,9 @@ class DIGIKAM_EXPORT HistogramBox : public QWidget
 
 public:
 
-    explicit HistogramBox(QWidget* const parent = 0, HistogramBoxType type = Digikam::LRGB, bool selectMode = false);
+    explicit HistogramBox(QWidget* const parent = 0,
+                          HistogramBoxType type = Digikam::LRGB,
+                          bool selectMode = false);
     ~HistogramBox();
 
     void setHistogramType(HistogramBoxType type);
@@ -89,4 +91,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* HISTOGRAMBOX_H */
+#endif // DIGIKAM_HISTOGRAM_BOX_H
