@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-10-26
  * Description : a class that manages painting histograms
  *
  * Copyright (C) 2009      by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,13 +46,13 @@
 namespace Digikam
 {
 
-class HistogramPainter::Private
+class Q_DECL_HIDDEN HistogramPainter::Private
 {
 
 public:
 
-    explicit Private() :
-        histogram(0),
+    explicit Private()
+      : histogram(0),
         widgetToInitFrom(0),
         scale(LogScaleHistogram),
         channelType(LuminosityChannel),
@@ -243,7 +243,7 @@ public:
         curvePath.lineTo(1,          wHeight - 1);
         curvePath.closeSubpath();
 
-        p2.fillRect(0, 0, wWidth, wHeight, palette.color(QPalette::Active, QPalette::Background));
+        p2.fillRect(0, 0, wWidth, wHeight, palette.color(QPalette::Active, QPalette::Window));
 
         QColor pColor;
         QColor bColor;
@@ -266,8 +266,8 @@ public:
                 break;
 
             default:
-                pColor = palette.color(QPalette::Active,   QPalette::Foreground);
-                bColor = palette.color(QPalette::Inactive, QPalette::Foreground);
+                pColor = palette.color(QPalette::Active,   QPalette::WindowText);
+                bColor = palette.color(QPalette::Inactive, QPalette::WindowText);
                 break;
         }
 
@@ -281,8 +281,8 @@ public:
                            (int)(selectionMax * wWidth - selectionMin * wWidth), wHeight);
             p2.fillRect((int)(selectionMin * wWidth), 0,
                         (int)(selectionMax * wWidth - selectionMin * wWidth), wHeight,
-                        QBrush(palette.color(QPalette::Active, QPalette::Foreground), Qt::SolidPattern));
-            p2.fillPath(curvePath, QBrush(palette.color(QPalette::Active, QPalette::Background), Qt::SolidPattern));
+                        QBrush(palette.color(QPalette::Active, QPalette::WindowText), Qt::SolidPattern));
+            p2.fillPath(curvePath, QBrush(palette.color(QPalette::Active, QPalette::Window), Qt::SolidPattern));
         }
 
         p2.end();
@@ -355,7 +355,7 @@ public:
         curveBlue.lineTo(1, wHeight - 1);
         curveBlue.closeSubpath();
 
-        p2.fillRect(0, 0, wWidth, wHeight, palette.color(QPalette::Active, QPalette::Background));
+        p2.fillRect(0, 0, wWidth, wHeight, palette.color(QPalette::Active, QPalette::Window));
         p2.fillPath(curveBlue,  QBrush(Qt::black, Qt::SolidPattern));
         p2.fillPath(curveRed,   QBrush(Qt::black, Qt::SolidPattern));
         p2.fillPath(curveGreen, QBrush(Qt::black, Qt::SolidPattern));
@@ -379,7 +379,7 @@ public:
             p2.setCompositionMode(QPainter::CompositionMode_Source);
             p2.fillRect((int)(selectionMin * wWidth), 0,
                         (int)(selectionMax * wWidth - selectionMin * wWidth), wHeight,
-                        palette.color(QPalette::Active, QPalette::Foreground));
+                        palette.color(QPalette::Active, QPalette::WindowText));
             p2.fillPath(curveBlue, QBrush(Qt::black,  Qt::SolidPattern));
             p2.fillPath(curveRed, QBrush(Qt::black,   Qt::SolidPattern));
             p2.fillPath(curveGreen, QBrush(Qt::black, Qt::SolidPattern));
@@ -514,7 +514,8 @@ public:
 };
 
 HistogramPainter::HistogramPainter(QObject* const parent)
-    : QObject(parent), d(new Private())
+    : QObject(parent),
+      d(new Private())
 {
 }
 
@@ -602,7 +603,7 @@ void HistogramPainter::render(QPixmap& bufferPixmap)
     }
 
     // clear background
-    d->painter.fillRect(0, 0, wWidth, wHeight, d->palette.color(QPalette::Active, QPalette::Background));
+    d->painter.fillRect(0, 0, wWidth, wHeight, d->palette.color(QPalette::Active, QPalette::Window));
 
     // decide how to render the line
     if (d->channelType == ColorChannels)
@@ -625,7 +626,7 @@ void HistogramPainter::render(QPixmap& bufferPixmap)
     }
 
     // draw a final border around everything
-    d->painter.setPen(QPen(d->palette.color(QPalette::Active, QPalette::Foreground), 1, Qt::SolidLine));
+    d->painter.setPen(QPen(d->palette.color(QPalette::Active, QPalette::WindowText), 1, Qt::SolidLine));
     d->painter.drawRect(0, 0, wWidth - 1, wHeight - 1);
     d->painter.end();
 }
