@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-07-21
  * Description : a widget to display an image histogram.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef HISTOGRAMWIDGET_H
-#define HISTOGRAMWIDGET_H
+#ifndef DIGIKAM_HISTOGRAM_WIDGET_H
+#define DIGIKAM_HISTOGRAM_WIDGET_H
 
 // Qt includes
 
@@ -54,7 +54,8 @@ public:
     /** Standard constructor. Needed to use updateData() methods after to create valid instance.
      */
     HistogramWidget(int w, int h,                              // Widget size.
-                    QWidget* const parent=0, bool selectMode=true,
+                    QWidget* const parent=0,
+                    bool selectMode=true,
                     bool showProgress=true,
                     bool statisticsVisible=false);
 
@@ -136,6 +137,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* HISTOGRAMWIDGET_H */
+#endif // DIGIKAM_HISTOGRAM_WIDGET_H
