@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-07-21
  * Description : image histogram manipulation methods.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,7 +42,7 @@
 namespace Digikam
 {
 
-class ImageHistogram::Private
+class Q_DECL_HIDDEN ImageHistogram::Private
 {
 
 public:
@@ -61,7 +61,7 @@ public:
 
 public:
 
-    Private()
+    explicit Private()
     {
         histogram     = 0;
         histoSegments = 0;
@@ -81,7 +81,8 @@ public:
 };
 
 ImageHistogram::ImageHistogram(const DImg& img, QObject* const parent)
-    : DynamicThread(parent), d(new Private)
+    : DynamicThread(parent),
+      d(new Private)
 {
     // A simple copy of reference must be enough instead a deep copy. See this BKO comment for details:
     // https://bugs.kde.org/show_bug.cgi?id=274555#c40
@@ -197,6 +198,7 @@ void ImageHistogram::calculate()
 
         // count here instead of inside the loop, because d is not optimized because it's not defined in the header
         const uint count = d->img.width() * d->img.height() * 4;
+
         for (i = 0 ; runningFlag() && (i < count) ; i += 4)
         {
             blue  = data[i    ];
@@ -228,6 +230,7 @@ void ImageHistogram::calculate()
 
         // count here instead of inside the loop, because d is not optimized because it's not defined in the header
         const uint count = d->img.width() * d->img.height() * 4;
+
         for (i = 0 ; runningFlag() && (i < count) ; i += 4)
         {
             blue  = data[i    ];
@@ -690,4 +693,4 @@ double ImageHistogram::getMaximum(int channel, int start, int end) const
     return max;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
