@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-07-21
  * Description : image histogram manipulation methods.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,11 +21,12 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEHISTOGRAM_H
-#define IMAGEHISTOGRAM_H
+#ifndef DIGIKAM_IMAGE_HISTOGRAM_H
+#define DIGIKAM_IMAGE_HISTOGRAM_H
 
 // Qt includes
 
+#include <QObject>
 #include <QEvent>
 #include <QThread>
 
@@ -34,8 +35,6 @@
 #include "digikam_export.h"
 #include "dynamicthread.h"
 
-class QObject;
-
 namespace Digikam
 {
 
@@ -50,15 +49,21 @@ public:
     explicit ImageHistogram(const DImg& img, QObject* const parent = 0);
     ~ImageHistogram();
 
-    /** Started computation: synchronous or threaded */
+    /**
+     * Started computation: synchronous or threaded.
+     */
     void calculate();
     void calculateInThread();
 
-    /** Stop threaded computation. */
+    /**
+     * Stop threaded computation.
+     */
     void stopCalculation();
     bool isCalculating()  const;
 
-    /** Methods to access the histogram data.*/
+    /**
+     * Methods to access the histogram data.
+     */
     bool   isSixteenBit() const;
     bool   isValid()      const;
 
@@ -91,6 +96,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* IMAGEHISTOGRAM_H */
+#endif // DIGIKAM_IMAGE_HISTOGRAM_H
