@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-07-29
  * Description : image levels manipulation methods.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -53,7 +53,7 @@
 namespace Digikam
 {
 
-class ImageLevels::Private
+class Q_DECL_HIDDEN ImageLevels::Private
 {
 
 public:
@@ -85,7 +85,7 @@ public:
 
 public:
 
-    Private()
+    explicit Private()
     {
         levels     = 0;
         lut        = 0;
@@ -355,7 +355,7 @@ void ImageLevels::levelsCalculateTransfers()
 
     for (j = 0 ; j < 5 ; ++j)
     {
-        for (i = 0; i <= (d->sixteenBit ? 65535 : 255); ++i)
+        for (i = 0 ; i <= (d->sixteenBit ? 65535 : 255) ; ++i)
         {
             //  determine input intensity.
 
@@ -374,6 +374,7 @@ void ImageLevels::levelsCalculateTransfers()
             if (d->levels->gamma[j] != 0.0)
             {
                 inten = pow(inten, (1.0 / d->levels->gamma[j]));
+                (void)inten; // Remove clang warnings.
             }
         }
     }
@@ -809,4 +810,4 @@ bool ImageLevels::saveLevelsToGimpLevelsFile(const QUrl& fileUrl)
     return true;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
