@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-25-02
  * Description : Levels image filter
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef LEVELSFILTER_H
-#define LEVELSFILTER_H
+#ifndef DIGIKAM_LEVELS_FILTER_H
+#define DIGIKAM_LEVELS_FILTER_H
 
 // Local includes
 
@@ -41,9 +41,9 @@ class DIGIKAM_EXPORT LevelsContainer
 
 public:
 
-    LevelsContainer()
+    explicit LevelsContainer()
     {
-        for (int i=0 ; i<5 ; ++i)
+        for (int i = 0 ; i < 5 ; ++i)
         {
             lInput[i]  = 0;
             hInput[i]  = 65535;
@@ -53,7 +53,9 @@ public:
         }
     };
 
-    ~LevelsContainer() {};
+    ~LevelsContainer()
+    {
+    };
 
 public:
 
@@ -73,9 +75,15 @@ class DIGIKAM_EXPORT LevelsFilter : public DImgThreadedFilter
 public:
 
     explicit LevelsFilter(QObject* const parent = 0);
-    explicit LevelsFilter(DImg* const orgImage, QObject* const parent=0, const LevelsContainer& settings=LevelsContainer());
-    explicit LevelsFilter(const LevelsContainer& settings, DImgThreadedFilter* const master,
-                          const DImg& orgImage, DImg& destImage, int progressBegin=0, int progressEnd=100);
+    explicit LevelsFilter(DImg* const orgImage,
+                          QObject* const parent=0,
+                          const LevelsContainer& settings=LevelsContainer());
+    explicit LevelsFilter(const LevelsContainer& settings,
+                          DImgThreadedFilter* const master,
+                          const DImg& orgImage,
+                          DImg& destImage,
+                          int progressBegin=0,
+                          int progressEnd=100);
     virtual ~LevelsFilter();
 
     static QString          FilterIdentifier()
@@ -117,4 +125,4 @@ private:
 
 } // namespace Digikam
 
-#endif // LEVELSFILTER_H
+#endif // DIGIKAM_LEVELS_FILTER_H
