@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-10-18
  * Description : Wavelets YCrCb Noise Reduction settings estimation by image content analys.
@@ -12,7 +12,7 @@
  *               http://community.kde.org/Digikam/SoK2012/AutoNR
  *
  * Copyright (C) 2012-2013 by Sayantan Datta <sayantan dot knz at gmail dot com>
- * Copyright (C) 2012-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,6 +27,8 @@
  *
  * ============================================================ */
 
+#include "nrestimate.h"
+
 // C++ includes
 
 #include <cmath>
@@ -34,7 +36,7 @@
 
 // OpenCV includes
 
-#include "libopencv.h"
+#include "digikam_opencv.h"
 
 // Qt includes.
 
@@ -44,21 +46,20 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "nrestimate.h"
 #include "nrfilter.h"
 
 namespace Digikam
 {
 
-class NREstimate::Private
+class Q_DECL_HIDDEN NREstimate::Private
 {
 public:
 
-    Private() :
-       clusterCount(30),
-       size(512)
+    explicit Private()
+      : clusterCount(30),
+        size(512)
     {
-        for (int c = 0 ; c < 3; c++)
+        for (int c = 0 ; c < 3 ; ++c)
         {
             fimg[c] = 0;
         }
@@ -98,16 +99,16 @@ void NREstimate::readImage() const
 {
     DColor col;
 
-    for (int c = 0; runningFlag() && (c < 3); c++)
+    for (int c = 0 ; runningFlag() && (c < 3) ; ++c)
     {
         d->fimg[c] = new float[m_orgImage.numPixels()];
     }
 
     int j = 0;
 
-    for (uint y = 0; runningFlag() && (y < m_orgImage.height()); y++)
+    for (uint y = 0 ; runningFlag() && (y < m_orgImage.height()) ; ++y)
     {
-        for (uint x = 0; runningFlag() && (x < m_orgImage.width()); x++)
+        for (uint x = 0 ; runningFlag() && (x < m_orgImage.width()) ; ++x)
         {
             col           = m_orgImage.getPixelColor(x, y);
             d->fimg[0][j] = col.red();
@@ -133,7 +134,7 @@ void NREstimate::startAnalyse()
     // convert the image into YCrCb color model
     NRFilter::srgb2ycbcr(d->fimg, m_orgImage.numPixels());
 
-    // One dimentional CvMat which stores the image
+    // One dimensional CvMat which stores the image
     CvMat* points    = cvCreateMat(m_orgImage.numPixels(), 3, CV_32FC1);
 
     // matrix to store the index of the clusters
@@ -142,9 +143,9 @@ void NREstimate::startAnalyse()
     // pointer variable to handle the CvMat* points (the image in CvMat format)
     float* pointsPtr = reinterpret_cast<float*>(points->data.ptr);
 
-    for (uint x=0 ; runningFlag() && (x < m_orgImage.numPixels()) ; x++)
+    for (uint x = 0 ; runningFlag() && (x < m_orgImage.numPixels()) ; ++x)
     {
-        for (int y=0 ; runningFlag() && (y < 3) ; y++)
+        for (int y = 0 ; runningFlag() && (y < 3) ; ++y)
         {
             *pointsPtr++ = (float)d->fimg[y][x];
         }
@@ -158,11 +159,8 @@ void NREstimate::startAnalyse()
 
     //-- KMEANS ---------------------------------------------------------------------------------------------
 
-    if (runningFlag())
-    {
-        cvKMeans2(points, d->clusterCount, clusters,
-                  cvTermCriteria(CV_TERMCRIT_EPS + CV_TERMCRIT_ITER, 10, 1.0), 3, 0, 0, centers, 0);
-    }
+    cvKMeans2(points, d->clusterCount, clusters,
+              cvTermCriteria(CV_TERMCRIT_EPS + CV_TERMCRIT_ITER, 10, 1.0), 3, 0, 0, centers, 0);
 
     qCDebug(DIGIKAM_DIMG_LOG) << "cvKmeans2 successfully run";
     postProgress(15);
@@ -171,17 +169,18 @@ void NREstimate::startAnalyse()
 
     QScopedArrayPointer<int> rowPosition(new int[d->clusterCount]);
 
-    //the row position array would just make the hold the number of elements in each cluster
+    // The row position array would just make the hold the number of elements in each cluster
 
-    for (uint i=0 ; runningFlag() && (i < d->clusterCount) ; i++)
+    for (uint i = 0 ; runningFlag() && (i < d->clusterCount) ; ++i)
     {
         //initializing the cluster count array
         rowPosition[i] = 0;
     }
 
-    int rowIndex, columnIndex;
+    int rowIndex    = 0;
+    int columnIndex = 0;
 
-    for (uint i=0 ; runningFlag() && (i < m_orgImage.numPixels()) ; i++)
+    for (uint i = 0 ; runningFlag() && (i < m_orgImage.numPixels()) ; ++i)
     {
         columnIndex = clusters->data.i[i];
         rowPosition[columnIndex]++;
@@ -190,7 +189,7 @@ void NREstimate::startAnalyse()
 /*
     qCDebug(DIGIKAM_DIMG_LOG) << "Lets see what the rowPosition array looks like : ";
 
-    for(uint i=0 ; runningFlag() && (i < d->clusterCount) ; i++)
+    for (uint i = 0 ; runningFlag() && (i < d->clusterCount) ; ++i)
     {
         qCDebug(DIGIKAM_DIMG_LOG) << "Cluster : "<< i << " the count is :" << rowPosition[i];
     }
@@ -203,7 +202,7 @@ void NREstimate::startAnalyse()
 
     int max = rowPosition[0];
 
-    for (uint i=1 ; runningFlag() && (i < d->clusterCount) ; i++)
+    for (uint i = 1 ; runningFlag() && (i < d->clusterCount) ; ++i)
     {
         if (rowPosition[i] > max)
         {
@@ -219,12 +218,7 @@ void NREstimate::startAnalyse()
 
     //-- Divide and conquer ---------------------------------------------------------------------------------
 
-    CvMat* sd = 0;
-
-    if (runningFlag())
-    {
-        sd = cvCreateMat(max, (d->clusterCount * points->cols), CV_32FC1);
-    }
+    CvMat* sd = cvCreateMat(max, (d->clusterCount * points->cols), CV_32FC1);
 
     postProgress(30);
 
@@ -232,7 +226,7 @@ void NREstimate::startAnalyse()
 
     QScopedArrayPointer<int> rPosition(new int[d->clusterCount]);
 
-    for (uint i=0 ; runningFlag() && (i < d->clusterCount) ; i++)
+    for (uint i = 0 ; runningFlag() && (i < d->clusterCount) ; ++i)
     {
         rPosition[i] = 0;
     }
@@ -242,7 +236,7 @@ void NREstimate::startAnalyse()
     qCDebug(DIGIKAM_DIMG_LOG) << "The rowPosition array is ready!";
     postProgress(40);
 
-    for (uint i=0 ; runningFlag() && (i < m_orgImage.numPixels()) ; i++)
+    for (uint i = 0 ; runningFlag() && (i < m_orgImage.numPixels()) ; ++i)
     {
         columnIndex = clusters->data.i[i];
         rowIndex    = rPosition[columnIndex];
@@ -251,15 +245,15 @@ void NREstimate::startAnalyse()
         ptr         = reinterpret_cast<float*>(sd->data.ptr + rowIndex*(sd->step));
 
         //moving to the right column
-        for (int j=0 ; runningFlag() && (j < columnIndex) ; j++)
+        for (int j = 0 ; runningFlag() && (j < columnIndex) ; ++j)
         {
-            for(int z=0 ; runningFlag() && (z < (points->cols)) ; z++)
+            for (int z = 0 ; runningFlag() && (z < (points->cols)) ; ++z)
             {
                 ptr++;
             }
         }
 
-        for (int z=0 ; runningFlag() && (z < (points->cols)) ; z++)
+        for (int z = 0 ; runningFlag() && (z < (points->cols)) ; ++z)
         {
             *ptr++ = cvGet2D(points, i, z).val[0];
         }
@@ -274,28 +268,20 @@ void NREstimate::startAnalyse()
 
     CvScalar std;
     CvScalar mean;
-    CvMat*   meanStore    = 0;
-    CvMat*   stdStore     = 0;
-    float*   meanStorePtr = 0;
-    float*   stdStorePtr  = 0;
-    int      totalcount   = 0; // Number of non-empty clusters
+    int      totalcount = 0; // Number of non-empty clusters
+    CvMat* meanStore    = cvCreateMat(d->clusterCount, points->cols, CV_32FC1);
+    CvMat* stdStore     = cvCreateMat(d->clusterCount, points->cols, CV_32FC1);
+    float* meanStorePtr = reinterpret_cast<float*>(meanStore->data.ptr);
+    float* stdStorePtr  = reinterpret_cast<float*>(stdStore->data.ptr);
 
-    if (runningFlag())
-    {
-        meanStore    = cvCreateMat(d->clusterCount, points->cols, CV_32FC1);
-        stdStore     = cvCreateMat(d->clusterCount, points->cols, CV_32FC1);
-        meanStorePtr = reinterpret_cast<float*>(meanStore->data.ptr);
-        stdStorePtr  = reinterpret_cast<float*>(stdStore->data.ptr);
-    }
-
-    for (int i=0 ; runningFlag() && (i < sd->cols) ; i++)
+    for (int i = 0 ; runningFlag() && (i < sd->cols) ; ++i)
     {
         if (runningFlag() && (rowPosition[(i/points->cols)] >= 1))
         {
             CvMat* workingArr = cvCreateMat(rowPosition[(i / points->cols)], 1, CV_32FC1);
             ptr               = reinterpret_cast<float*>(workingArr->data.ptr);
 
-            for (int j=0 ; runningFlag() && (j < rowPosition[(i / (points->cols))]) ; j++)
+            for (int j = 0 ; runningFlag() && (j < rowPosition[(i / (points->cols))]) ; ++j)
             {
                 *ptr++ = cvGet2D(sd, j, i).val[0];
             }
@@ -313,11 +299,8 @@ void NREstimate::startAnalyse()
 
     // -----------------------------------------------------------------------------------------------------------------
 
-    if (runningFlag())
-    {
-        meanStorePtr = reinterpret_cast<float*>(meanStore->data.ptr);
-        stdStorePtr  = reinterpret_cast<float*>(stdStore->data.ptr);
-    }
+    meanStorePtr = reinterpret_cast<float*>(meanStore->data.ptr);
+    stdStorePtr  = reinterpret_cast<float*>(stdStore->data.ptr);
 
     if (runningFlag() && !d->path.isEmpty())
     {
@@ -333,7 +316,7 @@ void NREstimate::startAnalyse()
             QTextStream oms(&filems);
             oms << "Mean Data\n";
 
-            for (int i=0 ; i < totalcount ; i++)
+            for (int i = 0 ; i < totalcount ; ++i)
             {
                 oms << *meanStorePtr++;
                 oms << "\t";
@@ -346,7 +329,7 @@ void NREstimate::startAnalyse()
 
             oms << "\nStd Data\n";
 
-            for (int i=0 ; i < totalcount ; i++)
+            for (int i = 0 ; i < totalcount ; ++i)
             {
                 oms << *stdStorePtr++;
                 oms << "\t";
@@ -388,18 +371,18 @@ void NREstimate::startAnalyse()
     float   weightedStd  = 0.0f;
     float   datasd[3]    = {0.0f, 0.0f, 0.0f};
 
-    for (int j=0 ; runningFlag() && (j < points->cols) ; j++)
+    for (int j = 0 ; runningFlag() && (j < points->cols) ; ++j)
     {
         meanStorePtr = reinterpret_cast<float*>(meanStore->data.ptr);
         stdStorePtr  = reinterpret_cast<float*>(stdStore->data.ptr);
 
-        for (int moveToChannel=0 ; moveToChannel <= j ; moveToChannel++)
+        for (int moveToChannel = 0 ; moveToChannel <= j ; ++moveToChannel)
         {
             meanStorePtr++;
             stdStorePtr++;
         }
 
-        for (uint i=0 ; i < d->clusterCount ; i++)
+        for (uint i = 0 ; i < d->clusterCount ; ++i)
         {
             if (rowPosition[i] >= 1)
             {
@@ -416,9 +399,9 @@ void NREstimate::startAnalyse()
 
         if (!d->path.isEmpty())
         {
-            owms << QLatin1String("\nChannel : ")     << j            << QLatin1String("\n");
-            owms << QLatin1String("Weighted Mean : ") << weightedMean << QLatin1String("\n");
-            owms << QLatin1String("Weighted Std  : ") << weightedStd  << QLatin1String("\n");
+            owms << QLatin1String("\nChannel : ")     << j            << QLatin1Char('\n');
+            owms << QLatin1String("Weighted Mean : ") << weightedMean << QLatin1Char('\n');
+            owms << QLatin1String("Weighted Std  : ") << weightedStd  << QLatin1Char('\n');
         }
 
         info.append(QLatin1String("\n\nChannel: "));
@@ -439,16 +422,22 @@ void NREstimate::startAnalyse()
 
     // -- adaptation ---------------------------------------------------------------------------------------
 
-    double L = 1.2, LSoft = 0.9, Cr = 1.2, CrSoft = 0.9, Cb = 1.2, CbSoft = 0.9;
+    double L      = 1.2;
+    double LSoft  = 0.9;
+    double Cr     = 1.2;
+    double CrSoft = 0.9;
+    double Cb     = 1.2;
+    double CbSoft = 0.9;
 
     if (runningFlag())
     {
         // for 16 bits images only
         if (m_orgImage.sixteenBit())
         {
-            for (int i=0 ; i < points->cols ; i++)
+            for (int i = 0 ; i < points->cols ; ++i)
             {
-                datasd[i] = datasd[i] / 256;
+                if (i < 3)
+                    datasd[i] = datasd[i] / 256;
             }
         }
 
@@ -506,7 +495,7 @@ void NREstimate::startAnalyse()
     cvReleaseMat(&points);
     cvReleaseMat(&clusters);
 
-    for (uint i = 0; i < 3; i++)
+    for (uint i = 0 ; i < 3 ; ++i)
     {
         delete [] d->fimg[i];
     }
@@ -514,4 +503,4 @@ void NREstimate::startAnalyse()
     postProgress(100);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
