@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-10-18
  * Description : Wavelets YCrCb Noise Reduction settings estimation by image content analys.
  *
  * Copyright (C) 2012-2013 by Sayantan Datta <sayantan dot knz at gmail dot com>
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef NRESTIMATE_H
-#define NRESTIMATE_H
+#ifndef DIGIKAM_NR_ESTIMATE_H
+#define DIGIKAM_NR_ESTIMATE_H
 
 // Qt includes
 
@@ -74,6 +74,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* NRESTIMATE_H */
+#endif // DIGIKAM_NR_ESTIMATE_H
