@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Wavelets Noise Reduction threaded image filter.
  *               This filter work in YCrCb color space.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef NRFILTER_H
-#define NRFILTER_H
+#ifndef DIGIKAM_NR_FILTER_H
+#define DIGIKAM_NR_FILTER_H
 
 // Qt includes
 
@@ -44,7 +44,7 @@ class DIGIKAM_EXPORT NRContainer
 
 public:
 
-    NRContainer();
+    explicit NRContainer();
     ~NRContainer();
 
 public:
@@ -116,6 +116,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* NRFILTER_H */
+#endif // DIGIKAM_NR_FILTER_H */
