@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-22
  * Description : noise reduction settings view.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -32,7 +32,6 @@
 #include <QTextStream>
 #include <QCheckBox>
 #include <QUrl>
-#include <QStandardPaths>
 #include <QApplication>
 #include <QStyle>
 #include <QStandardPaths>
@@ -52,12 +51,12 @@
 namespace Digikam
 {
 
-class NRSettings::Private
+class Q_DECL_HIDDEN NRSettings::Private
 {
 public:
 
-    Private() :
-        luminanceBox(0),
+    explicit Private()
+      : luminanceBox(0),
         chrominanceRedBox(0),
         chrominanceBlueBox(0),
         checkAutoEst(0),
@@ -68,7 +67,8 @@ public:
         softCrInput(0),
         thrCbInput(0),
         softCbInput(0)
-    {}
+    {
+    }
 
     static const QString configThrLumInputAdjustmentEntry;
     static const QString configSoftLumInputAdjustmentEntry;
@@ -108,7 +108,7 @@ NRSettings::NRSettings(QWidget* const parent)
     : QWidget(parent),
       d(new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing       = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     QGridLayout* const grid = new QGridLayout(parent);
 
@@ -212,13 +212,16 @@ NRSettings::NRSettings(QWidget* const parent)
 
     // -------------------------------------------------------------
 
-    d->advExpanderBox->addItem(d->luminanceBox, QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/colors-luma.png"))),
+    d->advExpanderBox->addItem(d->luminanceBox,
+                               QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/colors-luma.png"))),
                                i18n("Luminance"),
                                QLatin1String("Luminance"), true);
-    d->advExpanderBox->addItem(d->chrominanceBlueBox, QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/colors-chromablue.png"))),
+    d->advExpanderBox->addItem(d->chrominanceBlueBox,
+                               QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/colors-chromablue.png"))),
                                i18n("Chrominance Blue"),
                                QLatin1String("ChrominanceBlue"), true);
-    d->advExpanderBox->addItem(d->chrominanceRedBox, QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/colors-chromared.png"))),
+    d->advExpanderBox->addItem(d->chrominanceRedBox,
+                               QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/colors-chromared.png"))),
                                i18n("Chrominance Red"),
                                QLatin1String("ChrominanceRed"), true);
     d->advExpanderBox->addStretch();
@@ -432,12 +435,12 @@ void NRSettings::saveAsSettings()
     {
         QTextStream stream(&file);
         stream << QLatin1String("# Photograph Wavelets Noise Reduction Configuration File V2\n");
-        stream << d->thrLumInput->value()  << QLatin1String("\n");
-        stream << d->softLumInput->value() << QLatin1String("\n");
-        stream << d->thrCrInput->value()   << QLatin1String("\n");
-        stream << d->softCrInput->value()  << QLatin1String("\n");
-        stream << d->thrCbInput->value()   << QLatin1String("\n");
-        stream << d->softCbInput->value()  << QLatin1String("\n");
+        stream << d->thrLumInput->value()  << QLatin1Char('\n');
+        stream << d->softLumInput->value() << QLatin1Char('\n');
+        stream << d->thrCrInput->value()   << QLatin1Char('\n');
+        stream << d->softCrInput->value()  << QLatin1Char('\n');
+        stream << d->thrCbInput->value()   << QLatin1Char('\n');
+        stream << d->softCbInput->value()  << QLatin1Char('\n');
     }
     else
     {
@@ -448,4 +451,4 @@ void NRSettings::saveAsSettings()
     file.close();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
