@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-22
  * Description : noise reduction settings view.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef NRSETTINGS_H
-#define NRSETTINGS_H
+#ifndef DIGIKAM_NR_SETTINGS_H
+#define DIGIKAM_NR_SETTINGS_H
 
 // Local includes
 
@@ -79,6 +79,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* NRSETTINGS_H */
+#endif // DIGIKAM_NR_SETTINGS_H
