@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 17-8-2016
  * Description : A Red-Eye automatic detection and correction filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2016      by Omar Amin <Omar dot moh dot amin at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,6 +22,8 @@
  *
  * ============================================================ */
 
+#include "redeyecorrectionfilter.h"
+
 // C++ includes
 
 #include <iterator>
@@ -37,21 +39,20 @@
 
 #include "digikam_debug.h"
 #include "facedetector.h"
-#include "redeyecorrectionfilter.h"
 #include "shapepredictor.h"
 
 namespace Digikam
 {
 
-class RedEyeCorrectionFilter::Private
+class Q_DECL_HIDDEN RedEyeCorrectionFilter::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
-    FaceDetector      facedetector;
+    FaceDetector                   facedetector;
     static redeye::ShapePredictor* sp;
 
     RedEyeCorrectionContainer      settings;
@@ -66,7 +67,8 @@ RedEyeCorrectionFilter::RedEyeCorrectionFilter(QObject* const parent)
     initFilter();
 }
 
-RedEyeCorrectionFilter::RedEyeCorrectionFilter(DImg* const orgImage, QObject* const parent,
+RedEyeCorrectionFilter::RedEyeCorrectionFilter(DImg* const orgImage,
+                                               QObject* const parent,
                                                const RedEyeCorrectionContainer& settings)
     : DImgThreadedFilter(orgImage, parent,
                          QLatin1String("RedEyeCorrection")),
@@ -78,8 +80,10 @@ RedEyeCorrectionFilter::RedEyeCorrectionFilter(DImg* const orgImage, QObject* co
 
 RedEyeCorrectionFilter::RedEyeCorrectionFilter(const RedEyeCorrectionContainer& settings,
                                                DImgThreadedFilter* const parentFilter,
-                                               const DImg& orgImage, const DImg& destImage,
-                                               int progressBegin, int progressEnd)
+                                               const DImg& orgImage,
+                                               const DImg& destImage,
+                                               int progressBegin,
+                                               int progressEnd)
     : DImgThreadedFilter(parentFilter, orgImage, destImage,
                          progressBegin, progressEnd,
                          parentFilter->filterName() + QLatin1String(": RedEyeCorrection")),
@@ -112,7 +116,8 @@ void RedEyeCorrectionFilter::filterImage()
             QDataStream dataStream(&model);
             dataStream.setFloatingPointPrecision(QDataStream::SinglePrecision);
             dataStream >> *temp;
-            d->sp = temp;
+            d->sp                              = temp;
+            model.close();
         }
         else
         {
@@ -156,12 +161,12 @@ void RedEyeCorrectionFilter::filterImage()
         QRectFtocvRect(qrectdets, dets);
 
         // Eye Detection
-        for (unsigned int i = 0 ; runningFlag() && (i < dets.size()) ; i++)
+        for (unsigned int i = 0 ; runningFlag() && (i < dets.size()) ; ++i)
         {
             FullObjectDetection object = sp(gray,dets[i]);
             std::vector<cv::Rect> eyes = geteyes(object);
 
-            for (unsigned int j = 0 ; runningFlag() && (j < eyes.size()) ; j++)
+            for (unsigned int j = 0 ; runningFlag() && (j < eyes.size()) ; ++j)
             {
                 correctRedEye(intermediateImage.data,
                               intermediateImage.type(),
@@ -196,15 +201,15 @@ void RedEyeCorrectionFilter::correctRedEye(uchar* data, int type,
     }
     else
     {
-        qCDebug(DIGIKAM_DIMG_LOG) << "Insupported Type in redeye correction filter";
+        qCDebug(DIGIKAM_DIMG_LOG) << "Unsupported Type in redeye correction filter";
     }
 
     bool sixteendepth = (type == CV_8UC3) || (type == CV_8UC4) ? false : true;
     double redratio   = d->settings.m_redToAvgRatio;
 
-    for (int i = eyerect.y ; i < eyerect.y + eyerect.height ; i++)
+    for (int i = eyerect.y ; i < eyerect.y + eyerect.height ; ++i)
     {
-        for (int j = eyerect.x ; j < eyerect.x + eyerect.width ; j++)
+        for (int j = eyerect.x ; j < eyerect.x + eyerect.width ; ++j)
         {
             int pixelindex = (i*imgRect.width + j) * pixeldepth;
             onebytedata    = &(reinterpret_cast<uchar*> (data)[pixelindex]);
@@ -258,4 +263,4 @@ void RedEyeCorrectionFilter::readParameters(const FilterAction& action)
     d->settings = RedEyeCorrectionContainer::fromFilterAction(action);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
