@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-09
  * Description : Red Eyes auto correction settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2016      by Omar Amin <Omar dot moh dot amin at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -49,12 +49,12 @@
 namespace Digikam
 {
 
-class RedEyeCorrectionSettings::Private
+class Q_DECL_HIDDEN RedEyeCorrectionSettings::Private
 {
 public:
 
-    Private() :
-        redtoavgratioInput(0)
+    explicit Private()
+      : redtoavgratioInput(0)
     {
     }
 
@@ -136,8 +136,8 @@ void RedEyeCorrectionSettings::readSettings(KConfigGroup& group)
 {
     RedEyeCorrectionContainer prm;
     RedEyeCorrectionContainer defaultPrm = defaultSettings();
-
-    prm.m_redToAvgRatio = group.readEntry(d->configRedToAvgRatioAdjustmentEntry, defaultPrm.m_redToAvgRatio);
+    prm.m_redToAvgRatio                  = group.readEntry(d->configRedToAvgRatioAdjustmentEntry,
+                                                           defaultPrm.m_redToAvgRatio);
 
     setSettings(prm);
 }
@@ -149,4 +149,4 @@ void RedEyeCorrectionSettings::writeSettings(KConfigGroup& group)
     group.writeEntry(d->configRedToAvgRatioAdjustmentEntry, prm.m_redToAvgRatio);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
