@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-09
  * Description : Red Eyes auto correction settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2016      by Omar Amin <Omar dot moh dot amin at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef REDEYECORRECTIONSETTINGS_H
-#define REDEYECORRECTIONSETTINGS_H
+#ifndef DIGIKAM_RED_EYE_CORRECTION_SETTINGS_H
+#define DIGIKAM_RED_EYE_CORRECTION_SETTINGS_H
 
 // Local includes
 
@@ -69,6 +69,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* REDEYECORRECTIONSETTINGS_H */
+#endif // DIGIKAM_RED_EYE_CORRECTION_SETTINGS_H
