@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-29
  * Description : refocus deconvolution matrix implementation.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Original implementation from Refocus Gimp plug-in
- * Copyright (C) 1999-2003 Ernst Lippe
+ * Copyright (C) 1999-2003 Ernst Lippe <ernstl at users dot sourceforge dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,17 +43,18 @@
 // Eigen includes
 
 // Pragma directives to reduce warnings from Eigen header files.
-#if !defined(__APPLE__) && defined(__GNUC__)
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-local-typedefs"
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#pragma GCC diagnostic ignored "-Wlogical-op"
 #endif
 
 #include <Eigen/Eigen>
 #include <Eigen/LU>
 
 // Restore warnings
-#if !defined(__APPLE__) && defined(__GNUC__)
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #pragma GCC diagnostic pop
 #endif
 
@@ -655,4 +656,4 @@ void RefocusMatrix::make_circle_convolution(const double radius, CMat* const con
     fill_matrix(convolution, m, circle_intensity, radius);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
