@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-25
  * Description : Refocus threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Matthias Welwarsky <matze at welwarsky dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -31,7 +31,7 @@
 
 // Qt includes
 
-#include <QtConcurrent>
+#include <QtConcurrent>    // krazy:exclude=includes
 
 // Local includes
 
@@ -45,12 +45,12 @@ namespace Digikam
 
 const int MAX_MATRIX_SIZE = 25;
 
-class RefocusFilter::Private
+class Q_DECL_HIDDEN RefocusFilter::Private
 {
 public:
 
-    Private() :
-        matrixSize(5),
+    explicit Private()
+      : matrixSize(5),
         radius(0.9),
         gauss(0.0),
         correlation(0.5),
@@ -370,4 +370,4 @@ int RefocusFilter::maxMatrixSize()
     return MAX_MATRIX_SIZE;
 }
 
-}  // namespace DigikamImagesPluginCore
+} // namespace Digikam
