@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-17-07
  * Description : A Sharpen threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SHARPENFILTER_H
-#define SHARPENFILTER_H
+#ifndef DIGIKAM_SHARPEN_FILTER_H
+#define DIGIKAM_SHARPEN_FILTER_H
 
 // Local includes
 
@@ -106,6 +106,6 @@ private:
     double m_sigma;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* SHARPENFILTER_H */
+#endif // DIGIKAM_SHARPEN_FILTER_H
