@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-17-07
  * Description : A Unsharp Mask threaded image filter.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Matthias Welwarsky <matze at welwarsky dot de>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef UNSHARPMASKFILTER_H
-#define UNSHARPMASKFILTER_H
+#ifndef DIGIKAM_UNSHARP_MASK_FILTER_H
+#define DIGIKAM_UNSHARP_MASK_FILTER_H
 
 // Local includes
 
@@ -94,4 +94,4 @@ private:
 
 } // namespace Digikam
 
-#endif // UNSHARPMASKFILTER_H
+#endif // DIGIKAM_UNSHARP_MASK_FILTER_H
