@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-10-18
  * Description : Auto Crop analyzer
  *
- * Copyright (C) 2013 by Sayantan Datta <sayantan dot knz at gmail dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013      by Sayantan Datta <sayantan dot knz at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef AUTOCROP_H
-#define AUTOCROP_H
+#ifndef DIGIKAM_AUTO_CROP_H
+#define DIGIKAM_AUTO_CROP_H
 
 // Qt includes
 
@@ -59,21 +59,21 @@ public:
      */
     QRect autoInnerCrop() const;
 
-private :
+private:
 
     /** Takes in a binary image and crops it on the basis of black point
      *  detection, spirally moving outwards.
      *  topCrop can be set to explicitly crop a upper portion of the image
      *  bottomCrop can be set to explicitly crop a bottom portion of the image
      */
-    QRect spiralClockwiseTraversal(const QImage& source, int topCrop=-1, int bottomCrop=-1);
+    QRect spiralClockwiseTraversal(const QImage& source, int topCrop = -1, int bottomCrop = -1);
 
-private :
+private:
 
     class Private;
     Private* d;
 };
 
-}   //  namespace Digikam
+} // namespace Digikam
 
-#endif /*AUTOCROP_H*/
+#endif // DIGIKAM_AUTO_CROP_H
