@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-02-01
  * Description : Content aware resizer class.
  *
  * Copyright (C) 2009      by Julien Pontabry <julien dot pontabry at ulp dot u-strasbg dot fr>
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -94,11 +94,11 @@ static LqrResizeOrder toLqrOrder(Qt::Orientation direction)
 
 // --------------------------------------------------------------------------------------
 
-class ContentAwareFilter::Private
+class Q_DECL_HIDDEN ContentAwareFilter::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         carver   = 0;
         progress = 0;
