@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-07-18
  * Description : Free rotation threaded image filter.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -39,11 +39,11 @@
 namespace Digikam
 {
 
-class FreeRotationFilter::Private
+class Q_DECL_HIDDEN FreeRotationFilter::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
@@ -423,4 +423,4 @@ void FreeRotationFilter::readParameters(const FilterAction& action)
     d->settings.backgroundColor.setAlpha(action.parameter(QLatin1String("backgroundColorA")).toInt());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
