@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-07-18
  * Description : Free rotation threaded image filter.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef FREE_ROTATION_FILTER_H
-#define FREE_ROTATION_FILTER_H
+#ifndef DIGIKAM_FREE_ROTATION_FILTER_H
+#define DIGIKAM_FREE_ROTATION_FILTER_H
 
 // Qt includes
 
@@ -137,6 +137,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* FREE_ROTATION_FILTER_H */
+#endif // DIGIKAM_FREE_ROTATION_FILTER_H
