@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-16
  * Description : Free rotation settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef FREEROTATIONSETTINGS_H
-#define FREEROTATIONSETTINGS_H
+#ifndef DIGIKAM_FREE_ROTATION_SETTINGS_H
+#define DIGIKAM_FREE_ROTATION_SETTINGS_H
 
 // Local includes
 
@@ -68,6 +68,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* FREEROTATIONSETTINGS_H */
+#endif // DIGIKAM_FREE_ROTATION_SETTINGS_H
