@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-26
  * Description : White Balance settings view.
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -59,7 +59,7 @@
 namespace Digikam
 {
 
-class WBSettings::Private
+class Q_DECL_HIDDEN WBSettings::Private
 {
 
 public:
@@ -84,8 +84,8 @@ public:
 
 public:
 
-    Private() :
-        DefaultTemperature(DaylightD65),
+    explicit Private()
+      : DefaultTemperature(DaylightD65),
         pickTemperature(0),
         autoAdjustExposure(0),
         adjTemperatureLabel(0),
@@ -586,14 +586,14 @@ void WBSettings::saveAsSettings()
     {
         QTextStream stream(&file);
         stream << QLatin1String("# White Color Balance Configuration File V2\n");
-        stream << d->temperatureInput->value()  << QLatin1String("\n");
-        stream << d->darkInput->value()         << QLatin1String("\n");
-        stream << d->blackInput->value()        << QLatin1String("\n");
-        stream << d->mainExposureInput->value() << QLatin1String("\n");
-        stream << d->fineExposureInput->value() << QLatin1String("\n");
-        stream << d->gammaInput->value()        << QLatin1String("\n");
-        stream << d->saturationInput->value()   << QLatin1String("\n");
-        stream << d->greenInput->value()        << QLatin1String("\n");
+        stream << d->temperatureInput->value()  << QLatin1Char('\n');
+        stream << d->darkInput->value()         << QLatin1Char('\n');
+        stream << d->blackInput->value()        << QLatin1Char('\n');
+        stream << d->mainExposureInput->value() << QLatin1Char('\n');
+        stream << d->fineExposureInput->value() << QLatin1Char('\n');
+        stream << d->gammaInput->value()        << QLatin1Char('\n');
+        stream << d->saturationInput->value()   << QLatin1Char('\n');
+        stream << d->greenInput->value()        << QLatin1Char('\n');
     }
     else
     {
@@ -604,4 +604,4 @@ void WBSettings::saveAsSettings()
     file.close();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
