@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : DImg image loader interface
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -220,12 +220,12 @@ bool DImgLoader::readMetadata(const QString& filePath, DImg::FORMAT /*ff*/)
 
     if (m_loadFlags & LoadImageHistory)
     {
-        DImageHistory history = DImageHistory::fromXml(metaDataFromFile.getImageHistory());
+        DImageHistory history = DImageHistory::fromXml(metaDataFromFile.getItemHistory());
         HistoryImageId id     = createHistoryImageId(filePath, *m_image, metaDataFromFile);
         id.m_type             = HistoryImageId::Current;
         history << id;
 
-        m_image->setImageHistory(history);
+        m_image->setItemHistory(history);
         imageSetAttribute(QLatin1String("originalImageHistory"), QVariant::fromValue(history));
     }
 
@@ -261,9 +261,9 @@ HistoryImageId DImgLoader::createHistoryImageId(const QString& filePath, const D
         return HistoryImageId();
     }
 
-    HistoryImageId id(metadata.getImageUniqueId());
+    HistoryImageId id(metadata.getItemUniqueId());
 
-    QDateTime dt = metadata.getImageDateTime();
+    QDateTime dt = metadata.getItemDateTime();
 
     if (dt.isNull())
     {
@@ -282,7 +282,7 @@ bool DImgLoader::saveMetadata(const QString& filePath)
 {
     DMetadata metaDataToFile(filePath);
     metaDataToFile.setData(m_image->getMetadata());
-    return metaDataToFile.applyChanges();
+    return metaDataToFile.applyChanges(true);
 }
 
 bool DImgLoader::checkExifWorkingColorSpace() const
@@ -355,6 +355,8 @@ QByteArray DImgLoader::uniqueHashV2(const QString& filePath, const DImg* const i
         }
     }
 
+    file.close();
+
     QByteArray hash = md5.result().toHex();
 
     if (img && !hash.isNull())
@@ -404,6 +406,8 @@ QByteArray DImgLoader::uniqueHash(const QString& filePath, const DImg& img, bool
             md5.addData(size.setNum(qfile.size()));
             hash = md5.result().toHex();
         }
+
+        qfile.close();
     }
 
     if (!hash.isNull())
@@ -434,4 +438,4 @@ unsigned short* DImgLoader::new_short_failureTolerant(quint64 w, quint64 h, uint
     return new_failureTolerant<unsigned short>(w, h, typesPerPixel);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
