@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : DImg image loader interface
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DIMGLOADER_H
-#define DIMGLOADER_H
+#ifndef DIGIKAM_DIMG_LOADER_H
+#define DIGIKAM_DIMG_LOADER_H
 
 // C++ includes
 
@@ -54,13 +54,13 @@ public:
 
     enum LoadFlag
     {
-        LoadImageInfo    = 1,
+        LoadItemInfo    = 1,
         LoadMetadata     = 2,
         LoadICCData      = 4,
         LoadImageData    = 8,
         LoadUniqueHash   = 16,
         LoadImageHistory = 32,
-        LoadAll          = LoadImageInfo | LoadMetadata | LoadUniqueHash | LoadICCData | LoadImageData | LoadImageHistory
+        LoadAll          = LoadItemInfo | LoadMetadata | LoadUniqueHash | LoadICCData | LoadImageData | LoadImageHistory
     };
     Q_DECLARE_FLAGS(LoadFlags, LoadFlag)
 
@@ -191,6 +191,6 @@ Q_INLINE_TEMPLATE Type* DImgLoader::new_failureTolerant(size_t size)
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(DImgLoader::LoadFlags)
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* DIMGLOADER_H */
+#endif // DIGIKAM_DIMG_LOADER_H
