@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-06-14
  * Description : A JPEG2000 IO file for DImg framework
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This implementation use Jasper API
  * library : http://www.ece.uvic.ca/~mdadams/jasper
@@ -54,14 +54,14 @@ extern "C"
 {
 #endif
 
-#if defined(__APPLE__) && defined(__clang__)
+#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wshift-negative-value"
 #endif
 
 #include <jasper/jasper.h>
 
-#if defined(__APPLE__) && defined(__clang__)
+#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
 #pragma clang diagnostic pop
 #endif
 
@@ -122,7 +122,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver* const observe
         // This is bad when scanning. See bugs 215458 and 195583.
         // FIXME: Use Exiv2 to extract this info
         DMetadata metadata(filePath);
-        QSize size = metadata.getImageDimensions();
+        QSize size = metadata.getItemDimensions();
 
         if (size.isValid())
         {
@@ -163,7 +163,8 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver* const observe
         return false;
     }
 
-    jp2_image = jas_image_decode(jp2_stream, -1, 0);
+    int fmt   = jas_image_strtofmt(QByteArray("jp2").data());
+    jp2_image = jas_image_decode(jp2_stream, fmt, 0);
 
     if (jp2_image == 0)
     {
@@ -556,7 +557,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver* const observe
                         QByteArray profile_rawdata;
                         profile_rawdata.resize(blob->len_);
                         memcpy(profile_rawdata.data(), blob->buf_, blob->len_);
-                        imageSetIccProfile(profile_rawdata);
+                        imageSetIccProfile(IccProfile(profile_rawdata));
                         jas_stream_close(icc_stream);
                     }
                 }
@@ -827,12 +828,13 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver* const observe
     //                      the uncompressed size
     // use sprintf for locale-aware string
     char rateBuffer[16];
-    sprintf(rateBuffer, "rate=%.2g\n", (quality / 100.0));
+    sprintf(rateBuffer, "rate=%.2g", (quality / 100.0));
 
     qCDebug(DIGIKAM_DIMG_LOG_JP2K) << "JPEG2000 quality: " << quality;
     qCDebug(DIGIKAM_DIMG_LOG_JP2K) << "JPEG2000 "          << rateBuffer;
 
-    int ret = jas_image_encode(jp2_image, jp2_stream, -1, rateBuffer);
+    int fmt = jas_image_strtofmt(QByteArray("jp2").data());
+    int ret = jas_image_encode(jp2_image, jp2_stream, fmt, rateBuffer);
 
     if (ret != 0)
     {
@@ -887,4 +889,4 @@ bool JP2KLoader::isReadOnly() const
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
