@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : A JPEG IO file for DImg framework
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -61,7 +61,7 @@ void JPEGLoader::dimg_jpeg_error_exit(j_common_ptr cinfo)
     char buffer[JMSG_LENGTH_MAX];
     (*cinfo->err->format_message)(cinfo, buffer);
 
-    qCDebug(DIGIKAM_DIMG_LOG_JPEG) << buffer;
+    qCWarning(DIGIKAM_DIMG_LOG_JPEG) << buffer;
 
     longjmp(myerr->setjmp_buffer, 1);
 }
@@ -132,15 +132,16 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
     cinfo.err->output_message = dimg_jpeg_output_message;
 
     // setjmp-save cleanup
-    class CleanupData
+    class Q_DECL_HIDDEN CleanupData
     {
     public:
 
         CleanupData()
         {
-            data  = 0;
-            dest  = 0;
-            f     = 0;
+            data = 0;
+            dest = 0;
+            file = 0;
+            cmod = 0;
         }
 
         ~CleanupData()
@@ -148,9 +149,9 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
             delete [] data;
             delete [] dest;
 
-            if (f)
+            if (file)
             {
-                fclose(f);
+                fclose(file);
             }
         }
 
@@ -164,9 +165,19 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
             dest = d;
         }
 
-        void setFile(FILE* const file)
+        void setFile(FILE* const f)
         {
-            f = file;
+            file = f;
+        }
+
+        void setSize(const QSize& s)
+        {
+            size = s;
+        }
+
+        void setColorModel(int c)
+        {
+            cmod = c;
         }
 
         void deleteData()
@@ -184,7 +195,10 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
 
         uchar* data;
         uchar* dest;
-        FILE*  f;
+        FILE*  file;
+
+        QSize  size;
+        int    cmod;
     };
 
     CleanupData* const cleanupData = new CleanupData;
@@ -195,9 +209,38 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
     if (setjmp(jerr.setjmp_buffer))
     {
         jpeg_destroy_decompress(&cinfo);
+
+        if (!cleanupData->dest ||
+            !cleanupData->size.isValid())
+        {
+            delete cleanupData;
+            loadingFailed();
+            return false;
+        }
+
+        // We check only Exif metadata for ICC profile to prevent endless loop
+
+        if (m_loadFlags & LoadICCData)
+        {
+            checkExifWorkingColorSpace();
+        }
+
+        if (observer)
+        {
+            observer->progressInfo(m_image, 1.0);
+        }
+
+        imageWidth()  = cleanupData->size.width();
+        imageHeight() = cleanupData->size.height();
+        imageData()   = cleanupData->dest;
+        imageSetAttribute(QLatin1String("format"),             QLatin1String("JPG"));
+        imageSetAttribute(QLatin1String("originalColorModel"), cleanupData->cmod);
+        imageSetAttribute(QLatin1String("originalBitDepth"),   8);
+        imageSetAttribute(QLatin1String("originalSize"),       cleanupData->size);
+
+        cleanupData->takeDest();
         delete cleanupData;
-        loadingFailed();
-        return false;
+        return true;
     }
 
     // -------------------------------------------------------------------
@@ -282,6 +325,8 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
             break;
     }
 
+    cleanupData->setColorModel(colorModel);
+
     // -------------------------------------------------------------------
     // Load image data.
 
@@ -382,6 +427,7 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
         }
 
         dest = new_failureTolerant(w, h, 4);
+        cleanupData->setSize(QSize(w, h));
         cleanupData->setDest(dest);
 
         if (!dest)
@@ -582,7 +628,7 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* const observe
             QByteArray profile_rawdata;
             profile_rawdata.resize(profile_size);
             memcpy(profile_rawdata.data(), profile_data, profile_size);
-            imageSetIccProfile(profile_rawdata);
+            imageSetIccProfile(IccProfile(profile_rawdata));
             free(profile_data);
         }
         else
@@ -644,11 +690,13 @@ bool JPEGLoader::save(const QString& filePath, DImgLoaderObserver* const observe
     cinfo.err->output_message = dimg_jpeg_output_message;
 
     // setjmp-save cleanup
-    class CleanupData
+    class Q_DECL_HIDDEN CleanupData
     {
     public:
 
-        CleanupData() : line(0), f(0)
+        CleanupData()
+            : line(0),
+              f(0)
         {
         }
 
@@ -926,4 +974,4 @@ bool JPEGLoader::isReadOnly() const
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
