@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-08-02
  * Description : save JPEG image options.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,13 +45,13 @@
 namespace Digikam
 {
 
-class JPEGSettings::Private
+class Q_DECL_HIDDEN JPEGSettings::Private
 {
 
 public:
 
-    Private() :
-        JPEGGrid(0),
+    explicit Private()
+      : JPEGGrid(0),
         labelJPEGcompression(0),
         labelWarning(0),
         labelSubSampling(0),
@@ -175,4 +175,4 @@ int JPEGSettings::convertCompressionForLibJpeg(int value)
     return((int)((75.0 / 100.0) * (float)value + 26.0 - (75.0 / 100.0)));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
