@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-03
  * Description : A PGF IO file for DImg framework
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This implementation use LibPGF API <http://www.libpgf.org>
  *
@@ -24,7 +24,7 @@
  * ============================================================ */
 
 #include "digikam_config.h"
-#include "pgfloader.h"
+#include "pgfloader.h"       // krazy:exclude=includes
 
 // C Ansi includes
 
@@ -49,16 +49,17 @@ extern "C"
 #include <QByteArray>
 #include <QTextStream>
 #include <QDataStream>
+#include <qplatformdefs.h>
 
 // Windows includes
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #include <windows.h>
 #endif
 
 // Libpgf includes
 
-#include <PGFimage.h>
+#include "PGFimage.h"
 
 // Local includes
 
@@ -75,7 +76,7 @@ static bool CallbackForLibPGF(double percent, bool escapeAllowed, void* data)
 {
     if (data)
     {
-        PGFLoader* d = static_cast<PGFLoader*>(data);
+        PGFLoader* const d = static_cast<PGFLoader*>(data);
 
         if (d)
         {
@@ -99,7 +100,7 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
     m_observer = observer;
     readMetadata(filePath, DImg::PGF);
 
-    FILE* file = fopen(QFile::encodeName(filePath).constData(), "rb");
+    FILE* const file = fopen(QFile::encodeName(filePath).constData(), "rb");
 
     if (!file)
     {
@@ -132,22 +133,24 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
     // -------------------------------------------------------------------
     // Initialize PGF API.
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #ifdef UNICODE
-    HANDLE fd = CreateFile((LPCWSTR)(QFile::encodeName(filePath).constData()), GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
+    HANDLE fd = CreateFileW((LPCWSTR)filePath.utf16(), GENERIC_READ, 0, NULL, OPEN_EXISTING, 0, 0);
 #else
-    HANDLE fd = CreateFile(QFile::encodeName(filePath).constData(), GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
+    HANDLE fd = CreateFile(QFile::encodeName(filePath).constData(), GENERIC_READ, 0, NULL, OPEN_EXISTING, 0, 0);
 #endif
 
     if (fd == INVALID_HANDLE_VALUE)
     {
+        qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Error: Could not open source file.";
+        qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Last error code:" << GetLastError();
         loadingFailed();
         return false;
     }
 
 #else
 
-    int fd = open(QFile::encodeName(filePath).constData(), O_RDONLY);
+    int fd = QT_OPEN(QFile::encodeName(filePath).constData(), O_RDONLY);
 
     if (fd == -1)
     {
@@ -220,7 +223,8 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
                 break;
         }
 
-        if(DIGIKAM_DIMG_LOG_PGF().isDebugEnabled()) {
+        if (DIGIKAM_DIMG_LOG_PGF().isDebugEnabled())
+        {
             const PGFHeader* header = pgf.GetHeader();
             qCDebug(DIGIKAM_DIMG_LOG_PGF) << "PGF width    = " << header->width;
             qCDebug(DIGIKAM_DIMG_LOG_PGF) << "PGF height   = " << header->height;
@@ -232,7 +236,7 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
             qCDebug(DIGIKAM_DIMG_LOG_PGF) << "Is 16 bits   = " << m_sixteenBit;
         }
 
-        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properlly with libppgf 6.11.24
+        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properly with libppgf 6.11.24
         pgf.ConfigureDecoder(false);
 
         int width   = pgf.Width();
@@ -270,8 +274,8 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
                     height = h;
                     level  = i;
                     qCDebug(DIGIKAM_DIMG_LOG_PGF) << "Loading PGF scaled version at level " << i
-                                      << " (" << w << " x " << h << ") for size "
-                                      << scaledLoadingSize;
+                                                  << " (" << w << " x " << h << ") for size "
+                                                  << scaledLoadingSize;
                 }
             }
 
@@ -317,7 +321,7 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
         imageSetAttribute(QLatin1String("originalBitDepth"),   bitDepth);
         imageSetAttribute(QLatin1String("originalSize"),       originalSize);
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
         CloseHandle(fd);
 #else
         close(fd);
@@ -336,7 +340,7 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
 
         qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Error: Opening and reading PGF image failed (" << err << ")!";
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
         CloseHandle(fd);
 #else
         close(fd);
@@ -349,7 +353,7 @@ bool PGFLoader::load(const QString& filePath, DImgLoaderObserver* const observer
     {
         qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Failed to allocate memory for loading" << filePath << e.what();
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
         CloseHandle(fd);
 #else
         close(fd);
@@ -365,21 +369,24 @@ bool PGFLoader::save(const QString& filePath, DImgLoaderObserver* const observer
 {
     m_observer = observer;
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #ifdef UNICODE
-    HANDLE fd = CreateFile((LPCWSTR)(QFile::encodeName(filePath).constData()), GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
+    HANDLE fd = CreateFileW((LPCWSTR)filePath.utf16(), GENERIC_READ | GENERIC_WRITE, 0,
+                            NULL, CREATE_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
 #else
-    HANDLE fd = CreateFile(QFile::encodeName(filePath).constData(), GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
+    HANDLE fd = CreateFile(QFile::encodeName(filePath).constData(), GENERIC_READ | GENERIC_WRITE, 0,
+                           NULL, CREATE_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
 #endif
 
     if (fd == INVALID_HANDLE_VALUE)
     {
         qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Error: Could not open destination file.";
+        qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Last error code:" << GetLastError();
         return false;
     }
 
 #elif defined(__POSIX__)
-    int fd = open(QFile::encodeName(filePath).constData(), O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
+    int fd = QT_OPEN(QFile::encodeName(filePath).constData(), O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
 
     if (fd == -1)
     {
@@ -445,7 +452,7 @@ bool PGFLoader::save(const QString& filePath, DImgLoaderObserver* const observer
 
         pgf.SetHeader(header);
 
-        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properlly with libppgf 6.11.24
+        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properly with libppgf 6.11.24
         pgf.ConfigureEncoder(false);
 
         pgf.ImportBitmap(4 * imageWidth() * (imageSixteenBit() ? 2 : 1),
@@ -472,7 +479,7 @@ bool PGFLoader::save(const QString& filePath, DImgLoaderObserver* const observer
         qCDebug(DIGIKAM_DIMG_LOG_PGF) << "PGF mode      = " << header.mode;
         qCDebug(DIGIKAM_DIMG_LOG_PGF) << "Bytes Written = " << nWrittenBytes;
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
         CloseHandle(fd);
 #else
         close(fd);
@@ -501,7 +508,7 @@ bool PGFLoader::save(const QString& filePath, DImgLoaderObserver* const observer
 
         qCWarning(DIGIKAM_DIMG_LOG_PGF) << "Error: Opening and saving PGF image failed (" << err << ")!";
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
         CloseHandle(fd);
 #else
         close(fd);
@@ -509,6 +516,7 @@ bool PGFLoader::save(const QString& filePath, DImgLoaderObserver* const observer
 
         return false;
     }
+
     return true;
 }
 
@@ -542,4 +550,4 @@ bool PGFLoader::isReadOnly() const
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
