@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-03
  * Description : A PGF IO file for DImg framework
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef PGFLOADER_H
-#define PGFLOADER_H
+#ifndef DIGIKAM_PGF_LOADER_H
+#define DIGIKAM_PGF_LOADER_H
 
 // Local includes
 
@@ -57,6 +57,6 @@ private:
     DImgLoaderObserver* m_observer;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* PGFLOADER_H */
+#endif // DIGIKAM_PGF_LOADER_H
