@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-06
  * Description : save PGF image options.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,12 +44,12 @@
 namespace Digikam
 {
 
-class PGFSettings::Private
+class Q_DECL_HIDDEN PGFSettings::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         PGFGrid             = 0;
         labelPGFcompression = 0;
@@ -145,4 +145,4 @@ void PGFSettings::slotTogglePGFLossLess(bool b)
     d->labelPGFcompression->setEnabled(!b);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
