@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-06
  * Description : save PGF image options.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef PGFSETTINGS_H
-#define PGFSETTINGS_H
+#ifndef DIGIKAM_PGF_SETTINGS_H
+#define DIGIKAM_PGF_SETTINGS_H
 
 // Qt includes
 
@@ -64,6 +64,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* PGFSETTINGS_H */
+#endif // DIGIKAM_PGF_SETTINGS_H
