@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-11-01
  * Description : a PNG image loader for DImg framework.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -155,12 +155,12 @@ bool PNGLoader::load(const QString& filePath, DImgLoaderObserver* const observer
     // will jump here
 
     // setjmp-save cleanup
-    class CleanupData
+    class Q_DECL_HIDDEN CleanupData
     {
     public:
 
-        CleanupData():
-            data(0),
+        CleanupData()
+          : data(0),
             lines(0),
             f(0)
         {
@@ -531,7 +531,7 @@ bool PNGLoader::load(const QString& filePath, DImgLoaderObserver* const observer
             QByteArray profile_rawdata;
             profile_rawdata.resize(profile_size);
             memcpy(profile_rawdata.data(), profile_data, profile_size);
-            imageSetIccProfile(profile_rawdata);
+            imageSetIccProfile(IccProfile(profile_rawdata));
         }
         else
         {
@@ -660,12 +660,12 @@ bool PNGLoader::save(const QString& filePath, DImgLoaderObserver* const observer
     // will jump here
 
     // setjmp-save cleanup
-    class CleanupData
+    class Q_DECL_HIDDEN CleanupData
     {
     public:
 
-        CleanupData():
-            data(0),
+        CleanupData()
+          : data(0),
             f(0)
         {
         }
@@ -966,4 +966,4 @@ bool PNGLoader::isReadOnly() const
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
