@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-08-02
  * Description : save PNG image options.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,12 +43,12 @@
 namespace Digikam
 {
 
-class PNGSettings::Private
+class Q_DECL_HIDDEN PNGSettings::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         PNGGrid             = 0;
         labelPNGcompression = 0;
@@ -117,4 +117,4 @@ int PNGSettings::convertCompressionForLibPng(int value)
     return((int)(((1.0 - 100.0) / 8.0) * (float)value + 100.0 - ((1.0 - 100.0) / 8.0)));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
