@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-21-11
  * Description : A 16 bits/color/pixel PPM IO file for
  *               DImg framework
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef PPMLOADER_H
-#define PPMLOADER_H
+#ifndef DIGIKAM_PPM_LOADER_H
+#define DIGIKAM_PPM_LOADER_H
 
 // Local includes
 
@@ -49,6 +49,6 @@ public:
     virtual bool isReadOnly() const;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* PPMLOADER_H */
+#endif // DIGIKAM_PPM_LOADER_H
