@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-14
  * Description : A QImage loader for DImg framework.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2017 by Caulier Gilles <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Caulier Gilles <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,13 +22,14 @@
  *
  * ============================================================ */
 
-#ifndef QIMAGELOADER_H
-#define QIMAGELOADER_H
+#ifndef DIGIKAM_QIMAGE_LOADER_H
+#define DIGIKAM_QIMAGE_LOADER_H
 
 // Local includes
 
 #include "dimgloader.h"
 #include "digikam_export.h"
+#include "digikam_config.h"
 
 namespace Digikam
 {
@@ -47,11 +48,15 @@ public:
     virtual bool sixteenBit() const;
     virtual bool isReadOnly() const;
 
+private:
+
+    bool loadWithImageMagick(const QString& path, QImage& qimg);
+
 private:
 
     bool m_hasAlpha;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // QIMAGELOADER_H
+#endif // DIGIKAM_QIMAGE_LOADER_H
