@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-06-17
  * Description : A TIFF IO file for DImg framework
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef TIFFLOADER_H
-#define TIFFLOADER_H
+#ifndef DIGIKAM_TIFF_LOADER_H
+#define DIGIKAM_TIFF_LOADER_H
 
 // C ANSI includes
 
@@ -60,6 +60,8 @@ public:
 private:
 
     void tiffSetExifAsciiTag(TIFF* const tif, ttag_t tiffTag, const DMetadata& metaData, const char* const exifTagName);
+
+    // cppcheck-suppress unusedPrivateFunction
     void tiffSetExifDataTag(TIFF* const tif, ttag_t tiffTag, const DMetadata& metaData, const char* const exifTagName);
 
     static void dimg_tiff_warning(const char* module, const char* format, va_list warnings);
@@ -71,6 +73,6 @@ private:
     bool m_hasAlpha;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* TIFFLOADER_H */
+#endif // DIGIKAM_TIFF_LOADER_H
