@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-08-02
  * Description : save TIFF image options.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TIFFSETTINGS_H
-#define TIFFSETTINGS_H
+#ifndef DIGIKAM_TIFF_SETTINGS_H
+#define DIGIKAM_TIFF_SETTINGS_H
 
 // Qt includes
 
@@ -57,6 +57,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* TIFFSETTINGS_H */
+#endif // DIGIKAM_TIFF_SETTINGS_H
