@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-09-25
  * Description : a tool to convert RAW file to DNG
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Jens Mueller <tschenser at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -61,10 +61,7 @@ extern "C"
 #include <QFileInfo>
 #include <QIODevice>
 #include <QTemporaryFile>
-
-// LibDRawDecoder includes
-
-
+#include <qplatformdefs.h>
 
 // Local includes
 
@@ -180,8 +177,8 @@ int DNGWriter::convert()
 
         QFileInfo          outputInfo(dngFilePath);
         QByteArray         rawData;
-        RawInfo identify;
-        RawInfo identifyMake;
+        DRawInfo identify;
+        DRawInfo identifyMake;
 
         // -----------------------------------------------------------------------------------------
 
@@ -241,7 +238,7 @@ int DNGWriter::convert()
 
         QString matrixVal;
 
-        for(int i=0; i<4; ++i)
+        for (int i = 0 ; i < 4 ; ++i)
         {
             qCDebug(DIGIKAM_GENERAL_LOG) << "                   "
                      << QString().sprintf("%03.4f  %03.4f  %03.4f", identify.cameraXYZMatrix[i][0],
@@ -447,7 +444,7 @@ int DNGWriter::convert()
 
         ColorKeyCode colorCodes[4] = { colorKeyMaxEnum, colorKeyMaxEnum, colorKeyMaxEnum, colorKeyMaxEnum };
 
-        for(int i = 0; i < qMax(4, identify.colorKeys.length()); ++i)
+        for (int i = 0 ; i < qMax(4, identify.colorKeys.length()) ; ++i)
         {
             if (identify.colorKeys[i] == QLatin1Char('R'))
             {
@@ -524,19 +521,19 @@ int DNGWriter::convert()
 
         switch (identify.orientation)
         {
-            case RawInfo::ORIENTATION_180:
+            case DRawInfo::ORIENTATION_180:
                 orientation = dng_orientation::Rotate180();
                 break;
 
-            case RawInfo::ORIENTATION_Mirror90CCW:
+            case DRawInfo::ORIENTATION_Mirror90CCW:
                 orientation = dng_orientation::Mirror90CCW();
                 break;
 
-            case RawInfo::ORIENTATION_90CCW:
+            case DRawInfo::ORIENTATION_90CCW:
                 orientation = dng_orientation::Rotate90CCW();
                 break;
 
-            case RawInfo::ORIENTATION_90CW:
+            case DRawInfo::ORIENTATION_90CW:
                 orientation = dng_orientation::Rotate90CW();
                 break;
 
@@ -646,7 +643,7 @@ int DNGWriter::convert()
 
             // Time from original shot
             dng_date_time_info dti;
-            dti.SetDateTime(d->dngDateTime(meta.getImageDateTime()));
+            dti.SetDateTime(d->dngDateTime(meta.getItemDateTime()));
             exif->fDateTimeOriginal = dti;
 
             dti.SetDateTime(d->dngDateTime(meta.getDigitizationDateTime(true)));
@@ -924,7 +921,7 @@ int DNGWriter::convert()
 
             str = meta.getExifTagString("Exif.Pentax.LensType");
 
-            if (str.length())
+            if (!str.isEmpty())
             {
                 exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
                 exif->fLensName.TrimLeadingBlanks();
@@ -943,13 +940,13 @@ int DNGWriter::convert()
            // Olympus Makernotes
 
             str = meta.getExifTagString("Exif.OlympusEq.SerialNumber");
-            if (str.length()) exif->fCameraSerialNumber.Set_ASCII(str.trimmed().toLatin1().constData());
+            if (!str.isEmpty()) exif->fCameraSerialNumber.Set_ASCII(str.trimmed().toLatin1().constData());
 
             str = meta.getExifTagString("Exif.OlympusEq.LensSerialNumber");
-            if (str.length()) exif->fLensSerialNumber.Set_ASCII(str.trimmed().toLatin1().constData());
+            if (!str.isEmpty()) exif->fLensSerialNumber.Set_ASCII(str.trimmed().toLatin1().constData());
 
             str = meta.getExifTagString("Exif.OlympusEq.LensModel");
-            if (str.length()) exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
+            if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
 
             if (meta.getExifTagLong("Exif.OlympusEq.MinFocalLength", val))             exif->fLensInfo[0]              = dng_urational(val, 1);
             if (meta.getExifTagLong("Exif.OlympusEq.MaxFocalLength", val))             exif->fLensInfo[1]              = dng_urational(val, 1);
@@ -957,10 +954,10 @@ int DNGWriter::convert()
             // Panasonic Makernotes
 
             str = meta.getExifTagString("Exif.Panasonic.LensType");
-            if (str.length()) exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
+            if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
 
             str = meta.getExifTagString("Exif.Panasonic.LensSerialNumber");
-            if (str.length()) exif->fLensSerialNumber.Set_ASCII(str.trimmed().toLatin1().constData());
+            if (!str.isEmpty()) exif->fLensSerialNumber.Set_ASCII(str.trimmed().toLatin1().constData());
 
             // Sony Makernotes
 
@@ -970,7 +967,7 @@ int DNGWriter::convert()
             }
 
             str = meta.getExifTagString("Exif.Sony2.LensID");
-            if (str.length()) exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
+            if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.trimmed().toLatin1().constData());
 
             // -------------------------------------------
 
@@ -1020,7 +1017,8 @@ int DNGWriter::convert()
                 stream.SetReadPosition(0);
                 stream.Get(block->Buffer(), mkrnts.size());
 
-                if (identifyMake.make != QLatin1String("Canon"))
+                if (identifyMake.make != QLatin1String("Canon") &&
+                    identifyMake.make != QLatin1String("Panasonic"))
                 {
                     negative->SetMakerNote(block);
                     negative->SetMakerNoteSafety(true);
@@ -1116,6 +1114,7 @@ int DNGWriter::convert()
             tempDataStream.Put(compressedData.data(), compressedData.size());
 
             compressedFile.remove();
+            originalFile.close();
 
             tempDataStream.Put_uint32(0);
             tempDataStream.Put_uint32(0);
@@ -1281,14 +1280,14 @@ int DNGWriter::convert()
 
         if (d->updateFileDate)
         {
-            QDateTime date = meta.getImageDateTime();
+            QDateTime date = meta.getItemDateTime();
 
             qCDebug(DIGIKAM_GENERAL_LOG) << "DNGWriter: Setting modification date from meta data: " << date.toString();
 
             // don't touch access time
-            struct stat st;
+            QT_STATBUF st;
 
-            if (::stat(QFile::encodeName(dngFilePath).constData(), &st) == 0)
+            if (QT_STAT(QFile::encodeName(dngFilePath).constData(), &st) == 0)
             {
                 struct utimbuf ut;
                 ut.actime  = st.st_atime;
@@ -1316,4 +1315,4 @@ int DNGWriter::convert()
     return PROCESSCOMPLETE;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
