@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-09-25
  * Description : a tool to convert RAW file to DNG
  *
- * Copyright (C) 2008-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -20,22 +20,23 @@
  *
  * ============================================================ */
 
-#ifndef DNGWRITERHOST_H
-#define DNGWRITERHOST_H
+#ifndef DIGIKAM_DNG_WRITER_HOST_H
+#define DIGIKAM_DNG_WRITER_HOST_H
 
 // Local includes
 
 #include "dngwriter_p.h"
+#include "digikam_export.h"
 
 namespace Digikam
 {
 
-class DNGWriterHost : public dng_host
+class DIGIKAM_EXPORT DNGWriterHost : public dng_host
 {
 
 public:
 
-    DNGWriterHost(DNGWriter::Private* const priv, dng_memory_allocator* const allocator=0);
+    explicit DNGWriterHost(DNGWriter::Private* const priv, dng_memory_allocator* const allocator=0);
     ~DNGWriterHost();
 
 private:
@@ -49,4 +50,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DNGWRITERHOST_H
+#endif // DIGIKAM_DNG_WRITER_HOST_H
