@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-08-09
  * Description : DTrash item info model
  *
- * Copyright (C) 2015 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,9 +25,12 @@
 
 // Qt includes
 
-#include <QPixmap>
-#include <QPersistentModelIndex>
+#include <QIcon>
 #include <QTimer>
+#include <QPixmap>
+#include <QMimeType>
+#include <QMimeDatabase>
+#include <QPersistentModelIndex>
 
 // KDE includes
 
@@ -37,24 +40,22 @@
 
 #include "digikam_debug.h"
 #include "thumbnailsize.h"
-#include "thumbnailloadthread.h"
 #include "iojobsmanager.h"
 
 namespace Digikam
 {
 
-class DTrashItemModel::Private
+class Q_DECL_HIDDEN DTrashItemModel::Private
 {
 
 public:
 
-    Private() :
-        thumbSize(ThumbnailSize::Large),
+    explicit Private()
+      : thumbSize(ThumbnailSize::Large),
         sortColumn(2),
         sortOrder(Qt::DescendingOrder),
         itemsLoadingThread(0),
-        thumbnailThread(0),
-        timer(0)
+        thumbnailThread(0)
     {
     }
 
@@ -62,29 +63,31 @@ public:
 
     int                  thumbSize;
     int                  sortColumn;
+
     Qt::SortOrder        sortOrder;
+
     IOJobsThread*        itemsLoadingThread;
     ThumbnailLoadThread* thumbnailThread;
-    QTimer*              timer;
+
+    QList<QString>       failedThumbnails;
     DTrashItemInfoList   data;
 };
 
-DTrashItemModel::DTrashItemModel(QObject* parent)
-    : QAbstractTableModel(parent), d(new Private)
+DTrashItemModel::DTrashItemModel(QObject* const parent)
+    : QAbstractTableModel(parent),
+      d(new Private)
 {
     qRegisterMetaType<DTrashItemInfo>("DTrashItemInfo");
-    d->thumbnailThread = ThumbnailLoadThread::defaultThread();
+    d->thumbnailThread = new ThumbnailLoadThread;
+    d->thumbnailThread->setSendSurrogatePixmap(false);
 
-    d->timer = new QTimer();
-    d->timer->setInterval(100);
-    d->timer->setSingleShot(true);
-
-    connect(d->timer, SIGNAL(timeout()),
-            this, SLOT(refreshLayout()));
+    connect(d->thumbnailThread, SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
+            this, SLOT(refreshThumbnails(LoadingDescription,QPixmap)));
 }
 
 DTrashItemModel::~DTrashItemModel()
 {
+    delete d->thumbnailThread;
     delete d;
 }
 
@@ -100,11 +103,13 @@ int DTrashItemModel::columnCount(const QModelIndex&) const
 
 QVariant DTrashItemModel::data(const QModelIndex& index, int role) const
 {
-    if ( role != Qt::DisplayRole &&
-         role != Qt::DecorationRole &&
-         role != Qt::TextAlignmentRole &&
-         role != Qt::ToolTipRole)
+    if (role != Qt::DisplayRole       &&
+        role != Qt::DecorationRole    &&
+        role != Qt::TextAlignmentRole &&
+        role != Qt::ToolTipRole)
+    {
         return QVariant();
+    }
 
     const DTrashItemInfo& item = d->data[index.row()];
 
@@ -114,9 +119,29 @@ QVariant DTrashItemModel::data(const QModelIndex& index, int role) const
     if (role == Qt::DecorationRole && index.column() == 0)
     {
         QPixmap pix;
+        QString thumbPath;
 
-        if (pixmapForItem(item.trashPath, pix))
+        if (!d->failedThumbnails.contains(item.collectionPath))
         {
+            thumbPath = item.collectionPath;
+        }
+        else
+        {
+            thumbPath = item.trashPath;
+        }
+
+        if (pixmapForItem(thumbPath, pix))
+        {
+            if (pix.isNull())
+            {
+                QMimeType mimeType = QMimeDatabase().mimeTypeForFile(item.trashPath);
+
+                if (mimeType.isValid())
+                {
+                    pix = QIcon::fromTheme(mimeType.genericIconName()).pixmap(128);
+                }
+            }
+
             return pix;
         }
         else
@@ -130,9 +155,22 @@ QVariant DTrashItemModel::data(const QModelIndex& index, int role) const
 
     switch (index.column())
     {
-        case 1: return item.collectionRelativePath;
-        case 2: return item.deletionTimestamp.toString();
-        default: return QVariant();
+        case 1:
+            return item.collectionRelativePath;
+        case 2:
+        {
+            QString dateTimeFormat = QLocale().dateTimeFormat();
+
+            if (!dateTimeFormat.contains(QLatin1String("yyyy")))
+            {
+                dateTimeFormat.replace(QLatin1String("yy"),
+                                       QLatin1String("yyyy"));
+            }
+
+            return item.deletionTimestamp.toString(dateTimeFormat);
+        }
+        default:
+            return QVariant();
     };
 }
 
@@ -169,9 +207,9 @@ void DTrashItemModel::sort(int column, Qt::SortOrder order)
                     return a.collectionRelativePath < b.collectionRelativePath;
                 });
 
-    const QModelIndex topLeft     = index(0, 0, QModelIndex());
+    const QModelIndex topLeft     = index(0, 0);
     const QModelIndex bottomRight = index(rowCount(QModelIndex())-1,
-                                          columnCount(QModelIndex())-1, QModelIndex());
+                                          columnCount(QModelIndex())-1);
     dataChanged(topLeft, bottomRight);
 }
 
@@ -190,10 +228,14 @@ QVariant DTrashItemModel::headerData(int section, Qt::Orientation orientation, i
 
     switch (section)
     {
-        case 0: return i18n("Thumbnail");
-        case 1: return i18n("Relative Path");
-        case 2: return i18n("Deletion Time");
-        default: return QVariant();
+        case 0:
+            return i18n("Thumbnail");
+        case 1:
+            return i18n("Relative Path");
+        case 2:
+            return i18n("Deletion Time");
+        default:
+            return QVariant();
     }
 }
 
@@ -226,6 +268,11 @@ void DTrashItemModel::removeItems(const QModelIndexList& indexes)
         if (!index.isValid())
             continue;
 
+        const DTrashItemInfo& item = d->data[index.row()];
+
+        d->failedThumbnails.removeAll(item.collectionPath);
+        d->failedThumbnails.removeAll(item.trashPath);
+
         beginRemoveRows(QModelIndex(), index.row(), index.row());
         removeRow(index.row());
         d->data.removeAt(index.row());
@@ -238,12 +285,31 @@ void DTrashItemModel::removeItems(const QModelIndexList& indexes)
 
 void DTrashItemModel::refreshLayout()
 {
+    const QModelIndex topLeft     = index(0, 0);
+    const QModelIndex bottomRight = index(rowCount(QModelIndex())-1, 0);
+    dataChanged(topLeft, bottomRight);
     layoutAboutToBeChanged();
     layoutChanged();
 }
 
+void DTrashItemModel::refreshThumbnails(const LoadingDescription& desc, const QPixmap& pix)
+{
+    if (pix.isNull())
+    {
+        if (!d->failedThumbnails.contains(desc.filePath))
+        {
+            d->failedThumbnails << desc.filePath;
+        }
+    }
+
+    const QModelIndex topLeft     = index(0, 0);
+    const QModelIndex bottomRight = index(rowCount(QModelIndex())-1, 0);
+    dataChanged(topLeft, bottomRight);
+}
+
 void DTrashItemModel::clearCurrentData()
 {
+    d->failedThumbnails.clear();
     beginResetModel();
     d->data.clear();
     endResetModel();
@@ -285,6 +351,18 @@ DTrashItemInfoList DTrashItemModel::itemsForIndexes(const QList<QModelIndex>& in
     return items;
 }
 
+QModelIndex DTrashItemModel::indexForItem(const DTrashItemInfo& itemInfo) const
+{
+    int index = d->data.indexOf(itemInfo);
+
+    if (index != -1)
+    {
+        return createIndex(index, 0);
+    }
+
+    return QModelIndex();
+}
+
 DTrashItemInfoList DTrashItemModel::allItems()
 {
     return d->data;
@@ -302,11 +380,7 @@ void DTrashItemModel::changeThumbSize(int size)
     if (isEmpty())
         return;
 
-    const QModelIndex topLeft     = index(0, 0, QModelIndex());
-    const QModelIndex bottomRight = index(rowCount(QModelIndex())-1, 0, QModelIndex());
-    dataChanged(topLeft, bottomRight);
-
-    d->timer->start();
+    QTimer::singleShot(100, this, SLOT(refreshLayout()));
 }
 
 } // namespace Digikam
