@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-08-09
  * Description : DTrash item info model
  *
- * Copyright (C) 2015 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DTRASHITEMMODEL_H
-#define DTRASHITEMMODEL_H
+#ifndef DIGIKAM_DTRASH_ITEM_MODEL_H
+#define DIGIKAM_DTRASH_ITEM_MODEL_H
 
 // Qt includes
 
@@ -42,7 +42,7 @@ class DTrashItemModel : public QAbstractTableModel
 
 public:
 
-    DTrashItemModel(QObject* parent = 0);
+    explicit DTrashItemModel(QObject* const parent = 0);
     ~DTrashItemModel();
 
     /**
@@ -74,6 +74,11 @@ public:
      */
     DTrashItemInfoList itemsForIndexes(const QList<QModelIndex>& indexes);
 
+    /**
+     * @brief returns the index for the DTrashItemInfo in model
+     */
+    QModelIndex indexForItem(const DTrashItemInfo& itemInfo) const;
+
     /**
      * @brief returns a list of all items in model
      */
@@ -121,6 +126,13 @@ public Q_SLOTS:
      */
     void refreshLayout();
 
+    /**
+     * @brief refreshes the thumbnails
+     * @param desc: loading description from thumbnail load thread
+     * @param pix: pixmap from thumbnail load thread
+     */
+    void refreshThumbnails(const LoadingDescription& desc, const QPixmap& pix);
+
 Q_SIGNALS:
 
     void dataChange();
@@ -133,4 +145,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DTRASHITEMMODEL_H
+#endif // DIGIKAM_DTRASH_ITEM_MODEL_H
