@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-18
  * Description : Face database access wrapper.
  *
  * Copyright (C) 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,11 +45,11 @@
 namespace Digikam
 {
 
-class FaceDbAccessStaticPriv
+class Q_DECL_HIDDEN FaceDbAccessStaticPriv
 {
 public:
 
-    FaceDbAccessStaticPriv()
+    explicit FaceDbAccessStaticPriv()
         : backend(0),
           db(0),
           initializing(false)
@@ -74,11 +74,11 @@ FaceDbAccessStaticPriv* FaceDbAccess::d = 0;
 
 // ----------------------------------------------------------------
 
-class FaceDbAccessMutexLocker : public QMutexLocker
+class Q_DECL_HIDDEN FaceDbAccessMutexLocker : public QMutexLocker
 {
 public:
 
-    FaceDbAccessMutexLocker(FaceDbAccessStaticPriv* const d)
+    explicit FaceDbAccessMutexLocker(FaceDbAccessStaticPriv* const d)
         : QMutexLocker(&d->lock.mutex),
           d(d)
     {
@@ -293,7 +293,7 @@ FaceDbAccessUnlock::FaceDbAccessUnlock()
     FaceDbAccess::d->lock.lockCount = 0;
 
     // unlock
-    for (int i = 0; i < count; ++i)
+    for (int i = 0 ; i < count ; ++i)
     {
         FaceDbAccess::d->lock.mutex.unlock();
     }
@@ -311,7 +311,7 @@ FaceDbAccessUnlock::FaceDbAccessUnlock(FaceDbAccess* const)
     FaceDbAccess::d->lock.lockCount = 0;
 
     // unlock
-    for (int i = 0; i < count; ++i)
+    for (int i = 0 ; i < count ; ++i)
     {
         FaceDbAccess::d->lock.mutex.unlock();
     }
@@ -322,7 +322,7 @@ FaceDbAccessUnlock::FaceDbAccessUnlock(FaceDbAccess* const)
 FaceDbAccessUnlock::~FaceDbAccessUnlock()
 {
     // lock as often as it was locked before
-    for (int i = 0; i < count; ++i)
+    for (int i = 0 ; i < count ; ++i)
     {
         FaceDbAccess::d->lock.mutex.lock();
     }
