@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-29
  * Description : Face database schema updater
  *
  * Copyright (C) 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef FACE_DATABASE_SCHEMA_UPDATER_H
-#define FACE_DATABASE_SCHEMA_UPDATER_H
+#ifndef DIGIKAM_FACE_DB_SCHEMA_UPDATER_H
+#define DIGIKAM_FACE_DB_SCHEMA_UPDATER_H
 
 // Local includes
 
@@ -42,7 +42,7 @@ public:
 
 public:
 
-    FaceDbSchemaUpdater(FaceDbAccess* const access);
+    explicit FaceDbSchemaUpdater(FaceDbAccess* const dbAccess);
     ~FaceDbSchemaUpdater();
 
     bool update();
@@ -57,13 +57,16 @@ private:
     bool createIndices();
     bool createTriggers();
     bool updateV1ToV2();
+    bool updateV2ToV3();
 
 private:
 
+    FaceDbSchemaUpdater(const FaceDbSchemaUpdater&); // Disable
+
     class Private;
     Private* const d;
 };
 
 } // namespace Digikam
 
-#endif // FACE_DATABASE_SCHEMA_UPDATER_H
+#endif // DIGIKAM_FACE_DB_SCHEMA_UPDATER_H
