@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-02-05
  * Description : file action manager task list
@@ -30,8 +30,10 @@
 namespace Digikam
 {
 
-void TwoProgressItemsContainer::scheduleOnProgressItem(QAtomicPointer<ProgressItem>& ptr, int total,
-                                                       const QString& action, FileActionProgressItemCreator* const creator)
+void TwoProgressItemsContainer::scheduleOnProgressItem(QAtomicPointer<ProgressItem>& ptr,
+                                                       int total,
+                                                       const QString& action,
+                                                       FileActionProgressItemCreator* const creator)
 {
     if (total <= 0)
     {
@@ -70,10 +72,10 @@ void TwoProgressItemsContainer::advance(QAtomicPointer<ProgressItem>& ptr, int n
 
 FileActionProgressItemContainer::FileActionProgressItemContainer()
 {
-
 }
 
-void FileActionProgressItemContainer::schedulingForDB(int numberOfInfos, const QString& action,
+void FileActionProgressItemContainer::schedulingForDB(int numberOfInfos,
+                                                      const QString& action,
                                                       FileActionProgressItemCreator* const creator)
 {
     scheduleOnProgressItem(firstItem, numberOfInfos, action, creator);
@@ -89,10 +91,12 @@ void FileActionProgressItemContainer::dbFinished()
     //checkFinish(firstItem);
 }
 
-void FileActionProgressItemContainer::schedulingForWrite(int numberOfInfos, const QString& action,
+void FileActionProgressItemContainer::schedulingForWrite(int numberOfInfos,
+                                                         const QString& action,
                                                          FileActionProgressItemCreator* const creator)
 {
     scheduleOnProgressItem(secondItem, numberOfInfos, action, creator);
+
     connect(secondItem, SIGNAL(progressItemCompleted(ProgressItem*)),
             this, SIGNAL(signalWrittingDone()));
 }
@@ -107,18 +111,19 @@ void FileActionProgressItemContainer::finishedWriting()
 //    checkFinish(secondItem);
 }
 
-FileActionImageInfoList FileActionImageInfoList::create(const QList<ImageInfo>& infos)
+FileActionItemInfoList FileActionItemInfoList::create(const QList<ItemInfo>& infos)
 {
-    FileActionImageInfoList list;
-    list           = infos;
+    FileActionItemInfoList list;
+    list           = FileActionItemInfoList(infos);
     list.container = new FileActionProgressItemContainer;
     return list;
 }
 
-FileActionImageInfoList FileActionImageInfoList::continueTask(const QList<ImageInfo>& infos, FileActionProgressItemContainer* const container)
+FileActionItemInfoList FileActionItemInfoList::continueTask(const QList<ItemInfo>& infos,
+                                                              FileActionProgressItemContainer* const container)
 {
-    FileActionImageInfoList list;
-    list           = infos;
+    FileActionItemInfoList list;
+    list           = FileActionItemInfoList(infos);
     list.container = container;
     return list;
 }
