@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-18
  * Description : file worker interface
@@ -21,14 +21,14 @@
  *
  * ============================================================ */
 
-#ifndef FILEWORKERIFACE_H
-#define FILEWORKERIFACE_H
+#ifndef DIGIKAM_FILE_WORKER_IFACE_H
+#define DIGIKAM_FILE_WORKER_IFACE_H
 
 // Local includes
 
 #include "fileactionmngr.h"
 #include "fileactionimageinfolist.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "workerobject.h"
 
 namespace Digikam
@@ -42,10 +42,10 @@ class FileWorkerInterface : public WorkerObject
 
 public Q_SLOTS:
 
-    virtual void writeOrientationToFiles(FileActionImageInfoList, int){};
-    virtual void writeMetadataToFiles(FileActionImageInfoList)        {};
-    virtual void writeMetadata(FileActionImageInfoList, int)          {};
-    virtual void transform(FileActionImageInfoList, int)              {};
+    virtual void writeOrientationToFiles(FileActionItemInfoList, int){};
+    virtual void writeMetadataToFiles(FileActionItemInfoList)        {};
+    virtual void writeMetadata(FileActionItemInfoList, int)          {};
+    virtual void transform(FileActionItemInfoList, int)              {};
 
 Q_SIGNALS:
 
@@ -67,11 +67,13 @@ public:
 
 public:
 
-    void writeOrientationToFiles(FileActionImageInfoList infos, int orientation);
-    void writeMetadataToFiles(FileActionImageInfoList infos);
-    void writeMetadata(FileActionImageInfoList infos, int flags);
-    void transform(FileActionImageInfoList infos, int orientation);
-    void ajustFaceRectangles(const ImageInfo& info, int action);
+    void writeOrientationToFiles(FileActionItemInfoList infos, int orientation);
+    void writeMetadataToFiles(FileActionItemInfoList infos);
+    void writeMetadata(FileActionItemInfoList infos, int flags);
+    void transform(FileActionItemInfoList infos, int orientation);
+    void adjustFaceRectangles(const ItemInfo& info, bool rotatedPixels,
+                                                    int newOrientation,
+                                                    int oldOrientation);
 
 private:
 
@@ -80,4 +82,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* FILEWORKERIFACE_H */
+#endif // DIGIKAM_FILE_WORKER_IFACE_H
