@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-08-21
  * Description : a bar to indicate pending metadata
@@ -37,13 +37,13 @@
 
 // Local includes
 
-#include "metadatasettings.h"
+#include "metaenginesettings.h"
 #include "dexpanderbox.h"
 
 namespace Digikam
 {
 
-class MetadataStatusBar::Private
+class Q_DECL_HIDDEN MetadataStatusBar::Private
 {
 public:
 
@@ -56,7 +56,7 @@ public:
 
 public:
 
-    Private()
+    explicit Private()
     {
         status      = None;
         info        = 0;
@@ -74,15 +74,14 @@ MetadataStatusBar::MetadataStatusBar(QWidget* const parent)
       d(new Private)
 {
     QHBoxLayout* const vlay = new QHBoxLayout(this);
-
-    d->applyBtn    = new QToolButton(this);
+    d->applyBtn             = new QToolButton(this);
     d->applyBtn->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
     d->applyBtn->setToolTip(i18n("Apply pending changes to metadata"));
     d->applyBtn->setFocusPolicy(Qt::NoFocus);
     d->applyBtn->setAutoRaise(true);
     d->applyBtn->setDisabled(true);
 
-    d->info        = new DAdjustableLabel(this);
+    d->info                 = new DAdjustableLabel(this);
     d->info->setContextMenuPolicy(Qt::NoContextMenu);
     d->info->setAutoFillBackground(true);
     d->info->setFocusPolicy(Qt::NoFocus);
@@ -97,8 +96,8 @@ MetadataStatusBar::MetadataStatusBar(QWidget* const parent)
     vlay->setContentsMargins(QMargins());
     vlay->setStretchFactor(d->info, 10);
 
-    connect(MetadataSettings::instance(), SIGNAL(settingsChanged()), this,
-            SLOT(slotSettingsChanged()));
+    connect(MetaEngineSettings::instance(), SIGNAL(settingsChanged()),
+            this, SLOT(slotSettingsChanged()));
 
     connect(d->applyBtn, SIGNAL(released()),
             MetadataHubMngr::instance(), SLOT(slotApplyPending()));
@@ -106,7 +105,7 @@ MetadataStatusBar::MetadataStatusBar(QWidget* const parent)
     connect(MetadataHubMngr::instance(), SIGNAL(signalPendingMetadata(int)),
             this, SLOT(slotSetPendingItems(int)));
 
-    if (MetadataSettings::instance()->settings().useLazySync)
+    if (MetaEngineSettings::instance()->settings().useLazySync)
         this->show();
     else
         this->hide();
@@ -119,7 +118,7 @@ MetadataStatusBar::~MetadataStatusBar()
 
 void MetadataStatusBar::slotSettingsChanged()
 {
-    if (MetadataSettings::instance()->settings().useLazySync)
+    if (MetaEngineSettings::instance()->settings().useLazySync)
         this->show();
     else
         this->hide();
@@ -141,4 +140,4 @@ void MetadataStatusBar::slotSetPendingItems(int number)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
