@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-11-27
  * Description : a bar to indicate icon-view filters status
  *
- * Copyright (C) 2007-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2011      by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -42,7 +42,7 @@
 namespace Digikam
 {
 
-class FilterStatusBar::Private
+class Q_DECL_HIDDEN FilterStatusBar::Private
 {
 public:
 
@@ -55,7 +55,7 @@ public:
 
 public:
 
-    Private()
+    explicit Private()
     {
         status      = None;
         info        = 0;
@@ -69,7 +69,7 @@ public:
     QToolButton*      resetBtn;
     QToolButton*      settingsBtn;
 
-    ImageFilterSettings settings;
+    ItemFilterSettings settings;
 };
 
 FilterStatusBar::FilterStatusBar(QWidget* const parent)
@@ -217,9 +217,9 @@ void FilterStatusBar::slotFilterMatches(bool match)
     update();
 }
 
-void FilterStatusBar::slotFilterSettingsChanged(const ImageFilterSettings& settings)
+void FilterStatusBar::slotFilterSettingsChanged(const ItemFilterSettings& settings)
 {
     d->settings = settings;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
