@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-10-22
  * Description : a widget to filter album contents by type mime
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef MIMEFILTER_H
-#define MIMEFILTER_H
+#ifndef DIGIKAM_MIME_FILTER_H
+#define DIGIKAM_MIME_FILTER_H
 
 // Qt includes
 
@@ -49,7 +49,7 @@ public:
         RAWFiles,
         MoviesFiles,
         AudioFiles,
-        RasterFiles               // PSD, XCF, etc...
+        RasterGraphics       // PSD, XCF, etc...
     };
 
 public:
@@ -61,6 +61,6 @@ public:
     int mimeFilter();
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // MIMEFILTER_H
+#endif // DIGIKAM_MIME_FILTER_H
