@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-02-16
  * Description : pick label filter
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef PICKLABELFILTER_H
-#define PICKLABELFILTER_H
+#ifndef DIGIKAM_PICK_LABEL_FILTER_H
+#define DIGIKAM_PICK_LABEL_FILTER_H
 
 // Qt includes
 
@@ -60,6 +60,6 @@ private Q_SLOTS:
     void slotPickLabelSelectionChanged();
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // PICKLABELFILTER_H
+#endif // DIGIKAM_PICK_LABEL_FILTER_H
