@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-10-09
  * Description : a widget to filter album contents by rating
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Arnd Baecker <arnd dot baecker at web dot de>
- * Copyright (C) 2014      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,13 +23,13 @@
  *
  * ============================================================ */
 
-#ifndef RATINGFILTER_H
-#define RATINGFILTER_H
+#ifndef DIGIKAM_RATING_FILTER_H
+#define DIGIKAM_RATING_FILTER_H
 
 // Local includes
 
 #include "dlayoutbox.h"
-#include "imagefiltersettings.h"
+#include "itemfiltersettings.h"
 #include "ratingwidget.h"
 
 class QAction;
@@ -46,15 +46,15 @@ public:
     explicit RatingFilterWidget(QWidget* const parent);
     ~RatingFilterWidget();
 
-    void setRatingFilterCondition(ImageFilterSettings::RatingCondition cond);
-    ImageFilterSettings::RatingCondition ratingFilterCondition();
+    void setRatingFilterCondition(ItemFilterSettings::RatingCondition cond);
+    ItemFilterSettings::RatingCondition ratingFilterCondition();
 
     void setExcludeUnratedItems(bool excluded);
     bool isUnratedItemsExcluded();
 
 Q_SIGNALS:
 
-    void signalRatingFilterChanged(int, ImageFilterSettings::RatingCondition, bool);
+    void signalRatingFilterChanged(int, ItemFilterSettings::RatingCondition, bool);
 
 protected:
 
@@ -90,15 +90,15 @@ public:
     void setRating(int val);
     int  rating() const;
 
-    void setRatingFilterCondition(ImageFilterSettings::RatingCondition cond);
-    ImageFilterSettings::RatingCondition ratingFilterCondition();
+    void setRatingFilterCondition(ItemFilterSettings::RatingCondition cond);
+    ItemFilterSettings::RatingCondition ratingFilterCondition();
 
     void setExcludeUnratedItems(bool excluded);
     bool isUnratedItemsExcluded();
 
 Q_SIGNALS:
 
-    void signalRatingFilterChanged(int, ImageFilterSettings::RatingCondition, bool);
+    void signalRatingFilterChanged(int, ItemFilterSettings::RatingCondition, bool);
 
 private Q_SLOTS:
 
@@ -111,6 +111,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // RATINGFILTER_H
+#endif // DIGIKAM_RATING_FILTER_H
