@@ -1,17 +1,19 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-09-29
- * Description : perform lossless rotation/flip to JPEG file
+ * Description : helper methods for JPEG image format.
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * Parts of the loading code is taken from qjpeghandler.cpp, copyright follows:
- * Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+ * Parts of the loading code is taken from qjpeghandler.cpp
+ * Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+ * All rights reserved.
+ * Contact: Nokia Corporation (qt-info@nokia.com)
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,11 +37,6 @@
 #include <cstdio>
 #include <cstdlib>
 
-// Digikam includes
-
-#include <dimg.h>
-#include <dmetadata.h>
-
 // C ANSI includes
 
 extern "C"
@@ -53,14 +50,14 @@ extern "C"
 }
 
 // Pragma directives to reduce warnings from libjpeg transupp header file.
-#if !defined(__APPLE__) && defined(__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wunused-parameter"
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#   pragma GCC diagnostic push
+#   pragma GCC diagnostic ignored "-Wunused-parameter"
 #endif
 
-#if defined(__APPLE__) && defined(__clang__)
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wunused-parameter"
+#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wunused-parameter"
 #endif
 
 extern "C"
@@ -69,12 +66,12 @@ extern "C"
 }
 
 // Restore warnings
-#if !defined(__APPLE__) && defined(__GNUC__)
-#pragma GCC diagnostic pop
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#   pragma GCC diagnostic pop
 #endif
 
-#if defined(__APPLE__) && defined(__clang__)
-#pragma clang diagnostic pop
+#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
+#   pragma clang diagnostic pop
 #endif
 
 // Qt includes
@@ -83,18 +80,18 @@ extern "C"
 #include <QByteArray>
 #include <QFile>
 #include <QFileInfo>
+#include <qplatformdefs.h>
 
 // Local includes
 
 #include "digikam_debug.h"
-#include "digikam_config.h"
-#include "dmetadata.h"
-#include "metadatasettings.h"
+#include "dimg.h"
+#include "metaenginesettings.h"
 #include "filereadwritelock.h"
 
 #ifdef Q_OS_WIN
-#include "windows.h"
-#include "jpegwin.h"
+#   include "windows.h"
+#   include "jpegwin.h"
 #endif
 
 namespace Digikam
@@ -243,8 +240,8 @@ bool loadJPEGScaled(QImage& image, const QString& path, int maximumSize)
 
     // We only take RGB with 1 or 3 components, or CMYK with 4 components
     if (!(
-            (cinfo.out_color_space == JCS_RGB  && (cinfo.output_components == 3 || cinfo.output_components == 1)) ||
-            (cinfo.out_color_space == JCS_CMYK &&  cinfo.output_components == 4)
+           (cinfo.out_color_space == JCS_RGB  && (cinfo.output_components == 3 || cinfo.output_components == 1)) ||
+           (cinfo.out_color_space == JCS_CMYK &&  cinfo.output_components == 4)
         ))
     {
         jpeg_destroy_decompress(&cinfo);
@@ -284,28 +281,28 @@ bool loadJPEGScaled(QImage& image, const QString& path, int maximumSize)
     if (cinfo.output_components == 3)
     {
         // Expand 24->32 bpp.
-        for (uint j=0; j<cinfo.output_height; ++j)
+        for (uint j = 0 ; j < cinfo.output_height ; ++j)
         {
             uchar* in       = img.scanLine(j) + cinfo.output_width * 3;
             QRgb* const out = reinterpret_cast<QRgb*>(img.scanLine(j));
 
-            for (uint i = cinfo.output_width; --i; )
+            for (uint i = cinfo.output_width ; --i ; )
             {
-                in     -= 3;
+                in    -= 3;
                 out[i] = qRgb(in[0], in[1], in[2]);
             }
         }
     }
     else if (cinfo.out_color_space == JCS_CMYK)
     {
-        for (uint j = 0; j < cinfo.output_height; ++j)
+        for (uint j = 0 ; j < cinfo.output_height ; ++j)
         {
             uchar* in       = img.scanLine(j) + cinfo.output_width * 4;
             QRgb* const out = reinterpret_cast<QRgb*>(img.scanLine(j));
 
-            for (uint i = cinfo.output_width; --i; )
+            for (uint i = cinfo.output_width ; --i ; )
             {
-                in     -= 4;
+                in    -= 4;
                 int k  = in[3];
                 out[i] = qRgb(k * in[0] / 255, k * in[1] / 255, k * in[2] / 255);
             }
@@ -340,7 +337,7 @@ JpegRotator::JpegRotator(const QString& file)
       m_destFile(file)
 {
     m_metadata.load(file);
-    m_orientation  = m_metadata.getImageOrientation();
+    m_orientation  = m_metadata.getItemOrientation();
     QFileInfo info(file);
     m_documentName = info.fileName();
 }
@@ -411,7 +408,7 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
     QString     dir  = fi.absolutePath();
     QStringList removeLater;
 
-    for (int i = 0 ; i < actions.size() ; i++)
+    for (int i = 0 ; i < actions.size() ; ++i)
     {
         SafeTemporaryFile* const temp = new SafeTemporaryFile(dir + QLatin1String("/JpegRotator-XXXXXX.digikamtempfile.jpg"));
         temp->setAutoRemove(false);
@@ -453,7 +450,7 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
             qCDebug(DIGIKAM_GENERAL_LOG) << "Lossy transform done for " << src;
         }
 
-        if (i+1 != actions.size())
+        if (i + 1 != actions.size())
         {
             // another round
             src = tempFile;
@@ -507,9 +504,6 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
 
 void JpegRotator::updateMetadata(const QString& fileName, const MetaEngineRotation &matrix)
 {
-    // Reset the Exif orientation tag of the temp image to normal
-    m_metadata.setImageOrientation(DMetadata::ORIENTATION_NORMAL);
-
     QMatrix qmatrix = matrix.toMatrix();
     QRect r(QPoint(0, 0), m_originalSize);
     QSize newSize   = qmatrix.mapRect(r).size();
@@ -517,7 +511,7 @@ void JpegRotator::updateMetadata(const QString& fileName, const MetaEngineRotati
     // Get the new image dimension of the temp image. Using a dummy QImage object here
     // has a sense because the Exif dimension information can be missing from original image.
     // Get new dimensions with QImage will always work...
-    m_metadata.setImageDimensions(newSize);
+    m_metadata.setItemDimensions(newSize);
 
     // Update the image thumbnail.
     QImage exifThumb = m_metadata.getExifThumbnail(true);
@@ -529,23 +523,27 @@ void JpegRotator::updateMetadata(const QString& fileName, const MetaEngineRotati
 
     QImage imagePreview;
 
-    if (m_metadata.getImagePreview(imagePreview))
+    if (m_metadata.getItemPreview(imagePreview))
     {
-        m_metadata.setImagePreview(imagePreview.transformed(qmatrix));
+        m_metadata.setItemPreview(imagePreview.transformed(qmatrix));
     }
 
+    // Reset the Exif orientation tag of the temp image to normal
+    m_metadata.setItemOrientation(DMetadata::ORIENTATION_NORMAL);
+
     // We update all new metadata now...
-    m_metadata.save(fileName);
+    m_metadata.save(fileName, true);
 
     // File properties restoration.
 
-    struct stat st;
+    QT_STATBUF st;
 
-    if (::stat(QFile::encodeName(m_file).constData(), &st) == 0)
+    if (QT_STAT(QFile::encodeName(m_file).constData(), &st) == 0)
     {
-        // See bug #329608: Restore file modification time from original file only if updateFileTimeStamp for Setup/Metadata is turned off.
+        // See bug #329608: Restore file modification time from original file
+        // only if updateFileTimeStamp for Setup/Metadata is turned off.
 
-        if (!MetadataSettings::instance()->settings().updateFileTimeStamp)
+        if (!MetaEngineSettings::instance()->settings().updateFileTimeStamp)
         {
             struct utimbuf ut;
             ut.modtime = st.st_mtime;
@@ -731,7 +729,7 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
         if (format.toUpper() != QLatin1String("JPG") && format.toUpper() != QLatin1String("JPEG") &&
             format.toUpper() != QLatin1String("JPE"))
         {
-            meta.setImagePreview(preview);
+            meta.setItemPreview(preview);
         }
 
         // Update Exif thumbnail.
@@ -746,24 +744,24 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
 
         // And now save the image to a new file format.
 
-        if ( format.toUpper() == QLatin1String("PNG") )
+        if (format.toUpper() == QLatin1String("PNG"))
         {
             image.setAttribute(QLatin1String("quality"), 9);
         }
 
-        if ( format.toUpper() == QLatin1String("TIFF") || format.toUpper() == QLatin1String("TIF") )
+        if (format.toUpper() == QLatin1String("TIFF") || format.toUpper() == QLatin1String("TIF"))
         {
             image.setAttribute(QLatin1String("compress"), true);
         }
 
-        if ( format.toUpper() == QLatin1String("JP2") || format.toUpper() == QLatin1String("JPX") ||
-             format.toUpper() == QLatin1String("JPC") || format.toUpper() == QLatin1String("PGX") ||
-             format.toUpper() == QLatin1String("J2K") )
+        if (format.toUpper() == QLatin1String("JP2") || format.toUpper() == QLatin1String("JPX") ||
+            format.toUpper() == QLatin1String("JPC") || format.toUpper() == QLatin1String("PGX") ||
+            format.toUpper() == QLatin1String("J2K"))
         {
             image.setAttribute(QLatin1String("quality"), 100);    // LossLess
         }
 
-        if ( format.toUpper() == QLatin1String("PGF") )
+        if (format.toUpper() == QLatin1String("PGF"))
         {
             image.setAttribute(QLatin1String("quality"), 0);    // LossLess
         }
@@ -798,12 +796,12 @@ bool copyFile(const QString& src, const QString& dst)
     QFile sFile(src);
     QFile dFile(dst);
 
-    if ( !sFile.open(QIODevice::ReadOnly) )
+    if (!sFile.open(QIODevice::ReadOnly))
     {
         return false;
     }
 
-    if ( !dFile.open(QIODevice::WriteOnly) )
+    if (!dFile.open(QIODevice::WriteOnly))
     {
         sFile.close();
         return false;
@@ -874,11 +872,11 @@ int getJpegQuality(const QString& file)
     long i, j;
     long sum = 0;
 
-    for (i = 0; i < NUM_QUANT_TBLS; ++i)
+    for (i = 0 ; i < NUM_QUANT_TBLS ; ++i)
     {
         if (jpeg_info.quant_tbl_ptrs[i] != NULL)
         {
-            for (j = 0; j < DCTSIZE2; ++j)
+            for (j = 0 ; j < DCTSIZE2 ; ++j)
             {
                 sum += jpeg_info.quant_tbl_ptrs[i]->quantval[j];
             }
@@ -923,7 +921,7 @@ int getJpegQuality(const QString& file)
                        jpeg_info.quant_tbl_ptrs[1]->quantval[0]+
                        jpeg_info.quant_tbl_ptrs[1]->quantval[DCTSIZE2 - 1]);
 
-        for (i = 0; i < 100; ++i)
+        for (i = 0 ; i < 100 ; ++i)
         {
             if ((value < hash[i]) && (sum < sums[i]))
             {
@@ -973,7 +971,7 @@ int getJpegQuality(const QString& file)
         value = (long)(jpeg_info.quant_tbl_ptrs[0]->quantval[2]+
                        jpeg_info.quant_tbl_ptrs[0]->quantval[53]);
 
-        for (i = 0; i < 100; ++i)
+        for (i = 0 ; i < 100 ; ++i)
         {
             if ((value < hash[i]) && (sum < sums[i]))
             {
