@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-03-23
  * Description : Qt Model for Albums
@@ -23,7 +23,6 @@
  * ============================================================ */
 
 #include "abstractalbummodel.h"
-#include "abstractalbummodelpriv.h"
 
 // Qt includes
 
@@ -45,7 +44,37 @@
 namespace Digikam
 {
 
-AbstractAlbumModel::AbstractAlbumModel(Album::Type albumType, Album* const rootAlbum, RootAlbumBehavior rootBehavior,
+class Q_DECL_HIDDEN AbstractAlbumModel::Private
+{
+public:
+
+    explicit Private()
+        : rootAlbum(0),
+          addingAlbum(0),
+          type(Album::PHYSICAL),
+          dragDropHandler(0),
+          rootBehavior(AbstractAlbumModel::IncludeRootAlbum),
+          removingAlbum(0),
+          itemDrag(true),
+          itemDrop(true)
+    {
+    }
+
+    Album*                                rootAlbum;
+    Album*                                addingAlbum;
+    Album::Type                           type;
+    AlbumModelDragDropHandler*            dragDropHandler;
+    AbstractAlbumModel::RootAlbumBehavior rootBehavior;
+
+    quintptr                              removingAlbum;
+
+    bool                                  itemDrag;
+    bool                                  itemDrop;
+};
+
+AbstractAlbumModel::AbstractAlbumModel(Album::Type albumType,
+                                       Album* const rootAlbum,
+                                       RootAlbumBehavior rootBehavior,
                                        QObject* const parent)
     : QAbstractItemModel(parent),
       d(new Private)
@@ -139,7 +168,7 @@ int AbstractAlbumModel::rowCount(const QModelIndex& parent) const
     if (parent.isValid())
     {
         Album* const a = static_cast<Album*>(parent.internalPointer());
-        return d->numberOfChildren(a);
+        return a->childCount();
     }
     else
     {
@@ -154,7 +183,7 @@ int AbstractAlbumModel::rowCount(const QModelIndex& parent) const
         }
         else
         {
-            return d->numberOfChildren(d->rootAlbum);
+            return d->rootAlbum->childCount();
         }
     }
 }
@@ -210,7 +239,7 @@ QModelIndex AbstractAlbumModel::index(int row, int column, const QModelIndex& pa
     if (parent.isValid())
     {
         Album* const parentAlbum = static_cast<Album*>(parent.internalPointer());
-        Album* const a           = d->findNthChild(parentAlbum, row);
+        Album* const a           = parentAlbum->childAtRow(row);
 
         if (a)
         {
@@ -233,7 +262,7 @@ QModelIndex AbstractAlbumModel::index(int row, int column, const QModelIndex& pa
         }
         else
         {
-            Album* const a = d->findNthChild(d->rootAlbum, row);
+            Album* const a = d->rootAlbum->childAtRow(row);
 
             if (a)
             {
@@ -348,9 +377,7 @@ QModelIndex AbstractAlbumModel::indexForAlbum(Album* a) const
     }
 
     // Normal album. Get its row.
-    int row = d->findIndexAsChild(a);
-
-    return createIndex(row, 0, a);
+    return createIndex(a->rowFromAlbum(), 0, a);
 }
 
 Album* AbstractAlbumModel::albumForIndex(const QModelIndex& index) const
@@ -434,7 +461,7 @@ void AbstractAlbumModel::slotAlbumAboutToBeAdded(Album* album, Album* parent, Al
     }
 
     // start inserting operation
-    int row                 = prev ? d->findIndexAsChild(prev)+1 : 0;
+    int row                 = prev ? prev->rowFromAlbum()+1 : 0;
     QModelIndex parentIndex = indexForAlbum(parent);
     beginInsertRows(parentIndex, row, row);
 
@@ -480,13 +507,13 @@ void AbstractAlbumModel::slotAlbumAboutToBeDeleted(Album* album)
     }
 
     // begin removing operation
-    int row            = d->findIndexAsChild(album);
+    int row            = album->rowFromAlbum();
     QModelIndex parent = indexForAlbum(album->parent());
     beginRemoveRows(parent, row, row);
     albumCleared(album);
 
     // store album for slotAlbumHasBeenDeleted
-    d->removingAlbum = reinterpret_cast<quintptr>(album);
+    d->removingAlbum   = reinterpret_cast<quintptr>(album);
 }
 
 void AbstractAlbumModel::slotAlbumHasBeenDeleted(quintptr p)
@@ -610,11 +637,11 @@ void AbstractSpecificAlbumModel::emitDataChangedForChildren(Album* album)
 
 // ------------------------------------------------------------------
 
-class AbstractCountingAlbumModel::Private
+class Q_DECL_HIDDEN AbstractCountingAlbumModel::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         showCount = false;
     }
@@ -625,11 +652,16 @@ public:
     QSet<int>       includeChildrenAlbums;
 };
 
-AbstractCountingAlbumModel::AbstractCountingAlbumModel(Album::Type albumType, Album* const rootAlbum,
+AbstractCountingAlbumModel::AbstractCountingAlbumModel(Album::Type albumType,
+                                                       Album* const rootAlbum,
                                                        RootAlbumBehavior rootBehavior,
                                                        QObject* const parent)
     : AbstractSpecificAlbumModel(albumType, rootAlbum, rootBehavior, parent),
       d(new Private)
+{
+}
+
+void AbstractCountingAlbumModel::setup()
 {
     connect(AlbumManager::instance(), SIGNAL(signalAlbumMoved(Album*)),
             this, SLOT(slotAlbumMoved(Album*)));
@@ -853,11 +885,11 @@ void AbstractCountingAlbumModel::slotAlbumMoved(Album*)
 
 // ------------------------------------------------------------------
 
-class AbstractCheckableAlbumModel::Private
+class Q_DECL_HIDDEN AbstractCheckableAlbumModel::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : staticVectorContainingCheckStateRole(1, Qt::CheckStateRole)
     {
         extraFlags         = 0;
@@ -873,11 +905,14 @@ public:
     QVector<int> staticVectorContainingCheckStateRole;
 };
 
-AbstractCheckableAlbumModel::AbstractCheckableAlbumModel(Album::Type albumType, Album* const rootAlbum,
-                                                         RootAlbumBehavior rootBehavior, QObject* const parent)
+AbstractCheckableAlbumModel::AbstractCheckableAlbumModel(Album::Type albumType,
+                                                         Album* const rootAlbum,
+                                                         RootAlbumBehavior rootBehavior,
+                                                         QObject* const parent)
     : AbstractCountingAlbumModel(albumType, rootAlbum, rootBehavior, parent),
       d(new Private)
 {
+    setup();
 }
 
 AbstractCheckableAlbumModel::~AbstractCheckableAlbumModel()
@@ -993,7 +1028,7 @@ void AbstractCheckableAlbumModel::resetAllCheckedAlbums()
     const QHash<Album*, Qt::CheckState> oldChecked = d->checkedAlbums;
     d->checkedAlbums.clear();
 
-    for (QHash<Album*, Qt::CheckState>::const_iterator it = oldChecked.begin(); it != oldChecked.end(); ++it)
+    for (QHash<Album*, Qt::CheckState>::const_iterator it = oldChecked.begin() ; it != oldChecked.end() ; ++it)
     {
         if (it.value() != Qt::Unchecked)
         {
@@ -1008,7 +1043,7 @@ void AbstractCheckableAlbumModel::setDataForChildren(const QModelIndex& parent,
 {
     setData(parent, value, role);
 
-    for (int row = 0; row < rowCount(parent); ++row)
+    for (int row = 0 ; row < rowCount(parent) ; ++row)
     {
         QModelIndex childIndex = index(row, 0, parent);
         setDataForChildren(childIndex, value, role);
@@ -1062,7 +1097,7 @@ void AbstractCheckableAlbumModel::invertCheckedAlbums(const QModelIndex& parent)
         toggleChecked(album);
     }
 
-    for (int row = 0; row < rowCount(parent); ++row)
+    for (int row = 0 ; row < rowCount(parent) ; ++row)
     {
         invertCheckedAlbums(index(row, 0, parent));
     }
