@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-12-02
  * Description : Generic, standard item based model for DCategorizedView
@@ -94,7 +94,7 @@ static QString adjustedActionText(const QAction* const action)
     return text;
 }
 
-class ActionEnumerator
+class Q_DECL_HIDDEN ActionEnumerator
 {
 public:
 
