@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-07-03
  * Description : dialog-like popup that displays messages without interrupting the user
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2001-2006 by Richard Moore <rich at kde dot org>
  * Copyright (C) 2004-2005 by Sascha Cunz <sascha.cunz at tiscali dot de>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DNOTIFICATION_POPUP_H
-#define DNOTIFICATION_POPUP_H
+#ifndef DIGIKAM_DNOTIFICATION_POPUP_H
+#define DIGIKAM_DNOTIFICATION_POPUP_H
 
 // Qt includes
 
@@ -50,7 +50,7 @@ class DIGIKAM_EXPORT DNotificationPopup : public QFrame
 {
     Q_OBJECT
     Q_PROPERTY(bool autoDelete READ autoDelete WRITE setAutoDelete)
-    Q_PROPERTY(int timeout READ timeout WRITE setTimeout)
+    Q_PROPERTY(int timeout     READ timeout    WRITE setTimeout)
 
 public:
 
@@ -68,7 +68,7 @@ public:
     /**
      * Creates a popup for the specified widget.
      */
-    explicit DNotificationPopup(QWidget* parent = 0, Qt::WindowFlags f = 0);
+    explicit DNotificationPopup(QWidget* const parent = 0, Qt::WindowFlags f = 0);
 
     /**
      * Creates a popup for the specified window.
@@ -375,4 +375,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DNOTIFICATION_POPUP_H
+#endif // DIGIKAM_DNOTIFICATION_POPUP_H
