@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-07-03
  * Description : A widget to provide feedback or propose opportunistic interactions
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (c) 2011      by Aurelien Gateau <agateau at kde dot org>
  * Copyright (c) 2014      by Dominik Haumann <dhaumann at kde dot org>
  *
@@ -117,7 +117,7 @@ void DNotificationWidget::Private::createLayout()
     qDeleteAll(buttons);
     buttons.clear();
 
-    Q_FOREACH (QAction* const action, q->actions())
+    foreach(QAction* const action, q->actions())
     {
         QToolButton* const button = new QToolButton(content);
         button->setDefaultAction(action);
@@ -140,7 +140,7 @@ void DNotificationWidget::Private::createLayout()
         QHBoxLayout* const buttonLayout = new QHBoxLayout;
         buttonLayout->addStretch();
 
-        Q_FOREACH (QToolButton* const button, buttons)
+        foreach(QToolButton* const button, buttons)
         {
             // For some reason, calling show() is necessary if wordwrap is true,
             // otherwise the buttons do not show up. It is not needed if
@@ -158,7 +158,7 @@ void DNotificationWidget::Private::createLayout()
         layout->addWidget(iconLabel);
         layout->addWidget(textLabel);
 
-        Q_FOREACH (QToolButton* const button, buttons)
+        foreach(QToolButton* const button, buttons)
         {
             layout->addWidget(button);
         }
