@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-29
- * Description : PGF utils.
+ * Description : static helper methods for PGF image format.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-#include "digikam_config.h"
 #include "pgfutils.h"
 
 // C Ansi includes
@@ -39,16 +38,17 @@ extern "C"
 #include <QImage>
 #include <QByteArray>
 #include <QFile>
+#include <qplatformdefs.h>
 
 // Windows includes
 
-#ifdef WIN32
-#include <windows.h>
+#ifdef Q_OS_WIN32
+#   include <windows.h>
 #endif
 
 // LibPGF includes
 
-#include <PGFimage.h>
+#include "PGFimage.h"
 
 // Local includes
 
@@ -61,9 +61,15 @@ namespace PGFUtils
 {
 
 // Private method
-bool writePGFImageDataToStream(const QImage& image, CPGFStream& stream, int quality, UINT32& nWrittenBytes, bool verbose);
+bool writePGFImageDataToStream(const QImage& image,
+                               CPGFStream& stream,
+                               int quality,
+                               UINT32& nWrittenBytes,
+                               bool verbose);
 
-bool readPGFImageData(const QByteArray& data, QImage& img, bool verbose)
+bool readPGFImageData(const QByteArray& data,
+                      QImage& img,
+                      bool verbose)
 {
     try
     {
@@ -74,15 +80,18 @@ bool readPGFImageData(const QByteArray& data, QImage& img, bool verbose)
         }
 
         CPGFMemoryStream stream((UINT8*)data.data(), (size_t)data.size());
-        if (verbose) qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: image data stream size is : " << stream.GetSize();
+        
+        if (verbose)
+            qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: image data stream size is : " << stream.GetSize();
 
         CPGFImage pgfImg;
-        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properlly with libppgf 6.11.24
+        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properly with libppgf 6.11.24
         pgfImg.ConfigureDecoder(false);
 
         pgfImg.Open(&stream);
 
-        if (verbose) qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: PGF image is open";
+        if (verbose)
+            qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: PGF image is open";
 
         if (pgfImg.Channels() != 4)
         {
@@ -93,7 +102,8 @@ bool readPGFImageData(const QByteArray& data, QImage& img, bool verbose)
         img = QImage(pgfImg.Width(), pgfImg.Height(), QImage::Format_ARGB32);
         pgfImg.Read();
 
-        if (verbose) qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: PGF image is read";
+        if (verbose)
+            qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: PGF image is read";
 
         if (QSysInfo::ByteOrder == QSysInfo::BigEndian)
         {
@@ -106,7 +116,8 @@ bool readPGFImageData(const QByteArray& data, QImage& img, bool verbose)
             pgfImg.GetBitmap(img.bytesPerLine(), (UINT8*)img.bits(), img.depth(), map);
         }
 
-        if (verbose) qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: PGF image is decoded";
+        if (verbose)
+            qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: PGF image is decoded";
     }
     catch (IOException& e)
     {
@@ -124,9 +135,12 @@ bool readPGFImageData(const QByteArray& data, QImage& img, bool verbose)
     return true;
 }
 
-bool writePGFImageFile(const QImage& image, const QString& filePath, int quality, bool verbose)
+bool writePGFImageFile(const QImage& image,
+                       const QString& filePath,
+                       int quality,
+                       bool verbose)
 {
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #ifdef UNICODE
     HANDLE fd = CreateFile((LPCWSTR)(QFile::encodeName(filePath).constData()), GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
 #else
@@ -140,7 +154,8 @@ bool writePGFImageFile(const QImage& image, const QString& filePath, int quality
     }
 
 #elif defined(__POSIX__)
-    int fd = open(QFile::encodeName(filePath).constData(), O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
+    int fd = QT_OPEN(QFile::encodeName(filePath).constData(),
+                     O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
 
     if (fd == -1)
     {
@@ -160,10 +175,11 @@ bool writePGFImageFile(const QImage& image, const QString& filePath, int quality
     }
     else
     {
-        if (verbose) qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: file size written : " << nWrittenBytes;
+        if (verbose)
+            qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: file size written : " << nWrittenBytes;
     }
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
     CloseHandle(fd);
 #else
     close(fd);
@@ -228,7 +244,11 @@ bool writePGFImageData(const QImage& image, QByteArray& data, int quality, bool
     }
 }
 
-bool writePGFImageDataToStream(const QImage& image, CPGFStream& stream, int quality, UINT32& nWrittenBytes, bool verbose)
+bool writePGFImageDataToStream(const QImage& image,
+                               CPGFStream& stream,
+                               int quality,
+                               UINT32& nWrittenBytes,
+                               bool verbose)
 {
     try
     {
@@ -244,7 +264,9 @@ bool writePGFImageDataToStream(const QImage& image, CPGFStream& stream, int qual
         if (image.format() != QImage::Format_ARGB32)
         {
             img = image.convertToFormat(QImage::Format_ARGB32);
-            if (verbose) qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: RGB => ARGB";
+
+            if (verbose)
+                qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: RGB => ARGB";
         }
         else
         {
@@ -271,7 +293,7 @@ bool writePGFImageDataToStream(const QImage& image, CPGFStream& stream, int qual
 #endif
         pgfImg.SetHeader(header);
 
-        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properlly with libppgf 6.11.24
+        // NOTE: see bug #273765 : Loading PGF thumbs with OpenMP support through a separated thread do not work properly with libppgf 6.11.24
         pgfImg.ConfigureEncoder(false);
 
         if (verbose)
@@ -359,7 +381,7 @@ bool loadPGFScaled(QImage& img, const QString& path, int maximumSize)
     // -------------------------------------------------------------------
     // Initialize PGF API.
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #ifdef UNICODE
     HANDLE fd = CreateFile((LPCWSTR)(QFile::encodeName(path).constData()), GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
 #else
@@ -372,7 +394,7 @@ bool loadPGFScaled(QImage& img, const QString& path, int maximumSize)
     }
 
 #else
-    int fd = open(QFile::encodeName(path).constData(), O_RDONLY);
+    int fd = QT_OPEN(QFile::encodeName(path).constData(), O_RDONLY);
 
     if (fd == -1)
     {
@@ -393,7 +415,7 @@ bool loadPGFScaled(QImage& img, const QString& path, int maximumSize)
 
         if (pgf.Levels() > 0)
         {
-            for (i=pgf.Levels()-1 ; i>=0 ; --i)
+            for (i = pgf.Levels()-1 ; i >= 0 ; --i)
             {
                 if (qMin((int)pgf.Width(i), (int)pgf.Height(i)) >= maximumSize)
                 {
