@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-26
  * Description : History view.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,7 @@
 namespace Digikam
 {
 
-class DHistoryViewItem : public QTreeWidgetItem
+class Q_DECL_HIDDEN DHistoryViewItem : public QTreeWidgetItem
 {
 public:
 
@@ -151,7 +151,7 @@ void DHistoryView::slotCopy2ClipBoard()
         textInfo.append((*it)->text(1));
         textInfo.append(QLatin1String(" :: "));
         textInfo.append((*it)->text(2));
-        textInfo.append(QLatin1String("\n"));
+        textInfo.append(QLatin1Char('\n'));
         ++it;
     }
 
@@ -204,4 +204,4 @@ void DHistoryView::mouseMoveEvent(QMouseEvent* e)
     QTreeWidget::mouseMoveEvent(e);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
