@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-26
  * Description : History view.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DHISTORY_VIEW_H
-#define DHISTORY_VIEW_H
+#ifndef DIGIKAM_DHISTORY_VIEW_H
+#define DIGIKAM_DHISTORY_VIEW_H
 
 // Qt includes
 
@@ -78,4 +78,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DHISTORY_VIEW_H
+#endif // DIGIKAM_DHISTORY_VIEW_H
