@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-27-08
  * Description : a tool bar action object to display animated logo
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,11 +49,11 @@
 namespace Digikam
 {
 
-class DLogoAction::Private
+class Q_DECL_HIDDEN DLogoAction::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         alignOnright  = true;
         progressTimer = 0;
