@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-26
  * Description : a progress bar with information dispatched to progress manager
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,11 +35,11 @@
 namespace Digikam
 {
 
-class DProgressWdg::Private
+class Q_DECL_HIDDEN DProgressWdg::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
