@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-09-12
  * Description : A working pixmap manager.
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DWORKING_PIXMAP_H
-#define DWORKING_PIXMAP_H
+#ifndef DIGIKAM_DWORKING_PIXMAP_H
+#define DIGIKAM_DWORKING_PIXMAP_H
 
 // Qt includes
 
@@ -58,4 +58,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DWORKING_PIXMAP_H
+#endif // DIGIKAM_DWORKING_PIXMAP_H
