@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-13
  * Description : progress manager
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2004      by David Faure <faure at kde dot org>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef OVERLAY_WIDGET_H
-#define OVERLAY_WIDGET_H
+#ifndef DIGIKAM_OVERLAY_WIDGET_H
+#define DIGIKAM_OVERLAY_WIDGET_H
 
 // Local includes
 
@@ -49,7 +49,7 @@ class DIGIKAM_EXPORT OverlayWidget : public DHBox
 
 public:
 
-    OverlayWidget(QWidget* const alignWidget, QWidget* const parent, const QString& name = QString());
+    explicit OverlayWidget(QWidget* const alignWidget, QWidget* const parent, const QString& name = QString());
     ~OverlayWidget();
 
     QWidget* alignWidget() const;
@@ -71,4 +71,4 @@ private:
 
 } // namespace Digikam
 
-#endif // OVERLAY_WIDGET_H
+#endif // DIGIKAM_OVERLAY_WIDGET_H
