@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-13
  * Description : progress manager
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2004      by Till Adam <adam at kde dot org>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef PROGRESS_MANAGER_H
-#define PROGRESS_MANAGER_H
+#ifndef DIGIKAM_PROGRESS_MANAGER_H
+#define DIGIKAM_PROGRESS_MANAGER_H
 
 // Qt includes
 
@@ -467,4 +467,4 @@ private:
 
 } // namespace Digikam
 
-#endif // PROGRESS_MANAGER_H
+#endif // DIGIKAM_PROGRESS_MANAGER_H
