@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-13
  * Description : progress manager
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2004      by Till Adam <adam at kde dot org>
  *
@@ -125,7 +125,7 @@ void TransactionItemView::slotLayoutFirstItem()
     /*
         The below relies on some details in Qt's behaviour regarding deleting
         objects. This slot is called from the destroyed signal of an item just
-        going away. That item is at that point still in the  list of chilren, but
+        going away. That item is at that point still in the  list of children, but
         since the vtable is already gone, it will have type QObject. The first
         one with both the right name and the right class therefor is what will
         be the first item very shortly. That's the one we want to remove the
@@ -145,12 +145,12 @@ void TransactionItemView::slotLayoutFirstItem()
 
 // ----------------------------------------------------------------------------
 
-class TransactionItem::Private
+class Q_DECL_HIDDEN TransactionItem::Private
 {
 public:
 
-    Private() :
-        maxLabelWidth(650),
+    explicit Private()
+      : maxLabelWidth(650),
         progress(0),
         cancelButton(0),
         itemLabel(0),
@@ -297,12 +297,12 @@ void TransactionItem::addSubTransaction(ProgressItem* const item)
 
 // ---------------------------------------------------------------------------
 
-class ProgressView::Private
+class Q_DECL_HIDDEN ProgressView::Private
 {
 public:
 
-    Private() :
-        wasLastShown(false),
+    explicit Private()
+      : wasLastShown(false),
         scrollView(0),
         previousItem(0)
     {
@@ -398,7 +398,7 @@ void ProgressView::slotTransactionAdded(ProgressItem* item)
     }
     else
     {
-        const bool first          = d->transactionsToListviewItems.empty();
+        const bool first          = d->transactionsToListviewItems.isEmpty();
         TransactionItem* const ti = d->scrollView->addTransactionItem( item, first );
 
         if ( ti )
@@ -436,7 +436,7 @@ void ProgressView::slotTransactionCompleted(ProgressItem* item)
     }
 
     // This was the last item, hide.
-    if ( d->transactionsToListviewItems.empty() )
+    if ( d->transactionsToListviewItems.isEmpty() )
     {
         QTimer::singleShot( 3000, this, SLOT(slotHide()) );
     }
