@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-13
  * Description : progress manager
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2004      by Till Adam <adam at kde dot org>
  * Copyright (C) 2004      by David Faure <faure at kde dot org>
  *
@@ -53,7 +53,7 @@
 namespace Digikam
 {
 
-class StatusbarProgressWidget::Private
+class Q_DECL_HIDDEN StatusbarProgressWidget::Private
 {
 public:
 
@@ -65,8 +65,8 @@ public:
 
 public:
 
-    Private() :
-        mode(None),
+    explicit Private()
+      : mode(None),
         bShowButton(true),
         pProgressBar(0),
         pLabel(0),
