@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-13
  * Description : progress manager
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2004      by Till Adam <adam at kde dot org>
  * Copyright (C) 2004      by David Faure <faure at kde dot org>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef STATUS_BAR_PROGRESS_WIDGET_H
-#define STATUS_BAR_PROGRESS_WIDGET_H
+#ifndef DIGIKAM_STATUS_BAR_PROGRESS_WIDGET_H
+#define DIGIKAM_STATUS_BAR_PROGRESS_WIDGET_H
 
 // Qt includes
 
@@ -80,4 +80,4 @@ private:
 
 } // namespace Digikam
 
-#endif // STATUS_BAR_PROGRESS_WIDGET_H
+#endif // DIGIKAM_STATUS_BAR_PROGRESS_WIDGET_H
