@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-01-24
  * Description : a progress bar used to display action
  *               progress or a text in status bar.
  *               Progress events are dispatched to ProgressManager.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,7 +42,7 @@
 namespace Digikam
 {
 
-class StatusProgressBar::Private
+class Q_DECL_HIDDEN StatusProgressBar::Private
 {
 
 public:
@@ -53,8 +53,8 @@ public:
         ProgressBar
     };
 
-    Private() :
-        notify(false),
+    explicit Private()
+      : notify(false),
         progressWidget(0),
         cancelButton(0),
         progressBar(0),
@@ -254,4 +254,4 @@ ProgressItem* StatusProgressBar::currentProgressItem() const
     return (ProgressManager::instance()->findItembyId(d->progressId));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
