@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-01-24
  * Description : a progress bar used to display action
  *               progress or a text in status bar.
  *               Progress events are dispatched to ProgressManager.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef STATUS_PROGRESS_BAR_H
-#define STATUS_PROGRESS_BAR_H
+#ifndef DIGIKAM_STATUS_PROGRESS_BAR_H
+#define DIGIKAM_STATUS_PROGRESS_BAR_H
 
 // Qt includes
 
@@ -91,4 +91,4 @@ private:
 
 } // namespace Digikam
 
-#endif // STATUS_PROGRESS_BAR_H
+#endif // DIGIKAM_STATUS_PROGRESS_BAR_H
