@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-07-27
  * Description : Widget showing a throbber ("working" animation)
  *
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef WORKING_WIDGET_H
-#define WORKING_WIDGET_H
+#ifndef DIGIKAM_WORKING_WIDGET_H
+#define DIGIKAM_WORKING_WIDGET_H
 
 // Qt includes
 
@@ -65,4 +65,4 @@ private:
 
 } // namespace Digikam
 
-#endif // WORKING_WIDGET_H
+#endif // DIGIKAM_WORKING_WIDGET_H
