@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-10-09
  * Description : internal private container for DRawDecoder
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,20 +21,20 @@
  *
  * ============================================================ */
 
-#ifndef DRAW_DECODER_PRIVATE_H
-#define DRAW_DECODER_PRIVATE_H
+#ifndef DIGIKAM_DRAW_DECODER_PRIVATE_H
+#define DIGIKAM_DRAW_DECODER_PRIVATE_H
 
 // Qt includes
 
 #include <QByteArray>
 
 // Pragma directives to reduce warnings from LibRaw header files.
-#if !defined(__APPLE__) && defined(__GNUC__)
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
-#if defined(__APPLE__) && defined(__clang__)
+#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #endif
@@ -44,17 +44,17 @@
 #include <libraw.h>
 
 // Restore warnings
-#if !defined(__APPLE__) && defined(__GNUC__)
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #pragma GCC diagnostic pop
 #endif
 
-#if defined(__APPLE__) && defined(__clang__)
+#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
 #pragma clang diagnostic pop
 #endif
 
 // Local includes
 
-#include "rawinfo.h"
+#include "drawinfo.h"
 #include "drawdecoder.h"
 
 namespace Digikam
@@ -70,7 +70,7 @@ class Q_DECL_HIDDEN DRawDecoder::Private
 
 public:
 
-    Private(DRawDecoder* const p);
+    explicit Private(DRawDecoder* const p);
     ~Private();
 
 public:
@@ -87,11 +87,11 @@ public:
 
     static void createPPMHeader(QByteArray& imgData, libraw_processed_image_t* const img);
 
-    static void fillIndentifyInfo(LibRaw* const raw, RawInfo& identify);
+    static void fillIndentifyInfo(LibRaw* const raw, DRawInfo& identify);
 
-    static bool loadEmbeddedPreview(QByteArray&, LibRaw&);
+    static bool loadEmbeddedPreview(QByteArray&, LibRaw* const raw);
 
-    static bool loadHalfPreview(QImage&, LibRaw&);
+    static bool loadHalfPreview(QImage&, LibRaw* const raw);
 
 private:
 
@@ -104,4 +104,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DRAW_DECODER_PRIVATE_H
+#endif // DIGIKAM_DRAW_DECODER_PRIVATE_H
