@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-12-09
  * Description : Raw decoding settings
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2007-2008 by Guillaume Castagnino <casta at xwing dot info>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DRAW_DECODER_SETTINGS_H
-#define DRAW_DECODER_SETTINGS_H
+#ifndef DIGIKAM_DRAW_DECODER_SETTINGS_H
+#define DIGIKAM_DRAW_DECODER_SETTINGS_H
 
 // Qt includes
 
@@ -63,37 +63,19 @@ public:
      *  AHD:      use Adaptive Homogeneity-Directed interpolation.
      *            This method selects the direction of interpolation so as to
      *            maximize a homogeneity metric, thus typically minimizing color artifacts.
-     *
-     * NOTE: from GPL2 demosaic pack.
-     *
      *  DCB:      DCB interpolation (see http://www.linuxphoto.org/html/dcb.html for details)
-     *  PL_AHD:   modified AHD interpolation (see http://sites.google.com/site/demosaicalgorithms/modified-dcraw
-     *            for details).
-     *  AFD:      demosaicing through 5 pass median filter from PerfectRaw project.
-     *  VCD:      VCD interpolation.
-     *  VCD_AHD:  mixed demosaicing between VCD and AHD.
-     *  LMMSE:    LMMSE interpolation from PerfectRaw.
-     *
-     * NOTE: from GPL3 demosaic pack.
-     *
-     *  AMAZE:    AMaZE interpolation and color aberration removal from RawTherapee project.
+     *  DHT:      DHT interpolation.
+     *  AAHD:     Enhanced Adaptive AHD interpolation.
      */
     enum DecodingQuality
     {
-        // from original dcraw demosaic
         BILINEAR = 0,
         VNG      = 1,
         PPG      = 2,
         AHD      = 3,
-        // Extended demosaicing method from GPL2 demosaic pack
         DCB      = 4,
-        PL_AHD   = 5,
-        AFD      = 6,
-        VCD      = 7,
-        VCD_AHD  = 8,
-        LMMSE    = 9,
-        // Extended demosaicing methods from GPL3 demosaic pack
-        AMAZE    = 10
+        DHT      = 11,
+        AAHD     = 12
     };
 
     /** White balances alternatives
@@ -101,7 +83,7 @@ public:
      *  CAMERA:   Use the camera embedded WB if available. Reverts to NONE if not.
      *  AUTO:     Averages an auto WB on the entire image.
      *  CUSTOM:   Let use set it's own temperature and green factor (later converted to RGBG factors).
-     *  AERA:     Let use an aera from image to average white balance (see whiteBalanceArea for details).
+     *  AERA:     Let use an area from image to average white balance (see whiteBalanceArea for details).
      */
     enum WhiteBalance
     {
@@ -116,16 +98,12 @@ public:
      *  NONR:       No noise reduction.
      *  WAVELETSNR: wavelets correction to erase noise while preserving real detail. It's applied after interpolation.
      *  FBDDNR:     Fake Before Demosaicing Denoising noise reduction. It's applied before interpolation.
-     *  LINENR:     CFA Line Denoise. It's applied after interpolation.
-     *  IMPULSENR:  Impulse Denoise. It's applied after interpolation.
      */
     enum NoiseReduction
     {
         NONR = 0,
         WAVELETSNR,
-        FBDDNR,
-        LINENR,
-        IMPULSENR
+        FBDDNR
     };
 
     /** Input color profile used to decoded image
@@ -174,14 +152,14 @@ public:
      */
     virtual ~DRawDecoderSettings();
 
-    /** Method to use a settings to optimize time loading, for exemple to compute image histogram
+    /** Method to use a settings to optimize time loading, for example to compute image histogram
      */
     void optimizeTimeLoading();
 
 public:
 
     /** If true, images with overblown channels are processed much more accurate,
-     *  without 'pink clouds' (and blue highlights under tungsteen lamps).
+     *  without 'pink clouds' (and blue highlights under tungsten lamps).
      */
     bool fixColorsHighlights;
 
@@ -247,17 +225,6 @@ public:
      */
     int NRThreshold;
 
-    /** Turn on chromatic aberrations correction
-     */
-    bool enableCACorrection;
-
-    /** Magnification factor for Red and Blue layers
-     *  - caMultiplier[0] = amount of correction on red-green axis.
-     *  - caMultiplier[1] = amount of correction on blue-yellow axis.
-     *  - Both values set to 0.0 = automatic CA correction.
-     */
-    double caMultiplier[2];
-
     /** Brightness of output image.
      */
     double brightness;
@@ -318,23 +285,6 @@ public:
      */
     bool dcbEnhanceFl;
 
-    /// For VCD_AHD interpolation.
-
-    /** Turn on the EECI refine for VCD Demosaicing.
-     */
-    bool eeciRefine;
-
-    /** Use edge-sensitive median filtering for artifact supression after VCD demosaicing.
-     * 0   : disable (default)
-     * 1-10 : median filter passes.
-     */
-    int esMedPasses;
-
-    /** For IMPULSENR Noise reduction. Set the amount of Chrominance impulse denoise.
-        Null value disable NR. Range is between 100 and 1000.
-     */
-    int NRChroThreshold;
-
     /** Turn on the Exposure Correction before interpolation.
      */
     bool expoCorrection;
@@ -356,4 +306,4 @@ QDebug operator<<(QDebug dbg, const DRawDecoderSettings& s);
 
 } // namespace Digikam
 
-#endif // DRAW_DECODER_SETTINGS_H
+#endif // DIGIKAM_DRAW_DECODER_SETTINGS_H
