@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-16-10
  * Description : application settings interface
  *
  * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Arnd Baecker <arnd dot baecker at web dot de>
- * Copyright (C) 2014-2015 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * Copyright (C) 2014      by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
@@ -27,6 +27,7 @@
  * ============================================================ */
 
 #include "applicationsettings.h"
+#include "applicationsettings_p.h"
 
 // Qt includes
 
@@ -36,21 +37,20 @@
 // Local includes
 
 #include "digikam_config.h"
-#include "imagefiltersettings.h"
-#include "imagesortsettings.h"
+#include "itemfiltersettings.h"
+#include "itemsortsettings.h"
 #include "mimefilter.h"
 #include "thumbnailsize.h"
 #include "thememanager.h"
-#include "applicationsettings_p.h"
 
 #ifdef HAVE_KFILEMETADATA
-#include "baloowrap.h"
+#   include "baloowrap.h"
 #endif
 
 namespace Digikam
 {
 
-class ApplicationSettingsCreator
+class Q_DECL_HIDDEN ApplicationSettingsCreator
 {
 public:
 
@@ -122,15 +122,15 @@ void ApplicationSettings::readSettings()
     }
 
     d->albumSortRole                     = ApplicationSettings::AlbumSortRole(group.readEntry(d->configAlbumSortRoleEntry,
-                                           (int)ApplicationSettings::ByFolder));
+                                                                                                       (int)ApplicationSettings::ByFolder));
 
-    d->imageSortOrder                    = group.readEntry(d->configImageSortOrderEntry,      (int)ImageSortSettings::SortByFileName);
-    d->imageSorting                      = group.readEntry(d->configImageSortingEntry,        (int)ImageSortSettings::AscendingOrder);
-    d->imageSeparationMode                = group.readEntry(d->configImageSeparationModeEntry,      (int)ImageSortSettings::CategoryByAlbum);
-    d->imageSeparationSortOrder           = group.readEntry(d->configImageSeparationSortOrderEntry, (int)ImageSortSettings::AscendingOrder);
+    d->imageSortOrder                    = group.readEntry(d->configImageSortOrderEntry,               (int)ItemSortSettings::SortByFileName);
+    d->imageSorting                      = group.readEntry(d->configImageSortingEntry,                 (int)ItemSortSettings::AscendingOrder);
+    d->imageSeparationMode               = group.readEntry(d->configImageSeparationModeEntry,          (int)ItemSortSettings::CategoryByAlbum);
+    d->imageSeparationSortOrder          = group.readEntry(d->configImageSeparationSortOrderEntry,     (int)ItemSortSettings::AscendingOrder);
 
-    d->itemLeftClickAction               = ApplicationSettings::ItemLeftClickAction(group.readEntry( d->configItemLeftClickActionEntry,
-                                           (int)ApplicationSettings::ShowPreview));
+    d->itemLeftClickAction               = ApplicationSettings::ItemLeftClickAction(group.readEntry(d->configItemLeftClickActionEntry,
+                                                                                                       (int)ApplicationSettings::ShowPreview));
 
     d->thumbnailSize                     = group.readEntry(d->configDefaultIconSizeEntry,              (int)ThumbnailSize::Medium);
     d->treeThumbnailSize                 = group.readEntry(d->configDefaultTreeIconSizeEntry,          22);
@@ -138,10 +138,10 @@ void ApplicationSettings::readSettings()
     d->currentTheme                      = group.readEntry(d->configThemeEntry,                        ThemeManager::instance()->defaultThemeName());
 
     d->sidebarTitleStyle                 = (DMultiTabBar::TextStyle)group.readEntry(d->configSidebarTitleStyleEntry,
-                                           (int)DMultiTabBar::AllIconsText);
+                                                                                                       (int)DMultiTabBar::AllIconsText);
 
     d->ratingFilterCond                  = group.readEntry(d->configRatingFilterConditionEntry,
-                                           (int)ImageFilterSettings::GreaterEqualCondition);
+                                                                                                       (int)ItemFilterSettings::GreaterEqualCondition);
 
     d->recursiveAlbums                   = group.readEntry(d->configRecursiveAlbumsEntry,              false);
     d->recursiveTags                     = group.readEntry(d->configRecursiveTagsEntry,                true);
@@ -187,7 +187,7 @@ void ApplicationSettings::readSettings()
     d->tooltipShowVideoAspectRatio       = group.readEntry(d->configToolTipsShowVideoAspectRatioEntry,      true);
     d->tooltipShowVideoAudioBitRate      = group.readEntry(d->configToolTipsShowVideoAudioBitRateEntry,     true);
     d->tooltipShowVideoAudioChannelType  = group.readEntry(d->configToolTipsShowVideoAudioChannelTypeEntry, true);
-    d->tooltipShowVideoAudioCompressor   = group.readEntry(d->configToolTipsShowVideoAudioCompressorEntry,  true);
+    d->tooltipShowVideoAudioCodec        = group.readEntry(d->configToolTipsShowVideoAudioCodecEntry,       true);
     d->tooltipShowVideoDuration          = group.readEntry(d->configToolTipsShowVideoDurationEntry,         true);
     d->tooltipShowVideoFrameRate         = group.readEntry(d->configToolTipsShowVideoFrameRateEntry,        true);
     d->tooltipShowVideoVideoCodec        = group.readEntry(d->configToolTipsShowVideoVideoCodecEntry,       true);
@@ -222,7 +222,6 @@ void ApplicationSettings::readSettings()
     }
 
     d->previewSettings.convertToEightBit = group.readEntry(d->configPreviewConvertToEightBitEntry,     true);
-    d->previewSettings.zoomOrgSize       = group.readEntry(d->configPreviewZoomOrgSizeEntry,           true);
     d->previewShowIcons                  = group.readEntry(d->configPreviewShowIconsEntry,             true);
     d->showThumbbar                      = group.readEntry(d->configShowThumbbarEntry,                 true);
 
@@ -237,7 +236,13 @@ void ApplicationSettings::readSettings()
     d->showTrashDeleteDialog             = group.readEntry(d->configShowTrashDeleteDialogEntry,                       true);
     d->showPermanentDeleteDialog         = group.readEntry(d->configShowPermanentDeleteDialogEntry,                   true);
     d->sidebarApplyDirectly              = group.readEntry(d->configApplySidebarChangesDirectlyEntry,                 false);
+
+#ifdef Q_OS_OSX
+    d->useNativeFileDialog               = group.readEntry(d->configUseNativeFileDialogEntry,                         true);
+#else
     d->useNativeFileDialog               = group.readEntry(d->configUseNativeFileDialogEntry,                         false);
+#endif
+
     d->drawFramesToGrouped               = group.readEntry(d->configDrawFramesToGroupedEntry,                         true);
     d->scrollItemToCenter                = group.readEntry(d->configScrollItemToCenterEntry,                          false);
     d->showOnlyPersonTagsInPeopleSidebar = group.readEntry(d->configShowOnlyPersonTagsInPeopleSidebarEntry,           true);
@@ -249,7 +254,10 @@ void ApplicationSettings::readSettings()
     setApplicationStyle(QLatin1String("Fusion"));
 #endif
 
-    d->iconTheme                         = group.readEntry(d->configIconThemeEntry,                                   QString());
+    d->applicationIcon                   = group.readEntry(d->configIconThemeEntry,                                   QString());
+
+    setApplicationFont(group.readEntry(d->configApplicationFontEntry, QFontDatabase::systemFont(QFontDatabase::GeneralFont)));
+
     d->scanAtStart                       = group.readEntry(d->configScanAtStartEntry,                                 true);
     d->cleanAtStart                      = group.readEntry(d->configCleanAtStartEntry,                                false);
 
@@ -296,7 +304,7 @@ void ApplicationSettings::readSettings()
          it != d->groupingOperateOnAll.keyEnd(); ++it)
     {
         d->groupingOperateOnAll.insert(*it, (ApplicationSettings::ApplyToEntireGroup)group.readEntry(
-                                              d->configGroupingOperateOnAll.value(*it), (int)ApplicationSettings::Ask));
+                                             d->configGroupingOperateOnAll.value(*it), (int)ApplicationSettings::Ask));
     }
 
     emit setupChanged();
@@ -316,8 +324,8 @@ void ApplicationSettings::saveSettings()
     group.writeEntry(d->configAlbumSortRoleEntry,                      (int)d->albumSortRole);
     group.writeEntry(d->configImageSortOrderEntry,                     (int)d->imageSortOrder);
     group.writeEntry(d->configImageSortingEntry,                       (int)d->imageSorting);
-    group.writeEntry(d->configImageSeparationModeEntry,                     (int)d->imageSeparationMode);
-    group.writeEntry(d->configImageSeparationSortOrderEntry,                (int)d->imageSeparationSortOrder);
+    group.writeEntry(d->configImageSeparationModeEntry,                (int)d->imageSeparationMode);
+    group.writeEntry(d->configImageSeparationSortOrderEntry,           (int)d->imageSeparationSortOrder);
 
     group.writeEntry(d->configItemLeftClickActionEntry,                (int)d->itemLeftClickAction);
     group.writeEntry(d->configDefaultIconSizeEntry,                    QString::number(d->thumbnailSize));
@@ -370,7 +378,7 @@ void ApplicationSettings::saveSettings()
     group.writeEntry(d->configToolTipsShowVideoAspectRatioEntry,       d->tooltipShowVideoAspectRatio);
     group.writeEntry(d->configToolTipsShowVideoAudioBitRateEntry,      d->tooltipShowVideoAudioBitRate);
     group.writeEntry(d->configToolTipsShowVideoAudioChannelTypeEntry,  d->tooltipShowVideoAudioChannelType);
-    group.writeEntry(d->configToolTipsShowVideoAudioCompressorEntry,   d->tooltipShowVideoAudioCompressor);
+    group.writeEntry(d->configToolTipsShowVideoAudioCodecEntry,        d->tooltipShowVideoAudioCodec);
     group.writeEntry(d->configToolTipsShowVideoDurationEntry,          d->tooltipShowVideoDuration);
     group.writeEntry(d->configToolTipsShowVideoFrameRateEntry,         d->tooltipShowVideoFrameRate);
     group.writeEntry(d->configToolTipsShowVideoVideoCodecEntry,        d->tooltipShowVideoVideoCodec);
@@ -386,6 +394,7 @@ void ApplicationSettings::saveSettings()
     if (d->previewSettings.quality == PreviewSettings::HighQualityPreview)
     {
         group.writeEntry(d->configPreviewLoadFullItemSizeEntry, true);
+
         switch (d->previewSettings.rawLoading)
         {
             case PreviewSettings::RawPreviewAutomatic:
@@ -408,7 +417,6 @@ void ApplicationSettings::saveSettings()
     }
 
     group.writeEntry(d->configPreviewConvertToEightBitEntry,           d->previewSettings.convertToEightBit);
-    group.writeEntry(d->configPreviewZoomOrgSizeEntry,                 d->previewSettings.zoomOrgSize);
     group.writeEntry(d->configPreviewShowIconsEntry,                   d->previewShowIcons);
     group.writeEntry(d->configShowThumbbarEntry,                       d->showThumbbar);
     group.writeEntry(d->configShowFolderTreeViewItemsCountEntry,       d->showFolderTreeViewItemsCount);
@@ -430,7 +438,9 @@ void ApplicationSettings::saveSettings()
 #ifdef HAVE_APPSTYLE_SUPPORT
     group.writeEntry(d->configApplicationStyleEntry,                   d->applicationStyle);
 #endif
-    group.writeEntry(d->configIconThemeEntry,                          d->iconTheme);
+    group.writeEntry(d->configIconThemeEntry,                          d->applicationIcon);
+    group.writeEntry(d->configApplicationFontEntry,                    d->applicationFont);
+
     group.writeEntry(d->configScanAtStartEntry,                        d->scanAtStart);
     group.writeEntry(d->configCleanAtStartEntry,                       d->cleanAtStart);
 
@@ -478,4 +488,4 @@ void ApplicationSettings::saveSettings()
     config->sync();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
