@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-16-10
  * Description : application settings interface
  *
  * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Arnd Baecker <arnd dot baecker at web dot de>
- * Copyright (C) 2014-2015 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -25,8 +25,8 @@
  *
  * ============================================================ */
 
-#ifndef APPLICATIONSETTINGS_H
-#define APPLICATIONSETTINGS_H
+#ifndef DIGIKAM_APPLICATION_SETTINGS_H
+#define DIGIKAM_APPLICATION_SETTINGS_H
 
 // Qt includes
 
@@ -97,7 +97,7 @@ public:
     enum OperationType
     {
         Metadata = 0,
-        Kipi,
+        ImportExport,
         BQM,
         LightTable,
         Slideshow,
@@ -140,8 +140,6 @@ public:
     /**
      * @return true if the corresponding message box should be shown.
      * @param dontShowAgainName the name that identify the message box.
-     * @param result is set to the result that was chosen the last
-     * time the message box was shown.
      */
     bool readMsgBoxShouldBeShown(const QString& dontShowAgainName);
 
@@ -379,8 +377,8 @@ public:
     void setToolTipsShowVideoAudioChannelType(bool val);
     bool getToolTipsShowVideoAudioChannelType() const;
 
-    void setToolTipsShowVideoAudioCompressor(bool val);
-    bool getToolTipsShowVideoAudioCompressor() const;
+    void setToolTipsShowVideoAudioCodec(bool val);
+    bool getToolTipsShowVideoAudioCodec() const;
 
     void setToolTipsShowVideoDuration(bool val);
     bool getToolTipsShowVideoDuration() const;
@@ -448,6 +446,9 @@ public:
     void setIconTheme(const QString& theme);
     QString getIconTheme() const;
 
+    void setApplicationFont(const QFont& fnt);
+    QFont getApplicationFont() const;
+
     void setShowSplashScreen(bool val);
     bool getShowSplashScreen() const;
 
@@ -530,7 +531,7 @@ private Q_SLOTS:
 
 private:
 
-    ApplicationSettings();
+    explicit ApplicationSettings();
     ~ApplicationSettings();
 
     KConfigGroup generalConfigGroup() const;
@@ -543,6 +544,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif  // APPLICATIONSETTINGS_H
+#endif // DIGIKAM_APPLICATION_SETTINGS_H
