@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-16-10
  * Description : application settings interface
  *
  * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Arnd Baecker <arnd dot baecker at web dot de>
- * Copyright (C) 2014-2015 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * Copyright (C) 2014      by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -40,7 +40,8 @@ void ApplicationSettings::setTreeViewIconSize(int val)
 
 int ApplicationSettings::getTreeViewIconSize() const
 {
-    return ((d->treeThumbnailSize < 8) || (d->treeThumbnailSize > 48)) ? 48 : d->treeThumbnailSize;
+    return ((d->treeThumbnailSize < 8) ||
+            (d->treeThumbnailSize > 64)) ? 22 : d->treeThumbnailSize;
 }
 
 void ApplicationSettings::setTreeViewFont(const QFont& font)
@@ -132,4 +133,4 @@ bool ApplicationSettings::delAlbumCategoryName(const QString& name) const
     return (count > 0) ? true : false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
