@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-16-10
  * Description : application settings interface
  *
  * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Arnd Baecker <arnd dot baecker at web dot de>
- * Copyright (C) 2014      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * Copyright (C) 2014      by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -49,7 +49,7 @@ QString ApplicationSettings::getImageFileFilter() const
         wildcards << QLatin1String("*.") + suffix;
     }
 
-    return wildcards.join(QLatin1String(" "));
+    return wildcards.join(QLatin1Char(' '));
 }
 
 QString ApplicationSettings::getMovieFileFilter() const
@@ -63,7 +63,7 @@ QString ApplicationSettings::getMovieFileFilter() const
         wildcards << QLatin1String("*.") + suffix;
     }
 
-    return wildcards.join(QLatin1String(" "));
+    return wildcards.join(QLatin1Char(' '));
 }
 
 QString ApplicationSettings::getAudioFileFilter() const
@@ -77,7 +77,7 @@ QString ApplicationSettings::getAudioFileFilter() const
         wildcards << QLatin1String("*.") + suffix;
     }
 
-    return wildcards.join(QLatin1String(" "));
+    return wildcards.join(QLatin1Char(' '));
 }
 
 QString ApplicationSettings::getRawFileFilter() const
@@ -106,7 +106,7 @@ QString ApplicationSettings::getRawFileFilter() const
         wildcards << QLatin1String("*.") + suffix;
     }
 
-    return wildcards.join(QLatin1String(" "));
+    return wildcards.join(QLatin1Char(' '));
 }
 
 QString ApplicationSettings::getAllFileFilter() const
@@ -130,7 +130,7 @@ QString ApplicationSettings::getAllFileFilter() const
         wildcards << QLatin1String("*.") + suffix;
     }
 
-    return wildcards.join(QLatin1String(" "));
+    return wildcards.join(QLatin1Char(' '));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
