@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-16-10
  * Description : application settings interface
  *
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2015      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -23,12 +23,12 @@
  *
  * ============================================================ */
 
+#include "applicationsettings_p.h"
+
 // Qt includes
 
 #include <QApplication>
-#include <QFont>
 #include <QFontDatabase>
-#include <QString>
 
 // KDE includes
 
@@ -36,13 +36,9 @@
 
 // Local includes
 
-#include "imagefiltersettings.h"
-#include "imagesortsettings.h"
+#include "itemfiltersettings.h"
+#include "itemsortsettings.h"
 #include "thumbnailsize.h"
-#include "dbengineparameters.h"
-#include "versionmanager.h"
-#include "applicationsettings.h"
-#include "applicationsettings_p.h"
 
 namespace Digikam
 {
@@ -110,7 +106,7 @@ const QString ApplicationSettings::Private::configToolTipsShowLabelRatingEntry(Q
 const QString ApplicationSettings::Private::configToolTipsShowVideoAspectRatioEntry(QLatin1String("ToolTips Show Video Aspect Ratio"));
 const QString ApplicationSettings::Private::configToolTipsShowVideoAudioBitRateEntry(QLatin1String("ToolTips Show Audio Bit Rate"));
 const QString ApplicationSettings::Private::configToolTipsShowVideoAudioChannelTypeEntry(QLatin1String("ToolTips Show Audio Channel Type"));
-const QString ApplicationSettings::Private::configToolTipsShowVideoAudioCompressorEntry(QLatin1String("ToolTips Show Audio Compressor"));
+const QString ApplicationSettings::Private::configToolTipsShowVideoAudioCodecEntry(QLatin1String("ToolTips Show Audio Codec"));
 const QString ApplicationSettings::Private::configToolTipsShowVideoDurationEntry(QLatin1String("ToolTips Show Video Duration"));
 const QString ApplicationSettings::Private::configToolTipsShowVideoFrameRateEntry(QLatin1String("ToolTips Show Video Frame Rate"));
 const QString ApplicationSettings::Private::configToolTipsShowVideoVideoCodecEntry(QLatin1String("ToolTips Show Video Codec"));
@@ -125,7 +121,6 @@ const QString ApplicationSettings::Private::configPreviewLoadFullItemSizeEntry(Q
 const QString ApplicationSettings::Private::configPreviewRawUseEmbeddedPreview(QLatin1String("Preview Raw Use Embedded Preview"));
 const QString ApplicationSettings::Private::configPreviewRawUseHalfSizeData(QLatin1String("Preview Raw Use Half Size Data"));
 const QString ApplicationSettings::Private::configPreviewConvertToEightBitEntry(QLatin1String("Preview Convert To Eight Bit"));
-const QString ApplicationSettings::Private::configPreviewZoomOrgSizeEntry(QLatin1String("Preview Zoom Use Original Size"));
 const QString ApplicationSettings::Private::configPreviewShowIconsEntry(QLatin1String("Preview Show Icons"));
 const QString ApplicationSettings::Private::configShowThumbbarEntry(QLatin1String("Show Thumbbar"));
 const QString ApplicationSettings::Private::configShowFolderTreeViewItemsCountEntry(QLatin1String("Show Folder Tree View Items Count"));
@@ -144,6 +139,7 @@ const QString ApplicationSettings::Private::configStringComparisonTypeEntry(QLat
 const QString ApplicationSettings::Private::configFaceDetectionAccuracyEntry(QLatin1String("Detection Accuracy"));
 const QString ApplicationSettings::Private::configApplicationStyleEntry(QLatin1String("Application Style"));
 const QString ApplicationSettings::Private::configIconThemeEntry(QLatin1String("Icon Theme"));
+const QString ApplicationSettings::Private::configApplicationFontEntry(QLatin1String("Application Font"));
 const QString ApplicationSettings::Private::configScanAtStartEntry(QLatin1String("Scan At Start"));
 const QString ApplicationSettings::Private::configCleanAtStartEntry(QLatin1String("Clean core DB At Start"));
 const QString ApplicationSettings::Private::configMinimumSimilarityBound(QLatin1String("Lower bound for minimum similarity"));
@@ -157,13 +153,13 @@ const ApplicationSettings::OperationStrings ApplicationSettings::Private::config
 ApplicationSettings::OperationStrings ApplicationSettings::Private::createConfigGroupingOperateOnAll()
 {
     ApplicationSettings::OperationStrings out;
-    out.insert(ApplicationSettings::Metadata, QLatin1String("Do metadata operations on all"));
-    out.insert(ApplicationSettings::Kipi, QLatin1String("Do Kipi operations on all"));
-    out.insert(ApplicationSettings::BQM, QLatin1String("Do BQM operations on all"));
-    out.insert(ApplicationSettings::LightTable, QLatin1String("Do light table operations on all"));
-    out.insert(ApplicationSettings::Slideshow, QLatin1String("Do slideshow operations on all"));
-    out.insert(ApplicationSettings::Rename, QLatin1String("Rename all"));
-    out.insert(ApplicationSettings::Tools, QLatin1String("Operate tools on all"));
+    out.insert(ApplicationSettings::Metadata,     QLatin1String("Do metadata operations on all"));
+    out.insert(ApplicationSettings::ImportExport, QLatin1String("Do Import Export operations on all"));
+    out.insert(ApplicationSettings::BQM,          QLatin1String("Do BQM operations on all"));
+    out.insert(ApplicationSettings::LightTable,   QLatin1String("Do light table operations on all"));
+    out.insert(ApplicationSettings::Slideshow,    QLatin1String("Do slideshow operations on all"));
+    out.insert(ApplicationSettings::Rename,       QLatin1String("Rename all"));
+    out.insert(ApplicationSettings::Tools,        QLatin1String("Operate tools on all"));
     return out;
 }
 
@@ -214,7 +210,7 @@ ApplicationSettings::Private::Private(ApplicationSettings* const qq)
       tooltipShowVideoAspectRatio(false),
       tooltipShowVideoAudioBitRate(false),
       tooltipShowVideoAudioChannelType(false),
-      tooltipShowVideoAudioCompressor(false),
+      tooltipShowVideoAudioCodec(false),
       tooltipShowVideoDuration(false),
       tooltipShowVideoFrameRate(false),
       tooltipShowVideoVideoCodec(false),
@@ -281,10 +277,10 @@ void ApplicationSettings::Private::init()
     albumCategoryNames.sort();
 
     albumSortRole                        = ApplicationSettings::ByFolder;
-    imageSortOrder                       = ImageSortSettings::SortByFileName;
-    imageSorting                         = ImageSortSettings::AscendingOrder;
-    imageSeparationMode                       = ImageSortSettings::CategoryByAlbum;
-    imageSeparationSortOrder                  = ImageSortSettings::AscendingOrder;
+    imageSortOrder                       = ItemSortSettings::SortByFileName;
+    imageSorting                         = ItemSortSettings::AscendingOrder;
+    imageSeparationMode                  = ItemSortSettings::CategoryByAlbum;
+    imageSeparationSortOrder             = ItemSortSettings::AscendingOrder;
 
     itemLeftClickAction                  = ApplicationSettings::ShowPreview;
 
@@ -293,7 +289,7 @@ void ApplicationSettings::Private::init()
     treeviewFont                         = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     sidebarTitleStyle                    = DMultiTabBar::AllIconsText;
 
-    ratingFilterCond                     = ImageFilterSettings::GreaterEqualCondition;
+    ratingFilterCond                     = ItemFilterSettings::GreaterEqualCondition;
 
     showSplash                           = true;
     useTrash                             = true;
@@ -345,7 +341,7 @@ void ApplicationSettings::Private::init()
     tooltipShowVideoAspectRatio          = true;
     tooltipShowVideoAudioBitRate         = true;
     tooltipShowVideoAudioChannelType     = true;
-    tooltipShowVideoAudioCompressor      = true;
+    tooltipShowVideoAudioCodec           = true;
     tooltipShowVideoDuration             = true;
     tooltipShowVideoFrameRate            = true;
     tooltipShowVideoVideoCodec           = true;
@@ -384,9 +380,10 @@ void ApplicationSettings::Private::init()
     stringComparisonType                 = ApplicationSettings::Natural;
 
     applicationStyle                     = qApp->style()->objectName();
-    iconTheme                            = QString();
+    applicationIcon                      = QString();
+    applicationFont                      = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
 
-    for (int i = 0; i != ApplicationSettings::Unspecified; ++i)
+    for (int i = 0 ; i != ApplicationSettings::Unspecified ; ++i)
     {
         groupingOperateOnAll.insert((ApplicationSettings::OperationType)i,
                                     ApplicationSettings::Ask);
@@ -396,4 +393,4 @@ void ApplicationSettings::Private::init()
                q, SLOT(applyBalooSettings()));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
