@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-16-10
  * Description : application settings interface
  *
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C  2015      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C  2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -23,25 +23,30 @@
  *
  * ============================================================ */
 
-#ifndef APPLICATIONSETTINGS_P_H
-#define APPLICATIONSETTINGS_P_H
+#ifndef DIGIKAM_APPLICATION_SETTINGS_PRIVATE_H
+#define DIGIKAM_APPLICATION_SETTINGS_PRIVATE_H
+
+#include <QString>
+#include <QStringList>
+#include <QFont>
 
 // Local includes
 
+#include "applicationsettings.h"
 #include "previewsettings.h"
-
-class QString;
+#include "dbengineparameters.h"
+#include "versionmanager.h"
 
 namespace Digikam
 {
 
 class ApplicationSettings;
 
-class ApplicationSettings::Private
+class Q_DECL_HIDDEN ApplicationSettings::Private
 {
 public:
 
-    Private(ApplicationSettings* const qq);
+    explicit Private(ApplicationSettings* const qq);
     ~Private();
 
     void init();
@@ -110,7 +115,7 @@ public:
     static const QString configToolTipsShowVideoAspectRatioEntry;
     static const QString configToolTipsShowVideoAudioBitRateEntry;
     static const QString configToolTipsShowVideoAudioChannelTypeEntry;
-    static const QString configToolTipsShowVideoAudioCompressorEntry;
+    static const QString configToolTipsShowVideoAudioCodecEntry;
     static const QString configToolTipsShowVideoDurationEntry;
     static const QString configToolTipsShowVideoFrameRateEntry;
     static const QString configToolTipsShowVideoVideoCodecEntry;
@@ -130,7 +135,6 @@ public:
     static const QString configPreviewRawUseEmbeddedPreview;
     static const QString configPreviewRawUseHalfSizeData;
     static const QString configPreviewConvertToEightBitEntry;
-    static const QString configPreviewZoomOrgSizeEntry;
     static const QString configPreviewShowIconsEntry;
     static const QString configShowThumbbarEntry;
     static const QString configShowFolderTreeViewItemsCountEntry;
@@ -147,6 +151,7 @@ public:
     static const QString configFaceDetectionAccuracyEntry;
     static const QString configApplicationStyleEntry;
     static const QString configIconThemeEntry;
+    static const QString configApplicationFontEntry;
     static const QString configMinimumSimilarityBound;
     static const QString configDuplicatesSearchLastMinSimilarity;
     static const QString configDuplicatesSearchLastMaxSimilarity;
@@ -212,7 +217,7 @@ public:
     bool                                         tooltipShowVideoAspectRatio;
     bool                                         tooltipShowVideoAudioBitRate;
     bool                                         tooltipShowVideoAudioChannelType;
-    bool                                         tooltipShowVideoAudioCompressor;
+    bool                                         tooltipShowVideoAudioCodec;
     bool                                         tooltipShowVideoDuration;
     bool                                         tooltipShowVideoFrameRate;
     bool                                         tooltipShowVideoVideoCodec;
@@ -286,7 +291,8 @@ public:
     //misc
     ApplicationSettings::StringComparisonType    stringComparisonType;
     QString                                      applicationStyle;
-    QString                                      iconTheme;
+    QString                                      applicationIcon;
+    QFont                                        applicationFont;
 
     int                                          minimumSimilarityBound;
     int                                          duplicatesSearchLastMinSimilarity;
@@ -301,9 +307,12 @@ private:
 
     ApplicationSettings*                         q;
 
+private:
+
+    // cppcheck-suppress unusedPrivateFunction
     static ApplicationSettings::OperationStrings createConfigGroupingOperateOnAll();
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif  // APPLICATIONSETTINGS_P_H
+#endif // DIGIKAM_APPLICATION_SETTINGS_PRIVATE_H
