@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-20
  * Description : identity list view.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -58,7 +58,7 @@ void TemplateListItem::setTemplate(const Template& t)
     if (!m_template.isNull())
     {
         setText(0, m_template.templateTitle());
-        setText(1, m_template.authors().join(QLatin1String(";")));
+        setText(1, m_template.authors().join(QLatin1Char(';')));
     }
 }
 
@@ -164,4 +164,4 @@ TemplateListItem* TemplateList::find(const QString& title)
     return 0;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
