@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-20
  * Description : template list view.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TEMPLATELIST_H
-#define TEMPLATELIST_H
+#ifndef DIGIKAM_TEMPLATE_LIST_H
+#define DIGIKAM_TEMPLATE_LIST_H
 
 // Qt includes
 
@@ -40,7 +40,7 @@ class TemplateListItem : public QTreeWidgetItem
 
 public:
 
-    TemplateListItem(QTreeWidget* const parent, const Template& t);
+    explicit TemplateListItem(QTreeWidget* const parent, const Template& t);
     ~TemplateListItem();
 
     void     setTemplate(const Template& t);
@@ -68,6 +68,6 @@ public:
     void applySettings();
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // TEMPLATELIST_H
+#endif // DIGIKAM_TEMPLATE_LIST_H
