@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-07-06
  * Description : metadata template settings panel.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,12 +47,12 @@
 namespace Digikam
 {
 
-class TemplatePanel::Private
+class Q_DECL_HIDDEN TemplatePanel::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         authorsEdit               = 0;
         authorsPositionEdit       = 0;
@@ -126,7 +126,7 @@ TemplatePanel::TemplatePanel(QWidget* const parent)
     d->authorsEdit->setWhatsThis(i18n("<p>This field should contain the names of the persons who created the photograph. "
                                       "If it is not appropriate to add the name of the photographer (for example, if the identity of "
                                       "the photographer needs to be protected) the name of a company or organization can also be used. "
-                                      "Once saved, this field should not be changed by anyone. "
+                                      "Once saved, this field should not be changed by anyone.</p>"
                                       "<p>To enter more than one name, use <b>semi-colons as separators</b>.</p>"
                                       "<p>With IPTC, this field is limited to 32 ASCII characters.</p>"));
 
@@ -187,7 +187,7 @@ TemplatePanel::TemplatePanel(QWidget* const parent)
     d->rightUsageEdit->setFixedHeight(75);
     d->rightUsageEdit->setPlaceholderText(i18n("Enter the list of instructions on how a resource can be legally used here."));
     d->rightUsageEdit->setWhatsThis(i18n("<p>The Right Usage Terms field should be used to list instructions on how "
-                                         "a resource can be legally used."
+                                         "a resource can be legally used.</p>"
                                          "<p>With XMP, you can include more than one right usage terms string using "
                                          "different languages.</p>"
                                          "<p>This field does not exist with IPTC.</p>"));
@@ -449,7 +449,7 @@ TemplatePanel::~TemplatePanel()
 
 void TemplatePanel::setTemplate(const Template& t)
 {
-    d->authorsEdit->setText(t.authors().join(QLatin1String(";")));
+    d->authorsEdit->setText(t.authors().join(QLatin1Char(';')));
     d->authorsPositionEdit->setText(t.authorsPosition());
     d->creditEdit->setText(t.credit());
     d->copyrightEdit->setValues(t.copyright());
@@ -512,4 +512,4 @@ void TemplatePanel::apply()
 {
 }
 
-}  // namespace Digikam
+} // namespace Digikam
