@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-23
  * Description : a widget to select metadata template.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,11 +46,11 @@
 namespace Digikam
 {
 
-class TemplateSelector::Private
+class Q_DECL_HIDDEN TemplateSelector::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         label         = 0;
         setupButton   = 0;
@@ -200,4 +200,4 @@ void TemplateSelector::slotTemplateListChanged()
     populateTemplates();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
