@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-23
  * Description : a widget to select metadata template.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TEMPLATESELECTOR_H
-#define TEMPLATESELECTOR_H
+#ifndef DIGIKAM_TEMPLATE_SELECTOR_H
+#define DIGIKAM_TEMPLATE_SELECTOR_H
 
 // Local includes
 
@@ -76,6 +76,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // TEMPLATESELECTOR_H
+#endif // DIGIKAM_TEMPLATE_SELECTOR_H
