@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-29
  * Description : metadata template viewer.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -36,7 +36,7 @@
 // Local includes
 
 #include "dlayoutbox.h"
-#include "imagepropertiestxtlabel.h"
+#include "itempropertiestxtlabel.h"
 #include "template.h"
 #include "templatemanager.h"
 #include "countryselector.h"
@@ -44,11 +44,11 @@
 namespace Digikam
 {
 
-class TemplateViewer::Private
+class Q_DECL_HIDDEN TemplateViewer::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         names                      = 0;
         position                   = 0;
@@ -284,4 +284,4 @@ void TemplateViewer::setTemplate(const Template& t)
     d->subjectsList->addItems(t.IptcSubjects());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
