@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-06-29
  * Description : metadata template viewer.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TEMPLATEVIEWER_H
-#define TEMPLATEVIEWER_H
+#ifndef DIGIKAM_TEMPLATE_VIEWER_H
+#define DIGIKAM_TEMPLATE_VIEWER_H
 
 // Qt includes
 
@@ -30,6 +30,7 @@
 
 // Local includes
 
+#include "digikam_export.h"
 #include "dexpanderbox.h"
 
 namespace Digikam
@@ -37,7 +38,7 @@ namespace Digikam
 
 class Template;
 
-class TemplateViewer : public DExpanderBox
+class DIGIKAM_EXPORT TemplateViewer : public DExpanderBox
 {
     Q_OBJECT
 
@@ -54,6 +55,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // TEMPLATEVIEWER_H
+#endif // DIGIKAM_TEMPLATE_VIEWER_H
