@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-12-28
  * Description : Low level threads management for batch processing on multi-core
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2014 by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  * Copyright (C) 2011-2012 by Janardhan Reddy <annapareddyjanardhanreddy at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ACTION_THREAD_BASE_H
-#define ACTION_THREAD_BASE_H
+#ifndef DIGIKAM_ACTION_THREAD_BASE_H
+#define DIGIKAM_ACTION_THREAD_BASE_H
 
 // Qt includes
 
@@ -95,7 +95,7 @@ class DIGIKAM_EXPORT ActionThreadBase : public QThread
 
 public:
 
-    ActionThreadBase(QObject* const parent=0);
+    explicit ActionThreadBase(QObject* const parent=0);
     virtual ~ActionThreadBase();
 
     /** Adjust maximum number of threads used to parallelize collection of job processing.
@@ -130,6 +130,10 @@ protected:
      */
     bool isEmpty() const;
 
+    /** Return the number of pending jobs to process.
+     */
+    int pendingCount() const;
+
 protected Q_SLOTS:
 
     void slotJobFinished();
@@ -142,4 +146,4 @@ private:
 
 } // namespace Digikam
 
-#endif // ACTION_THREAD_BASE_H
+#endif // DIGIKAM_ACTION_THREAD_BASE_H
