@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-04-06
  * Description : Multithreaded worker object
@@ -39,11 +39,11 @@
 namespace Digikam
 {
 
-class WorkerObject::WorkerObjectPriv
+class Q_DECL_HIDDEN WorkerObject::Private
 {
 public:
 
-    WorkerObjectPriv()
+    Private()
     {
         state         = WorkerObject::Inactive;
         eventLoop     = 0;
@@ -62,7 +62,7 @@ public:
 };
 
 WorkerObject::WorkerObject()
-    : d(new WorkerObjectPriv)
+    : d(new Private)
 {
     ThreadManager::instance()->initialize(this);
 }
