@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-06-04
  * Description : A label to show video frame effect preview
  *
- * Copyright (C) 2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2017-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef EFFECT_PREVIEW_H
-#define EFFECT_PREVIEW_H
+#ifndef DIGIKAM_EFFECT_PREVIEW_H
+#define DIGIKAM_EFFECT_PREVIEW_H
 
 // Qt includes
 
@@ -66,4 +66,4 @@ private:
 
 } // namespace Digikam
 
-#endif // EFFECT_PREVIEW_H
+#endif // DIGIKAM_EFFECT_PREVIEW_H
