@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-06-04
  * Description : A label to show transition preview
  *
- * Copyright (C) 2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2017-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,11 +37,11 @@
 namespace Digikam
 {
 
-class TransitionPreview::Private
+class Q_DECL_HIDDEN TransitionPreview::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         mngr          = 0;
         curTransition = TransitionMngr::None;
