@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-06-18
  * Description : class for determining new file name in terms of version management
@@ -41,7 +41,7 @@
 namespace Digikam
 {
 
-class VersionManagerSettingsConfig
+class Q_DECL_HIDDEN VersionManagerSettingsConfig
 {
 public:
 
@@ -89,10 +89,10 @@ void VersionManagerSettings::readFromConfig(KConfigGroup& group)
 
     showInViewFlags             = OnlyShowCurrent;
 
-    if (group.readEntry(VersionManagerSettingsConfig::configViewShowOriginal, false))
+    if (group.readEntry(VersionManagerSettingsConfig::configViewShowOriginal, true))
         showInViewFlags |= ShowOriginal;
 
-    if (group.readEntry(VersionManagerSettingsConfig::configViewShowIntermediates, false))
+    if (group.readEntry(VersionManagerSettingsConfig::configViewShowIntermediates, true))
         showInViewFlags |= ShowIntermediates;
 
     bool autoSave               = group.readEntry(VersionManagerSettingsConfig::configAutoSaveWhenClosingEditor, false);
@@ -115,7 +115,7 @@ void VersionManagerSettings::writeToConfig(KConfigGroup& group) const
 
 // ---------------------------------------------------------------------------------------------
 
-class DefaultVersionNamingScheme : public VersionNamingScheme
+class Q_DECL_HIDDEN DefaultVersionNamingScheme : public VersionNamingScheme
 {
 public:
 
@@ -213,7 +213,7 @@ QString DefaultVersionNamingScheme::intermediateDirectory(const QString& current
 
 // -------------------------------------------------------------------------------------------------------
 
-class VersionNameCreator
+class Q_DECL_HIDDEN VersionNameCreator
 {
 public:
 
@@ -364,7 +364,7 @@ void VersionNameCreator::setSaveFileName()
 
         // To find the right number for the new version, go through all the items in the given dir,
         // the version number won't be bigger than count()
-        for (uint i = 0; i <= dirInfo.count(); ++i)
+        for (uint i = 0 ; i <= dirInfo.count() ; ++i)
         {
             QString suggestedName = scheme->versionFileName(m_result.path, m_baseName, m_version);
 
@@ -419,8 +419,8 @@ void VersionNameCreator::checkIntermediates()
                                  << "save after raw" << bool(m_settings.saveIntermediateVersions & VersionManagerSettings::AfterRawConversion)
                                  << "save when not repro" << bool(m_settings.saveIntermediateVersions & VersionManagerSettings::WhenNotReproducible);
 
-    if ( (m_settings.saveIntermediateVersions & VersionManagerSettings::AfterEachSession) &&
-         (m_operation.tasks & VersionFileOperation::Replace) )
+    if ((m_settings.saveIntermediateVersions & VersionManagerSettings::AfterEachSession) &&
+        (m_operation.tasks & VersionFileOperation::Replace))
     {
         // We want a snapshot after each session. The main file will be overwritten by the current state.
         // So we consider the current file as snapshot of the last session and move
@@ -457,7 +457,7 @@ void VersionNameCreator::checkIntermediates()
     {
         int rawConversionStep = -1;
 
-        for (int i = firstStep; i <= lastStep; ++i)
+        for (int i = firstStep ; i <= lastStep ; ++i)
         {
             if (DImgFilterManager::instance()->isRawConversion(m_currentHistory.action(i).identifier()))
             {
@@ -474,10 +474,10 @@ void VersionNameCreator::checkIntermediates()
 
     if (m_settings.saveIntermediateVersions & VersionManagerSettings::WhenNotReproducible)
     {
-        for (int i = firstStep; i <= lastStep; ++i)
+        for (int i = firstStep ; i <= lastStep ; ++i)
         {
             qCDebug(DIGIKAM_GENERAL_LOG) << "step" << i
-                                         << "is reproducable"
+                                         << "is reproducible"
                                          << (m_currentHistory.action(i).category() == FilterAction::ReproducibleFilter);
 
             switch (m_currentHistory.action(i).category())
@@ -501,7 +501,7 @@ void VersionNameCreator::checkIntermediates()
         // now all steps are available, already ordered thanks to QMap. Just fill in the empty VersionFileInfos.
         QMap<int,VersionFileInfo>::iterator it;
 
-        for (it = m_operation.intermediates.begin(); it != m_operation.intermediates.end(); ++it)
+        for (it = m_operation.intermediates.begin() ; it != m_operation.intermediates.end() ; ++it)
         {
             it.value() = nextIntermediate(m_result.format);
         }
@@ -518,7 +518,7 @@ VersionFileInfo VersionNameCreator::nextIntermediate(const QString& format)
 
     QDir dirInfo(m_intermediatePath);
 
-    for (uint i = 0; i <= dirInfo.count(); ++i)
+    for (uint i = 0 ; i <= dirInfo.count() ; ++i)
     {
         QString suggestedName = scheme->intermediateFileName(m_intermediatePath, m_baseName,
                                                              m_version, m_intermediateCounter);
@@ -630,7 +630,7 @@ QStringList VersionFileOperation::allFilePaths() const
 
 // ------------------------------------------------------------------------------------------------------
 
-class VersionManager::VersionManagerPriv
+class Q_DECL_HIDDEN VersionManager::VersionManagerPriv
 {
 public:
 
