@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-07-28
  * Description : a color gradient widget
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef COLORGRADIENTWIDGET_H
-#define COLORGRADIENTWIDGET_H
+#ifndef DIGIKAM_COLOR_GRADIENT_WIDGET_H
+#define DIGIKAM_COLOR_GRADIENT_WIDGET_H
 
 // KDE includes
 
@@ -59,4 +59,4 @@ private:
 
 } // namespace Digikam
 
-#endif // COLORGRADIENTWIDGET_H
+#endif // DIGIKAM_COLOR_GRADIENT_WIDGET_H
