@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-02-20
  * Description : color selector widget
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DCOLOR_SELECT_H
-#define DCOLOR_SELECT_H
+#ifndef DIGIKAM_DCOLOR_SELECTOR_H
+#define DIGIKAM_DCOLOR_SELECTOR_H
 
 // Qt includes
 
@@ -72,4 +72,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DCOLOR_SELECT_H
+#endif // DIGIKAM_DCOLOR_SELECTOR_H
