@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-02-20
  * Description : color chooser widgets
  *
  * Copyright (C)      1997 by Martin Jones <mjones at kde dot org>
- * Copyright (C) 2015-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2015-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DCOLORVALUESELECTOR_H
-#define DCOLORVALUESELECTOR_H
+#ifndef DIGIKAM_DCOLOR_VALUE_SELECTOR_H
+#define DIGIKAM_DCOLOR_VALUE_SELECTOR_H
 
 // Qt includes
 
@@ -231,4 +231,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DCOLORVALUESELECTOR_H
+#endif // DIGIKAM_DCOLOR_VALUE_SELECTOR_H
