@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-07-03
  * Description : a color gradient slider
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2008 by Cyrille Berger <cberger at cberger dot net>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DGRADIENTSLIDER_H
-#define DGRADIENTSLIDER_H
+#ifndef DIGIKAM_DGRADIENT_SLIDER_H
+#define DIGIKAM_DGRADIENT_SLIDER_H
 
 // Qt includes
 
@@ -88,4 +88,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DGRADIENTSLIDER_H
+#endif // DIGIKAM_DGRADIENT_SLIDER_H
