@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 1997-02-20
  * Description : color chooser widgets
  *
  * Copyright (C)      1997 by Martin Jones (mjones at kde dot org)
- * Copyright (C) 2015-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2015-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DHUESATURATIONSELECT_H
-#define DHUESATURATIONSELECT_H
+#ifndef DIGIKAM_DHUE_SATURATION_SELECT_H
+#define DIGIKAM_DHUE_SATURATION_SELECT_H
 
 // Qt includes
 
@@ -50,7 +50,7 @@ public:
      * Constructs a two-dimensional selector widget which
      * has a value range of [0..100] in both directions.
      */
-    explicit DPointSelect(QWidget* const parent=0);
+    explicit DPointSelect(QWidget* const parent);
     ~DPointSelect();
 
     /**
@@ -144,11 +144,12 @@ private:
 
 private:
 
+    DPointSelect(); // Disable default constructor.
+    Q_DISABLE_COPY(DPointSelect)
+
     class Private;
     friend class Private;
     Private* const d;
-
-    Q_DISABLE_COPY(DPointSelect)
 };
 
 // --------------------------------------------------------------------------------
@@ -214,7 +215,7 @@ public:
     void setSaturation(int saturation);
 
     /**
-     * Returns the color value (also known as lumniousity, 0-255)
+     * Returns the color value (also known as luminosity, 0-255)
      *
      * @return  The color value (0-255)
      */
@@ -250,13 +251,13 @@ protected:
 
 private:
 
+    Q_DISABLE_COPY(DHueSaturationSelector)
+
     class Private;
     friend class Private;
     Private* const d;
-
-    Q_DISABLE_COPY(DHueSaturationSelector)
 };
 
 } // namespace Digikam
 
-#endif // DHUESATURATIONSELECT_H
+#endif // DIGIKAM_DHUE_SATURATION_SELECT_H
