@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-16
  * Description : a combo box widget re-implemented with a
  *               reset button to switch to a default item
  *
- * Copyright (C) 2008-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,7 @@ class Q_DECL_HIDDEN DComboBox::Private
 
 public:
 
-    Private()
+    explicit Private()
     {
         defaultIndex = 0;
         resetButton  = 0;
@@ -102,9 +102,9 @@ void DComboBox::addItem(const QString& t, int index)
     d->combo->addItem(t, index);
 }
 
-void DComboBox::insertItem(int index, const QString& t)
+void DComboBox::insertItem(int index, const QString& t, const QVariant& data)
 {
-    d->combo->insertItem(index, t);
+    d->combo->insertItem(index, t, data);
 }
 
 int DComboBox::currentIndex() const
@@ -149,4 +149,4 @@ void DComboBox::slotCurrentIndexChanged(int v)
     emit currentIndexChanged(v);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
