@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-16
  * Description : a combo box widget re-implemented with a
  *               reset button to switch to a default item
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,13 +22,14 @@
  *
  * ============================================================ */
 
-#ifndef DCOMBO_BOX_H
-#define DCOMBO_BOX_H
+#ifndef DIGIKAM_DCOMBO_BOX_H
+#define DIGIKAM_DCOMBO_BOX_H
 
 // Qt includes
 
 #include <QWidget>
 #include <QComboBox>
+#include <QVariant>
 
 // Local includes
 
@@ -44,7 +45,7 @@ class DIGIKAM_EXPORT DComboBox : public QWidget
 
 public:
 
-    DComboBox(QWidget* const parent=0);
+    explicit DComboBox(QWidget* const parent=0);
     ~DComboBox();
 
     void setCurrentIndex(int d);
@@ -56,7 +57,7 @@ public:
     QComboBox* combo() const;
 
     void addItem(const QString& t, int index = -1);
-    void insertItem(int index, const QString& t);
+    void insertItem(int index, const QString& t, const QVariant& data = QVariant());
 
 Q_SIGNALS:
 
@@ -81,4 +82,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DCOMBO_BOX_H
+#endif // DIGIKAM_DCOMBO_BOX_H
