@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-21
  * Description : a combo box with a width not depending of text
  *               content size
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2008 by Andi Clemens <andi dot clemens at googlemail dot com>
  * Copyright (C)      2005 by Tom Albers <tomalbers at kde dot nl>
  *
@@ -41,7 +41,7 @@ class Q_DECL_HIDDEN SqueezedComboBox::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         timer = 0;
     }
@@ -52,16 +52,20 @@ public:
 };
 
 SqueezedComboBox::SqueezedComboBox(QWidget* const parent, const char* name)
-    : QComboBox(parent), d(new Private)
+    : QComboBox(parent),
+      d(new Private)
 {
     setObjectName(QString::fromUtf8(name));
     setMinimumWidth(100);
+
     d->timer = new QTimer(this);
     d->timer->setSingleShot(true);
 
-    connect(d->timer, &QTimer::timeout, this, &SqueezedComboBox::slotTimeOut);
+    connect(d->timer, &QTimer::timeout,
+            this, &SqueezedComboBox::slotTimeOut);
 
-    connect(this, static_cast<void (SqueezedComboBox::*)(int)>(&SqueezedComboBox::activated), this, &SqueezedComboBox::slotUpdateToolTip);
+    connect(this, static_cast<void (SqueezedComboBox::*)(int)>(&SqueezedComboBox::activated),
+            this, &SqueezedComboBox::slotUpdateToolTip);
 }
 
 SqueezedComboBox::~SqueezedComboBox()
@@ -76,7 +80,8 @@ bool SqueezedComboBox::contains(const QString& text) const
     if (text.isEmpty())
         return false;
 
-    for (QMap<int, QString>::const_iterator it = d->originalItems.constBegin() ; it != d->originalItems.constEnd(); ++it)
+    for (QMap<int, QString>::const_iterator it = d->originalItems.constBegin() ;
+         it != d->originalItems.constEnd() ; ++it)
     {
         if (it.value() == text)
             return true;
@@ -90,7 +95,7 @@ QSize SqueezedComboBox::sizeHint() const
     ensurePolished();
     QFontMetrics fm = fontMetrics();
     int maxW        = count() ? 18 : 7 * fm.width(QLatin1Char('x')) + 18;
-    int maxH        = qMax( fm.lineSpacing(), 14 ) + 2;
+    int maxH        = qMax(fm.lineSpacing(), 14) + 2;
 
     QStyleOptionComboBox options;
     options.initFrom(this);
@@ -112,10 +117,11 @@ void SqueezedComboBox::insertSqueezedItem(const QString& newItem, int index,
 
 void SqueezedComboBox::insertSqueezedList(const QStringList& newItems, int index)
 {
-    for(QStringList::const_iterator it = newItems.constBegin() ; it != newItems.constEnd() ; ++it)
+    for (QStringList::const_iterator it = newItems.constBegin() ;
+         it != newItems.constEnd() ; ++it)
     {
         insertSqueezedItem(*it, index);
-        index++;
+        ++index;
     }
 }
 
@@ -141,17 +147,18 @@ void SqueezedComboBox::resizeEvent(QResizeEvent *)
 
 void SqueezedComboBox::slotTimeOut()
 {
-    for (QMap<int, QString>::iterator it = d->originalItems.begin() ; it != d->originalItems.end(); ++it)
+    for (QMap<int, QString>::iterator it = d->originalItems.begin() ;
+         it != d->originalItems.end() ; ++it)
     {
-        setItemText( it.key(), squeezeText( it.value() ) );
+        setItemText(it.key(), squeezeText(it.value()));
     }
 }
 
 QString SqueezedComboBox::squeezeText(const QString& original) const
 {
     // not the complete widgetSize is usable. Need to compensate for that.
-    int widgetSize = width()-30;
-    QFontMetrics fm( fontMetrics() );
+    int widgetSize = width() - 30;
+    QFontMetrics fm(fontMetrics());
 
     // If we can fit the full text, return that.
     if (fm.width(original) < widgetSize)
@@ -161,7 +168,7 @@ QString SqueezedComboBox::squeezeText(const QString& original) const
     QString sqItem = original; // prevent empty return value;
     widgetSize     = widgetSize-fm.width(QLatin1String("..."));
 
-    for (int i = 0 ; i != original.length(); ++i)
+    for (int i = 0 ; i != original.length() ; ++i)
     {
         if ((int)fm.width(original.right(i)) > widgetSize)
         {
@@ -189,4 +196,4 @@ QString SqueezedComboBox::item(int index) const
     return d->originalItems[index];
 }
 
-}  // namespace Digikam
+} // namespace Digikam
