@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-21
  * Description : a combo box with a width not depending of text
  *               content size
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2008 by Andi Clemens <andi dot clemens at googlemail dot com>
  * Copyright (C)      2005 by Tom Albers <tomalbers at kde dot nl>
  *
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef SQUEEZED_COMBOBOX_H
-#define SQUEEZED_COMBOBOX_H
+#ifndef DIGIKAM_SQUEEZED_COMBOBOX_H
+#define DIGIKAM_SQUEEZED_COMBOBOX_H
 
 // Qt includes
 
@@ -158,4 +158,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SQUEEZED_COMBOBOX_H
+#endif // DIGIKAM_SQUEEZED_COMBOBOX_H
