@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-09-12
  * Description : A label with an active url
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DACTIVE_LABEL_H
-#define DACTIVE_LABEL_H
+#ifndef DIGIKAM_DACTIVE_LABEL_H
+#define DIGIKAM_DACTIVE_LABEL_H
 
 // Qt includes
 
@@ -38,8 +38,9 @@
 namespace Digikam
 {
 
-/** A widget to host an image into a label with an active url which can be
- *  open to default web browser using simple mouse click.
+/**
+ * A widget to host an image into a label with an active url which can be
+ * open to default web browser using simple mouse click.
  */
 class DIGIKAM_EXPORT DActiveLabel : public QLabel
 {
@@ -55,4 +56,4 @@ public:
 
 } // namespace Digikam
 
-#endif // DACTIVE_LABEL_H
+#endif // DIGIKAM_DACTIVE_LABEL_H
