@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-01-02
  * Description : Sample implementations for drag and drop handling
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DRAGDROPIMPLEMENTATIONS_H
-#define DRAGDROPIMPLEMENTATIONS_H
+#ifndef DIGIKAM_DRAG_DROP_IMPLEMENTATIONS_H
+#define DIGIKAM_DRAG_DROP_IMPLEMENTATIONS_H
 
 // Qt includes
 
@@ -156,4 +156,4 @@ protected:
 
 } // namespace Digikam
 
-#endif // DRAGDROPIMPLEMENTATIONS_H
+#endif // DIGIKAM_DRAG_DROP_IMPLEMENTATIONS_H
