@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-06-13
  * Description : A QCompleter for AbstractAlbumModels
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  * Copyright (C) 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef MODELCOMPLETER_H
-#define MODELCOMPLETER_H
+#ifndef DIGIKAM_MODEL_COMPLETER_H
+#define DIGIKAM_MODEL_COMPLETER_H
 
 // QT includes
 
@@ -45,7 +45,7 @@ class DIGIKAM_EXPORT ModelCompleter : public QCompleter
 
 public:
 
-    ModelCompleter(QObject* parent = 0);
+    explicit ModelCompleter(QObject* const parent = 0);
     ~ModelCompleter();
 
     /**
@@ -83,4 +83,4 @@ private:
 
 } // namespace Digikam
 
-#endif // MODELCOMPLETER_H
+#endif // DIGIKAM_MODEL_COMPLETER_H
