@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-11-25
  * Description : a bar used to search a string.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  *
  * This program is free software; you can redistribute it
@@ -50,12 +50,12 @@ bool operator==(const SearchTextSettings& a, const SearchTextSettings& b)
     return a.caseSensitive == b.caseSensitive && a.text == b.text;
 }
 
-class SearchTextBar::Private
+class Q_DECL_HIDDEN SearchTextBar::Private
 {
 public:
 
-    Private() :
-        optionAutoCompletionModeEntry(QLatin1String("AutoCompletionMode")),
+    explicit Private()
+      : optionAutoCompletionModeEntry(QLatin1String("AutoCompletionMode")),
         optionCaseSensitiveEntry(QLatin1String("CaseSensitive")),
         textQueryCompletion(false),
         hasCaseSensitive(true),
@@ -319,4 +319,4 @@ void SearchTextBar::setIgnoreCase(bool ignore)
     emit signalSearchTextSettings(d->settings);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
