@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-11-25
  * Description : a bar used to search a string.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SEARCH_TEXT_BAR_H
-#define SEARCH_TEXT_BAR_H
+#ifndef DIGIKAM_SEARCH_TEXT_BAR_H
+#define DIGIKAM_SEARCH_TEXT_BAR_H
 
 // Qt includes
 
@@ -205,4 +205,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SEARCH_TEXT_BAR_H
+#endif // DIGIKAM_SEARCH_TEXT_BAR_H
