@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * date        : 2017-07-04
  * Description : wrapper for the QFileDialog
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2017      by Maik Qualmann <metzpinguin at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DFILE_DIALOG_H
-#define DFILE_DIALOG_H
+#ifndef DIGIKAM_DFILE_DIALOG_H
+#define DIGIKAM_DFILE_DIALOG_H
 
 // Qt includes
 
@@ -103,4 +103,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DFILE_DIALOG_H
+#endif // DIGIKAM_DFILE_DIALOG_H
