@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * date        : 2014-09-12
  * Description : a file or folder selector widget
  *
- * Copyright (C) 2014-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DFILE_SELECTOR_H
-#define DFILE_SELECTOR_H
+#ifndef DIGIKAM_DFILE_SELECTOR_H
+#define DIGIKAM_DFILE_SELECTOR_H
 
 // Qt includes
 
@@ -57,10 +57,10 @@ public:
     void setFileDlgPath(const QString& path);
     QString fileDlgPath() const;
 
-    void setFileDlgMode(DFileDialog::FileMode mode);
+    void setFileDlgMode(QFileDialog::FileMode mode);
     void setFileDlgFilter(const QString& filter);
     void setFileDlgTitle(const QString& title);
-    void setFileDlgOptions(DFileDialog::Options opts);
+    void setFileDlgOptions(QFileDialog::Options opts);
 
 Q_SIGNALS:
 
@@ -79,4 +79,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DFILE_SELECTOR_H
+#endif // DIGIKAM_DFILE_SELECTOR_H
