@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-09-13
  * Description : a widget to provide conflict rules to save image.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -40,11 +40,11 @@
 namespace Digikam
 {
 
-class FileSaveConflictBox::Private
+class Q_DECL_HIDDEN FileSaveConflictBox::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         conflictLabel       = 0;
         conflictButtonGroup = 0;
