@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-08-02
  * Description : a stack of widgets to set image file save
  *               options into image editor.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,18 +50,18 @@
 #include "pgfsettings.h"
 
 #ifdef HAVE_JASPER
-#include "jp2ksettings.h"
+#   include "jp2ksettings.h"
 #endif // HAVE_JASPER
 
 namespace Digikam
 {
 
-class FileSaveOptionsBox::Private
+class Q_DECL_HIDDEN FileSaveOptionsBox::Private
 {
 
 public:
 
-    Private() :
+    explicit Private() :
         noneOptions(0),
         noneGrid(0),
         labelNone(0),
@@ -244,4 +244,4 @@ void FileSaveOptionsBox::readSettings()
     d->PGFOptions->setLossLessCompression( group.readEntry(QLatin1String("PGFLossLess"),           true) );
 }
 
-}  // namespace Digikam
+} // namespace Digikam
