@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-08-02
  * Description : a stack of widgets to set image file save
  *               options into image editor.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef FILESAVEOPTIONSBOX_H
-#define FILESAVEOPTIONSBOX_H
+#ifndef DIGIKAM_FILE_SAVE_OPTIONS_BOX_H
+#define DIGIKAM_FILE_SAVE_OPTIONS_BOX_H
 
 // Qt includes
 
@@ -83,4 +83,4 @@ private:
 
 } // namespace Digikam
 
-#endif // FILESAVEOPTIONSBOX_H
+#endif // DIGIKAM_FILE_SAVE_OPTIONS_BOX_H
