@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-12-23
  * Description : a widget to change font properties.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      1996 by Bernd Johannes Wuebben  <wuebben at kde dot org>
  * Copyright (c)      1999 by Preston Brown <pbrown at kde dot org>
  * Copyright (c)      1999 by Mario Weilguni <mweilguni at kde dot org>
@@ -64,7 +64,7 @@ static int minimumListWidth(const QListWidget* list)
 {
     int w = 0;
 
-    for (int i = 0; i < list->count(); i++)
+    for (int i = 0; i < list->count(); ++i)
     {
         int itemWidth = list->visualItemRect(list->item(i)).width();
         // ...and add a space on both sides for not too tight look.
@@ -108,11 +108,11 @@ static QString formatFontSize(qreal size)
 
 // -----------------------------------------------------------------------------------
 
-class DFontProperties::Private
+class Q_DECL_HIDDEN DFontProperties::Private
 {
 public:
 
-    Private(DFontProperties* const qq)
+    explicit Private(DFontProperties* const qq)
         : q(qq)
     {
         palette.setColor(QPalette::Active, QPalette::Text, Qt::black);
@@ -231,7 +231,7 @@ DFontProperties::DFontProperties(QWidget* const parent,
     // The top layout is divided vertically into a splitter with font
     // attribute widgets and preview on the top, and XLFD data at the bottom.
     QVBoxLayout* const topLayout = new QVBoxLayout(this);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     const int spacingHint        = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
     int checkBoxGap              = spacingHint / 2;
 
@@ -260,7 +260,7 @@ DFontProperties::DFontProperties(QWidget* const parent,
         page       = new QWidget(this);
         splitter->addWidget(page);
         gridLayout = new QGridLayout(page);
-        gridLayout->setMargin(0);
+        gridLayout->setContentsMargins(0, 0, 0, 0);
     }
 
     // first, create the labels across the top
@@ -727,7 +727,7 @@ void DFontProperties::Private::_d_family_chosen_slot(const QString& family)
     qtStyles.clear();
     styleIDs.clear();
 
-    Q_FOREACH (const QString& style, styles)
+    foreach(const QString& style, styles)
     {
         // Sometimes the font database will report an invalid style,
         // that falls back to another when set.
@@ -1039,7 +1039,7 @@ qreal DFontProperties::Private::fillSizeList(const QList<qreal>& sizes_)
     sizeListBox->clear();
     std::sort(sizes.begin(), sizes.end());
 
-    Q_FOREACH (qreal size, sizes)
+    foreach(qreal size, sizes)
     {
         sizeListBox->addItem(formatFontSize(size));
     }
@@ -1073,7 +1073,7 @@ qreal DFontProperties::Private::setupSizeListBox(const QString& family, const QS
 
         QList<int> smoothSizes = dbase.smoothSizes(family, style);
 
-        Q_FOREACH (int size, smoothSizes)
+        foreach(int size, smoothSizes)
         {
             sizes.append(size);
         }
@@ -1386,7 +1386,7 @@ QStringList DFontProperties::Private::translateFontNameList(const QStringList& n
     QStringList             trNames;
     QHash<QString, QString> trMap;
 
-    Q_FOREACH (const QString& name, names)
+    foreach(const QString& name, names)
     {
         QString trName = translateFontName(name);
 
@@ -1404,7 +1404,7 @@ QStringList DFontProperties::Private::translateFontNameList(const QStringList& n
 
     // Prepend generic fonts, in the predefined order.
 
-    Q_FOREACH (const QString& genericName, genericNames)
+    foreach(const QString& genericName, genericNames)
     {
         QString trGenericName = translateFontName(genericName);
 
