@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-12-23
  * Description : a widget to select between system font or a custom font.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DFONTSELECT_H
-#define DFONTSELECT_H
+#ifndef DIGIKAM_DFONT_SELECT_H
+#define DIGIKAM_DFONT_SELECT_H
 
 // Qt includes
 
@@ -80,4 +80,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DFONTSELECT_H
+#endif // DIGIKAM_DFONT_SELECT_H
