@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-04-30
  * Description : Graphics View item for DImg
  *
  * Copyright (C) 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GRAPHICSDIMGITEM_H
-#define GRAPHICSDIMGITEM_H
+#ifndef DIGIKAM_GRAPHICS_DIMG_ITEM_H
+#define DIGIKAM_GRAPHICS_DIMG_ITEM_H
 
 // Qt includes
 
@@ -94,4 +94,4 @@ protected:
 
 } // namespace Digikam
 
-#endif // GRAPHICSDIMGITEM_H
+#endif // DIGIKAM_GRAPHICS_DIMG_ITEM_H
