@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-04-30
  * Description : Image zoom settings
@@ -39,12 +39,14 @@ namespace Digikam
 {
 
 ImageZoomSettings::ImageZoomSettings()
-    : m_zoom(1), m_zoomConst(1)
+    : m_zoom(1),
+      m_zoomConst(1)
 {
 }
 
 ImageZoomSettings::ImageZoomSettings(const QSize& imageSize, const QSize& originalSize)
-    : m_zoom(1), m_zoomConst(1)
+    : m_zoom(1),
+      m_zoomConst(1)
 {
     setImageSize(imageSize, originalSize);
 }
