@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-09-20
  * Description : Managing visibility state with animations
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ITEMVISIBILITYCONTROLLER_H
-#define ITEMVISIBILITYCONTROLLER_H
+#ifndef DIGIKAM_ITEM_VISIBILITY_CONTROLLER_H
+#define DIGIKAM_ITEM_VISIBILITY_CONTROLLER_H
 
 // Qt includes
 
@@ -57,7 +57,7 @@ public:
      *  2) visible determines if the items shall be shown now.
      *     Only takes effect if shallBeShown is true.
      *     Default is false: Initially, controlled items are hidden.
-     *  3) Opacitiy and individual item visibility:
+     *  3) Opacity and individual item visibility:
      *     When showing, items are first set to individually visible,
      *     then their opacity is increased from 0 to 1.
      *     When hiding, opacity is first decreased from 1 to 0,
@@ -220,7 +220,7 @@ public:
      *  Connect to the signals accordingly, e.g. to trigger a repaint.
      */
 
-    explicit ItemVisibilityControllerPropertyObject(QObject* parent = 0);
+    explicit ItemVisibilityControllerPropertyObject(QObject* const parent = 0);
 
     qreal opacity() const;
     void setOpacity(qreal opacity);
@@ -311,4 +311,4 @@ protected:
 
 } // namespace Digikam
 
-#endif // ITEMVISIBILITYCONTROLLER_H
+#endif // DIGIKAM_ITEM_VISIBILITY_CONTROLLER_H
