@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-22
  * Description : a generic widget to display a panel to choose
@@ -10,7 +10,7 @@
  * Copyright (C) 1997      by Tim D. Gilman (tdgilman at best dot org)
  * Copyright (C) 1998-2001 by Mirko Boehm (mirko at kde dot org)
  * Copyright (C) 2007      by John Layt <john at layt dot net>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,8 +25,8 @@
  *
  * ============================================================ */
 
-#ifndef PANICONWIDGET_H
-#define PANICONWIDGET_H
+#ifndef DIGIKAM_PAN_ICON_WIDGET_H
+#define DIGIKAM_PAN_ICON_WIDGET_H
 
 // Qt includes
 
@@ -59,7 +59,7 @@ class DIGIKAM_EXPORT PanIconFrame : public QFrame
 
 public:
 
-    PanIconFrame(QWidget* const parent=0);
+    explicit PanIconFrame(QWidget* const parent=0);
     ~PanIconFrame();
 
     /**
@@ -185,4 +185,4 @@ private:
 
 } // namespace Digikam
 
-#endif // PANICONWIDGET_H
+#endif // DIGIKAM_PAN_ICON_WIDGET_H
