@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-04-30
  * Description : Layout for an item on image preview
@@ -37,11 +37,11 @@
 namespace Digikam
 {
 
-class SinglePhotoPreviewLayout::Private
+class Q_DECL_HIDDEN SinglePhotoPreviewLayout::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         view           = 0;
         item           = 0;
@@ -76,7 +76,8 @@ public:
 };
 
 SinglePhotoPreviewLayout::SinglePhotoPreviewLayout(QObject* const parent)
-    : QObject(parent), d(new Private)
+    : QObject(parent),
+      d(new Private)
 {
 }
 
