@@ -1,7 +1,7 @@
 /* ============================================================
 *
 * This file is a part of digiKam project
-* http://www.digikam.org
+* https://www.digikam.org
 *
 * Date        : 2010-09-09
 * Description : tag region frame
@@ -92,7 +92,7 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::CropHandle)
 namespace Digikam
 {
 
-class RegionFrameItem::Private
+class Q_DECL_HIDDEN RegionFrameItem::Private
 {
 public:
 
@@ -376,7 +376,8 @@ void RegionFrameItem::Private::updateHudWidgetPosition()
 // ---------------------------------------------------------------------------------------
 
 RegionFrameItem::RegionFrameItem(QGraphicsItem* const item)
-    : DImgChildItem(item), d(new Private(this))
+    : DImgChildItem(item),
+      d(new Private(this))
 {
     d->resizeHandleVisibility = new AnimatedVisibility(this);
     d->resizeHandleVisibility->controller()->setShallBeShown(false);
@@ -408,7 +409,7 @@ RegionFrameItem::~RegionFrameItem()
 {
     if (d->hudWidget)
     {
-        // See bug #359196: hide or close the QGraphicsWidget befor delete it. Possible Qt bug?
+        // See bug #359196: hide or close the QGraphicsWidget before delete it. Possible Qt bug?
         d->hudWidget->hide();
         delete d->hudWidget;
     }
