@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-10
  * Description : a widget to display CIE tongue from an ICC profile.
  *
- * Copyright (C) 2006-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Any source code are inspired from lprof project and
- * Copyright (C) 1998-2001 Marti Maria
+ * Copyright (C) 1998-2001 Marti Maria <info at littlecms dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -153,12 +153,12 @@ static const double spectral_chromaticity[81][3] =
     { 0.7347, 0.2653 }  // 780 nm
 };
 
-class CIETongueWidget::Private
+class Q_DECL_HIDDEN CIETongueWidget::Private
 {
 public:
 
-    Private() :
-        profileDataAvailable(true),
+    explicit Private()
+      : profileDataAvailable(true),
         loadingImageMode(false),
         loadingImageSucess(false),
         needUpdatePixmap(false),
@@ -725,12 +725,12 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
     // Widget is disable : drawing grayed frame.
 
-    if ( !isEnabled() )
+    if (!isEnabled())
     {
         p.fillRect(0, 0, width(), height(),
-                   palette().color(QPalette::Disabled, QPalette::Background));
+                   palette().color(QPalette::Disabled, QPalette::Window));
 
-        QPen pen(palette().color(QPalette::Disabled, QPalette::Foreground));
+        QPen pen(palette().color(QPalette::Disabled, QPalette::WindowText));
         pen.setStyle(Qt::SolidLine);
         pen.setWidth(1);
 
@@ -756,7 +756,7 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
         // ... and we render busy text.
 
-        p.fillRect(0, 0, width(), height(), palette().color(QPalette::Active, QPalette::Background));
+        p.fillRect(0, 0, width(), height(), palette().color(QPalette::Active, QPalette::Window));
         p.drawPixmap(width()/2 - anim.width() /2, anim.height(), anim);
         QPen pen(palette().color(QPalette::Active, QPalette::Text));
         pen.setStyle(Qt::SolidLine);
@@ -774,7 +774,7 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
     if (!d->profileDataAvailable || (!d->loadingImageMode && !d->loadingImageSucess))
     {
-        p.fillRect(0, 0, width(), height(), palette().color(QPalette::Active, QPalette::Background));
+        p.fillRect(0, 0, width(), height(), palette().color(QPalette::Active, QPalette::Window));
         QPen pen(palette().color(QPalette::Active, QPalette::Text));
         pen.setStyle(Qt::SolidLine);
         pen.setWidth(1);
@@ -820,4 +820,4 @@ void CIETongueWidget::slotProgressTimerDone()
     d->progressTimer->start(200);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
