@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-10
  * Description : a widget to display CIE tongue from an ICC profile.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef CIETONGUEWIDGET_H
-#define CIETONGUEWIDGET_H
+#ifndef DIGIKAM_CIE_TONGUE_WIDGET_H
+#define DIGIKAM_CIE_TONGUE_WIDGET_H
 
 // Qt includes
 
@@ -45,7 +45,7 @@ class DIGIKAM_EXPORT CIETongueWidget : public QWidget
 
 public:
 
-    CIETongueWidget(int w, int h, QWidget* const parent=0, cmsHPROFILE hMonitor=0);
+    explicit CIETongueWidget(int w, int h, QWidget* const parent=0, cmsHPROFILE hMonitor=0);
     ~CIETongueWidget();
 
     bool setProfileData(const QByteArray& profileData=QByteArray());
@@ -96,4 +96,4 @@ private:
 
 } // namespace Digikam
 
-#endif // CIETONGUEWIDGET_H
+#endif // DIGIKAM_CIE_TONGUE_WIDGET_H
