@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-12
  * Description : a widget to display ICC profiles descriptions
  *               in file dialog preview.
  *
  * Copyright (C) 2006-2007 by Francisco J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCPREVIEWWIDGET_H
-#define ICCPREVIEWWIDGET_H
+#ifndef DIGIKAM_ICC_PREVIEW_WIDGET_H
+#define DIGIKAM_ICC_PREVIEW_WIDGET_H
 
 // Qt includes
 
@@ -62,4 +62,4 @@ private :
 
 } // namespace Digikam
 
-#endif // ICCPREVIEWWIDGET_H
+#endif // DIGIKAM_ICC_PREVIEW_WIDGET_H
