@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-06-23
  * Description : a tab widget to display ICC profile infos
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -67,7 +67,7 @@ static const char* ICCEntryList[] =
 namespace Digikam
 {
 
-class ICCTagInfo
+class Q_DECL_HIDDEN ICCTagInfo
 {
 
 public:
@@ -101,12 +101,12 @@ typedef QMap<QString, ICCTagInfo> ICCTagInfoMap;
 
 // ---------------------------------------------------------------------------------------
 
-class ICCProfileWidget::Private
+class Q_DECL_HIDDEN ICCProfileWidget::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         cieTongue = 0;
     }
@@ -124,6 +124,7 @@ ICCProfileWidget::ICCProfileWidget(QWidget* const parent, int w, int h)
     : MetadataWidget(parent),
       d(new Private)
 {
+    setup();
     dkCmsErrorAction(LCMS_ERROR_SHOW);
 
     // Set the translated ICC tags titles/descriptions list
@@ -142,14 +143,14 @@ ICCProfileWidget::ICCProfileWidget(QWidget* const parent, int w, int h)
     d->iccTagsDescription[QLatin1String("Icc.Header.CMMFlags")]        = ICCTagInfo(i18n("CMM Flags"),        i18n("The ICC profile color management flags"));
 
     // Set the list of keys and tags filters.
-    for (int i=0 ; QLatin1String(ICCEntryList[i]) != QLatin1String("-1") ; ++i)
+    for (int i = 0 ; QLatin1String(ICCEntryList[i]) != QLatin1String("-1") ; ++i)
     {
         d->keysFilter << QLatin1String(ICCEntryList[i]);
     }
 
     QStringList tagsFilter;
 
-    for (int i=0 ; QLatin1String(ICCHumanList[i]) != QLatin1String("-1") ; ++i)
+    for (int i = 0 ; QLatin1String(ICCHumanList[i]) != QLatin1String("-1") ; ++i)
     {
         tagsFilter << QLatin1String(ICCHumanList[i]);
     }
@@ -258,7 +259,7 @@ bool ICCProfileWidget::loadFromURL(const QUrl& url)
 bool ICCProfileWidget::loadFromProfileData(const QString& fileName, const QByteArray& data)
 {
     setFileName(fileName);
-    return(setProfile(data));
+    return(setProfile(IccProfile(data)));
 }
 
 bool ICCProfileWidget::loadProfile(const QString& fileName, const IccProfile& profile)
@@ -287,32 +288,32 @@ bool ICCProfileWidget::decodeMetadata()
 
     DMetadata::MetaDataMap metaDataMap;
 
-    if ( !QString(dkCmsTakeProductName(hProfile)).isEmpty() )
+    if (!QString(dkCmsTakeProductName(hProfile)).isEmpty())
     {
         metaDataMap.insert(QLatin1String("Icc.Header.Name"), dkCmsTakeProductName(hProfile).replace(QLatin1Char('\n'), QLatin1Char(' ')));
     }
 
-    if ( !dkCmsTakeProductDesc(hProfile).isEmpty() )
+    if (!dkCmsTakeProductDesc(hProfile).isEmpty())
     {
         metaDataMap.insert(QLatin1String("Icc.Header.Description"), dkCmsTakeProductDesc(hProfile).replace(QLatin1Char('\n'), QLatin1Char(' ')));
     }
 
-    if ( !dkCmsTakeProductInfo(hProfile).isEmpty() )
+    if (!dkCmsTakeProductInfo(hProfile).isEmpty())
     {
         metaDataMap.insert(QLatin1String("Icc.Header.Information"), dkCmsTakeProductInfo(hProfile).replace(QLatin1Char('\n'), QLatin1Char(' ')));
     }
 
-    if ( !dkCmsTakeManufacturer(hProfile).isEmpty() )
+    if (!dkCmsTakeManufacturer(hProfile).isEmpty())
     {
         metaDataMap.insert(QLatin1String("Icc.Header.Manufacturer"), dkCmsTakeManufacturer(hProfile).replace(QLatin1Char('\n'), QLatin1Char(' ')));
     }
 
-    if ( !dkCmsTakeModel(hProfile).isEmpty() )
+    if (!dkCmsTakeModel(hProfile).isEmpty())
     {
         metaDataMap.insert(QLatin1String("Icc.Header.Model"), dkCmsTakeModel(hProfile).replace(QLatin1Char('\n'), QLatin1Char(' ')));
     }
 
-    if ( !dkCmsTakeCopyright(hProfile).isEmpty() )
+    if (!dkCmsTakeCopyright(hProfile).isEmpty())
     {
         metaDataMap.insert(QLatin1String("Icc.Header.Copyright"), dkCmsTakeCopyright(hProfile).replace(QLatin1Char('\n'), QLatin1Char(' ')));
     }
@@ -496,4 +497,4 @@ QString ICCProfileWidget::getTagDescription(const QString& key)
     return key.section(QLatin1Char('.'), 2, 2);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
