@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-06-23
  * Description : a tab widget to display ICC profile infos
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCPROFILEWIDGET_H
-#define ICCPROFILEWIDGET_H
+#ifndef DIGIKAM_ICC_PROFILE_WIDGET_H
+#define DIGIKAM_ICC_PROFILE_WIDGET_H
 
 // Qt includes
 
@@ -81,4 +81,4 @@ private:
 
 } // namespace Digikam
 
-#endif // ICCPROFILEWIDGET_H
+#endif // DIGIKAM_ICC_PROFILE_WIDGET_H
