@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-20
  * Description : action categorized view
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ACTIONCATEGORIZEDVIEW_H
-#define ACTIONCATEGORIZEDVIEW_H
+#ifndef DIGIKAM_ACTION_CATEGORIZED_VIEW_H
+#define DIGIKAM_ACTION_CATEGORIZED_VIEW_H
 
 // Local includes
 
@@ -64,4 +64,4 @@ protected:
 
 } // namespace Digikam
 
-#endif // ACTIONCATEGORIZEDVIEW_H
+#endif // DIGIKAM_ACTION_CATEGORIZED_VIEW_H
