@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-01-16
  * Description : categorize item view based on DCategorizedView
@@ -9,7 +9,7 @@
  * Copyright (C) 2007      by Rafael Fernández López <ereslibre at kde dot org>
  * Copyright (C) 2007      by John Tapsell <tapsell at kde dot org>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef DCATEGORIZED_SORT_FILTER_PROXY_MODEL_H
-#define DCATEGORIZED_SORT_FILTER_PROXY_MODEL_H
+#ifndef DIGIKAM_DCATEGORIZED_SORT_FILTER_PROXY_MODEL_H
+#define DIGIKAM_DCATEGORIZED_SORT_FILTER_PROXY_MODEL_H
 
 // Qt includes
 
@@ -68,7 +68,7 @@ public:
                                            ///< CategoryDisplayRole.
     };
 
-    DCategorizedSortFilterProxyModel(QObject* const parent = 0);
+    explicit DCategorizedSortFilterProxyModel(QObject* const parent = 0);
     virtual ~DCategorizedSortFilterProxyModel();
 
     /**
@@ -143,7 +143,7 @@ protected:
       *
       * Internally and if not reimplemented, this method will ask for @p left and
       * @p right models for role CategorySortRole. In order to correctly sort
-      * categories, the data() metod of the model should return a qlonglong (or numeric) value, or
+      * categories, the data() method of the model should return a qlonglong (or numeric) value, or
       * a QString object. QString objects will be sorted with QString::localeAwareCompare if
       * sortCategoriesByNaturalComparison() is true.
       *
@@ -182,4 +182,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DCATEGORIZED_SORT_FILTER_PROXY_MODEL_H
+#endif // DIGIKAM_DCATEGORIZED_SORT_FILTER_PROXY_MODEL_H
