@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-01-16
  * Description : Item view for listing items in a categorized fashion optionally
  *
  * Copyright (C) 2007      by Rafael Fernández López <ereslibre at kde dot org>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DCATEGORIZED_VIEW_P_H
-#define DCATEGORIZED_VIEW_P_H
+#ifndef DIGIKAM_DCATEGORIZED_VIEW_PRIVATE_H
+#define DIGIKAM_DCATEGORIZED_VIEW_PRIVATE_H
 
 // Qt includes
 
@@ -37,11 +37,11 @@ namespace Digikam
 
 class DCategorizedSortFilterProxyModel;
 
-class SparseModelIndexVector : public QVector<QModelIndex>
+class Q_DECL_HIDDEN SparseModelIndexVector : public QVector<QModelIndex>
 {
 public:
 
-    SparseModelIndexVector(int rowCount, QAbstractItemModel* const model_, int column_)
+    explicit SparseModelIndexVector(int rowCount, QAbstractItemModel* const model_, int column_)
         : QVector<QModelIndex>(rowCount),
           model(model_),
           column(column_)
@@ -76,7 +76,7 @@ private:
 
 // ------------------------------------------------------------------------------------
 
-class DCategorizedView::Private
+class Q_DECL_HIDDEN DCategorizedView::Private
 {
 public:
 
@@ -221,6 +221,6 @@ public:
     DCategorizedSortFilterProxyModel* proxyModel;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // DCATEGORIZED_VIEW_P_H
+#endif // DIGIKAM_DCATEGORIZED_VIEW_PRIVATE_H
