@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-01-16
  * Description : Qt item view for images - common delegate code
  *
  * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C)      2009 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2002-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2002-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -50,11 +50,11 @@
 namespace Digikam
 {
 
-class DItemDelegate::Private
+class Q_DECL_HIDDEN DItemDelegate::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
