@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-12-10
  * Description : tool tip widget for iconview, thumbbar, and folderview items
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,7 +45,6 @@
 
 #include <klocalizedstring.h>
 
-
 namespace Digikam
 {
 
@@ -161,11 +160,11 @@ QString DToolTipStyleSheet::imageAsBase64(const QImage& img) const
 
 // --------------------------------------------------------------------------------------------------
 
-class DItemToolTip::Private
+class Q_DECL_HIDDEN DItemToolTip::Private
 {
 public:
 
-    Private() :
+    explicit Private() :
         tipBorder(5)
     {
         corner = 0;
@@ -182,8 +181,8 @@ DItemToolTip::DItemToolTip(QWidget* const parent)
 {
     hide();
 
+    setForegroundRole(QPalette::ToolTipText);
     setBackgroundRole(QPalette::ToolTipBase);
-    setPalette(QToolTip::palette());
     ensurePolished();
     const int fwidth = qMax(d->tipBorder, 1 + style()->pixelMetric(QStyle::PM_ToolTipLabelFrameWidth, 0, this));
     setContentsMargins(fwidth, fwidth, fwidth, fwidth);
@@ -243,14 +242,14 @@ void DItemToolTip::reposition()
     if (rect.center().x() + width() > desk.right())
     {
         // to the left
-        if (pos.x() - width() < 0)
+        if (pos.x() - width() < desk.left())
         {
             pos.setX(0);
             d->corner = 4;
         }
         else
         {
-            pos.setX( pos.x() - width() );
+            pos.setX(pos.x() - width());
             d->corner = 1;
         }
     }
@@ -259,15 +258,32 @@ void DItemToolTip::reposition()
     if (rect.bottom() + height() > desk.bottom())
     {
         // above
-        pos.setY( rect.top() - height() - 5);
+        int top = rect.top() - height() - 5;
+
+        if (top < desk.top())
+        {
+            top = desk.top();
+
+            // recalculate x
+            if (d->corner == 0)
+            {
+                pos.setX(rect.right() + 5);
+            }
+            else if (d->corner == 1)
+            {
+                pos.setX(rect.left() - width() - 5);
+            }
+        }
+
+        pos.setY(top);
         d->corner += 2;
     }
     else
     {
-        pos.setY( rect.bottom() + 5 );
+        pos.setY(rect.bottom() + 5);
     }
 
-    move( pos );
+    move(pos);
 }
 
 void DItemToolTip::renderArrows()
@@ -283,7 +299,7 @@ void DItemToolTip::renderArrows()
     QPainter p0(&pix0);
     p0.setPen(QPen(qApp->palette().color(QPalette::Text), 1));
 
-    for (int j=0; j<w; ++j)
+    for (int j = 0 ; j < w ; ++j)
     {
         p0.drawLine(0, j, w-j-1, j);
     }
@@ -299,7 +315,7 @@ void DItemToolTip::renderArrows()
     QPainter p1(&pix1);
     p1.setPen(QPen(qApp->palette().color(QPalette::Text), 1));
 
-    for (int j=0; j<w; ++j)
+    for (int j = 0 ; j < w ; ++j)
     {
         p1.drawLine(j, j, w-1, j);
     }
@@ -315,7 +331,7 @@ void DItemToolTip::renderArrows()
     QPainter p2(&pix2);
     p2.setPen(QPen(qApp->palette().color(QPalette::Text), 1));
 
-    for (int j=0; j<w; ++j)
+    for (int j = 0 ; j < w ; ++j)
     {
         p2.drawLine(0, j, j, j);
     }
@@ -331,7 +347,7 @@ void DItemToolTip::renderArrows()
     QPainter p3(&pix3);
     p3.setPen(QPen(qApp->palette().color(QPalette::Text), 1));
 
-    for (int j=0; j<w; ++j)
+    for (int j = 0 ; j < w ; ++j)
     {
         p3.drawLine(w-j-1, j, w-1, j);
     }
@@ -341,7 +357,7 @@ void DItemToolTip::renderArrows()
 
 bool DItemToolTip::event(QEvent* e)
 {
-    switch ( e->type() )
+    switch (e->type())
     {
         case QEvent::Leave:
         case QEvent::MouseButtonPress:
@@ -396,18 +412,18 @@ void DItemToolTip::paintEvent(QPaintEvent* e)
     switch (d->corner)
     {
         case 0:
-            p.drawPixmap( 3, 3, pix );
+            p.drawPixmap(3, 3, pix);
             break;
         case 1:
-            p.drawPixmap( width() - pix.width() - 3, 3, pix );
+            p.drawPixmap(width() - pix.width() - 3, 3, pix);
             break;
         case 2:
-            p.drawPixmap( 3, height() - pix.height() - 3, pix );
+            p.drawPixmap(3, height() - pix.height() - 3, pix);
             break;
         case 3:
-            p.drawPixmap( width() - pix.width() - 3, height() - pix.height() - 3, pix );
+            p.drawPixmap(width() - pix.width() - 3, height() - pix.height() - 3, pix);
             break;
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
