@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-12-10
  * Description : tool tip widget for iconview, thumbbar, and folderview items
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DITEM_TOOL_TIP_H
-#define DITEM_TOOL_TIP_H
+#ifndef DIGIKAM_DITEM_TOOL_TIP_H
+#define DIGIKAM_DITEM_TOOL_TIP_H
 
 // Qt includes
 
@@ -102,4 +102,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DITEM_TOOL_TIP_H
+#endif // DIGIKAM_DITEM_TOOL_TIP_H
