@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-01-16
  * Description : Qt item view for images
  *
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,14 +44,12 @@
 namespace Digikam
 {
 
-// -------------------------------------------------------------------------------
-
-class ItemViewCategorized::Private
+class Q_DECL_HIDDEN ItemViewCategorized::Private
 {
 public:
 
-    explicit Private(ItemViewCategorized* const q) :
-        delegate(0),
+    explicit Private(ItemViewCategorized* const q)
+      : delegate(0),
         toolTip(0),
         notificationToolTip(0),
         showToolTip(false),
@@ -311,7 +309,7 @@ void ItemViewCategorized::setSelectedIndexes(const QList<QModelIndex>& indexes)
 
     QItemSelection mySelection;
 
-    foreach(const QModelIndex& index, indexes)
+    foreach (const QModelIndex& index, indexes)
     {
         mySelection.select(index, index);
     }
@@ -380,18 +378,13 @@ void ItemViewCategorized::slotActivated(const QModelIndex& index)
     if (d->currentMouseEvent)
     {
         // Ignore activation if Ctrl or Shift is pressed (for selection)
-        modifiers                       = d->currentMouseEvent->modifiers();
-        const bool shiftKeyPressed      = modifiers & Qt::ShiftModifier;
-        const bool controlKeyPressed    = modifiers & Qt::ControlModifier;
+        modifiers                    = d->currentMouseEvent->modifiers();
+        Qt::MouseButton button       = d->currentMouseEvent->button();
+        const bool shiftKeyPressed   = modifiers & Qt::ShiftModifier;
+        const bool controlKeyPressed = modifiers & Qt::ControlModifier;
+        const bool rightClickPressed = button & Qt::RightButton;
 
-        if (shiftKeyPressed || controlKeyPressed)
-        {
-            return;
-        }
-
-        const bool rightClick = d->currentMouseEvent->button() & Qt::RightButton;
-
-        if (rightClick)
+        if (shiftKeyPressed || controlKeyPressed || rightClickPressed)
         {
             return;
         }
@@ -429,8 +422,8 @@ void ItemViewCategorized::reset()
 {
     DCategorizedView::reset();
 
-    // FIXME : Emiting this causes a crash importstackedview, because the model is not yet set.
-    //         atm there's a check agaisnt null models though.
+    // FIXME : Emitting this causes a crash importstackedview, because the model is not yet set.
+    //         atm there's a check against null models though.
     emit selectionChanged();
     emit selectionCleared();
 
@@ -526,7 +519,7 @@ void ItemViewCategorized::rowsAboutToBeRemoved(const QModelIndex& parent, int st
 
 void ItemViewCategorized::layoutAboutToBeChanged()
 {
-    if(selectionModel())
+    if (selectionModel())
     {
         d->ensureOneSelectedItem = selectionModel()->hasSelection();
     }
@@ -614,7 +607,7 @@ void ItemViewCategorized::ensureSelectionAfterChanges()
         bool hadInitial              = d->ensureInitialSelectedItem;
         d->ensureInitialSelectedItem = false;
         d->ensureOneSelectedItem     = false;
-        QModelIndex index            = model()->index(0,0);
+        QModelIndex index            = model()->index(0, 0);
 
         if (index.isValid())
         {
@@ -654,7 +647,7 @@ void ItemViewCategorized::ensureSelectionAfterChanges()
 
             if (!index.isValid())
             {
-                index = model()->index(0,0);
+                index = model()->index(0, 0);
             }
 
             d->hintAtSelectionRow   = -1;
@@ -943,7 +936,7 @@ void ItemViewCategorized::keyPressEvent(QKeyEvent* event)
     if (trigger)
     {
         const QModelIndexList indexList = selModel->selectedIndexes();
-        foreach(const QModelIndex& index, indexList)
+        foreach (const QModelIndex& index, indexList)
         {
             emit itemTriggered(itemForIndex(index));
         }
