@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-01-16
  * Description : Qt item view for images
  *
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef ITEMVIEWCATEGORIZED_H
-#define ITEMVIEWCATEGORIZED_H
+#ifndef DIGIKAM_ITEM_VIEW_CATEGORIZED_H
+#define DIGIKAM_ITEM_VIEW_CATEGORIZED_H
 
 // Local includes
 
@@ -201,4 +201,4 @@ private:
 
 } // namespace Digikam
 
-#endif // ITEMVIEWCATEGORIZED_H
+#endif // DIGIKAM_ITEM_VIEW_CATEGORIZED_H
