@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-04-30
  * Description : Qt item view mouse hover button
@@ -48,7 +48,10 @@ ItemViewHoverButton::ItemViewHoverButton(QAbstractItemView* const view)
 
     setCheckable(true);
     setChecked(false);
+}
 
+void ItemViewHoverButton::setup()
+{
     connect(m_fadingTimeLine, SIGNAL(frameChanged(int)),
             this, SLOT(setFadingValue(int)));
 
