@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-04-30
  * Description : Qt item view mouse hover button
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ITEMVIEWHOVERBUTTON_H
-#define ITEMVIEWHOVERBUTTON_H
+#ifndef DIGIKAM_ITEM_VIEW_HOVER_BUTTON_H
+#define DIGIKAM_ITEM_VIEW_HOVER_BUTTON_H
 
 // Qt includes
 
@@ -57,6 +57,11 @@ public:
 
 protected:
 
+    /**
+     * to call in children class contructors to init signal/slot connections.
+     */
+    void setup();
+
     void enterEvent(QEvent* event);
     void leaveEvent(QEvent* event);
     void paintEvent(QPaintEvent* event);
@@ -84,4 +89,4 @@ protected:
 
 } // namespace Digikam
 
-#endif // ITEMVIEWHOVERBUTTON_H
+#endif // DIGIKAM_ITEM_VIEW_HOVER_BUTTON_H
