@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-04-24
  * Description : A DItemToolTip prepared for use in QAbstractItemViews
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ITEMVIEWTOOLTIP_H
-#define ITEMVIEWTOOLTIP_H
+#ifndef DIGIKAM_ITEM_VIEW_TOOL_TIP_H
+#define DIGIKAM_ITEM_VIEW_TOOL_TIP_H
 
 // Qt includes
 
@@ -40,7 +40,7 @@ class DIGIKAM_EXPORT ItemViewToolTip : public DItemToolTip
 {
 public:
 
-    explicit ItemViewToolTip(QAbstractItemView* view);
+    explicit ItemViewToolTip(QAbstractItemView* const view);
     ~ItemViewToolTip();
 
     QAbstractItemView* view()   const;
@@ -78,4 +78,4 @@ private:
 
 } // namespace Digikam
 
-#endif // ITEMVIEWTOOLTIP_H
+#endif // DIGIKAM_ITEM_VIEW_TOOL_TIP_H
