@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-23-03
  * Description : A tool tip widget which follows cursor movements.
  *               Tool tip content is displayed without delay.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -41,12 +41,12 @@
 namespace Digikam
 {
 
-class DCursorTracker::Private
+class Q_DECL_HIDDEN DCursorTracker::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         keepOpen      = false;
         enable        = true;
@@ -67,7 +67,6 @@ DCursorTracker::DCursorTracker(const QString& txt, QWidget* const parent, Qt::Al
 {
     setForegroundRole(QPalette::ToolTipText);
     setBackgroundRole(QPalette::ToolTipBase);
-    setPalette(QToolTip::palette());
     ensurePolished();
     const int fwidth = 1 + style()->pixelMetric(QStyle::PM_ToolTipLabelFrameWidth, 0, this);
     setContentsMargins(fwidth, fwidth, fwidth, fwidth);
