@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-04-29
  * Description : digiKam XML GUI window
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -40,6 +40,7 @@
 #include <QStatusBar>
 #include <QMenu>
 #include <QUrl>
+#include <QDomDocument>
 #include <QUrlQuery>
 #include <QIcon>
 #include <QDir>
@@ -69,16 +70,17 @@
 #include "digikam_debug.h"
 #include "digikam_globals.h"
 #include "daboutdata.h"
+#include "dpluginloader.h"
 #include "webbrowserdlg.h"
 
 namespace Digikam
 {
 
-class DXmlGuiWindow::Private
+class Q_DECL_HIDDEN DXmlGuiWindow::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         fsOptions              = FS_NONE;
         fullScreenAction       = 0;
@@ -172,22 +174,7 @@ DXmlGuiWindow::DXmlGuiWindow(QWidget* const parent, Qt::WindowFlags f)
     : KXmlGuiWindow(parent, f),
       d(new Private)
 {
-    m_expoBlendingAction    = 0;
-    m_panoramaAction        = 0;
-    m_videoslideshowAction  = 0;
-    m_htmlGalleryAction     = 0;
-    m_sendByMailAction      = 0;
-    m_printCreatorAction    = 0;
-    m_calendarAction        = 0;
-    m_presentationAction    = 0;
-    m_metadataEditAction    = 0;
-    m_geolocationEditAction = 0;
-    m_mediaServerAction     = 0;
-    m_animLogo              = 0;
-
-#ifdef HAVE_KSANE
-    m_ksaneAction           = 0;
-#endif
+    m_animLogo = 0;
 
     installEventFilter(this);
 }
@@ -209,10 +196,18 @@ QString DXmlGuiWindow::configGroupName() const
 
 void DXmlGuiWindow::closeEvent(QCloseEvent* e)
 {
-    if(fullScreenIsActive())
+    if (fullScreenIsActive())
         slotToggleFullScreen(false);
 
+    if (!testAttribute(Qt::WA_DeleteOnClose))
+    {
+        setVisible(false);
+        e->ignore();
+        return;
+    }
+
     KXmlGuiWindow::closeEvent(e);
+    e->accept();
 }
 
 void DXmlGuiWindow::setFullScreenOptions(int options)
@@ -220,6 +215,38 @@ void DXmlGuiWindow::setFullScreenOptions(int options)
     d->fsOptions = options;
 }
 
+void DXmlGuiWindow::registerPluginsActions()
+{
+    guiFactory()->removeClient(this);
+
+    DPluginLoader* const dpl = DPluginLoader::instance();
+    dpl->registerGenericPlugins(this);
+
+    QList<DPluginAction*> actions = dpl->pluginsActions(DPluginAction::Generic, this);
+
+    foreach (DPluginAction* const ac, actions)
+    {
+        actionCollection()->addActions(QList<QAction*>() << ac);
+        actionCollection()->setDefaultShortcuts(ac, ac->shortcuts());
+    }
+
+    QString dom = domDocument().toString();
+    dom.replace(QLatin1String("<!-- _DPLUGINS_GENERIC_TOOL_ACTIONS_ -->"),     dpl->pluginXmlSections(DPluginAction::GenericTool,     this));
+    dom.replace(QLatin1String("<!-- _DPLUGINS_GENERIC_METADATA_ACTIONS_ -->"), dpl->pluginXmlSections(DPluginAction::GenericMetadata, this));
+    dom.replace(QLatin1String("<!-- _DPLUGINS_GENERIC_IMPORT_ACTIONS_ -->"),   dpl->pluginXmlSections(DPluginAction::GenericImport,   this));
+    dom.replace(QLatin1String("<!-- _DPLUGINS_GENERIC_EXPORT_ACTIONS_ -->"),   dpl->pluginXmlSections(DPluginAction::GenericExport,   this));
+    dom.replace(QLatin1String("<!-- _DPLUGINS_GENERIC_VIEW_ACTIONS_ -->"),     dpl->pluginXmlSections(DPluginAction::GenericView,     this));
+
+    registerExtraPluginsActions(dom);
+
+    setXML(dom);
+
+    guiFactory()->reset();
+    guiFactory()->addClient(this);
+
+    checkAmbiguousShortcuts();
+}
+
 void DXmlGuiWindow::createHelpActions(bool coreOptions)
 {
     d->libsInfoAction = new QAction(QIcon::fromTheme(QLatin1String("help-about")), i18n("Components Information"), this);
@@ -272,9 +299,7 @@ void DXmlGuiWindow::cleanupActions()
     if (ac) actionCollection()->removeAction(ac);
 
 /*
-    QList<QAction*> lst = actionCollection()->actions();
-
-    foreach(QAction* const act, lst)
+    foreach (QAction* const act, actionCollection()->actions())
         qCDebug(DIGIKAM_WIDGETS_LOG) << "action: " << act->objectName();
 */
 }
@@ -282,35 +307,35 @@ void DXmlGuiWindow::cleanupActions()
 void DXmlGuiWindow::createSidebarActions()
 {
     KActionCollection* const ac = actionCollection();
-    QAction* const tlsb = new QAction(i18n("Toggle Left Side-bar"), this);
+    QAction* const tlsb         = new QAction(i18n("Toggle Left Side-bar"), this);
     connect(tlsb, SIGNAL(triggered()), this, SLOT(slotToggleLeftSideBar()));
     ac->addAction(QLatin1String("toggle-left-sidebar"), tlsb);
-    ac->setDefaultShortcut(tlsb, Qt::CTRL + Qt::META + Qt::Key_Left);
+    ac->setDefaultShortcut(tlsb, Qt::CTRL + Qt::ALT + Qt::Key_Left);
 
     QAction* const trsb = new QAction(i18n("Toggle Right Side-bar"), this);
     connect(trsb, SIGNAL(triggered()), this, SLOT(slotToggleRightSideBar()));
     ac->addAction(QLatin1String("toggle-right-sidebar"), trsb);
-    ac->setDefaultShortcut(trsb, Qt::CTRL + Qt::META + Qt::Key_Right);
+    ac->setDefaultShortcut(trsb, Qt::CTRL + Qt::ALT + Qt::Key_Right);
 
     QAction* const plsb = new QAction(i18n("Previous Left Side-bar Tab"), this);
     connect(plsb, SIGNAL(triggered()), this, SLOT(slotPreviousLeftSideBarTab()));
     ac->addAction(QLatin1String("previous-left-sidebar-tab"), plsb);
-    ac->setDefaultShortcut(plsb, Qt::CTRL + Qt::META + Qt::Key_Home);
+    ac->setDefaultShortcut(plsb, Qt::CTRL + Qt::ALT + Qt::Key_Home);
 
     QAction* const nlsb = new QAction(i18n("Next Left Side-bar Tab"), this);
     connect(nlsb, SIGNAL(triggered()), this, SLOT(slotNextLeftSideBarTab()));
     ac->addAction(QLatin1String("next-left-sidebar-tab"), nlsb);
-    ac->setDefaultShortcut(nlsb, Qt::CTRL + Qt::META + Qt::Key_End);
+    ac->setDefaultShortcut(nlsb, Qt::CTRL + Qt::ALT + Qt::Key_End);
 
     QAction* const prsb = new QAction(i18n("Previous Right Side-bar Tab"), this);
     connect(prsb, SIGNAL(triggered()), this, SLOT(slotPreviousRightSideBarTab()));
     ac->addAction(QLatin1String("previous-right-sidebar-tab"), prsb);
-    ac->setDefaultShortcut(prsb, Qt::CTRL + Qt::META + Qt::Key_PageUp);
+    ac->setDefaultShortcut(prsb, Qt::CTRL + Qt::ALT + Qt::Key_PageUp);
 
     QAction* const nrsb = new QAction(i18n("Next Right Side-bar Tab"), this);
     connect(nrsb, SIGNAL(triggered()), this, SLOT(slotNextRightSideBarTab()));
     ac->addAction(QLatin1String("next-right-sidebar-tab"), nrsb);
-    ac->setDefaultShortcut(nrsb, Qt::CTRL + Qt::META + Qt::Key_PageDown);
+    ac->setDefaultShortcut(nrsb, Qt::CTRL + Qt::ALT + Qt::Key_PageDown);
 }
 
 void DXmlGuiWindow::createSettingsActions()
@@ -401,150 +426,6 @@ void DXmlGuiWindow::slotNewToolbarConfig()
     applyMainWindowSettings(group);
 }
 
-void DXmlGuiWindow::createGeolocationEditAction()
-{
-#ifdef HAVE_MARBLE
-    m_geolocationEditAction = new QAction(QIcon::fromTheme(QLatin1String("globe")), i18n("Edit Geolocation..."), this);
-    actionCollection()->addAction(QLatin1String("geolocation_edit"), m_geolocationEditAction);
-    actionCollection()->setDefaultShortcut(m_geolocationEditAction, Qt::CTRL + Qt::SHIFT + Qt::Key_G);
-
-    connect(m_geolocationEditAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotEditGeolocation()));
-#endif
-}
-
-void DXmlGuiWindow::createMetadataEditAction()
-{
-    m_metadataEditAction = new QAction(QIcon::fromTheme(QLatin1String("format-text-code")), i18n("Edit Metadata..."), this);
-    actionCollection()->addAction(QLatin1String("metadata_edit"), m_metadataEditAction);
-    actionCollection()->setDefaultShortcut(m_metadataEditAction, Qt::CTRL + Qt::SHIFT + Qt::Key_M);
-
-    connect(m_metadataEditAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotEditMetadata()));
-}
-
-void DXmlGuiWindow::createPresentationAction()
-{
-    m_presentationAction = new QAction(QIcon::fromTheme(QLatin1String("view-presentation")), i18n("Presentation..."), this);
-
-    actionCollection()->addAction(QLatin1String("presentation"), m_presentationAction);
-    actionCollection()->setDefaultShortcut(m_presentationAction, Qt::ALT+Qt::SHIFT+Qt::Key_F9);
-
-    connect(m_presentationAction, SIGNAL(triggered()),
-            this, SLOT(slotPresentation()));
-}
-
-void DXmlGuiWindow::createExpoBlendingAction()
-{
-    m_expoBlendingAction = new QAction(QIcon::fromTheme(QLatin1String("expoblending")),
-                                       i18nc("@action", "Create Stacked Images..."),
-                                       this);
-
-    actionCollection()->addAction(QLatin1String("expoblending"), m_expoBlendingAction);
-
-    connect(m_expoBlendingAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotExpoBlending()));
-
-}
-
-void DXmlGuiWindow::createPanoramaAction()
-{
-#ifdef HAVE_PANORAMA
-    m_panoramaAction = new QAction(QIcon::fromTheme(QLatin1String("panorama")),
-                                    i18nc("@action", "Create panorama..."),
-                                    this);
-    actionCollection()->addAction(QLatin1String("panorama"), m_panoramaAction);
-
-    connect(m_panoramaAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotPanorama()));
-#endif
-}
-
-void DXmlGuiWindow::createVideoSlideshowAction()
-{
-#ifdef HAVE_MEDIAPLAYER
-    m_videoslideshowAction = new QAction(QIcon::fromTheme(QLatin1String("media-record")),
-                                         i18nc("@action", "Create video slideshow..."),
-                                         this);
-    actionCollection()->addAction(QLatin1String("videoslideshow"), m_videoslideshowAction);
-
-    connect(m_videoslideshowAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotVideoSlideshow()));
-#endif
-}
-
-void DXmlGuiWindow::createCalendarAction()
-{
-    m_calendarAction = new QAction(QIcon::fromTheme(QLatin1String("view-calendar")),
-                                    i18nc("@action", "Create Calendar..."),
-                                    this);
-    actionCollection()->addAction(QLatin1String("calendar"), m_calendarAction);
-
-    connect(m_calendarAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotCalendar()));
-}
-
-void DXmlGuiWindow::createSendByMailAction()
-{
-    m_sendByMailAction = new QAction(QIcon::fromTheme(QLatin1String("mail-send")),
-                                    i18nc("@action", "Send by Mail..."),
-                                    this);
-    actionCollection()->addAction(QLatin1String("sendbymail"), m_sendByMailAction);
-
-    connect(m_sendByMailAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotSendByMail()));
-}
-
-void DXmlGuiWindow::createPrintCreatorAction()
-{
-    m_printCreatorAction = new QAction(QIcon::fromTheme(QLatin1String("document-print")),
-                                    i18nc("@action", "Print Creator..."),
-                                    this);
-    actionCollection()->addAction(QLatin1String("printcreator"), m_printCreatorAction);
-
-    connect(m_printCreatorAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotPrintCreator()));
-}
-
-void DXmlGuiWindow::createHtmlGalleryAction()
-{
-#ifdef HAVE_HTMLGALLERY
-    m_htmlGalleryAction = new QAction(QIcon::fromTheme(QLatin1String("text-html")),
-                                      i18nc("@action", "Create Html gallery..."),
-                                      this);
-
-    actionCollection()->setDefaultShortcut(m_htmlGalleryAction, Qt::ALT+Qt::SHIFT+Qt::Key_H);
-    actionCollection()->addAction(QLatin1String("htmlgallery"), m_htmlGalleryAction);
-
-    connect(m_htmlGalleryAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotHtmlGallery()));
-#endif
-}
-
-void DXmlGuiWindow::createMediaServerAction()
-{
-    m_mediaServerAction = new QAction(QIcon::fromTheme(QLatin1String("arrow-right-double")),
-                                      i18n("Share with DLNA"),
-                                      this);
-
-    
-    actionCollection()->addAction(QLatin1String("mediaserver"), m_mediaServerAction);
-
-    connect(m_mediaServerAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotMediaServer()));
-}
-
-void DXmlGuiWindow::createKSaneAction()
-{
-#ifdef HAVE_KSANE
-    m_ksaneAction = new KSaneAction(this);
-    actionCollection()->addAction(QLatin1String("import_scan"), m_ksaneAction);
-
-    connect(m_ksaneAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotImportFromScanner()));
-#endif
-}
-
 void DXmlGuiWindow::createFullScreenAction(const QString& name)
 {
     d->fullScreenAction = KStandardAction::fullScreen(0, 0, this, this);
@@ -594,7 +475,7 @@ void DXmlGuiWindow::slotToggleFullScreen(bool set)
         if ((d->fsOptions & FS_SIDEBARS) && d->fullScreenHideSideBars)
             showSideBars(true);
 
-        // restore thummbbar
+        // restore thumbbar
 
         if ((d->fsOptions & FS_THUMBBAR) && d->fullScreenHideThumbBar)
             showThumbBar(d->thumbbarVisibility);
@@ -641,7 +522,7 @@ void DXmlGuiWindow::slotToggleFullScreen(bool set)
         if ((d->fsOptions & FS_SIDEBARS) && d->fullScreenHideSideBars)
             showSideBars(false);
 
-        // hide thummbbar
+        // hide thumbbar
 
         d->thumbbarVisibility = thumbbarVisibility();
 
@@ -766,7 +647,7 @@ KToolBar* DXmlGuiWindow::mainToolBar() const
     QList<KToolBar*> toolbars = toolBars();
     KToolBar* mainToolbar     = 0;
 
-    foreach(KToolBar* const toolbar, toolbars)
+    foreach (KToolBar* const toolbar, toolbars)
     {
         if (toolbar && (toolbar->objectName() == QLatin1String("mainToolBar")))
         {
@@ -785,7 +666,7 @@ void DXmlGuiWindow::showToolBars(bool visible)
     {
         d->toolbarsVisibility.clear();
 
-        foreach(KToolBar* const toolbar, toolBars())
+        foreach (KToolBar* const toolbar, toolBars())
         {
             if (toolbar)
             {
@@ -897,7 +778,10 @@ QAction* DXmlGuiWindow::buildStdAction(StdActionType type, const QObject* const
             return KStandardAction::zoomOut(recvr, slot, parent);
             break;
         case StdOpenAction:
+#ifndef __clang_analyzer__
+            // NOTE: disable false positive report from scan build about open()
             return KStandardAction::open(recvr, slot, parent);
+#endif
             break;
         case StdSaveAction:
             return KStandardAction::save(recvr, slot, parent);
@@ -984,17 +868,17 @@ void DXmlGuiWindow::setupIconTheme()
         {
             QIcon::setThemeName(QLatin1String("breeze"));
             cg.writeEntry("Theme", "breeze");
-            qCDebug(DIGIKAM_WIDGETS_LOG) << "Breeze icons ressource file found";
+            qCDebug(DIGIKAM_WIDGETS_LOG) << "Breeze icons resource file found";
         }
         else if (hasBreezeDark)
         {
             QIcon::setThemeName(QLatin1String("breeze-dark"));
             cg.writeEntry("Theme", "breeze-dark");
-            qCDebug(DIGIKAM_WIDGETS_LOG) << "Breeze-dark icons ressource file found";
+            qCDebug(DIGIKAM_WIDGETS_LOG) << "Breeze-dark icons resource file found";
         }
         else
         {
-            qCDebug(DIGIKAM_WIDGETS_LOG) << "No icons ressource file found";
+            qCDebug(DIGIKAM_WIDGETS_LOG) << "No icons resource file found";
         }
 
         cg.sync();
