@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-04-29
  * Description : digiKam XML GUI window
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DXML_GUI_WINDOW_H
-#define DXML_GUI_WINDOW_H
+#ifndef DIGIKAM_DXML_GUI_WINDOW_H
+#define DIGIKAM_DXML_GUI_WINDOW_H
 
 // Qt includes
 
@@ -34,6 +34,7 @@
 // KDE includes
 
 #include <kxmlguiwindow.h>
+#include <kxmlguifactory.h>
 #include <kconfiggroup.h>
 
 // Local includes
@@ -41,10 +42,9 @@
 #include "digikam_export.h"
 #include "digikam_config.h"
 #include "dlogoaction.h"
-
-#ifdef HAVE_KSANE
-#   include "ksaneaction.h"
-#endif
+#include "dinfointerface.h"
+#include "dpluginaction.h"
+#include "dpluginloader.h"
 
 class QEvent;
 
@@ -105,54 +105,6 @@ public:
     void setConfigGroupName(const QString& name);
     QString configGroupName() const;
 
-    /** Create Geolocation Edit tool action.
-     */
-    void createGeolocationEditAction();
-
-    /** Create Metadata Edit tool action.
-     */
-    void createMetadataEditAction();
-
-    /** Create Presentation tool action.
-     */
-    void createPresentationAction();
-
-    /** Create Calendar tool action.
-     */
-    void createCalendarAction();
-
-    /** Create Exposure Blending tool action.
-     */
-    void createExpoBlendingAction();
-
-    /** Create Panorama tool action.
-     */
-    void createPanoramaAction();
-
-    /** Create Video Slideshow tool action.
-     */
-    void createVideoSlideshowAction();
-
-    /** Create HTML Gallery tool action.
-     */
-    void createHtmlGalleryAction();
-
-    /** Create Print Creator tool action.
-     */
-    void createPrintCreatorAction();
-
-    /** Create Send by Mail tool action.
-     */
-    void createSendByMailAction();
-
-    /** Create Media Server action to share through DLNA.
-     */
-    void createMediaServerAction();
-    
-    /** Create Ksane action to import from scanner.
-     */
-    void createKSaneAction();
-
     /** Create common actions to setup all digiKam main windows.
      */
     void createSettingsActions();
@@ -187,6 +139,20 @@ public:
      */
     bool fullScreenIsActive() const;
 
+public:
+
+    /** Register all generic plugins action to this instance.
+     *  Call registerExtraPluginsActions() to plug oter kind of plugins in GUI.
+     */
+    void registerPluginsActions();
+    virtual void registerExtraPluginsActions(QString& /*dom*/) {};
+
+    /** Return the interface instance to access to items information.
+     */
+    virtual DInfoInterface* infoIface(DPluginAction* const ac) = 0;
+
+public:
+
     static void openHandbook();
     static void restoreWindowSize(QWindow* const win, const KConfigGroup& group);
     static void saveWindowSize(QWindow* const win, KConfigGroup& group);
@@ -203,23 +169,8 @@ public:
 
 protected:
 
-    QAction*     m_metadataEditAction;
-    QAction*     m_geolocationEditAction;
-    QAction*     m_presentationAction;
-    QAction*     m_calendarAction;
-    QAction*     m_htmlGalleryAction;
-    QAction*     m_printCreatorAction;
-    QAction*     m_sendByMailAction;
-    QAction*     m_expoBlendingAction;
-    QAction*     m_panoramaAction;
-    QAction*     m_videoslideshowAction;
-    QAction*     m_mediaServerAction;
     DLogoAction* m_animLogo;
 
-#ifdef HAVE_KSANE
-    KSaneAction* m_ksaneAction;
-#endif
-
 protected:
 
     QAction* showMenuBarAction()   const;
@@ -285,42 +236,6 @@ private Q_SLOTS:
     virtual void slotEditKeys()                { editKeyboardShortcuts(); };
     virtual void slotSetup() = 0;
 
-    // Called by KSane action.
-    virtual void slotImportFromScanner()       {};
-
-    // Called by Metadata Edit tool.
-    virtual void slotEditMetadata()            {};
-
-    // Called by Geolocation Edit tool.
-    virtual void slotEditGeolocation()         {};
-
-    // Called by Presentation tool.
-    virtual void slotPresentation()            {};
-
-    // Called by SendByMail tool.
-    virtual void slotSendByMail()              {};
-
-    // Called by PrintCreator tool.
-    virtual void slotPrintCreator()            {};
-
-    // Called by HTML Gallery tool.
-    virtual void slotHTMLGallery()             {};
-
-    // Called by Calendar tool.
-    virtual void slotCalendar()                {};
-
-    // Called by Video Slideshow tool.
-    virtual void slotVideoSlideshow()          {};
-
-    // Called by Panorama tool.
-    virtual void slotPanorama()                {};
-
-    // Called by Exposure Blending tool.
-    virtual void slotExpoBlending()            {};
-
-    // Called by Media Server tool.
-    virtual void slotMediaServer()             {};
-    
 private:
 
     /** Used by slotToggleFullScreen() to switch tool-bar visibility in managed window
@@ -339,4 +254,4 @@ private:
 
 } // namespace Digikam
 
-#endif // DXML_GUI_WINDOW_H
+#endif // DIGIKAM_DXML_GUI_WINDOW_H
