@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-04-15
  * Description : a zoom bar used in status bar.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -52,12 +52,11 @@
 namespace Digikam
 {
 
-class DZoomBar::Private
+class Q_DECL_HIDDEN DZoomBar::Private
 {
-
 public:
 
-    Private()
+    explicit Private()
     {
         zoomToFitButton = 0;
         zoomTo100Button = 0;
