@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-04-29
  * Description : a full screen settings widget
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,6 +21,8 @@
  *
  * ============================================================ */
 
+#include "fullscreensettings.h"
+
 // Qt includes
 
 #include <QString>
@@ -36,16 +38,15 @@
 // Local includes
 
 #include "dxmlguiwindow.h"
-#include "fullscreensettings.h"
 
 namespace Digikam
 {
 
-class FullScreenSettings::Private
+class Q_DECL_HIDDEN FullScreenSettings::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         options      = FS_NONE;
         hideToolBars = 0;
@@ -64,7 +65,7 @@ FullScreenSettings::FullScreenSettings(int options, QWidget* const parent)
     : QGroupBox(i18n("Full-screen Options"), parent),
       d(new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing        = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     d->options               = options;
     QVBoxLayout* const vlay  = new QVBoxLayout(this);
