@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-02
  * Description : colors scheme manager
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2007      by Matthew Woehlke <mw_triad at users dot sourceforge dot net>
  *
  * This program is free software; you can redistribute it
@@ -43,7 +43,7 @@ namespace Digikam
 
 // HCY color space management
 
-class HCYColorSpace
+class Q_DECL_HIDDEN HCYColorSpace
 {
 public:
 
@@ -475,12 +475,14 @@ qreal HCYColorSpace::luma(const QColor& color)
 
 // -------------------------------------------------------------------------------------
 
-class StateEffects
+class Q_DECL_HIDDEN StateEffects
 {
 public:
 
     explicit StateEffects(QPalette::ColorGroup state, const KSharedConfigPtr&);
-    ~StateEffects() {}
+    ~StateEffects()
+    {
+    }
 
     QBrush brush(const QBrush& background) const;
     QBrush brush(const QBrush& foreground, const QBrush& background) const;
@@ -727,13 +729,15 @@ static const DecoDefaultColors defaultDecorationColors =
 
 // ------------------------------------------------------------------------------------
 
-class SchemeManagerPrivate : public QSharedData
+class Q_DECL_HIDDEN SchemeManagerPrivate : public QSharedData
 {
 public:
 
     explicit SchemeManagerPrivate(const KSharedConfigPtr&, QPalette::ColorGroup, const char*, SetDefaultColors);
     explicit SchemeManagerPrivate(const KSharedConfigPtr&, QPalette::ColorGroup, const char*, SetDefaultColors, const QBrush&);
-    ~SchemeManagerPrivate() {}
+    ~SchemeManagerPrivate()
+    {
+    }
 
     QBrush background(SchemeManager::BackgroundRole) const;
     QBrush foreground(SchemeManager::ForegroundRole) const;
@@ -822,7 +826,7 @@ void SchemeManagerPrivate::init(const KSharedConfigPtr& config,
     {
         StateEffects effects(state, config);
 
-        for (int i = 0; i < 8; i++)
+        for (int i = 0 ; i < 8 ; ++i)
         {
             _brushes.fg[i] = effects.brush(_brushes.fg[i], _brushes.bg[0]);
         }
@@ -1104,7 +1108,7 @@ QPalette SchemeManager::createApplicationPalette(const KSharedConfigPtr& config)
     // TT thinks tooltips shouldn't use active, so we use our active colors for all states
     SchemeManager schemeTooltip(QPalette::Active, SchemeManager::Tooltip, config);
 
-    for (int i = 0; i < 3; i++)
+    for (int i = 0 ; i < 3 ; ++i)
     {
         QPalette::ColorGroup state = states[i];
         SchemeManager schemeView(state,      SchemeManager::View,      config);
@@ -1137,4 +1141,4 @@ QPalette SchemeManager::createApplicationPalette(const KSharedConfigPtr& config)
     return palette;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
