@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-03-22
  * Description : a widget to manage sidebar in GUI.
  *
  * Copyright (C) 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2001-2003 by Joseph Wenninger <jowenn at kde dot org>
  *
@@ -54,7 +54,7 @@
 namespace Digikam
 {
 
-class DMultiTabBarFrame::Private
+class Q_DECL_HIDDEN DMultiTabBarFrame::Private
 {
 public:
 
@@ -79,7 +79,7 @@ DMultiTabBarFrame::DMultiTabBarFrame(QWidget* const parent, Qt::Edge pos)
     d->mainLayout->setSpacing(0);
     d->mainLayout->addStretch();
     setFrameStyle(NoFrame);
-    setBackgroundRole(QPalette::Background);
+    setBackgroundRole(QPalette::Window);
 }
 
 DMultiTabBarFrame::~DMultiTabBarFrame()
@@ -93,7 +93,7 @@ void DMultiTabBarFrame::setStyle(DMultiTabBar::TextStyle style)
 {
     d->style = style;
 
-    for (int i = 0 ; i < d->tabs.count() ; i++)
+    for (int i = 0 ; i < d->tabs.count() ; ++i)
         d->tabs.at(i)->setStyle(d->style);
 
     updateGeometry();
@@ -137,7 +137,7 @@ int DMultiTabBarFrame::appendTab(const QPixmap& pic, int id, const QString& text
 
 void DMultiTabBarFrame::removeTab(int id)
 {
-    for (int pos = 0 ; pos < d->tabs.count() ; pos++)
+    for (int pos = 0 ; pos < d->tabs.count() ; ++pos)
     {
         if (d->tabs.at(pos)->id() == id)
         {
@@ -152,7 +152,7 @@ void DMultiTabBarFrame::setPosition(Qt::Edge pos)
 {
     d->position = pos;
 
-    for (int i = 0 ; i < d->tabs.count() ; i++)
+    for (int i = 0 ; i < d->tabs.count() ; ++i)
         d->tabs.at(i)->setPosition(d->position);
 
     updateGeometry();
@@ -233,7 +233,7 @@ void DMultiTabBarButton::paintEvent(QPaintEvent*)
 
 // -------------------------------------------------------------------------------------
 
-class DMultiTabBarTab::Private
+class Q_DECL_HIDDEN DMultiTabBarTab::Private
 {
 public:
 
@@ -537,7 +537,7 @@ void DMultiTabBarTab::paintEvent(QPaintEvent*)
 
 // -------------------------------------------------------------------------------------
 
-class DMultiTabBar::Private
+class Q_DECL_HIDDEN DMultiTabBar::Private
 {
 public:
 
@@ -555,12 +555,12 @@ DMultiTabBar::DMultiTabBar(Qt::Edge pos, QWidget* const parent)
     if (pos == Qt::LeftEdge || pos == Qt::RightEdge)
     {
         d->layout = new QVBoxLayout(this);
-        setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding/*, true*/);
+        setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
     }
     else
     {
         d->layout = new QHBoxLayout(this);
-        setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed/*, true*/);
+        setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     }
 
     d->layout->setContentsMargins(QMargins());
@@ -647,7 +647,7 @@ DMultiTabBarTab* DMultiTabBar::tab(int id) const
 
 void DMultiTabBar::removeButton(int id)
 {
-    for (int pos = 0 ; pos < d->buttons.count() ; pos++)
+    for (int pos = 0 ; pos < d->buttons.count() ; ++pos)
     {
         if (d->buttons.at(pos)->id() == id)
         {
@@ -711,7 +711,7 @@ void DMultiTabBar::fontChange(const QFont&)
 
 // -------------------------------------------------------------------------------------
 
-class SidebarState
+class Q_DECL_HIDDEN SidebarState
 {
 
 public:
@@ -734,13 +734,13 @@ public:
 
 // -------------------------------------------------------------------------------------
 
-class Sidebar::Private
+class Q_DECL_HIDDEN Sidebar::Private
 {
 
 public:
 
-    Private() :
-        minimizedDefault(false),
+    explicit Private()
+      : minimizedDefault(false),
         minimized(false),
         isMinimized(false),
         tabs(0),
@@ -779,7 +779,7 @@ public:
     const QString                 optionRestoreSizeEntry;
 };
 
-class SidebarSplitter::Private
+class Q_DECL_HIDDEN SidebarSplitter::Private
 {
 public:
 
@@ -873,7 +873,7 @@ void Sidebar::backup(const QList<QWidget*> thirdWidgetsToBackup, QList<int>* con
 {
     sizes->clear();
 
-    foreach(QWidget* const widget, thirdWidgetsToBackup)
+    foreach (QWidget* const widget, thirdWidgetsToBackup)
     {
         *sizes << d->splitter->size(widget);
     }
@@ -898,7 +898,7 @@ void Sidebar::restore(const QList<QWidget*> thirdWidgetsToRestore, const QList<i
 
     if (thirdWidgetsToRestore.size() == sizes.size())
     {
-        for (int i=0; i<thirdWidgetsToRestore.size(); ++i)
+        for (int i = 0 ; i < thirdWidgetsToRestore.size() ; ++i)
         {
             d->splitter->setSize(thirdWidgetsToRestore.at(i), sizes.at(i));
         }
@@ -1101,6 +1101,11 @@ void Sidebar::expand()
     d->minimized = false;
     d->stack->show();
 
+    QTimer::singleShot(0, this, SLOT(slotExpandTimer()));
+}
+
+void Sidebar::slotExpandTimer()
+{
     // Do not expand to size 0 (only splitter handle visible)
     // but either to previous size, or the minimum size hint
     if (d->splitter->size(this) == 0)
@@ -1119,11 +1124,11 @@ bool Sidebar::isExpanded() const
 
 bool Sidebar::eventFilter(QObject* obj, QEvent* ev)
 {
-    for (int i = 0 ; i < d->tabs; ++i)
+    for (int i = 0 ; i < d->tabs ; ++i)
     {
-        if ( obj == tab(i) )
+        if (obj == tab(i))
         {
-            if ( ev->type() == QEvent::DragEnter)
+            if (ev->type() == QEvent::DragEnter)
             {
                 QDragEnterEvent* const e = static_cast<QDragEnterEvent*>(ev);
                 enterEvent(e);
@@ -1199,7 +1204,7 @@ SidebarSplitter::SidebarSplitter(Qt::Orientation orientation, QWidget* const par
 SidebarSplitter::~SidebarSplitter()
 {
     // retreat cautiously from sidebars that live longer
-    foreach(Sidebar* const sidebar, d->sidebars)
+    foreach (Sidebar* const sidebar, d->sidebars)
     {
         sidebar->d->splitter = 0;
     }
@@ -1304,7 +1309,7 @@ void SidebarSplitter::slotSplitterMoved(int pos, int index)
     {
         QWidget* const w = widget(index-1);
 
-        foreach(Sidebar* const sidebar, d->sidebars)
+        foreach (Sidebar* const sidebar, d->sidebars)
         {
             if (w == sidebar->d->stack)
             {
@@ -1325,7 +1330,7 @@ void SidebarSplitter::slotSplitterMoved(int pos, int index)
     {
         QWidget* const w = widget(index);
 
-        foreach(Sidebar* sidebar, d->sidebars)
+        foreach (Sidebar* const sidebar, d->sidebars)
         {
             if (w == sidebar->d->stack)
             {
@@ -1341,4 +1346,4 @@ void SidebarSplitter::slotSplitterMoved(int pos, int index)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
