@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-03-22
  * Description : a widget to manage sidebar in GUI.
  *
  * Copyright (C) 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * Copyright (C) 2006-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2001-2003 by Joseph Wenninger <jowenn at kde dot org>
  *
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef SIDE_BAR_H
-#define SIDE_BAR_H
+#ifndef DIGIKAM_SIDE_BAR_H
+#define DIGIKAM_SIDE_BAR_H
 
 // Qt includes
 
@@ -79,7 +79,7 @@ public:
      * append  a new button to the button area. The button can later on be accessed with button(ID)
      * eg for connecting signals to it
      * @param pic a pixmap for the button
-     * @param id an arbitraty ID value. It will be emitted in the clicked signal for identifying the button
+     * @param id an arbitrary ID value. It will be emitted in the clicked signal for identifying the button
      *  if more than one button is connected to a signals.
      * @param popup A popup menu which should be displayed if the button is clicked
      * @param not_used_yet will be used for a popup text in the future
@@ -92,7 +92,7 @@ public:
     void removeButton(int id);
 
     /**
-     * append a new tab to the tab area. It can be accessed lateron with tabb(id);
+     * append a new tab to the tab area. It can be accessed later on with tabb(id);
      * @param pic a bitmap for the tab
      * @param id an arbitrary ID which can be used later on to identify the tab
      * @param text if a mode with text is used it will be the tab text, otherwise a mouse over hint
@@ -122,7 +122,7 @@ public:
     DMultiTabBarButton* button(int id) const;
 
     /**
-     * get a pointer to a tab within the tab area, identiifed by its ID
+     * get a pointer to a tab within the tab area, identified by its ID
      */
     DMultiTabBarTab* tab(int id) const;
 
@@ -221,13 +221,13 @@ public:
 public Q_SLOTS:
 
     /**
-     * this is used internaly, but can be used by the user.
+     * this is used internally, but can be used by the user.
      * It the according call of DMultiTabBar is invoked though this modifications will be overwritten
      */
     void setPosition(Qt::Edge);
 
     /**
-     * this is used internaly, but can be used by the user.
+     * this is used internally, but can be used by the user.
      * It the according call of DMultiTabBar is invoked though this modifications will be overwritten
      */
     void setStyle(DMultiTabBar::TextStyle);
@@ -359,12 +359,12 @@ public:
     void setActiveTab(QWidget* const w);
 
     /**
-     * Activates a next tab from current one. If current one is last, first one is actived.
+     * Activates a next tab from current one. If current one is last, first one is activated.
      */
     void activeNextTab();
 
     /**
-     * Activates a previous tab from current one. If current one is first, last one is actived.
+     * Activates a previous tab from current one. If current one is first, last one is activated.
      */
     void activePreviousTab();
 
@@ -435,6 +435,7 @@ private Q_SLOTS:
      */
     void clicked(int tab);
 
+    void slotExpandTimer();
     void slotDragSwitchTimer();
 
     void slotSplitterBtnClicked();
@@ -527,4 +528,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SIDE_BAR_H
+#endif // DIGIKAM_SIDE_BAR_H
