@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-15-08
  * Description : A floatable/dockable widget for thumbnail bars (ThumbBarView
@@ -25,8 +25,8 @@
  *
  * ============================================================ */
 
-#ifndef THUMB_BAR_DOCK_H
-#define THUMB_BAR_DOCK_H
+#ifndef DIGIKAM_THUMB_BAR_DOCK_H
+#define DIGIKAM_THUMB_BAR_DOCK_H
 
 // Qt includes
 
@@ -137,4 +137,4 @@ private:
 
 } // namespace Digikam
 
-#endif // THUMB_BAR_DOCK_H
+#endif // DIGIKAM_THUMB_BAR_DOCK_H
