@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-01-28
  * Description : color label widget
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef COLORLABELWIDGET_H
-#define COLORLABELWIDGET_H
+#ifndef DIGIKAM_COLOR_LABEL_WIDGET_H
+#define DIGIKAM_COLOR_LABEL_WIDGET_H
 
 // Qt includes
 
@@ -52,7 +52,7 @@ public:
     virtual ~ColorLabelWidget();
 
     /**
-     * Show or not on the bottom view the description of label with shorcuts.
+     * Show or not on the bottom view the description of label with shortcuts.
      */
     void setDescriptionBoxVisible(bool b);
 
@@ -145,4 +145,4 @@ Q_SIGNALS:
 
 Q_DECLARE_METATYPE(QList<Digikam::ColorLabel>)
 
-#endif // COLORLABELWIDGET_H
+#endif // DIGIKAM_COLOR_LABEL_WIDGET_H
