@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-02-20
  * Description : a widget to display Standard Exif metadata
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef EXIFWIDGET_H
-#define EXIFWIDGET_H
+#ifndef DIGIKAM_EXIF_WIDGET_H
+#define DIGIKAM_EXIF_WIDGET_H
 
 // Qt includes
 
@@ -68,4 +68,4 @@ private:
 
 } // namespace Digikam
 
-#endif // EXIFWIDGET_H
+#endif // DIGIKAM_EXIF_WIDGET_H
