@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-02-20
  * Description : A widget to display IPTC metadata
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IPTCWIDGET_H
-#define IPTCWIDGET_H
+#ifndef DIGIKAM_IPTC_WIDGET_H
+#define DIGIKAM_IPTC_WIDGET_H
 
 // Local includes
 
@@ -64,4 +64,4 @@ private:
 
 } // namespace Digikam
 
-#endif // IPTCWIDGET_H
+#endif // DIGIKAM_IPTC_WIDGET_H
