@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-02-21
  * Description : a generic list view widget to
  *               display metadata
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -63,8 +63,8 @@ MetadataListView::MetadataListView(QWidget* const parent)
 
     m_parent = dynamic_cast<MetadataWidget*>(parent);
 
-    connect(this, SIGNAL(itemClicked(QTreeWidgetItem*, int)),
-            this, SLOT(slotSelectionChanged(QTreeWidgetItem*, int)));
+    connect(this, SIGNAL(itemClicked(QTreeWidgetItem*,int)),
+            this, SLOT(slotSelectionChanged(QTreeWidgetItem*,int)));
 }
 
 MetadataListView::~MetadataListView()
@@ -156,12 +156,12 @@ void MetadataListView::setIfdList(const DMetadata::MetaDataMap& ifds, const QStr
         // We checking if we have changed of ifDName
         QString currentIfDName = it.key().section(QLatin1Char('.'), 1, 1);
 
-        if ( currentIfDName != ifDItemName )
+        if (currentIfDName != ifDItemName)
         {
             ifDItemName = currentIfDName;
 
             // Check if the current IfD have any items. If no remove it before to toggle to the next IfD.
-            if ( subItems == 0 && parentifDItem)
+            if (subItems == 0 && parentifDItem)
             {
                 delete parentifDItem;
             }
@@ -193,7 +193,7 @@ void MetadataListView::setIfdList(const DMetadata::MetaDataMap& ifds, const QStr
                 // We using the filter to make a more user friendly output (Custom Mode)
 
                 // Filter is not a list of complete tag keys
-                if (!filters.at(0).contains(QLatin1String(".")) && filters.contains(it.key().section(QLatin1Char('.'), 2, 2)))
+                if (!filters.at(0).contains(QLatin1Char('.')) && filters.contains(it.key().section(QLatin1Char('.'), 2, 2)))
                 {
                     QString tagTitle = m_parent->getTagTitle(it.key());
                     new MetadataListViewItem(parentifDItem, it.key(), tagTitle, it.value());
@@ -212,13 +212,13 @@ void MetadataListView::setIfdList(const DMetadata::MetaDataMap& ifds, const QStr
     }
 
     // To check if the last IfD have any items...
-    if ( subItems == 0 && parentifDItem)
+    if (subItems == 0 && parentifDItem)
     {
         delete parentifDItem;
     }
 
     // Add not found tags from filter as grey items.
-    if (!filters.isEmpty() && filters.at(0) != QLatin1String("FULL") && filters.at(0).contains(QLatin1String(".")))
+    if (!filters.isEmpty() && filters.at(0) != QLatin1String("FULL") && filters.at(0).contains(QLatin1Char('.')))
     {
         foreach(const QString& key, filters)
         {
@@ -265,7 +265,7 @@ void MetadataListView::setIfdList(const DMetadata::MetaDataMap& ifds, const QStr
         {
             --it;
 
-            if ( *itKeysFilter == it.key().section(QLatin1Char('.'), 1, 1) )
+            if (*itKeysFilter == it.key().section(QLatin1Char('.'), 1, 1))
             {
                 if (filters.isEmpty())
                 {
@@ -290,7 +290,7 @@ void MetadataListView::setIfdList(const DMetadata::MetaDataMap& ifds, const QStr
                         // We using the filter to make a more user friendly output (Custom Mode)
 
                         // Filter is not a list of complete tag keys
-                        if (!filters.at(0).contains(QLatin1String(".")) && filters.contains(it.key().section(QLatin1Char('.'), 2, 2)))
+                        if (!filters.at(0).contains(QLatin1Char('.')) && filters.contains(it.key().section(QLatin1Char('.'), 2, 2)))
                         {
                             QString tagTitle = m_parent->getTagTitle(it.key());
                             new MetadataListViewItem(parentifDItem, it.key(), tagTitle, it.value());
@@ -310,14 +310,14 @@ void MetadataListView::setIfdList(const DMetadata::MetaDataMap& ifds, const QStr
         }
 
         // We checking if the last IfD have any items. If no, we remove it.
-        if ( subItems == 0 && parentifDItem)
+        if (subItems == 0 && parentifDItem)
         {
             delete parentifDItem;
         }
     }
 
     // Add not found tags from filter as grey items.
-    if (!filters.isEmpty() && filters.at(0) != QLatin1String("FULL") && filters.at(0).contains(QLatin1String(".")))
+    if (!filters.isEmpty() && filters.at(0) != QLatin1String("FULL") && filters.at(0).contains(QLatin1Char('.')))
     {
         foreach(const QString& key, filters)
         {
@@ -441,4 +441,4 @@ MdKeyListViewItem* MetadataListView::findMdKeyItem(const QString& key)
     return 0;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
