@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-07-16
  * Description : metadata selector.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -121,12 +121,12 @@ void MetadataSelector::setTagsMap(const DMetadata::TagsMap& map)
         // We checking if we have changed of ifDName
         currentIfDName = it.key().section(QLatin1Char('.'), 1, 1);
 
-        if ( currentIfDName != ifDItemName )
+        if (currentIfDName != ifDItemName)
         {
             ifDItemName = currentIfDName;
 
             // Check if the current IfD have any items. If not, remove it before to toggle to the next IfD.
-            if ( subItems == 0 && parentifDItem)
+            if (subItems == 0 && parentifDItem)
             {
                 delete parentifDItem;
             }
@@ -240,11 +240,11 @@ void MetadataSelector::selectAll()
 
 // ------------------------------------------------------------------------------------
 
-class MetadataSelectorView::Private
+class Q_DECL_HIDDEN MetadataSelectorView::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         selectAllBtn        = 0;
         clearSelectionBtn   = 0;
@@ -487,4 +487,4 @@ void MetadataSelectorView::selectDefault()
     slotDeflautSelection();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
