@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-07-16
  * Description : metadata selector.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef METADATA_SELECTOR_H
-#define METADATA_SELECTOR_H
+#ifndef DIGIKAM_META_DATA_SELECTOR_H
+#define DIGIKAM_META_DATA_SELECTOR_H
 
 // Qt includes
 
@@ -94,6 +94,8 @@ public:
     };
     Q_DECLARE_FLAGS(ControlElements, ControlElement)
 
+public:
+
     explicit MetadataSelectorView(QWidget* const parent);
     virtual ~MetadataSelectorView();
 
@@ -127,6 +129,8 @@ private:
 
 private:
 
+    MetadataSelectorView(); // Disable default constructor.
+
     class Private;
     Private* const d;
 };
@@ -135,4 +139,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::MetadataSelectorView::ControlElements)
 
-#endif // METADATA_SELECTOR_H
+#endif // DIGIKAM_META_DATA_SELECTOR_H
