@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-02-22
  * Description : a generic widget to display metadata
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -66,12 +66,12 @@
 namespace Digikam
 {
 
-class MetadataWidget::Private
+class Q_DECL_HIDDEN MetadataWidget::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         view           = 0;
         mainLayout     = 0;
@@ -99,6 +99,10 @@ public:
 
     QStringList            tagsFilter;
 
+    QAction*               saveMetadata;
+    QAction*               printMetadata;
+    QAction*               copy2ClipBoard;
+
     QMenu*                 optionsMenu;
 
     MetadataListView*      view;
@@ -116,8 +120,7 @@ MetadataWidget::MetadataWidget(QWidget* const parent, const QString& name)
     setObjectName(name);
 
     const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-
-    d->mainLayout = new QGridLayout(this);
+    d->mainLayout     = new QGridLayout(this);
 
     // -----------------------------------------------------------------
 
@@ -154,14 +157,13 @@ MetadataWidget::MetadataWidget(QWidget* const parent, const QString& name)
     d->toolBtn->setPopupMode(QToolButton::InstantPopup);
     d->toolBtn->setWhatsThis(i18n("Run tool over metadata tags."));
 
-    QMenu* const toolMenu         = new QMenu(d->toolBtn);
-    QAction* const saveMetadata   = toolMenu->addAction(i18nc("@action:inmenu", "Save in file"));
-    QAction* const printMetadata  = toolMenu->addAction(i18nc("@action:inmenu", "Print"));
-    QAction* const copy2ClipBoard = toolMenu->addAction(i18nc("@action:inmenu", "Copy to Clipboard"));
+    QMenu* const toolMenu = new QMenu(d->toolBtn);
+    d->saveMetadata       = toolMenu->addAction(i18nc("@action:inmenu", "Save in file"));
+    d->printMetadata      = toolMenu->addAction(i18nc("@action:inmenu", "Print"));
+    d->copy2ClipBoard     = toolMenu->addAction(i18nc("@action:inmenu", "Copy to Clipboard"));
     d->toolBtn->setMenu(toolMenu);
 
     d->view         = new MetadataListView(this);
-
     QString barName = name + QLatin1String("SearchBar");
     d->searchBar    = new SearchTextBar(this, barName);
 
@@ -175,19 +177,25 @@ MetadataWidget::MetadataWidget(QWidget* const parent, const QString& name)
     d->mainLayout->setRowStretch(1, 10);
     d->mainLayout->setContentsMargins(spacing, spacing, spacing, spacing);
     d->mainLayout->setSpacing(0);
+}
 
-    // -----------------------------------------------------------------
+MetadataWidget::~MetadataWidget()
+{
+    delete d;
+}
 
+void MetadataWidget::setup()
+{
     connect(d->optionsMenu, SIGNAL(triggered(QAction*)),
             this, SLOT(slotFilterChanged(QAction*)));
 
-    connect(copy2ClipBoard, SIGNAL(triggered(bool)),
+    connect(d->copy2ClipBoard, SIGNAL(triggered(bool)),
             this, SLOT(slotCopy2Clipboard()));
 
-    connect(printMetadata, SIGNAL(triggered(bool)),
+    connect(d->printMetadata, SIGNAL(triggered(bool)),
             this, SLOT(slotPrintMetadata()));
 
-    connect(saveMetadata, SIGNAL(triggered(bool)),
+    connect(d->saveMetadata, SIGNAL(triggered(bool)),
             this, SLOT(slotSaveMetadataToFile()));
 
     connect(d->searchBar, SIGNAL(signalSearchTextSettings(SearchTextSettings)),
@@ -197,11 +205,6 @@ MetadataWidget::MetadataWidget(QWidget* const parent, const QString& name)
             d->searchBar, SLOT(slotSearchResult(bool)));
 }
 
-MetadataWidget::~MetadataWidget()
-{
-    delete d;
-}
-
 void MetadataWidget::slotFilterChanged(QAction* action)
 {
     if (action == d->settingsAction)
@@ -279,14 +282,14 @@ const DMetadata& MetadataWidget::getMetadata()
 
 bool MetadataWidget::storeMetadataToFile(const QUrl& url, const QByteArray& metaData)
 {
-    if ( url.isEmpty() )
+    if (url.isEmpty())
     {
         return false;
     }
 
     QFile file(url.toLocalFile());
 
-    if ( !file.open(QIODevice::WriteOnly) )
+    if (!file.open(QIODevice::WriteOnly))
     {
         return false;
     }
@@ -348,7 +351,7 @@ void MetadataWidget::slotCopy2Clipboard()
                     textmetadata.append(lvItem2->text(0));
                     textmetadata.append(QLatin1String(" : "));
                     textmetadata.append(lvItem2->text(1));
-                    textmetadata.append(QLatin1String("\n"));
+                    textmetadata.append(QLatin1Char('\n'));
                 }
 
                 ++j;
@@ -432,8 +435,8 @@ void MetadataWidget::slotPrintMetadata()
 QUrl MetadataWidget::saveMetadataToFile(const QString& caption, const QString& fileFilter)
 {
     QPointer<DFileDialog> fileSaveDialog = new DFileDialog(this, caption, QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
-    fileSaveDialog->setAcceptMode(DFileDialog::AcceptSave);
-    fileSaveDialog->setFileMode(DFileDialog::AnyFile);
+    fileSaveDialog->setAcceptMode(QFileDialog::AcceptSave);
+    fileSaveDialog->setFileMode(QFileDialog::AnyFile);
     fileSaveDialog->selectFile(d->fileName);
     fileSaveDialog->setNameFilter(fileFilter);
 
@@ -521,4 +524,4 @@ void MetadataWidget::buildView()
     d->view->slotSearchTextChanged(d->searchBar->searchTextSettings());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
