@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-02-14
  * Description : pick label widget
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,12 +50,12 @@
 namespace Digikam
 {
 
-class PickLabelWidget::Private
+class Q_DECL_HIDDEN PickLabelWidget::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         pickBtns = 0;
         btnNone  = 0;
@@ -188,36 +188,36 @@ void PickLabelWidget::updateDescription(PickLabel label)
 
 bool PickLabelWidget::eventFilter(QObject* obj, QEvent* ev)
 {
-    if ( obj == d->btnNone)
+    if (obj == d->btnNone)
     {
-        if ( ev->type() == QEvent::Enter)
+        if (ev->type() == QEvent::Enter)
         {
             updateDescription(NoPickLabel);
             return false;
         }
     }
 
-    if ( obj == d->btnRej)
+    if (obj == d->btnRej)
     {
-        if ( ev->type() == QEvent::Enter)
+        if (ev->type() == QEvent::Enter)
         {
             updateDescription(RejectedLabel);
             return false;
         }
     }
 
-    if ( obj == d->btnPndg)
+    if (obj == d->btnPndg)
     {
-        if ( ev->type() == QEvent::Enter)
+        if (ev->type() == QEvent::Enter)
         {
             updateDescription(PendingLabel);
             return false;
         }
     }
 
-    if ( obj == d->btnAccpt)
+    if (obj == d->btnAccpt)
     {
-        if ( ev->type() == QEvent::Enter)
+        if (ev->type() == QEvent::Enter)
         {
             updateDescription(AcceptedLabel);
             return false;
@@ -297,12 +297,12 @@ QString PickLabelWidget::labelPickName(PickLabel label)
 
 // -----------------------------------------------------------------------------
 
-class PickLabelSelector::Private
+class Q_DECL_HIDDEN PickLabelSelector::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         plw = 0;
     }
@@ -385,4 +385,4 @@ PickLabelMenuAction::~PickLabelMenuAction()
 {
 }
 
-}  // namespace Digikam
+} // namespace Digikam
