@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-08-15
  * Description : a widget to draw stars rating
  *
  * Copyright (C) 2005      by Owen Hirst <n8rider@sbcglobal.net>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,11 +55,11 @@
 namespace Digikam
 {
 
-class RatingWidget::Private
+class Q_DECL_HIDDEN RatingWidget::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         tracking       = true;
         isHovered      = false;
@@ -470,12 +470,12 @@ void RatingWidget::applyFading(QPixmap& pix)
 
 // -------------------------------------------------------------------------------
 
-class RatingBox::Private
+class Q_DECL_HIDDEN RatingBox::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         shortcut     = 0;
         ratingWidget = 0;
@@ -557,4 +557,4 @@ RatingMenuAction::~RatingMenuAction()
 {
 }
 
-}  // namespace Digikam
+} // namespace Digikam
