@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-08-15
  * Description : a widget to draw stars rating
  *
  * Copyright (C) 2005      by Owen Hirst <n8rider@sbcglobal.net>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef RATINGWIDGET_H
-#define RATINGWIDGET_H
+#ifndef DIGIKAM_RATING_WIDGET_H
+#define DIGIKAM_RATING_WIDGET_H
 
 // Qt includes
 
@@ -151,4 +151,4 @@ Q_SIGNALS:
 
 } // namespace Digikam
 
-#endif // RATINGWIDGET_H
+#endif // DIGIKAM_RATING_WIDGET_H
