@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-10-15
  * Description : IPTC subjects editor.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
@@ -64,7 +64,7 @@ public:
 
 public:
 
-    Private()
+    explicit Private()
     {
         addSubjectButton = 0;
         delSubjectButton = 0;
@@ -120,7 +120,7 @@ SubjectWidget::SubjectWidget(QWidget* const parent)
     // See http://iptc.cms.apa.at/std/topicset/topicset.iptc-subjectcode.xml for details.
 
     QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                          QString::fromLatin1("digikam/metadata/topicset.iptc-subjectcode.xml"));
+                                          QLatin1String("digikam/metadata/topicset.iptc-subjectcode.xml"));
 
     if (!loadSubjectCodesFromXML(QUrl::fromLocalFile(path)))
         qCDebug(DIGIKAM_WIDGETS_LOG) << "Cannot load IPTC/NAA subject codes XML database";
@@ -128,7 +128,7 @@ SubjectWidget::SubjectWidget(QWidget* const parent)
     // --------------------------------------------------------
 
     // Subject Reference Number only accept digit.
-    QRegExp refDigitRx(QString::fromLatin1("^[0-9]{8}$"));
+    QRegExp refDigitRx(QLatin1String("^[0-9]{8}$"));
     QValidator* const refValidator = new QRegExpValidator(refDigitRx, this);
 
     // --------------------------------------------------------
@@ -209,9 +209,9 @@ SubjectWidget::SubjectWidget(QWidget* const parent)
     d->addSubjectButton = new QPushButton(i18n("&Add"));
     d->delSubjectButton = new QPushButton(i18n("&Delete"));
     d->repSubjectButton = new QPushButton(i18n("&Replace"));
-    d->addSubjectButton->setIcon(QIcon::fromTheme(QString::fromLatin1("list-add")).pixmap(16, 16));
-    d->delSubjectButton->setIcon(QIcon::fromTheme(QString::fromLatin1("edit-delete")).pixmap(16, 16));
-    d->repSubjectButton->setIcon(QIcon::fromTheme(QString::fromLatin1("view-refresh")).pixmap(16, 16));
+    d->addSubjectButton->setIcon(QIcon::fromTheme(QLatin1String("list-add")).pixmap(16, 16));
+    d->delSubjectButton->setIcon(QIcon::fromTheme(QLatin1String("edit-delete")).pixmap(16, 16));
+    d->repSubjectButton->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")).pixmap(16, 16));
     d->delSubjectButton->setEnabled(false);
     d->repSubjectButton->setEnabled(false);
 
@@ -370,13 +370,13 @@ void SubjectWidget::slotRefChanged()
 QString SubjectWidget::buildSubject() const
 {
     QString subject = m_iprEdit->text();
-    subject.append(QString::fromLatin1(":"));
+    subject.append(QLatin1Char(':'));
     subject.append(m_refEdit->text());
-    subject.append(QString::fromLatin1(":"));
+    subject.append(QLatin1Char(':'));
     subject.append(m_nameEdit->text());
-    subject.append(QString::fromLatin1(":"));
+    subject.append(QLatin1Char(':'));
     subject.append(m_matterEdit->text());
-    subject.append(QString::fromLatin1(":"));
+    subject.append(QLatin1Char(':'));
     subject.append(m_detailEdit->text());
     return subject;
 }
@@ -413,11 +413,11 @@ void SubjectWidget::slotSubjectSelectionChanged()
     if (!d->subjectsBox->selectedItems().isEmpty())
     {
         QString subject = d->subjectsBox->selectedItems()[0]->text();
-        m_iprEdit->setText(subject.section(QString::fromLatin1(":"), 0, 0));
-        m_refEdit->setText(subject.section(QString::fromLatin1(":"), 1, 1));
-        m_nameEdit->setText(subject.section(QString::fromLatin1(":"), 2, 2));
-        m_matterEdit->setText(subject.section(QString::fromLatin1(":"), 3, 3));
-        m_detailEdit->setText(subject.section(QString::fromLatin1(":"), 4, 4));
+        m_iprEdit->setText(subject.section(QLatin1Char(':'), 0, 0));
+        m_refEdit->setText(subject.section(QLatin1Char(':'), 1, 1));
+        m_nameEdit->setText(subject.section(QLatin1Char(':'), 2, 2));
+        m_matterEdit->setText(subject.section(QLatin1Char(':'), 3, 3));
+        m_detailEdit->setText(subject.section(QLatin1Char(':'), 4, 4));
         d->delSubjectButton->setEnabled(true);
         d->repSubjectButton->setEnabled(true);
     }
@@ -436,7 +436,7 @@ void SubjectWidget::slotAddSubject()
 
     bool found = false;
 
-    for (int i = 0 ; i < d->subjectsBox->count(); i++)
+    for (int i = 0 ; i < d->subjectsBox->count() ; ++i)
     {
         QListWidgetItem* const item = d->subjectsBox->item(i);
 
@@ -465,15 +465,21 @@ bool SubjectWidget::loadSubjectCodesFromXML(const QUrl& url)
     if (!xmlfile.open(QIODevice::ReadOnly))
         return false;
 
-    QDomDocument xmlDoc(QString::fromLatin1("NewsML"));
+    QDomDocument xmlDoc(QLatin1String("NewsML"));
 
     if (!xmlDoc.setContent(&xmlfile))
+    {
+        xmlfile.close();
         return false;
+    }
 
     QDomElement xmlDocElem = xmlDoc.documentElement();
 
-    if (xmlDocElem.tagName() != QString::fromLatin1("NewsML"))
+    if (xmlDocElem.tagName() != QLatin1String("NewsML"))
+    {
+        xmlfile.close();
         return false;
+    }
 
     for (QDomNode nbE1 = xmlDocElem.firstChild();
          !nbE1.isNull(); nbE1 = nbE1.nextSibling())
@@ -481,7 +487,7 @@ bool SubjectWidget::loadSubjectCodesFromXML(const QUrl& url)
         QDomElement newsItemElement = nbE1.toElement();
 
         if (newsItemElement.isNull()) continue;
-        if (newsItemElement.tagName() != QString::fromLatin1("NewsItem")) continue;
+        if (newsItemElement.tagName() != QLatin1String("NewsItem")) continue;
 
         for (QDomNode nbE2 = newsItemElement.firstChild();
             !nbE2.isNull(); nbE2 = nbE2.nextSibling())
@@ -489,7 +495,7 @@ bool SubjectWidget::loadSubjectCodesFromXML(const QUrl& url)
             QDomElement topicSetElement = nbE2.toElement();
 
             if (topicSetElement.isNull()) continue;
-            if (topicSetElement.tagName() != QString::fromLatin1("TopicSet")) continue;
+            if (topicSetElement.tagName() != QLatin1String("TopicSet")) continue;
 
             for (QDomNode nbE3 = topicSetElement.firstChild();
                 !nbE3.isNull(); nbE3 = nbE3.nextSibling())
@@ -497,7 +503,7 @@ bool SubjectWidget::loadSubjectCodesFromXML(const QUrl& url)
                 QDomElement topicElement = nbE3.toElement();
 
                 if (topicElement.isNull()) continue;
-                if (topicElement.tagName() != QString::fromLatin1("Topic")) continue;
+                if (topicElement.tagName() != QLatin1String("Topic")) continue;
 
                 QString type, name, matter, detail, ref;
 
@@ -508,20 +514,20 @@ bool SubjectWidget::loadSubjectCodesFromXML(const QUrl& url)
 
                     if (topicSubElement.isNull()) continue;
 
-                    if (topicSubElement.tagName() == QString::fromLatin1("TopicType"))
-                        type = topicSubElement.attribute(QString::fromLatin1("FormalName"));
+                    if (topicSubElement.tagName() == QLatin1String("TopicType"))
+                        type = topicSubElement.attribute(QLatin1String("FormalName"));
 
-                    if (topicSubElement.tagName() == QString::fromLatin1("FormalName"))
+                    if (topicSubElement.tagName() == QLatin1String("FormalName"))
                         ref = topicSubElement.text();
 
-                    if (topicSubElement.tagName() == QString::fromLatin1("Description") &&
-                        topicSubElement.attribute(QString::fromLatin1("Variant")) == QString::fromLatin1("Name"))
+                    if (topicSubElement.tagName() == QLatin1String("Description") &&
+                        topicSubElement.attribute(QLatin1String("Variant")) == QLatin1String("Name"))
                     {
-                        if (type == QString::fromLatin1("Subject"))
+                        if (type == QLatin1String("Subject"))
                             name = topicSubElement.text();
-                        else if (type == QString::fromLatin1("SubjectMatter"))
+                        else if (type == QLatin1String("SubjectMatter"))
                             matter = topicSubElement.text();
-                        else if (type == QString::fromLatin1("SubjectDetail"))
+                        else if (type == QLatin1String("SubjectDetail"))
                             detail = topicSubElement.text();
                     }
                 }
@@ -531,6 +537,8 @@ bool SubjectWidget::loadSubjectCodesFromXML(const QUrl& url)
         }
     }
 
+    xmlfile.close();
+
     // Set the Subject Name everywhere on the map.
 
     for (Private::SubjectCodesMap::Iterator it = d->subMap.begin();
@@ -610,7 +618,7 @@ QStringList SubjectWidget::subjectsList() const
 {
     QStringList newSubjects;
 
-    for (int i = 0 ; i < d->subjectsBox->count(); i++)
+    for (int i = 0 ; i < d->subjectsBox->count() ; ++i)
     {
         QListWidgetItem* item = d->subjectsBox->item(i);
         newSubjects.append(item->text());
@@ -619,4 +627,4 @@ QStringList SubjectWidget::subjectsList() const
     return newSubjects;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
