@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-10-15
  * Description : IPTC subjects editor.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,19 +22,19 @@
  *
  * ============================================================ */
 
-#ifndef SUBJECTWIDGET_H
-#define SUBJECTWIDGET_H
+#ifndef DIGIKAM_SUBJECT_WIDGET_H
+#define DIGIKAM_SUBJECT_WIDGET_H
 
 // Qt includes
 
-#include <QtCore/QByteArray>
-#include <QtCore/QMap>
-#include <QtCore/QStringList>
-#include <QtCore/QUrl>
-#include <QtWidgets/QWidget>
-#include <QtWidgets/QCheckBox>
-#include <QtWidgets/QLabel>
-#include <QtWidgets/QLineEdit>
+#include <QByteArray>
+#include <QMap>
+#include <QStringList>
+#include <QUrl>
+#include <QWidget>
+#include <QCheckBox>
+#include <QLabel>
+#include <QLineEdit>
 
 // Local includes
 
@@ -67,7 +67,7 @@ class DIGIKAM_EXPORT SubjectWidget : public QWidget
 
 public:
 
-    SubjectWidget(QWidget* const parent);
+    explicit SubjectWidget(QWidget* const parent);
     ~SubjectWidget();
 
     void setSubjectsList(const QStringList& list);
@@ -112,4 +112,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SUBJECTWIDGET_H
+#endif // DIGIKAM_SUBJECT_WIDGET_H
