@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-08-09
  * Description : Generic range boxes, i.e. ranges where a minimum and maximum can be given.
@@ -37,7 +37,7 @@ class Q_DECL_HIDDEN DIntRangeBox::Private
 
 public:
 
-    Private()
+    explicit Private()
     {
         intervalLabel = 0;
         minValueBox   = 0;
@@ -138,7 +138,7 @@ void DIntRangeBox::slotMinimumChanged(int newValue)
     // Set the new minimum value of the maximum similarity
     d->maxValueBox->setMinimum(newValue);
 
-    // If the new value of the mimimum is now higher than the maximum similarity,
+    // If the new value of the minimum is now higher than the maximum similarity,
     // set the maximum similarity to the new value.
     if (newValue > d->maxValueBox->value())
     {
@@ -146,4 +146,4 @@ void DIntRangeBox::slotMinimumChanged(int newValue)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
