@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-11-30
  * Description : Save space slider widget
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Justin Noel <justin at ics dot com>
  * Copyright (C)      2010 by Cyrille Berger <cberger at cberger dot net>
  *
@@ -43,7 +43,7 @@
 namespace Digikam
 {
 
-class DAbstractSliderSpinBoxPrivate
+class Q_DECL_HIDDEN DAbstractSliderSpinBoxPrivate
 {
 public:
 
@@ -201,7 +201,7 @@ void DAbstractSliderSpinBox::paintEvent(QPaintEvent* e)
     painter.end();
 }
 
-void DAbstractSliderSpinBox::paint(QPainter &painter)
+void DAbstractSliderSpinBox::paint(QPainter& painter)
 {
     Q_D(DAbstractSliderSpinBox);
 
@@ -238,7 +238,7 @@ void DAbstractSliderSpinBox::paint(QPainter &painter)
     }
 }
 
-void DAbstractSliderSpinBox::paintFusion(QPainter &painter)
+void DAbstractSliderSpinBox::paintFusion(QPainter& painter)
 {
     Q_D(DAbstractSliderSpinBox);
 
@@ -307,7 +307,7 @@ void DAbstractSliderSpinBox::paintFusion(QPainter &painter)
     painter.restore();
 }
 
-void DAbstractSliderSpinBox::paintPlastique(QPainter &painter)
+void DAbstractSliderSpinBox::paintPlastique(QPainter& painter)
 {
     Q_D(DAbstractSliderSpinBox);
 
@@ -370,7 +370,7 @@ void DAbstractSliderSpinBox::paintPlastique(QPainter &painter)
     painter.restore();
 }
 
-void DAbstractSliderSpinBox::paintBreeze(QPainter &painter)
+void DAbstractSliderSpinBox::paintBreeze(QPainter& painter)
 {
     Q_D(DAbstractSliderSpinBox);
 
@@ -466,7 +466,7 @@ void DAbstractSliderSpinBox::mouseReleaseEvent(QMouseEvent* e)
     d->isDragging = false;
 
     // Step up/down for buttons
-    // Emualting mouse grab too
+    // Emulating mouse grab too
     if (upButtonRect(spinOpts).contains(e->pos()) && d->upButtonDown)
     {
         setInternalValue(d->value + d->singleStep);
@@ -945,11 +945,12 @@ void DAbstractSliderSpinBox::changeEvent(QEvent* e)
 
 // ---------------------------------------------------------------------------------------------
 
-class DSliderSpinBoxPrivate : public DAbstractSliderSpinBoxPrivate
+class Q_DECL_HIDDEN DSliderSpinBoxPrivate : public DAbstractSliderSpinBoxPrivate
 {
 };
 
-DSliderSpinBox::DSliderSpinBox(QWidget* parent) : DAbstractSliderSpinBox(parent, new DSliderSpinBoxPrivate)
+DSliderSpinBox::DSliderSpinBox(QWidget* const parent)
+    : DAbstractSliderSpinBox(parent, new DSliderSpinBoxPrivate)
 {
     setRange(0, 99);
 }
@@ -1050,11 +1051,12 @@ void DSliderSpinBox::setInternalValue(int _value, bool blockUpdateSignal)
 
 // ---------------------------------------------------------------------------------------------
 
-class DDoubleSliderSpinBoxPrivate : public DAbstractSliderSpinBoxPrivate
+class Q_DECL_HIDDEN DDoubleSliderSpinBoxPrivate : public DAbstractSliderSpinBoxPrivate
 {
 };
 
-DDoubleSliderSpinBox::DDoubleSliderSpinBox(QWidget* parent) : DAbstractSliderSpinBox(parent, new DDoubleSliderSpinBoxPrivate)
+DDoubleSliderSpinBox::DDoubleSliderSpinBox(QWidget* const parent)
+    : DAbstractSliderSpinBox(parent, new DDoubleSliderSpinBoxPrivate)
 {
 }
 
@@ -1166,4 +1168,4 @@ void DDoubleSliderSpinBox::setInternalValue(int _value, bool blockUpdateSignal)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
