@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-11-22
  * Description : showFoto is a stand alone version of image
  *               editor with no support of digiKam database.
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -41,10 +41,19 @@
 
 // Local includes
 
+#include "digikam_config.h"
+#include "digikam_debug.h"
+#include "digikam_globals.h"
+#include "digikam_version.h"
 #include "metaengine.h"
 #include "daboutdata.h"
 #include "showfoto.h"
-#include "digikam_version.h"
+
+#ifdef Q_OS_WIN
+#   include <windows.h>
+#   include <shellapi.h>
+#   include <objbase.h>
+#endif
 
 using namespace Digikam;
 
@@ -52,16 +61,22 @@ int main(int argc, char* argv[])
 {
     QApplication app(argc, argv);
 
+    tryInitDrMingw();
+
+#ifdef Q_OS_LINUX
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
+
     // if we have some local breeze icon resource, prefer it
     DXmlGuiWindow::setupIconTheme();
 
     KLocalizedString::setApplicationDomain("digikam");
 
-    KAboutData aboutData(QString::fromLatin1("showfoto"), // component name
-                         i18n("Showfoto"),                // display name
-                         digiKamVersion());               // NOTE: showFoto version = digiKam version
+    KAboutData aboutData(QLatin1String("showfoto"), // component name
+                         i18n("Showfoto"),          // display name
+                         digiKamVersion());         // NOTE: showFoto version = digiKam version
 
-    aboutData.setShortDescription(DAboutData::digiKamSlogan());;
+    aboutData.setShortDescription(QString::fromUtf8("%1 - %2").arg(DAboutData::digiKamSlogan()).arg(DAboutData::digiKamFamily()));
     aboutData.setLicense(KAboutLicense::GPL);
     aboutData.setCopyrightStatement(DAboutData::copyright());
     aboutData.setOtherText(additionalInformation());
@@ -91,7 +106,7 @@ int main(int argc, char* argv[])
     QList<QUrl> urlList;
     QStringList urls = parser.positionalArguments();
 
-    Q_FOREACH(const QString& url, urls)
+    foreach (const QString& url, urls)
     {
         urlList.append(QUrl::fromLocalFile(url));
     }
@@ -103,6 +118,11 @@ int main(int argc, char* argv[])
         QIcon::setThemeName(iconTheme);
     }
 
+#ifdef Q_OS_WIN
+    // Necessary to open native open with dialog on windows
+    CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
+#endif
+
     ShowFoto::ShowFoto* const w = new ShowFoto::ShowFoto(urlList);
 
     // If application storage place in home directory to save customized XML settings files do not exist, create it,
@@ -111,7 +131,7 @@ int main(int argc, char* argv[])
     {
         QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
     }
-    
+
     // If application cache place in home directory to save cached files do not exist, create it.
     if (!QFile::exists(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)))
     {
@@ -124,5 +144,10 @@ int main(int argc, char* argv[])
 
     MetaEngine::cleanupExiv2();
 
+#ifdef Q_OS_WIN
+    // Necessary to open native open with dialog on windows
+    CoUninitialize();
+#endif
+
     return ret;
 }
