@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-11-22
  * Description : stand alone digiKam image editor GUI
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
@@ -49,32 +49,16 @@ public:
     explicit ShowFoto(const QList<QUrl>& urlList);
     ~ShowFoto();
 
+public:
+
+    DInfoInterface* infoIface(DPluginAction* const ac);
+
     virtual void show();
 
-public Q_SLOTS:
-
-    void slotSetup();
-    void slotSetupICC();
-
 private:
 
-    bool setup(bool iccSetupPage=false);
-
     bool queryClose();
 
-    void setupActions();
-    void setupConnections();
-    void setupUserArea();
-
-    void readSettings();
-    void saveSettings();
-    void applySettings();
-
-    void toggleActions(bool val);
-    void addServicesMenu();
-
-    void toggleNavigation(int index);
-
     bool save();
     bool saveAs();
     void moveFile();
@@ -89,8 +73,6 @@ private:
     void saveAsIsComplete();
     void saveVersionIsComplete();
 
-    void slideShow(Digikam::SlideShowSettings& settings);
-
     void openFolder(const QUrl& url);
     void openUrls(const QList<QUrl>& urls);
 
@@ -103,16 +85,14 @@ private Q_SLOTS:
     void slotBackward();
     void slotLast();
     void slotFirst();
-    void slotFilePrint();
     void slotFileWithDefaultApplication();
     void slotOpenWith(QAction* action=0);
     void slotShowfotoItemInfoActivated(const ShowfotoItemInfo& info);
 
     void slotOpenFile();
+    void slotOpenFolder();
     void slotOpenUrl(const ShowfotoItemInfo& info);
-    void slotOpenFolder(const QUrl&);
-    void slotOpenFilesInFolder();
-    void slotDroppedUrls(const QList<QUrl>& droppedUrls);
+    void slotDroppedUrls(const QList<QUrl>& droppedUrls, bool dropped);
     void slotDeleteCurrentItem();
 
     void slotChanged();
@@ -123,27 +103,10 @@ private Q_SLOTS:
     void slotLoadingFinished(const QString& filename, bool success);
     void slotSavingStarted(const QString& filename);
 
-    void slotContextMenu();
     void slotRevert();
-    void slotSetupMetadataFilters(int);
 
     void slotAddedDropedItems(QDropEvent*);
 
-    void slotImportFromScanner();
-    void slotImportedImagefromScanner(const QUrl& url);
-
-    void slotEditMetadata();
-    void slotEditGeolocation();
-    void slotHtmlGallery();
-    void slotCalendar();
-    void slotPresentation();
-    void slotExpoBlending();
-    void slotPanorama();
-    void slotVideoSlideshow();
-    void slotSendByMail();
-    void slotPrintCreator();
-    void slotMediaServer();
-
 Q_SIGNALS:
 
     void signalLoadCurrentItem(const QList<QUrl>& urlList);
@@ -151,6 +114,54 @@ Q_SIGNALS:
     void signalOpenFile(const QList<QUrl>& urls);
     void signalInfoList(ShowfotoItemInfoList&);
 
+// -- Internal setup methods implemented in showfoto_config.cpp ----------------------------------------
+
+public Q_SLOTS:
+
+    void slotSetup();
+    void slotSetupICC();
+
+private:
+
+    bool setup(bool iccSetupPage=false);
+    void applySettings();
+    void readSettings();
+    void saveSettings();
+
+private Q_SLOTS:
+
+    void slotSetupMetadataFilters(int);
+
+// -- Internal setup methods implemented in showfoto_setup.cpp ----------------------------------------
+
+private:
+
+    void setupActions();
+    void setupConnections();
+    void setupUserArea();
+
+    void toggleActions(bool val);
+    void toggleNavigation(int index);
+    void addServicesMenu();
+
+private Q_SLOTS:
+
+    void slotContextMenu();
+
+// -- Extra tool methods implemented in showfoto_tools.cpp ----------------------------------------
+
+private:
+
+    void slideShow(Digikam::SlideShowSettings& settings);
+
+// -- Import tools methods implemented in showfoto_import.cpp -------------------------------------
+
+private Q_SLOTS:
+
+    void slotImportedImagefromScanner(const QUrl& url);
+
+// -- Internal private container --------------------------------------------------------------------
+
 private:
 
     class Private;
