@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-02
  * Description : showFoto setup dialog.
  *
- * Copyright (C) 2005-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOSETUP_H
-#define SHOWFOTOSETUP_H
+#ifndef SHOW_FOTO_SETUP_H
+#define SHOW_FOTO_SETUP_H
 
 // Local includes
 
@@ -50,6 +50,7 @@ public:
         IOFilesPage,
         SlideshowPage,
         ICCPage,
+        PluginsPage,
         MiscellaneousPage,
 
         SetupPageEnumLast
@@ -78,6 +79,6 @@ private:
     Private* const d;
 };
 
-}   // namespace ShowFoto
+} // namespace ShowFoto
 
-#endif // SHOWFOTOSETUP_H
+#endif // SHOW_FOTO_SETUP_H
