@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-07-18
  * Description : setup Metadata tab.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,18 +46,18 @@
 
 #include "metaengine.h"
 #include "metadatapanel.h"
-#include "metadatasettings.h"
+#include "metaenginesettings.h"
 #include "dactivelabel.h"
 
 namespace ShowFoto
 {
 
-class SetupMetadata::Private
+class Q_DECL_HIDDEN SetupMetadata::Private
 {
 public:
 
-    Private() :
-        exifRotateBox(0),
+    explicit Private()
+      : exifRotateBox(0),
         exifSetOrientationBox(0),
         tab(0),
         tagsCfgPanel(0)
@@ -172,14 +172,14 @@ SetupMetadata::~SetupMetadata()
 
 void SetupMetadata::applySettings()
 {
-    Digikam::MetadataSettings* const mSettings = Digikam::MetadataSettings::instance();
+    Digikam::MetaEngineSettings* const mSettings = Digikam::MetaEngineSettings::instance();
 
     if (!mSettings)
     {
         return;
     }
 
-    Digikam::MetadataSettingsContainer set;
+    Digikam::MetaEngineSettingsContainer set;
 
     set.exifRotate         = d->exifRotateBox->isChecked();
     set.exifSetOrientation = d->exifSetOrientationBox->isChecked();
@@ -190,14 +190,14 @@ void SetupMetadata::applySettings()
 
 void SetupMetadata::readSettings()
 {
-    Digikam::MetadataSettings* const mSettings = Digikam::MetadataSettings::instance();
+    Digikam::MetaEngineSettings* const mSettings = Digikam::MetaEngineSettings::instance();
 
     if (!mSettings)
     {
         return;
     }
 
-    Digikam::MetadataSettingsContainer set     = mSettings->settings();
+    Digikam::MetaEngineSettingsContainer set     = mSettings->settings();
 
     d->exifRotateBox->setChecked(set.exifRotate);
     d->exifSetOrientationBox->setChecked(set.exifSetOrientation);
@@ -208,4 +208,4 @@ void SetupMetadata::setActiveTab(MetadataTab tab)
     d->tab->setCurrentIndex(tab);
 }
 
-}  // namespace ShowFoto
+} // namespace ShowFoto
