@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-07-18
  * Description : setup Metadata tab.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOSETUPMETADATA_H
-#define SHOWFOTOSETUPMETADATA_H
+#ifndef SHOW_FOTO_SETUP_METADATA_H
+#define SHOW_FOTO_SETUP_METADATA_H
 
 // Qt includes
 
@@ -64,6 +64,6 @@ private:
     Private* const d;
 };
 
-}  // namespace ShowFoto
+} // namespace ShowFoto
 
-#endif // SHOWFOTOSETUPMETADATA_H
+#endif // SHOW_FOTO_SETUP_METADATA_H
