@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-02
  * Description : setup Misc tab.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOSETUPMISC_H
-#define SHOWFOTOSETUPMISC_H
+#ifndef SHOW_FOTO_SETUP_MISC_H
+#define SHOW_FOTO_SETUP_MISC_H
 
 // Qt includes
 
@@ -43,10 +43,16 @@ public:
         SortByFileSize
     };
 
+    enum MiscTab
+    {
+        Behaviour = 0,
+        Appearance
+    };
+
 public:
 
     explicit SetupMisc(QWidget* const parent = 0);
-    virtual ~SetupMisc();
+    ~SetupMisc();
 
     void applySettings();
 
@@ -62,4 +68,4 @@ private:
 
 } // namespace ShowFoto
 
-#endif // SHOWFOTOSETUPMISC_H
+#endif // SHOW_FOTO_SETUP_MISC_H
