@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-02-06
  * Description : setup RAW decoding settings.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,13 +34,12 @@
 namespace ShowFoto
 {
 
-class SetupRaw::Private
+class Q_DECL_HIDDEN SetupRaw::Private
 {
 public:
 
-
-    Private() :
-        tab(0),
+    explicit Private()
+      : tab(0),
         raw(0)
     {
     }
@@ -77,4 +76,4 @@ void SetupRaw::readSettings()
     d->raw->readSettings();
 }
 
-}  // namespace ShowFoto
+} // namespace ShowFoto
