@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-02-06
  * Description : setup RAW decoding settings.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOSETUPRAW_H
-#define SHOWFOTOSETUPRAW_H
+#ifndef SHOW_FOTO_SETUP_RAW_H
+#define SHOW_FOTO_SETUP_RAW_H
 
 // Qt includes
 
@@ -52,6 +52,6 @@ private:
     Private* const d;
 };
 
-}  // namespace ShowFoto
+} // namespace ShowFoto
 
-#endif // SHOWFOTOSETUPRAW_H
+#endif // SHOW_FOTO_SETUP_RAW_H
