@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2013-2014 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,12 +44,12 @@
 namespace ShowFoto
 {
 
-class SetupToolTip::Private
+class Q_DECL_HIDDEN SetupToolTip::Private
 {
 public:
 
-    Private() :
-        showFileDateBox(0),
+    explicit Private()
+      : showFileDateBox(0),
         showFileNameBox(0),
         showFileSizeBox(0),
         showImageDimBox(0),
@@ -266,4 +266,4 @@ void SetupToolTip::applySettings()
     d->settings->syncConfig();
 }
 
-}  // namespace ShowFoto
+} // namespace ShowFoto
