@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOSETUPTOOLTIP_H
-#define SHOWFOTOSETUPTOOLTIP_H
+#ifndef SHOW_FOTO_SETUP_TOOL_TIP_H
+#define SHOW_FOTO_SETUP_TOOL_TIP_H
 
 // Qt includes
 
@@ -52,6 +52,6 @@ private:
     Private* const d;
 };
 
-}  // namespace ShowFoto
+} // namespace ShowFoto
 
-#endif // SHOWFOTOSETUPTOOLTIP_H
+#endif // SHOW_FOTO_SETUP_TOOL_TIP_H
