@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-01
- * Description : Qt item view for images - the delegate
+ * Description : Qt model view for Showfoto item - the delegate
  *
- * Copyright (C) 2013 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2013 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,6 +22,7 @@
  * ============================================================ */
 
 #include "itemviewshowfotodelegate.h"
+#include "itemviewshowfotodelegate_p.h"
 
 // Qt includes
 
@@ -35,11 +36,10 @@
 // Local includes
 
 #include "thememanager.h"
-#include "imagescanner.h"
-#include "imagepropertiestab.h"
+#include "itemscanner.h"
+#include "itempropertiestab.h"
 #include "showfotoiteminfo.h"
 #include "colorlabelwidget.h"
-#include "itemviewshowfotodelegatepriv.h"
 
 namespace ShowFoto
 {
@@ -48,7 +48,7 @@ ItemViewShowfotoDelegatePrivate::ItemViewShowfotoDelegatePrivate()
 {
     q             = 0;
     spacing       = 0;
-    thumbSize     = 0;
+    thumbSize     = ThumbnailSize(0);
 
     // painting constants
     radius        = 3;
@@ -101,7 +101,7 @@ void ItemViewShowfotoDelegate::setThumbnailSize(const ThumbnailSize& thumbSize)
 {
     Q_D(ItemViewShowfotoDelegate);
 
-    if ( d->thumbSize != thumbSize)
+    if (d->thumbSize != thumbSize)
     {
         d->thumbSize = thumbSize;
         invalidatePaintingCache();
@@ -182,13 +182,13 @@ QAbstractItemDelegate* ItemViewShowfotoDelegate::asDelegate()
 
 void ItemViewShowfotoDelegate::overlayDestroyed(QObject* o)
 {
-    ImageDelegateOverlayContainer::overlayDestroyed(o);
+    ItemDelegateOverlayContainer::overlayDestroyed(o);
 }
 
 void ItemViewShowfotoDelegate::mouseMoved(QMouseEvent* e, const QRect& visualRect, const QModelIndex& index)
 {
-    // 3-way indirection AbstractShowfotoItemDelegate -> ItemViewShowfotoDelegate -> ImageDelegateOverlayContainer
-    ImageDelegateOverlayContainer::mouseMoved(e, visualRect, index);
+    // 3-way indirection AbstractShowfotoItemDelegate -> ItemViewShowfotoDelegate -> ItemDelegateOverlayContainer
+    ItemDelegateOverlayContainer::mouseMoved(e, visualRect, index);
 }
 
 void ItemViewShowfotoDelegate::setDefaultViewOptions(const QStyleOptionViewItem& option)
@@ -335,7 +335,7 @@ void ItemViewShowfotoDelegate::drawFileSize(QPainter* p, const QRect& r, qlonglo
 {
     Q_D(const ItemViewShowfotoDelegate);
     p->setFont(d->fontXtra);
-    p->drawText(r, Qt::AlignCenter, ImagePropertiesTab::humanReadableBytesCount(bytes));
+    p->drawText(r, Qt::AlignCenter, ItemPropertiesTab::humanReadableBytesCount(bytes));
 }
 
 void ItemViewShowfotoDelegate::drawFocusRect(QPainter* p, const QStyleOptionViewItem& option,
