@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-07-13
  * Description : Qt categorized item view for showfoto items
  *
- * Copyright (C) 2013 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2013 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -40,7 +40,7 @@ using namespace Digikam;
 namespace ShowFoto
 {
 
-class ShowfotoItemViewToolTip : public ItemViewToolTip
+class Q_DECL_HIDDEN ShowfotoItemViewToolTip : public ItemViewToolTip
 {
 public:
 
@@ -58,17 +58,17 @@ protected:
 
     virtual QString tipContents()
     {
-        ShowfotoItemInfo info = ShowfotoImageModel::retrieveShowfotoItemInfo(currentIndex());
+        ShowfotoItemInfo info = ShowfotoItemModel::retrieveShowfotoItemInfo(currentIndex());
         return ShowfotoToolTipFiller::ShowfotoItemInfoTipContents(info);
     }
 };
 
-class ShowfotoCategorizedView::Private
+class Q_DECL_HIDDEN ShowfotoCategorizedView::Private
 {
 public:
 
-    Private() :
-        model(0),
+    explicit Private()
+      : model(0),
         filterModel(0),
         delegate(0),
         showToolTip(false),
@@ -78,7 +78,7 @@ public:
     {
     }
 
-    ShowfotoImageModel*      model;
+    ShowfotoItemModel*      model;
     ShowfotoSortFilterModel* filterModel;
 
     ShowfotoDelegate*        delegate;
@@ -92,7 +92,8 @@ public:
 };
 
 ShowfotoCategorizedView::ShowfotoCategorizedView(QWidget* const parent)
-    : ItemViewCategorized(parent), d(new Private)
+    : ItemViewCategorized(parent),
+      d(new Private)
 {
     setToolTip(new ShowfotoItemViewToolTip(this));
 
@@ -103,7 +104,8 @@ ShowfotoCategorizedView::ShowfotoCategorizedView(QWidget* const parent)
     d->delayedEnterTimer->setInterval(10);
     d->delayedEnterTimer->setSingleShot(false);
 
-    connect(d->delayedEnterTimer, &QTimer::timeout, this, &ShowfotoCategorizedView::slotDelayedEnter);
+    connect(d->delayedEnterTimer, &QTimer::timeout,
+            this, &ShowfotoCategorizedView::slotDelayedEnter);
 }
 
 ShowfotoCategorizedView::~ShowfotoCategorizedView()
@@ -112,7 +114,7 @@ ShowfotoCategorizedView::~ShowfotoCategorizedView()
     delete d;
 }
 
-void ShowfotoCategorizedView::setModels(ShowfotoImageModel* model, ShowfotoSortFilterModel* filterModel)
+void ShowfotoCategorizedView::setModels(ShowfotoItemModel* model, ShowfotoSortFilterModel* filterModel)
 {
     if (d->delegate)
     {
@@ -133,9 +135,11 @@ void ShowfotoCategorizedView::setModels(ShowfotoImageModel* model, ShowfotoSortF
 
     setModel(d->filterModel);
 
-    connect(d->filterModel, &ShowfotoSortFilterModel::layoutAboutToBeChanged, this, &ShowfotoCategorizedView::layoutAboutToBeChanged);
+    connect(d->filterModel, &ShowfotoSortFilterModel::layoutAboutToBeChanged,
+            this, &ShowfotoCategorizedView::layoutAboutToBeChanged);
 
-    connect(d->filterModel, &ShowfotoSortFilterModel::layoutChanged, this, &ShowfotoCategorizedView::layoutWasChanged, Qt::QueuedConnection);
+    connect(d->filterModel, &ShowfotoSortFilterModel::layoutChanged,
+            this, &ShowfotoCategorizedView::layoutWasChanged, Qt::QueuedConnection);
 
     emit modelChanged();
 
@@ -145,7 +149,7 @@ void ShowfotoCategorizedView::setModels(ShowfotoImageModel* model, ShowfotoSortF
     }
 }
 
-ShowfotoImageModel* ShowfotoCategorizedView::showfotoImageModel() const
+ShowfotoItemModel* ShowfotoCategorizedView::showfotoItemModel() const
 {
     return d->model;
 }
@@ -208,9 +212,11 @@ void ShowfotoCategorizedView::setItemDelegate(ShowfotoDelegate* delegate)
     d->delegate->setViewOnAllOverlays(this);
     d->delegate->setAllOverlaysActive(true);
 
-    connect(d->delegate, &ShowfotoDelegate::requestNotification, this, &ShowfotoCategorizedView::showIndexNotification);
+    connect(d->delegate, &ShowfotoDelegate::requestNotification,
+            this, &ShowfotoCategorizedView::showIndexNotification);
 
-    connect(d->delegate, &ShowfotoDelegate::hideNotification, this, &ShowfotoCategorizedView::hideIndexNotification);
+    connect(d->delegate, &ShowfotoDelegate::hideNotification,
+            this, &ShowfotoCategorizedView::hideIndexNotification);
 }
 
 ShowfotoItemInfo ShowfotoCategorizedView::currentInfo() const
@@ -234,7 +240,7 @@ QList<ShowfotoItemInfo> ShowfotoCategorizedView::selectedShowfotoItemInfosCurren
     QModelIndex        current = currentIndex();
     QList<ShowfotoItemInfo> infos;
 
-    foreach(const QModelIndex& index, indexes)
+    foreach (const QModelIndex& index, indexes)
     {
         ShowfotoItemInfo info = d->filterModel->showfotoItemInfo(index);
 
@@ -261,7 +267,7 @@ QList<QUrl> ShowfotoCategorizedView::urls() const
     QList<ShowfotoItemInfo> infos = showfotoItemInfos();
     QList<QUrl>              urls;
 
-    foreach(const ShowfotoItemInfo& info, infos)
+    foreach (const ShowfotoItemInfo& info, infos)
     {
         urls << info.url;
     }
@@ -274,7 +280,7 @@ QList<QUrl> ShowfotoCategorizedView::selectedUrls() const
     QList<ShowfotoItemInfo> infos = selectedShowfotoItemInfos();
     QList<QUrl>              urls;
 
-    foreach(const ShowfotoItemInfo& info, infos)
+    foreach (const ShowfotoItemInfo& info, infos)
     {
         urls << info.url;
     }
@@ -316,7 +322,7 @@ QModelIndex ShowfotoCategorizedView::nextIndexHint(const QModelIndex& anchor, co
             int minDiff                                   = d->filterModel->rowCount();
             QList<QModelIndex> indexesForShowfotoItemInfo = d->filterModel->mapListFromSource(d->model->indexesForShowfotoItemInfo(info));
 
-            foreach(const QModelIndex& index, indexesForShowfotoItemInfo)
+            foreach (const QModelIndex& index, indexesForShowfotoItemInfo)
             {
                 if (index == anchor || !index.isValid() || removed.contains(index))
                 {
@@ -402,7 +408,7 @@ void ShowfotoCategorizedView::setSelectedUrls(const QList<QUrl>& urlList)
 {
     QItemSelection mySelection;
 
-    for (QList<QUrl>::const_iterator it = urlList.constBegin(); it!=urlList.constEnd(); ++it)
+    for (QList<QUrl>::const_iterator it = urlList.constBegin() ; it!=urlList.constEnd() ; ++it)
     {
         const QModelIndex index = d->filterModel->indexForUrl(*it);
 
@@ -425,7 +431,7 @@ void ShowfotoCategorizedView::setSelectedShowfotoItemInfos(const QList<ShowfotoI
 {
     QItemSelection mySelection;
 
-    foreach(const ShowfotoItemInfo& info, infos)
+    foreach (const ShowfotoItemInfo& info, infos)
     {
         QModelIndex index = d->filterModel->indexForShowfotoItemInfo(info);
         mySelection.select(index, index);
@@ -452,7 +458,7 @@ void ShowfotoCategorizedView::hintAt(const ShowfotoItemInfo& info)
     scrollTo(index);
 }
 
-void ShowfotoCategorizedView::addOverlay(ImageDelegateOverlay* overlay, ShowfotoDelegate* delegate)
+void ShowfotoCategorizedView::addOverlay(ItemDelegateOverlay* overlay, ShowfotoDelegate* delegate)
 {
     if (!delegate)
     {
@@ -468,7 +474,7 @@ void ShowfotoCategorizedView::addOverlay(ImageDelegateOverlay* overlay, Showfoto
     }
 }
 
-void ShowfotoCategorizedView::removeOverlay(ImageDelegateOverlay* overlay)
+void ShowfotoCategorizedView::removeOverlay(ItemDelegateOverlay* overlay)
 {
     ShowfotoDelegate* const delegate = dynamic_cast<ShowfotoDelegate*>(overlay->delegate());
 
