@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-07-13
  * Description : Qt categorized item view for showfoto items
  *
- * Copyright (C) 2013 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2013 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOCATEGORIZEDVIEW_H
-#define SHOWFOTOCATEGORIZEDVIEW_H
+#ifndef SHOW_FOTO_CATEGORIZED_VIEW_H
+#define SHOW_FOTO_CATEGORIZED_VIEW_H
 
 // Local includes
 
@@ -31,7 +31,7 @@
 #include "showfotofiltermodel.h"
 #include "showfotothumbnailmodel.h"
 #include "showfotoiteminfo.h"
-#include "imagedelegateoverlay.h"
+#include "itemdelegateoverlay.h"
 
 namespace ShowFoto
 {
@@ -49,9 +49,9 @@ public:
     explicit ShowfotoCategorizedView(QWidget* const parent = 0);
     ~ShowfotoCategorizedView();
 
-    void setModels(ShowfotoImageModel* model, ShowfotoSortFilterModel* filterModel);
+    void setModels(ShowfotoItemModel* model, ShowfotoSortFilterModel* filterModel);
 
-    ShowfotoImageModel*         showfotoImageModel()                    const;
+    ShowfotoItemModel*         showfotoItemModel()                    const;
     ShowfotoSortFilterModel*    showfotoSortFilterModel()               const;
 
     QItemSelectionModel*        getSelectionModel()                     const;
@@ -59,7 +59,7 @@ public:
     /// Returns any ShowfotoFilterModel in chain. May not be sourceModel()
     ShowfotoFilterModel*        showfotoFilterModel()                   const;
 
-    /// Returns 0 if the ShowfotoImageModel is not an ShowfotoThumbnailModel
+    /// Returns 0 if the ShowfotoItemModel is not an ShowfotoThumbnailModel
     ShowfotoThumbnailModel*     showfotoThumbnailModel()                const;
 
     ShowfotoDelegate*           delegate()                              const;
@@ -98,8 +98,8 @@ public:
 
     /// Add and remove an overlay. It will as well be removed automatically when destroyed.
     /// Unless you pass a different delegate, the current delegate will be used.
-    void addOverlay(ImageDelegateOverlay* overlay, ShowfotoDelegate* delegate = 0);
-    void removeOverlay(ImageDelegateOverlay* overlay);
+    void addOverlay(ItemDelegateOverlay* overlay, ShowfotoDelegate* delegate = 0);
+    void removeOverlay(ItemDelegateOverlay* overlay);
 
     //TODO: Implement This
 //    void addSelectionOverlay(ShowfotoDelegate* delegate = 0);
@@ -190,4 +190,4 @@ private:
 
 } // namespace Showfoto
 
-#endif // SHOWFOTOCATEGORIZEDVIEW_H
+#endif // SHOW_FOTO_CATEGORIZED_VIEW_H
