@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-05-28
  * Description : overlay for GPS location indicator
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTO_COORDINATES_OVERLAY_H
-#define SHOWFOTO_COORDINATES_OVERLAY_H
+#ifndef SHOW_FOTO_COORDINATES_OVERLAY_H
+#define SHOW_FOTO_COORDINATES_OVERLAY_H
 
 // Qt includes
 
@@ -32,7 +32,7 @@
 // Local includes
 
 #include "itemviewhoverbutton.h"
-#include "imagedelegateoverlay.h"
+#include "itemdelegateoverlay.h"
 #include "itemviewshowfotodelegate.h"
 
 using namespace Digikam;
@@ -82,4 +82,4 @@ protected:
 
 } // namespace ShowFoto
 
-#endif // SHOWFOTO_COORDINATES_OVERLAY_H
+#endif // SHOW_FOTO_COORDINATES_OVERLAY_H
