@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-01
- * Description : Qt item view for images - the delegate
+ * Description : Qt model view for Showfoto item - the delegate
  *
- * Copyright (C) 2013      by Mohamed Anwer <m dot anwer at gmx dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,7 +23,7 @@
  * ============================================================ */
 
 #include "showfotodelegate.h"
-#include "showfotodelegatepriv.h"
+#include "showfotodelegate_p.h"
 
 // Qt includes
 
@@ -169,9 +169,9 @@ QPixmap ShowfotoDelegate::retrieveThumbnailPixmap(const QModelIndex& index, int
     // work around constness
     QAbstractItemModel* const model = const_cast<QAbstractItemModel*>(index.model());
     // set requested thumbnail size
-    model->setData(index, thumbnailSize, ShowfotoImageModel::ThumbnailRole);
+    model->setData(index, thumbnailSize, ShowfotoItemModel::ThumbnailRole);
     // get data from model
-    QVariant thumbData              = index.data(ShowfotoImageModel::ThumbnailRole);
+    QVariant thumbData              = index.data(ShowfotoItemModel::ThumbnailRole);
 
     return thumbData.value<QPixmap>();
 }
@@ -185,7 +185,7 @@ QPixmap ShowfotoDelegate::thumbnailPixmap(const QModelIndex& index) const
 void ShowfotoDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
     Q_D(const ShowfotoDelegate);
-    ShowfotoItemInfo info     = ShowfotoImageModel::retrieveShowfotoItemInfo(index);
+    ShowfotoItemInfo info     = ShowfotoItemModel::retrieveShowfotoItemInfo(index);
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group("ImageViewer Settings");
 
@@ -264,7 +264,8 @@ void ShowfotoDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, co
     drawOverlays(p, option, index);
 }
 
-QPixmap ShowfotoDelegate::pixmapForDrag(const QStyleOptionViewItem& option, const QList<QModelIndex>& indexes) const
+QPixmap ShowfotoDelegate::pixmapForDrag(const QStyleOptionViewItem& option,
+                                        const QList<QModelIndex>& indexes) const
 {
     QPixmap icon;
 
@@ -508,7 +509,7 @@ int ShowfotoThumbnailDelegate::minimumSize() const
 }
 
 bool ShowfotoThumbnailDelegate::acceptsActivation(const QPoint& pos, const QRect& visualRect,
-                                                const QModelIndex& index, QRect* activationRect) const
+                                                  const QModelIndex& index, QRect* activationRect) const
 {
     // reuse implementation from grandparent
     return ItemViewShowfotoDelegate::acceptsActivation(pos, visualRect, index, activationRect);
@@ -528,7 +529,7 @@ void ShowfotoThumbnailDelegate::updateContentWidth()
         maxSize = d->viewSize.width();
     }
 
-    d->thumbSize = thumbnailPixmapSize(true, maxSize - 2*d->radius - 2*d->margin);
+    d->thumbSize = ThumbnailSize(thumbnailPixmapSize(true, maxSize - 2*d->radius - 2*d->margin));
 
     ShowfotoDelegate::updateContentWidth();
 }
