@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-01
- * Description : Qt item view for images - the delegate
+ * Description : Qt model view for Showfoto item - the delegate
  *
- * Copyright (C) 2013      by Mohamed Anwer <m dot anwer at gmx dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTODELEGATE_H
-#define SHOWFOTODELEGATE_H
+#ifndef SHOW_FOTO_DELEGATE_H
+#define SHOW_FOTO_DELEGATE_H
 
 // Qt includes
 
@@ -72,7 +72,7 @@ public:
     virtual QPixmap pixmapForDrag(const QStyleOptionViewItem& option, const QList<QModelIndex>& indexes) const;
 
     /**
-     * Retrieve the thumbnail pixmap in given size for the ShowfotoImageModel::ThumbnailRole for
+     * Retrieve the thumbnail pixmap in given size for the ShowfotoItemModel::ThumbnailRole for
      * the given index from the given index, which must adhere to ShowfotoThumbnailModel semantics.
      */
     static QPixmap retrieveThumbnailPixmap(const QModelIndex& index, int thumbnailSize);
@@ -185,6 +185,6 @@ private:
     Q_DECLARE_PRIVATE(ShowfotoNormalDelegate)
 };
 
-}// namespace ShowFoto
+} // namespace ShowFoto
 
-#endif // SHOWFOTODELEGATE_H
+#endif // SHOW_FOTO_DELEGATE_H
