@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-02-01
  * Description : Kinetic Scroller for Thumbnail Bar
+ *               based on Razvan Petru implementation.
  *
- * Copyright (C) 2010 by Razvan Petru
- * Copyright (C) 2014 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -60,11 +60,11 @@ static const int gMaxDecelerationSpeed = 30;
  */
 static const int gFriction             = 1;
 
-class ShowfotoKineticScroller::Private
+class Q_DECL_HIDDEN ShowfotoKineticScroller::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         scrollArea            = 0;
         isPressed             = false;
@@ -102,9 +102,11 @@ public:
 };
 
 ShowfotoKineticScroller::ShowfotoKineticScroller(QObject* const parent)
-    : QObject(parent), d(new Private())
+    : QObject(parent),
+      d(new Private())
 {
-    connect(&d->kineticTimer, &QTimer::timeout, this, &ShowfotoKineticScroller::onKineticTimerElapsed);
+    connect(&d->kineticTimer, &QTimer::timeout,
+            this, &ShowfotoKineticScroller::onKineticTimerElapsed);
 }
 
 ShowfotoKineticScroller::~ShowfotoKineticScroller()
@@ -201,7 +203,7 @@ bool ShowfotoKineticScroller::eventFilter(QObject* object, QEvent* event)
                         d->kineticTimer.start(gTimerInterval);
                 }
             }
-            else if(d->isPressed)
+            else if (d->isPressed)
             {
                 // manual scroll
                 if (d->scrollFlow == QListView::TopToBottom)
@@ -224,10 +226,14 @@ bool ShowfotoKineticScroller::eventFilter(QObject* object, QEvent* event)
 
             // Looks like the user wanted a single click. Simulate the click,
             // as the events were already consumed
-            if( !d->isMoving )
+            if (!d->isMoving)
             {
-                QMouseEvent* const mousePress   = new QMouseEvent(QEvent::MouseButtonPress,   d->lastPressPoint, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
-                QMouseEvent* const mouseRelease = new QMouseEvent(QEvent::MouseButtonRelease, d->lastPressPoint, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+                QMouseEvent* const mousePress   = new QMouseEvent(QEvent::MouseButtonPress,
+                                                                  d->lastPressPoint, Qt::LeftButton,
+                                                                  Qt::LeftButton, Qt::NoModifier);
+                QMouseEvent* const mouseRelease = new QMouseEvent(QEvent::MouseButtonRelease,
+                                                                  d->lastPressPoint, Qt::LeftButton,
+                                                                  Qt::LeftButton, Qt::NoModifier);
                 d->ignoredMouseActions          = 2;
 
                 QApplication::postEvent(object, mousePress);
@@ -267,11 +273,12 @@ void ShowfotoKineticScroller::onKineticTimerElapsed()
         // use the previously recorded speed and gradually decelerate
         d->velocity = qBound(-gMaxDecelerationSpeed, d->velocity, gMaxDecelerationSpeed);
 
-        if( d->velocity > 0 )
+        if (d->velocity > 0)
             d->velocity -= gFriction;
-        else if( d->velocity < 0 )
+        else if (d->velocity < 0)
             d->velocity += gFriction;
-        if( qAbs(d->velocity) < qAbs(gFriction) )
+
+        if (qAbs(d->velocity) < qAbs(gFriction))
             d->stopMotion();
 
         if (d->scrollFlow == QListView::TopToBottom)
