@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 02-08-2013
  * Description : Thumbnail bar for Showfoto
  *
- * Copyright (C) 2013      by Mohamed Anwer <m dot anwer at gmx dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOTHUMBNAILBAR_H
-#define SHOWFOTOTHUMBNAILBAR_H
+#ifndef SHOW_FOTO_THUMB_NAIL_BAR_H
+#define SHOW_FOTO_THUMB_NAIL_BAR_H
 
 // Local Includes
 
@@ -44,10 +44,10 @@ public:
     ~ShowfotoThumbnailBar();
 
     /**
-     * This installs a duplicate filter model, if the ShwofotoImageModel may contain duplicates.
+     * This installs a duplicate filter model, if the ShwofotoItemModel may contain duplicates.
      * Otherwise, just use setModels().
      */
-    void setModelsFiltered(ShowfotoImageModel* model, ShowfotoSortFilterModel* filterModel);
+    void setModelsFiltered(ShowfotoItemModel* model, ShowfotoSortFilterModel* filterModel);
 
     QModelIndex nextIndex(const QModelIndex& index)     const;
     QModelIndex previousIndex(const QModelIndex& index) const;
@@ -58,7 +58,7 @@ public:
     void setScrollBarPolicy(Qt::ScrollBarPolicy policy);
     void setFlow(QListView::Flow newFlow);
 
-    ShowfotoItemInfo findItemByUrl(const QUrl url);
+    ShowfotoItemInfo findItemByUrl(const QUrl& url);
 
     void installOverlays();
 
@@ -79,4 +79,4 @@ private:
 
 } // namespace ShowFoto
 
-#endif // SHOWFOTOTHUMBNAILBAR_H
+#endif // SHOW_FOTO_THUMB_NAIL_BAR_H
