@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-07-22
  * Description : Qt item model for Showfoto thumbnails entries
  *
- * Copyright (C) 2013 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2013 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOTHUMBNAILMODEL_H
-#define SHOWFOTOTHUMBNAILMODEL_H
+#ifndef SHOW_FOTO_THUMB_NAIL_MODEL_H
+#define SHOW_FOTO_THUMB_NAIL_MODEL_H
 
 // Local Include
 
@@ -38,14 +38,14 @@ namespace ShowFoto
 
 typedef QPair<ShowfotoItemInfo, QPixmap> CachedItem;
 
-class ShowfotoThumbnailModel : public ShowfotoImageModel
+class ShowfotoThumbnailModel : public ShowfotoItemModel
 {
     Q_OBJECT
 
 public:
 
     /**
-     *  An ImageModel that supports thumbnail loading.
+     *  An ItemModel that supports thumbnail loading.
      *  You need to set a ThumbnailLoadThread to enable thumbnail loading.
      *  Adjust the thumbnail size to your needs.
      *  Note that setKeepsFilePatindexesForPathhCache is enabled per default.
@@ -128,4 +128,4 @@ private:
 
 } // namespace ShowFoto
 
-#endif // SHOWFOTOTHUMBNAILMODEL_H
+#endif // SHOW_FOTO_THUMB_NAIL_MODEL_H
