@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-11
  * Description : test cases for the various album models
@@ -81,7 +81,7 @@ AlbumModelTest::~AlbumModelTest()
 void AlbumModelTest::initTestCase()
 {
     tempSuffix = QLatin1String("albummodeltest-") + QTime::currentTime().toString();
-    dbPath     = QDir::temp().absolutePath() + QLatin1String("/") + tempSuffix;
+    dbPath     = QDir::temp().absolutePath() + QLatin1Char('/') + tempSuffix;
 
     if (QDir::temp().exists(tempSuffix))
     {
@@ -118,7 +118,7 @@ void AlbumModelTest::initTestCase()
     AlbumList all = AlbumManager::instance()->allPAlbums();
     qDebug() << "PAlbum registered : " << all.size();
 
-    Q_FOREACH(Album* const a, all)
+    foreach(Album* const a, all)
     {
         if (a)
         {
@@ -427,9 +427,9 @@ void AlbumModelTest::cleanup()
     // remove all tags
 
     QString error;
-    bool removed = AlbumManager::instance()->deleteTAlbum(talbumRoot0, error);
+    bool removed = AlbumManager::instance()->deleteTAlbum(talbumRoot0, error, false);
     QVERIFY2(removed, QString::fromUtf8("Error removing a tag: %1").arg(error).toLatin1().constData());
-    removed      = AlbumManager::instance()->deleteTAlbum(talbumRoot1, error);
+    removed      = AlbumManager::instance()->deleteTAlbum(talbumRoot1, error, false);
     QVERIFY2(removed, QString::fromUtf8("Error removing a tag: %1").arg(error).toLatin1().constData());
 
     QCOMPARE(AlbumManager::instance()->allTAlbums().size(), 1);
