@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-11-13
  * Description : a test for applying FilterActions
@@ -35,13 +35,10 @@
 // Local includes
 
 #include "metaengine.h"
-#include "dimg.h"
 #include "dimagehistory.h"
 #include "drawdecoding.h"
 #include "filteractionfilter.h"
 
-using namespace Digikam;
-
 QTEST_MAIN(DImgFilterActionTest)
 
 void DImgFilterActionTest::testDRawDecoding()
@@ -52,7 +49,7 @@ void DImgFilterActionTest::testDRawDecoding()
     params.rawPrm.autoBrightness        = true;
     params.rawPrm.whiteBalance          = DRawDecoderSettings::AERA;
     params.rawPrm.RGBInterpolate4Colors = true;
-    params.rawPrm.RAWQuality            = DRawDecoderSettings::AMAZE;
+    params.rawPrm.RAWQuality            = DRawDecoderSettings::DHT;
     params.rawPrm.NRType                = DRawDecoderSettings::WAVELETSNR;
     params.rawPrm.outputColorSpace      = DRawDecoderSettings::ADOBERGB;
 
@@ -85,7 +82,7 @@ void DImgFilterActionTest::testActions()
     {
         DImg ref(imageDir().filePath(fileName));
         QVERIFY(!ref.isNull());
-        DImageHistory history = ref.getImageHistory();
+        DImageHistory history = ref.getItemHistory();
 
         FilterActionFilter filter;
         filter.setFilterActions(history.allActions());
@@ -127,8 +124,8 @@ void DImgFilterActionTest::testActions()
     }
 }
 
-void DImgFilterActionTest::showDiff(const Digikam::DImg& orig, const Digikam::DImg& ref,
-                                      const Digikam::DImg& result, const DImg& diff)
+void DImgFilterActionTest::showDiff(const DImg& orig, const DImg& ref,
+                                    const DImg& result, const DImg& diff)
 {
     QDialog d;
     QLabel l1, l2, l3, l4;
