@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-08-01
  * Description : a test for the DImageHistory
@@ -42,10 +42,10 @@
 #include "collectionscanner.h"
 #include "editorcore.h"
 #include "dmetadata.h"
-#include "imageinfo.h"
-#include "imagehistorygraph.h"
-#include "imagehistorygraphdata.h"
-#include "imagehistorygraphmodel.h"
+#include "iteminfo.h"
+#include "itemhistorygraph.h"
+#include "itemhistorygraphdata.h"
+#include "itemhistorygraphmodel.h"
 #include "iofilesettings.h"
 #include "tagscache.h"
 #include "../modeltest/modeltest.h"
@@ -92,7 +92,7 @@ void DImgHistoryGraphTest::initTestCase()
 
     foreach(const QString& file, readOnlyImages)
     {
-        ids << ImageInfo::fromLocalFile(file).id();
+        ids << ItemInfo::fromLocalFile(file).id();
     }
 
     QVERIFY(!ids.contains(-1));
@@ -143,53 +143,53 @@ void DImgHistoryGraphTest::testEditing()
 
     IOFileSettings container;
     m_im->load(readOnlyImages.first(), &container);
-    m_loop.exec();
+    m_loop.exec();    // krazy:exclude=crashy
 
     applyFilters1();
     m_im->saveAs(collectionDir.filePath(QLatin1String("1.jpg")), &container, true, QString(), QString());
-    m_loop.exec();
+    m_loop.exec();    // krazy:exclude=crashy
 
     applyFilters2();
     m_im->saveAs(collectionDir.filePath(QLatin1String("2.jpg")), &container, true, QString(), QString());
-    m_loop.exec();
+    m_loop.exec();    // krazy:exclude=crashy
 
     applyFilters3();
     m_im->saveAs(collectionDir.filePath(QLatin1String("3.jpg")), &container, true, QString(), QString());
-    m_loop.exec();
+    m_loop.exec();    // krazy:exclude=crashy
 
     m_im->load(collectionDir.filePath(QLatin1String("2.jpg")), &container);
-    m_loop.exec();
+    m_loop.exec();    // krazy:exclude=crashy
 
     applyFilters4();
     m_im->saveAs(collectionDir.filePath(QLatin1String("4.jpg")), &container, true, QString(), QString());
-    m_loop.exec();
+    m_loop.exec();    // krazy:exclude=crashy
 
     CollectionScanner().completeScan();
 
-    ImageInfo orig  = ImageInfo::fromLocalFile(readOnlyImages.first());
-    ImageInfo one   = ImageInfo::fromLocalFile(collectionDir.filePath(QLatin1String("1.jpg"))),
-              two   = ImageInfo::fromLocalFile(collectionDir.filePath(QLatin1String("2.jpg"))),
-              three = ImageInfo::fromLocalFile(collectionDir.filePath(QLatin1String("3.jpg"))),
-              four  = ImageInfo::fromLocalFile(collectionDir.filePath(QLatin1String("4.jpg")));
+    ItemInfo orig  = ItemInfo::fromLocalFile(readOnlyImages.first());
+    ItemInfo one   = ItemInfo::fromLocalFile(collectionDir.filePath(QLatin1String("1.jpg"))),
+              two   = ItemInfo::fromLocalFile(collectionDir.filePath(QLatin1String("2.jpg"))),
+              three = ItemInfo::fromLocalFile(collectionDir.filePath(QLatin1String("3.jpg"))),
+              four  = ItemInfo::fromLocalFile(collectionDir.filePath(QLatin1String("4.jpg")));
 
     typedef QPair<qlonglong, qlonglong> IdPair;
     QList<IdPair> controlCloud;
-    controlCloud << IdPair(one.id(), orig.id()); //X
-    controlCloud << IdPair(two.id(), one.id());  //X
-    controlCloud << IdPair(three.id(), two.id());//X
-    controlCloud << IdPair(four.id(), two.id()); //X
+    controlCloud << IdPair(one.id(),   orig.id()); //X
+    controlCloud << IdPair(two.id(),   one.id());  //X
+    controlCloud << IdPair(three.id(), two.id());  //X
+    controlCloud << IdPair(four.id(),  two.id());  //X
     controlCloud << IdPair(three.id(), one.id());
-    controlCloud << IdPair(four.id(), one.id());
-    controlCloud << IdPair(two.id(), orig.id());
+    controlCloud << IdPair(four.id(),  one.id());
+    controlCloud << IdPair(two.id(),   orig.id());
     controlCloud << IdPair(three.id(), orig.id());
-    controlCloud << IdPair(four.id(), orig.id());
+    controlCloud << IdPair(four.id(),  orig.id());
     std::sort(controlCloud.begin(), controlCloud.end());
 
-    ImageHistoryGraph graph1 = ImageHistoryGraph::fromInfo(three);
+    ItemHistoryGraph graph1 = ItemHistoryGraph::fromInfo(three);
     qDebug() << graph1;
-    ImageHistoryGraph graph2 = ImageHistoryGraph::fromInfo(four);
+    ItemHistoryGraph graph2 = ItemHistoryGraph::fromInfo(four);
     qDebug() << graph2;
-    ImageHistoryGraph graph3 = ImageHistoryGraph::fromInfo(one);
+    ItemHistoryGraph graph3 = ItemHistoryGraph::fromInfo(one);
     qDebug() << graph3;
 
     // all three must have the full cloud
@@ -197,12 +197,12 @@ void DImgHistoryGraphTest::testEditing()
     QVERIFY(graph2.data().vertexCount() == 5);
     QVERIFY(graph3.data().vertexCount() == 5);
 
-    QList<IdPair> cloud = graph3.relationCloud();
+    QList<IdPair> cloud        = graph3.relationCloud();
     std::sort(cloud.begin(), cloud.end());
     QVERIFY(cloud == controlCloud);
 
-    int needResolvingTag = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::needResolvingHistory());
-    int needTaggingTag   = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::needTaggingHistoryGraph());
+    int needResolvingTag       = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::needResolvingHistory());
+    int needTaggingTag         = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::needTaggingHistoryGraph());
 
     int originalVersionTag     = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::originalVersion());
     int currentVersionTag      = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::currentVersion());
@@ -222,12 +222,12 @@ void DImgHistoryGraphTest::testEditing()
     fileTwo.remove();
     QVERIFY(!fileTwo.exists());
     CollectionScanner().completeScan();
-    graph2 = ImageHistoryGraph::fromInfo(four);
+    graph2 = ItemHistoryGraph::fromInfo(four);
     // graph is prepared for display, vertex of removed file cleared
     QVERIFY(graph2.data().vertexCount() == 4);
     qDebug() << graph2;
 
-    // Check that removal of current version leads to resetting of current verion tag
+    // Check that removal of current version leads to resetting of current version tag
     QFile fileThree(three.filePath());
     fileThree.remove();
     QFile fileFour(four.filePath());
@@ -240,8 +240,8 @@ void DImgHistoryGraphTest::testEditing()
 
 void DImgHistoryGraphTest::testHistory()
 {
-    ImageHistoryGraph graph;
-    ImageInfo subject(ids.first());
+    ItemHistoryGraph graph;
+    ItemInfo subject(ids.first());
     graph.addHistory(history1(), subject);
     graph.reduceEdges();
 
@@ -249,11 +249,11 @@ void DImgHistoryGraphTest::testHistory()
     QCOMPARE(graph.data().edges().size(), 2);
 }
 
-class lessThanById
+class Q_DECL_HIDDEN lessThanById
 {
 public:
 
-    lessThanById(const QMap<HistoryGraph::Vertex, qlonglong>& vertexToId)
+    explicit lessThanById(const QMap<HistoryGraph::Vertex, qlonglong>& vertexToId)
         : vertexToId(vertexToId)
     {
     }
@@ -366,8 +366,8 @@ void DImgHistoryGraphTest::testGraph()
     pairs << IdPair(22,1);
     pairs << IdPair(23,1);
     pairs << IdPair(24,1);
-    pairs << IdPair(8,2); //X
-    pairs << IdPair(9,2); //X
+    pairs << IdPair(8,2);  //X
+    pairs << IdPair(9,2);  //X
     pairs << IdPair(10,2); //X
     //pairs << IdPair(19,2);
     //pairs << IdPair(20,2);
@@ -392,7 +392,7 @@ void DImgHistoryGraphTest::testGraph()
     pairs << IdPair(24,1);
     pairs << IdPair(24,12);
 
-    ImageHistoryGraph graph;
+    ItemHistoryGraph graph;
     graph.addRelations(pairs);
 
     qDebug() << "Initial graph:" << graph;
@@ -411,7 +411,7 @@ void DImgHistoryGraphTest::testGraph()
     /*
     QBENCHMARK
     {
-        ImageHistoryGraph benchGraph;
+        ItemHistoryGraph benchGraph;
         graph.addRelations(pairs);
         graph.finish();
         graph.relationCloud();
