@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-08-01
  * Description : a test for the DImageHistory
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef DIMGEHISTORYTEST_H
-#define DIMGEHISTORYTEST_H
+#ifndef DIGIKAM_DIMG_HISTORY_TEST_H
+#define DIGIKAM_DIMG_HISTORY_TEST_H
 
 // Qt includes
 
@@ -52,4 +52,4 @@ private Q_SLOTS:
     void cleanupTestCase();
 };
 
-#endif // DIMGEHISTORYTEST_H
+#endif // DIGIKAM_DIMG_HISTORY_TEST_H
