@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-06-29
  * Description : Pressable Button class using QGraphicsItem
+ *               based on Frederico Duarte implementation.
  *
- * Copyright (C) 2010      by Frederico Duarte
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef BUTTON_H
-#define BUTTON_H
+#ifndef DIGIKAM_DEMO_BUTTON_H
+#define DIGIKAM_DEMO_BUTTON_H
 
 // Qt includes
 
@@ -35,7 +35,8 @@
 namespace Digikam
 {
 
-class Button : public QObject, public QGraphicsItem
+class Button : public QObject,
+               public QGraphicsItem
 {
     Q_OBJECT
     Q_INTERFACES(QGraphicsItem)
@@ -70,4 +71,4 @@ private:
 
 } // namespace Digikam
 
-#endif // BUTTON_H
+#endif // DIGIKAM_DEMO_BUTTON_H
