@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-06-21
  * Description : GUI test program for FacesEngine
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Alex Jironkin <alexjironkin at gmail dot com>
  * Copyright (C)      2010 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -23,17 +23,17 @@
  *
  * ============================================================ */
 
-#ifndef FACEITEM_H
-#define FACEITEM_H
+#ifndef DIGIKAM_DEMO_FACE_ITEM_H
+#define DIGIKAM_DEMO_FACE_ITEM_H
 
 // Qt includes
 
-#include <QtCore/QtGlobal>
-#include <QtCore/QObject>
-#include <QtWidgets/QGraphicsObject>
-#include <QtWidgets/QGraphicsRectItem>
-#include <QtGui/QBrush>
-#include <QtGui/QFont>
+#include <QtGlobal>
+#include <QObject>
+#include <QGraphicsObject>
+#include <QGraphicsRectItem>
+#include <QBrush>
+#include <QFont>
 
 // Local includes
 
@@ -48,9 +48,12 @@ class FaceItem : public QGraphicsObject
 
 public:
 
-    explicit FaceItem(QGraphicsItem* const parent = 0, QGraphicsScene* const scene = 0,
+    explicit FaceItem(QGraphicsItem* const parent = 0,
+                      QGraphicsScene* const scene = 0,
                       const QRect& rect = QRect(0, 0, 0, 0),
-                      double scale = 1, const QString& name = QString(), double originalscale = 1);
+                      double scale = 1,
+                      const QString& name = QString(),
+                      double originalscale = 1);
     ~FaceItem();
 
     QRectF boundingRect() const;
@@ -96,4 +99,4 @@ private:
 
 } // namespace Digikam
 
-#endif // FACEITEM_H
+#endif // DIGIKAM_DEMO_FACE_ITEM_H
