@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-07-23
  * Description : QGraphicsRectItem wrapper for FacesEngine
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2008 by Adrien Bustany <madcat at mymadcat dot com>
  * Copyright (C)      2010 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -23,9 +23,8 @@
  *
  * ============================================================ */
 
-
-#ifndef FANCYRECT_H
-#define FANCYRECT_H
+#ifndef DIGIKAM_DEMO_FANCY_RECT_H
+#define DIGIKAM_DEMO_FANCY_RECT_H
 
 // Qt includes
 
@@ -46,6 +45,7 @@ public:
 
     explicit FancyRect(QGraphicsItem* const parent = 0);
     explicit FancyRect(const QRectF& rect, QGraphicsItem* const parent = 0);
+
     FancyRect(qreal x, qreal y, qreal w, qreal h, QGraphicsItem* const parent = 0);
     FancyRect(QGraphicsRectItem* const other, QGraphicsItem* const parent);
 
@@ -54,4 +54,4 @@ public:
 
 } // namespace Digikam
 
-#endif /* FANCYRECT_H */
+#endif // DIGIKAM_DEMO_FANCY_RECT_H
