@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-06-21
  * Description : GUI test program for FacesEngine
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Alex Jironkin <alexjironkin at gmail dot com>
  * Copyright (C)      2010 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef MAINWINDOW_H
-#define MAINWINDOW_H
+#ifndef DIGIKAM_DEMO_MAIN_WINDOW_H
+#define DIGIKAM_DEMO_MAIN_WINDOW_H
 
 // Qt includes
 
@@ -62,4 +62,4 @@ private:
     Private* const d;
 };
 
-#endif // MAINWINDOW_H
+#endif // DIGIKAM_DEMO_MAIN_WINDOW_H
