@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-07-23
  * Description : face marquer widget for FacesEngine
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Adrien Bustany <madcat at mymadcat dot com>
  * Copyright (C)      2010 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -41,7 +41,7 @@
 namespace Digikam
 {
 
-class Marquee::Private
+class Q_DECL_HIDDEN Marquee::Private
 {
 public:
 
@@ -53,7 +53,9 @@ public:
         BottomRight
     };
 
-    Private()
+public:
+
+    explicit Private()
       : handleSize(10)
     {
         htl        = 0;
@@ -67,6 +69,8 @@ public:
         resizeType = 0;
     }
 
+public:
+
     const int                handleSize;
     QPen                     rectPen;    // The pen used to draw the frames
     QPen                     outlinePen; // Text outline pen
@@ -87,9 +91,10 @@ public:
 };
 
 Marquee::Marquee(FancyRect* const rect, QGraphicsItem* const parent)
-    : QObject(0), QGraphicsItemGroup(parent), d(new Private)
+    : QObject(0), QGraphicsItemGroup(parent),
+      d(new Private)
 {
-    d->rect   = rect;
+    d->rect    = rect;
     d->rectPen.setColor(Qt::red);
     d->rectPen.setWidth(2);
     d->outlinePen.setColor(Qt::red);
@@ -213,7 +218,7 @@ void Marquee::mouseMoveEvent(QGraphicsSceneMouseEvent* e)
     {
         QRectF r = d->rect->rect();
 
-        switch(d->resizeType)
+        switch (d->resizeType)
         {
             case Private::TopLeft:
                 r.setTopLeft(e->pos());
