@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-06-16
  * Description : CLI test program for training database
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,19 +42,18 @@
 
 using namespace Digikam;
 
-
-
 // --------------------------------------------------------------------------------------------------
 
 const int firstMultiplier  = 20;
 const int secondMultiplier = 20;
 
-class Runnable : public QRunnable
+class Q_DECL_HIDDEN Runnable : public QRunnable
 {
 public:
 
     Runnable(int number, RecognitionDatabase db)
-        : number(number), db(db)
+        : number(number),
+          db(db)
     {
     }
 
@@ -67,7 +66,7 @@ public:
 
         // Populate database.
 
-        for (int i = number * secondMultiplier ; i < number * secondMultiplier + secondMultiplier; i++)
+        for (int i = number * secondMultiplier ; i < number * secondMultiplier + secondMultiplier ; ++i)
         {
             QString name      = QString::fromLatin1("face%1").arg(i);
             qDebug() << "Record Identity " << name << " to DB";
@@ -81,7 +80,7 @@ public:
 
         // Check records in database.
 
-        for (int i=number*secondMultiplier ; i < number*secondMultiplier+secondMultiplier; i++)
+        for (int i = number * secondMultiplier ; i < number*secondMultiplier+secondMultiplier ; ++i)
         {
             QString name = QString::fromLatin1("face%1").arg(i);
             identity     = db.findIdentity(QString::fromLatin1("name"), name);
@@ -97,7 +96,9 @@ public:
         }
     }
 
-    const int number;
+public:
+
+    const int           number;
     RecognitionDatabase db;
 };
 
@@ -114,7 +115,7 @@ int main(int argc, char** argv)
     QThreadPool pool;
     pool.setMaxThreadCount(101);
 
-    for (int i = 0 ; i < firstMultiplier ; i++)
+    for (int i = 0 ; i < firstMultiplier ; ++i)
     {
         Runnable* r= new Runnable(i, db);
         pool.start(r);
@@ -127,7 +128,7 @@ int main(int argc, char** argv)
     QImage image(256, 256, QImage::Format_ARGB32);
     QList<Identity> list = db.recognizeFaces(QList<QImage>() << image);
 
-    if (!list.empty())
+    if (!list.isEmpty())
     {
         foreach(Identity id, list)
         {
