@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-09-18
  * Description : A tool to calibrate the tiling levels
@@ -58,12 +58,12 @@ using namespace Digikam;
 
 const int CoordinatesRole = Qt::UserRole + 1;
 
-class CalibratorModelHelper::Private
+class Q_DECL_HIDDEN CalibratorModelHelper::Private
 {
 public:
 
-    Private()
-     : model(0)
+    explicit Private()
+        : model(0)
     {
     }
 
@@ -124,11 +124,11 @@ GeoModelHelper::PropertyFlags CalibratorModelHelper::modelFlags() const
 
 // ---------------------------------------------------------------------------------------------
 
-class Calibrator::Private
+class Q_DECL_HIDDEN Calibrator::Private
 {
 public:
 
-    Private()
+    explicit Private()
      : hBoxLayout(0),
        model(0),
        modelHelper(0),
