@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : main-window of the demo application
@@ -34,7 +34,6 @@
 #include <QFutureWatcher>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QProgressBar>
 #include <QPushButton>
 #include <QSplitter>
 #include <QTimer>
@@ -125,7 +124,7 @@ void MarkerModelHelper::onIndicesMoved(const QList<QPersistentModelIndex>& moved
 
 // ----------------------------------------------------------------------
 
-class MyImageData
+class Q_DECL_HIDDEN MyImageData
 {
 public:
 
@@ -180,11 +179,11 @@ TrackManager::Track::List MyTrackModelHelper::getTracks() const
 
 // ----------------------------------------------------------------------
 
-class MainWindow::Private
+class Q_DECL_HIDDEN MainWindow::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : splitter(0),
         mapWidget(0),
         lookupAltitudeList(),
@@ -234,7 +233,7 @@ MainWindow::MainWindow(QCommandLineParser* const cmdLineArgs, QWidget* const par
 
     d->treeWidget = new MyTreeWidget(this);
     d->treeWidget->setColumnCount(2);
-    d->treeWidget->setHeaderLabels(QStringList()<<i18n("Filename")<<i18n("Coordinates"));
+    d->treeWidget->setHeaderLabels(QStringList() << i18n("Filename") << i18n("Coordinates"));
     d->treeWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
     d->displayMarkersModel    = d->treeWidget->model();
@@ -245,7 +244,7 @@ MainWindow::MainWindow(QCommandLineParser* const cmdLineArgs, QWidget* const par
 
     resize(512, 512);
     setWindowTitle(i18n("Geolocation Interface demo"));
-    setWindowIcon(QIcon::fromTheme(QString::fromLatin1("globe")));
+    setWindowIcon(QIcon::fromTheme(QLatin1String("globe")));
     setObjectName(QLatin1String("DemoGeoLocationInterface" ));
 
     d->cmdLineArgs = cmdLineArgs;
@@ -313,7 +312,8 @@ MainWindow::MainWindow(QCommandLineParser* const cmdLineArgs, QWidget* const par
     // Sagrada Familia in Spain
     markerList<<GeoCoordinates::fromGeoUrl(QLatin1String("geo:41.4036480511,2.1743756533,46" ));
 
-    if (cmdLineArgs->isSet(QString::fromLatin1("demopoints_single")) || cmdLineArgs->isSet(QString::fromLatin1("demopoints_group")))
+    if (cmdLineArgs->isSet(QLatin1String("demopoints_single")) ||
+        cmdLineArgs->isSet(QLatin1String("demopoints_group")))
     {
         for (int i = 0; i < markerList.count(); ++i)
         {
@@ -532,7 +532,7 @@ void MainWindow::slotMarkersMoved(const QList<QPersistentModelIndex>& markerIndi
 
     if (!altitudeQueries.isEmpty())
     {
-        LookupAltitude* const myAltitudeLookup = LookupFactory::getAltitudeLookup(QString::fromLatin1("geonames"), this);
+        LookupAltitude* const myAltitudeLookup = LookupFactory::getAltitudeLookup(QLatin1String("geonames"), this);
 
         connect(myAltitudeLookup, SIGNAL(signalRequestsReady(QList<int>)),
                 this, SLOT(slotAltitudeRequestsReady(QList<int>)));
@@ -596,7 +596,7 @@ void MainWindow::slotAddImages()
     if (fileNames.isEmpty())
         return;
 
-    d->lastImageOpenDir         = fileNames.first().resolved(QUrl(QString::fromLatin1("../")));
+    d->lastImageOpenDir         = fileNames.first().resolved(QUrl(QLatin1String("../")));
 
     slotScheduleImagesForLoading(fileNames);
 }
