@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-12-28
  * Description : test for implementation of thread manager api
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2014 by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -45,11 +45,11 @@
 
 #include "myactionthread.h"
 
-class ProcessorDlg::Private
+class Q_DECL_HIDDEN ProcessorDlg::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         count        = 0;
         page         = 0;
