@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-09-14
  * Description : a rename dialog for the AdvancedRename utility
  *
  * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +30,6 @@
 #include <QEvent>
 #include <QFileInfo>
 #include <QGridLayout>
-#include <QHeaderView>
 #include <QMoveEvent>
 #include <QSet>
 #include <QString>
@@ -62,11 +61,11 @@
 namespace Digikam
 {
 
-class AdvancedRenameListItem::Private
+class Q_DECL_HIDDEN AdvancedRenameListItem::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
@@ -144,12 +143,12 @@ bool AdvancedRenameListItem::isNameEqual() const
 
 // --------------------------------------------------------
 
-class AdvancedRenameDialog::Private
+class Q_DECL_HIDDEN AdvancedRenameDialog::Private
 {
 public:
 
-    Private() :
-        singleFileMode(false),
+    explicit Private()
+      : singleFileMode(false),
         minSizeDialog(450),
         sortActionName(0),
         sortActionDate(0),
@@ -202,6 +201,12 @@ AdvancedRenameDialog::AdvancedRenameDialog(QWidget* const parent)
     : QDialog(parent),
       d(new Private)
 {
+    setWindowFlags((windowFlags() & ~Qt::Dialog) |
+                   Qt::Window                    |
+                   Qt::WindowCloseButtonHint     |
+                   Qt::WindowMinMaxButtonsHint);
+
+    setModal(true);
     setupWidgets();
     setupConnections();
 
@@ -541,7 +546,6 @@ bool AdvancedRenameDialog::checkNewNames() const
             completeNewName.append(item->newName());
 
             bool invalid = tmpNewNames.contains(completeNewName);
-            invalid     |= QFile::exists(completeNewName);
             tmpNewNames << completeNewName;
 
             item->markInvalid(invalid);
@@ -584,4 +588,4 @@ void AdvancedRenameDialog::slotHelp()
     DXmlGuiWindow::openHandbook();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
