@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-09-03
  * Description : an input widget for the AdvancedRename utility
@@ -52,12 +52,12 @@ static const QString DUMMY_TEXT(QLatin1String("DUMMY_TEXT_y_fjqp|"));
 namespace Digikam
 {
 
-class AdvancedRenameLineEdit::Private
+class Q_DECL_HIDDEN AdvancedRenameLineEdit::Private
 {
 public:
 
-    Private() :
-        allowDirectoryCreation(false),
+    explicit Private()
+      : allowDirectoryCreation(false),
         verticalSliderPosition(INVALID),
         parseTimer(0),
         parser(0)
@@ -243,12 +243,12 @@ void AdvancedRenameLineEdit::slotSetText(const QString& text)
 
 // --------------------------------------------------------
 
-class AdvancedRenameInput::Private
+class Q_DECL_HIDDEN AdvancedRenameInput::Private
 {
 public:
 
-    Private() :
-        maxVisibleItems(10),
+    explicit Private()
+      : maxVisibleItems(10),
         maxHistoryItems(30),
         lineEdit(0),
         proxy(0),
@@ -435,4 +435,4 @@ void AdvancedRenameInput::writeSettings()
     group.writeEntry(d->configPatternHistoryListEntry, patternHistory);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
