@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-11-14
  * Description : process dialog for renaming files
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ADVANCEDRENAMEPROCESSDIALOG_H
-#define ADVANCEDRENAMEPROCESSDIALOG_H
+#ifndef DIGIKAM_ADVANCED_RENAME_PROCESS_DIALOG_H
+#define DIGIKAM_ADVANCED_RENAME_PROCESS_DIALOG_H
 
 // Local includes
 
@@ -45,9 +45,11 @@ class DIGIKAM_EXPORT AdvancedRenameProcessDialog : public DProgressDlg
 
 public:
 
-    explicit AdvancedRenameProcessDialog(const NewNamesList& list);
+    explicit AdvancedRenameProcessDialog(const NewNamesList& list, QWidget* const parent = 0);
     ~AdvancedRenameProcessDialog();
 
+    QList<QUrl> failedUrls() const;
+
 private:
 
     AdvancedRenameProcessDialog(const AdvancedRenameProcessDialog&);
@@ -56,6 +58,7 @@ private:
     void abort();
     void complete();
     void processOne();
+    void getNextThumbnail();
 
 protected:
 
@@ -64,13 +67,13 @@ protected:
 protected Q_SLOTS:
 
     void slotCancel();
-    void slotRenameSuccess(const QUrl&);
-    void slotRenameFailed(const QUrl&);
+    void slotRenameFinished();
+    void slotRenameFailed(const QUrl& url);
 
 private Q_SLOTS:
 
     void slotRenameImages();
-    void slotGotThumbnail(const LoadingDescription&, const QPixmap&);
+    void slotGotThumbnail(const LoadingDescription& desc, const QPixmap& pix);
 
 private:
 
@@ -78,6 +81,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* ADVANCEDRENAMEPROCESSDIALOG_H */
+#endif // DIGIKAM_ADVANCED_RENAME_PROCESS_DIALOG_H
