@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-05-22
  * Description : a control widget for the AdvancedRename utility
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ADVANCEDRENAMEWIDGET_H
-#define ADVANCEDRENAMEWIDGET_H
+#ifndef DIGIKAM_ADVANCED_RENAME_WIDGET_H
+#define DIGIKAM_ADVANCED_RENAME_WIDGET_H
 
 // Qt includes
 
@@ -173,8 +173,8 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::AdvancedRenameWidget::ControlWidgets)
 
-#endif /* ADVANCEDRENAMEWIDGET_H */
+#endif // DIGIKAM_ADVANCED_RENAME_WIDGET_H
