@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-10-22
  * Description : a dynamic layout manager
@@ -31,18 +31,19 @@
 namespace Digikam
 {
 
-class DynamicLayout::Private
+class Q_DECL_HIDDEN DynamicLayout::Private
 {
 public:
 
-    Private(int hSpacing, int vSpacing)
+    explicit Private(int hSpacing, int vSpacing)
       : hSpace(hSpacing),
         vSpace(vSpacing),
         spaceX(0),
         spaceY(0),
         minItemWidth(0),
         minColumns(2)
-    {}
+    {
+    }
 
     int                 hSpace;
     int                 vSpace;
@@ -56,8 +57,9 @@ public:
 
 // --------------------------------------------------------
 
-DynamicLayout::DynamicLayout(QWidget* parent, int margin, int hSpacing, int vSpacing)
-    : QLayout(parent), d(new Private(hSpacing, vSpacing))
+DynamicLayout::DynamicLayout(QWidget* const parent, int margin, int hSpacing, int vSpacing)
+    : QLayout(parent),
+      d(new Private(hSpacing, vSpacing))
 {
     setContentsMargins(margin, margin, margin, margin);
 }
@@ -85,7 +87,7 @@ void DynamicLayout::addItem(QLayoutItem* item)
     d->minItemWidth = 0;
     d->itemList.append(item);
 
-    foreach(QLayoutItem* const item, d->itemList)
+    foreach (QLayoutItem* const item, d->itemList)
     {
         QWidget* wid    = item->widget();
         d->spaceX       = qMax<int>(wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton,
@@ -165,7 +167,7 @@ QSize DynamicLayout::minimumSize() const
 {
     QSize size;
 
-    foreach(QLayoutItem* const item, d->itemList)
+    foreach (QLayoutItem* const item, d->itemList)
     {
         size = size.expandedTo(item->minimumSize());
     }
@@ -173,6 +175,7 @@ QSize DynamicLayout::minimumSize() const
     size += QSize(2 * contentsMargins().left(), 2 * contentsMargins().top());
     int w = (size.width() * d->minColumns) + (d->minColumns * d->spaceX);
     size.setWidth(w);
+
     return size;
 }
 
@@ -192,7 +195,11 @@ int DynamicLayout::reLayout(const QRect& rect, bool testOnly) const
     // --------------------------------------------------------
 
     int buttonWidth     = d->minItemWidth + d->spaceX;
-    buttonWidth         = (buttonWidth == 0) ? 1 : buttonWidth;
+
+    if (buttonWidth == 0)
+    {
+        buttonWidth = 1;
+    }
 
     int maxButtonsInRow = (effectiveRect.width() - d->spaceX) / buttonWidth;
 
@@ -201,14 +208,13 @@ int DynamicLayout::reLayout(const QRect& rect, bool testOnly) const
         maxButtonsInRow = d->minColumns;
     }
 
-    maxButtonsInRow     = (maxButtonsInRow == 0) ? d->minColumns : maxButtonsInRow;
     int maxButtonWidth  = d->minItemWidth + ((effectiveRect.width() - (maxButtonsInRow * buttonWidth)) / maxButtonsInRow);
 
     int currentBtnWidth = (maxButtonsInRow >= d->itemList.count()) ? buttonWidth : maxButtonWidth;
 
     // --------------------------------------------------------
 
-    foreach(QLayoutItem* const item, d->itemList)
+    foreach (QLayoutItem* const item, d->itemList)
     {
         int nextX = x + currentBtnWidth + d->spaceX;
 
