@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-09-12
  * Description : parse settings class
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef PARSESETTINGS_H
-#define PARSESETTINGS_H
+#ifndef DIGIKAM_PARSE_SETTINGS_H
+#define DIGIKAM_PARSE_SETTINGS_H
 
 // Qt includes
 
@@ -32,7 +32,7 @@
 
 // Local includes
 
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "parseresults.h"
 #include "advancedrenamemanager.h"
 
@@ -48,19 +48,21 @@ public:
     {
         init();
     };
-    explicit ParseSettings(const QString& _parseString) :
-        parseString(_parseString)
+
+    explicit ParseSettings(const QString& _parseString)
+        : parseString(_parseString)
     {
         init();
     };
 
-    // ImageInfo ctors
-    explicit ParseSettings(const ImageInfo& info)
+    // ItemInfo ctors
+    explicit ParseSettings(const ItemInfo& info)
     {
         init(info);
     };
-    ParseSettings(const QString& _parseString, const ImageInfo& info) :
-        parseString(_parseString)
+
+    ParseSettings(const QString& _parseString, const ItemInfo& info)
+        : parseString(_parseString)
     {
         init(info);
     };
@@ -97,7 +99,7 @@ private:
         str2Modify.clear();
     }
 
-    void init(const ImageInfo& info)
+    void init(const ItemInfo& info)
     {
         init();
         fileUrl = info.fileUrl();
@@ -106,4 +108,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* PARSESETTINGS_H */
+#endif // DIGIKAM_PARSE_SETTINGS_H
