@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-05-28
  * Description : a dialog for showing the advancedrename tooltip
@@ -41,12 +41,12 @@
 namespace Digikam
 {
 
-class TooltipDialog::Private
+class Q_DECL_HIDDEN TooltipDialog::Private
 {
 public:
 
-    Private() :
-        buttons(0),
+    explicit Private()
+      : buttons(0),
         textBrowser(0)
     {
     }
@@ -56,11 +56,12 @@ public:
 };
 
 TooltipDialog::TooltipDialog(QWidget* const parent)
-    : QDialog(parent), d(new Private)
+    : QDialog(parent),
+      d(new Private)
 {
     setWindowTitle(i18n("Information"));
 
-    d->buttons = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    d->buttons     = new QDialogButtonBox(QDialogButtonBox::Close, this);
     d->buttons->button(QDialogButtonBox::Close)->setDefault(true);
 
     d->textBrowser = new QTextBrowser(this);
