@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-08
  * Description : an option to provide date information to the parser
@@ -283,7 +283,7 @@ QString DateOption::parseOperation(ParseSettings& settings)
     else
     {
         // lets try to re-read the file information
-        ImageInfo info = ImageInfo::fromUrl(settings.fileUrl);
+        ItemInfo info = ItemInfo::fromUrl(settings.fileUrl);
 
         if (!info.isNull())
         {
