@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-09-12
  * Description : Widget for assignment and confirmation of names for faces
@@ -30,7 +30,6 @@
 #include <QToolButton>
 #include <QApplication>
 #include <QIcon>
-#include <QFontDatabase>
 
 // Local includes
 
@@ -43,14 +42,14 @@
 #include "albumtreeview.h"
 #include "facetagsiface.h"
 #include "dimg.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "thememanager.h"
 #include "applicationsettings.h"
 
 namespace Digikam
 {
 
-class AssignNameWidget::Private
+class Q_DECL_HIDDEN AssignNameWidget::Private
 {
 public:
 
@@ -85,7 +84,9 @@ private:
     void         updateLayout();
     void         updateVisualStyle();
 
-    QToolButton* createToolButton(const QIcon& icon, const QString& text, const QString& tip = QString()) const;
+    QToolButton* createToolButton(const QIcon& icon,
+                                  const QString& text,
+                                  const QString& tip = QString()) const;
 
     QWidget* addTagsWidget() const
     {
@@ -108,7 +109,7 @@ private:
 
 public:
 
-    ImageInfo                  info;
+    ItemInfo                  info;
     QVariant                   faceIdentifier;
     AlbumPointer<TAlbum>       currentTag;
 
@@ -145,19 +146,19 @@ bool AssignNameWidget::Private::isValid() const
 void AssignNameWidget::Private::clearWidgets()
 {
     delete comboBox;
-    comboBox = 0;
+    comboBox       = 0;
 
     delete lineEdit;
-    lineEdit = 0;
+    lineEdit      = 0;
 
     delete confirmButton;
     confirmButton = 0;
 
     delete rejectButton;
-    rejectButton = 0;
+    rejectButton  = 0;
 
     delete clickLabel;
-    clickLabel = 0;
+    clickLabel    = 0;
 }
 
 QToolButton* AssignNameWidget::Private::createToolButton(const QIcon& icon, const QString& text, const QString& tip) const
@@ -167,6 +168,7 @@ QToolButton* AssignNameWidget::Private::createToolButton(const QIcon& icon, cons
     b->setText(text);
     b->setToolTip(tip);
     b->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+
     return b;
 }
 
@@ -226,6 +228,7 @@ void AssignNameWidget::Private::checkWidgets()
                     if (!comboBox)
                     {
                         comboBox = new AddTagsComboBox(q);
+                        comboBox->setMinimumWidth(230);
                         setupAddTagsWidget(comboBox);
                     }
 
@@ -384,6 +387,7 @@ static QString styleSheetFontDescriptor(const QFont& font)
     s += (font.pointSize() == -1) ? QString::fromUtf8("font-size: %1px; ").arg(font.pixelSize())
                                   : QString::fromUtf8("font-size: %1pt; ").arg(font.pointSize());
     s += QString::fromUtf8("font-family: \"%1\"; ").arg(font.family());
+
     return s;
 }
 
@@ -394,6 +398,17 @@ void AssignNameWidget::Private::updateVisualStyle()
         return;
     }
 
+    QFont appFont = ApplicationSettings::instance()->getApplicationFont();
+
+    if (appFont.pointSize() == -1)
+    {
+        appFont.setPixelSize(appFont.pixelSize() - 1);
+    }
+    else
+    {
+        appFont.setPointSize(appFont.pointSize() - 1);
+    }
+
     switch (visualStyle)
     {
         case InvalidVisualStyle:
@@ -454,7 +469,7 @@ void AssignNameWidget::Private::updateVisualStyle()
                     "QLabel { "
                     "  color: white; background-color: transparent; border: none; "
                     "}"
-                ).arg(styleSheetFontDescriptor(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont)))
+                ).arg(styleSheetFontDescriptor(appFont))
                  .arg((mode == ConfirmedMode) ? QLatin1String("8") : QLatin1String("4"))
             );
             break;
@@ -476,7 +491,7 @@ void AssignNameWidget::Private::updateVisualStyle()
                     "  border: none; "
                     "  border-radius: 8px; "
                     "}"
-                ).arg(styleSheetFontDescriptor(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont)))
+                ).arg(styleSheetFontDescriptor(appFont))
                  .arg(bg.red())
                  .arg(bg.green())
                  .arg(bg.blue())
@@ -526,7 +541,8 @@ void AssignNameWidget::Private::updateContents()
 
     if (clickLabel)
     {
-        clickLabel->setText(currentTag ? currentTag->title() : QString());
+        clickLabel->setText(currentTag ? currentTag->title()
+                                       : QString());
     }
 }
 
@@ -550,14 +566,16 @@ void AssignNameWidget::setDefaultModel()
     setModel(0, 0, 0);
 }
 
-void AssignNameWidget::setModel(TagModel* const model, TagPropertiesFilterModel* const filteredModel, CheckableAlbumFilterModel* const filterModel)
+void AssignNameWidget::setModel(TagModel* const model,
+                                TagPropertiesFilterModel* const filteredModel,
+                                CheckableAlbumFilterModel* const filterModel)
 {
     // Restrict the tag properties filter model to people if configured.
     ApplicationSettings* const settings = ApplicationSettings::instance();
 
     if (settings)
     {
-        if (settings->showOnlyPersonTagsInPeopleSidebar())
+        if (filteredModel && settings->showOnlyPersonTagsInPeopleSidebar())
         {
             filteredModel->listOnlyTagsWithProperty(TagPropertyName::person());
         }
@@ -673,13 +691,13 @@ AssignNameWidget::VisualStyle AssignNameWidget::visualStyle() const
     return d->visualStyle;
 }
 
-void AssignNameWidget::setUserData(const ImageInfo& info, const QVariant& faceIdentifier)
+void AssignNameWidget::setUserData(const ItemInfo& info, const QVariant& faceIdentifier)
 {
     d->info           = info;
     d->faceIdentifier = faceIdentifier;
 }
 
-ImageInfo AssignNameWidget::info() const
+ItemInfo AssignNameWidget::info() const
 {
     return d->info;
 }
@@ -710,6 +728,12 @@ void AssignNameWidget::setCurrentTag(TAlbum* album)
 {
     if (d->currentTag == album)
     {
+        if (d->clickLabel)
+        {
+            d->clickLabel->setText(d->currentTag ? d->currentTag->title()
+                                                 : QString());
+        }
+
         return;
     }
 
