@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-09-12
  * Description : Widget for assignment and confirmation of names for faces
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ASSIGNNAMEWIDGET_H
-#define ASSIGNNAMEWIDGET_H
+#ifndef DIGIKAM_ASSIGN_NAME_WIDGET_H
+#define DIGIKAM_ASSIGN_NAME_WIDGET_H
 
 // Qt includes
 
@@ -36,7 +36,7 @@ class AddTagsComboBox;
 class AddTagsLineEdit;
 class CheckableAlbumFilterModel;
 class FaceTagsIface;
-class ImageInfo;
+class ItemInfo;
 class TAlbum;
 class TaggingAction;
 class TagModel;
@@ -102,13 +102,13 @@ public:
     TagEntryWidgetMode tagEntryWidgetMode() const;
 
     void setLayoutMode(LayoutMode mode);
-    LayoutMode layoutMode() const;
+    LayoutMode layoutMode()     const;
 
     void setVisualStyle(VisualStyle style);
-    VisualStyle visualStyle() const;
+    VisualStyle visualStyle()   const;
 
-    ImageInfo info()           const;
-    QVariant  faceIdentifier() const;
+    ItemInfo info()            const;
+    QVariant  faceIdentifier()  const;
 
     /// The combo box or line edit in use, if any
     AddTagsComboBox* comboBox() const;
@@ -117,7 +117,7 @@ public:
 public Q_SLOTS:
 
     /** The identifying information emitted with the signals */
-    void setUserData(const ImageInfo& info, const QVariant& faceIdentifier = QVariant());
+    void setUserData(const ItemInfo& info, const QVariant& faceIdentifier = QVariant());
 
     /** Sets the suggested (UnconfirmedEditMode) or assigned (ConfirmedMode) tag to be displayed. */
     void setCurrentTag(int tagId);
@@ -134,25 +134,25 @@ Q_SIGNALS:
      * This can be an existing tag, or a new tag, as described by TaggingAction.
      * For convenience, info() and faceIdentifier() are provided.
      */
-    void assigned(const TaggingAction& action, const ImageInfo& info, const QVariant& faceIdentifier);
+    void assigned(const TaggingAction& action, const ItemInfo& info, const QVariant& faceIdentifier);
 
     /**
      * The face has been reject and shall be removed.
      * For convenience, info() and faceIdentifier() are provided.
      */
-    void rejected(const ImageInfo& info, const QVariant& faceIdentifier);
+    void rejected(const ItemInfo& info, const QVariant& faceIdentifier);
 
     /**
      * In ConfirmedMode, this signal is emitted when the user clicked on the label
      */
-    void labelClicked(const ImageInfo& info, const QVariant& faceIdentifier);
+    void labelClicked(const ItemInfo& info, const QVariant& faceIdentifier);
 
     /**
      * An action has been selected. This purely signals user interaction,
      * no fixed decision - mouse hover may be enough to emit this signal.
      * The action may be invalid (user switched back to empty selection).
      */
-    void selected(const TaggingAction& action, const ImageInfo& info, const QVariant& faceIdentifier);
+    void selected(const TaggingAction& action, const ItemInfo& info, const QVariant& faceIdentifier);
 
 protected:
 
@@ -175,4 +175,4 @@ private:
 
 } // namespace Digikam
 
-#endif // ASSIGNNAMEWIDGET_H
+#endif // DIGIKAM_ASSIGN_NAME_WIDGET_H
