@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-09-17
  * Description : Managing of face tag region items on a GraphicsDImgView
@@ -43,7 +43,8 @@
 #include "facetags.h"
 #include "facetagseditor.h"
 #include "graphicsdimgview.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
+#include "metadatahub.h"
 #include "regionframeitem.h"
 #include "taggingaction.h"
 #include "itemvisibilitycontroller.h"
@@ -61,7 +62,7 @@ enum FaceGroupState
 
 //-------------------------------------------------------------------------------
 
-class FaceItem : public RegionFrameItem
+class Q_DECL_HIDDEN FaceItem : public RegionFrameItem
 {
 public:
 
@@ -77,8 +78,8 @@ public:
 
 protected:
 
+    FaceTagsIface       m_face;
     AssignNameWidget*   m_widget;
-    FaceTagsIface        m_face;
     HidingStateChanger* m_changer;
 };
 
@@ -166,7 +167,7 @@ void AssignNameWidgetHidingStateChanger::slotStateChanged()
 
 //-------------------------------------------------------------------------------
 
-class FaceGroup::Private
+class Q_DECL_HIDDEN FaceGroup::Private
 {
 public:
 
@@ -196,7 +197,7 @@ public:
 public:
 
     GraphicsDImgView*          view;
-    ImageInfo                  info;
+    ItemInfo                  info;
     bool                       autoSuggest;
     bool                       showOnHover;
 
@@ -225,6 +226,12 @@ FaceGroup::FaceGroup(GraphicsDImgView* const view)
     d->visibilityController = new ItemVisibilityController(this);
     d->visibilityController->setShallBeShown(false);
 
+    connect(AlbumManager::instance(), SIGNAL(signalAlbumRenamed(Album*)),
+            this, SLOT(slotAlbumRenamed(Album*)));
+
+    connect(AlbumManager::instance(), SIGNAL(signalAlbumsUpdated(int)),
+            this, SLOT(slotAlbumsUpdated(int)));
+
     connect(view->previewItem(), SIGNAL(stateChanged(int)),
             this, SLOT(itemStateChanged(int)));
 
@@ -269,7 +276,7 @@ bool FaceGroup::hasVisibleItems() const
     return d->visibilityController->hasVisibleItems();
 }
 
-ImageInfo FaceGroup::info() const
+ItemInfo FaceGroup::info() const
 {
     return d->info;
 }
@@ -278,7 +285,7 @@ QList<RegionFrameItem*> FaceGroup::items() const
 {
     QList<RegionFrameItem*> items;
 
-    foreach(FaceItem* const item, d->items)
+    foreach (FaceItem* const item, d->items)
     {
         items << item;
     }
@@ -340,7 +347,7 @@ void FaceGroup::setVisibleItem(RegionFrameItem* item)
     d->applyVisible();
 }
 
-void FaceGroup::setInfo(const ImageInfo& info)
+void FaceGroup::setInfo(const ItemInfo& info)
 {
     if (d->info == info && d->state != NoFaces)
     {
@@ -356,18 +363,18 @@ void FaceGroup::setInfo(const ImageInfo& info)
     }
 }
 
-void FaceGroup::aboutToSetInfo(const ImageInfo& info)
+void FaceGroup::aboutToSetInfo(const ItemInfo& info)
 {
     if (d->info == info)
     {
         return;
     }
 
-    applyItemGeometryChanges();
+    //applyItemGeometryChanges();
     clear();
 }
 
-void FaceGroup::aboutToSetInfoAfterRotate(const ImageInfo& info)
+void FaceGroup::aboutToSetInfoAfterRotate(const ItemInfo& info)
 {
     if (d->info == info)
     {
@@ -409,7 +416,7 @@ RegionFrameItem* FaceGroup::closestItem(const QPointF& p, qreal* const manhattan
     qreal minDistance            = 0;
     qreal minCenterDistance      = 0;
 
-    foreach(RegionFrameItem* const item, d->items)
+    foreach (RegionFrameItem* const item, d->items)
     {
         QRectF r       = item->boundingRect().translated(item->pos());
         qreal distance = (p - closestPointOfRect(p, r)).manhattanLength();
@@ -481,9 +488,9 @@ void FaceGroup::itemHoverMoveEvent(QGraphicsSceneHoverEvent* e)
             // this will be the one item shown by mouse over
             QList<QObject*> visible        = d->visibilityController->visibleItems(ItemVisibilityController::ExcludeFadingOut);
 
-            foreach(QGraphicsItem* const item, hotItems)
+            foreach (QGraphicsItem* const item, hotItems)
             {
-                foreach(QObject* const parent, visible)
+                foreach (QObject* const parent, visible)
                 {
                     if (static_cast<QGraphicsObject*>(parent)->isAncestorOf(item))
                     {
@@ -524,9 +531,6 @@ FaceItem* FaceGroup::Private::createItem(const FaceTagsIface& face)
     item->setOriginalRect(face.region().toRect());
     item->setVisible(false);
 
-    q->connect(view, SIGNAL(viewportRectChanged(QRectF)),
-               item, SLOT(setViewportRect(QRectF)));
-
     return item;
 }
 
@@ -542,6 +546,7 @@ FaceItem* FaceGroup::Private::addItem(const FaceTagsIface& face)
     visibilityController->addItem(item);
 
     items << item;
+
     return item;
 }
 
@@ -591,14 +596,14 @@ AssignNameWidget* FaceGroup::Private::createAssignNameWidget(const FaceTagsIface
     assignWidget->setModel(tagModel, filteredModel, filterModel);
     assignWidget->setParentTag(AlbumManager::instance()->findTAlbum(FaceTags::personParentTag()));
 
-    q->connect(assignWidget, SIGNAL(assigned(TaggingAction,ImageInfo,QVariant)),
-               q, SLOT(slotAssigned(TaggingAction,ImageInfo,QVariant)));
+    q->connect(assignWidget, SIGNAL(assigned(TaggingAction,ItemInfo,QVariant)),
+               q, SLOT(slotAssigned(TaggingAction,ItemInfo,QVariant)));
 
-    q->connect(assignWidget, SIGNAL(rejected(ImageInfo,QVariant)),
-               q, SLOT(slotRejected(ImageInfo,QVariant)));
+    q->connect(assignWidget, SIGNAL(rejected(ItemInfo,QVariant)),
+               q, SLOT(slotRejected(ItemInfo,QVariant)));
 
-    q->connect(assignWidget, SIGNAL(labelClicked(ImageInfo,QVariant)),
-               q, SLOT(slotLabelClicked(ImageInfo,QVariant)));
+    q->connect(assignWidget, SIGNAL(labelClicked(ItemInfo,QVariant)),
+               q, SLOT(slotLabelClicked(ItemInfo,QVariant)));
 
     return assignWidget;
 }
@@ -621,7 +626,7 @@ void FaceGroup::load()
     QList<FaceTagsIface> faces = FaceTagsEditor().databaseFaces(d->info.id());
     d->visibilityController->clear();
 
-    foreach(const FaceTagsIface& face, faces)
+    foreach (const FaceTagsIface& face, faces)
     {
         d->addItem(face);
     }
@@ -639,7 +644,7 @@ void FaceGroup::clear()
     cancelAddItem();
     d->visibilityController->clear();
 
-    foreach(RegionFrameItem* const item, d->items)
+    foreach (RegionFrameItem* const item, d->items)
     {
         delete item;
     }
@@ -650,23 +655,57 @@ void FaceGroup::clear()
 
 void FaceGroup::rejectAll()
 {
-    foreach(FaceItem* const item, d->items)
-    {
-        d->editPipeline.remove(d->info, item->face());
-        item->setFace(FaceTagsIface());
-        d->visibilityController->hideAndRemoveItem(item);
-    }
+    FaceTagsEditor().removeAllFaces(d->info.id());
+
+    MetadataHub hub;
+    hub.load(d->info);
+    hub.loadFaceTags(d->info, d->info.dimensions());
+    hub.write(d->info.filePath(), MetadataHub::WRITE_ALL);
 
     clear();
 }
 
-void FaceGroup::slotAssigned(const TaggingAction& action, const ImageInfo&, const QVariant& faceIdentifier)
+void FaceGroup::slotAlbumsUpdated(int type)
+{
+    if (type != Album::TAG)
+    {
+        return;
+    }
+
+    if (d->items.isEmpty())
+    {
+        return;
+    }
+
+    clear();
+    load();
+}
+
+void FaceGroup::slotAlbumRenamed(Album* album)
+{
+    if (!album || album->type() != Album::TAG)
+    {
+        return;
+    }
+
+    foreach (FaceItem* const item, d->items)
+    {
+        if (!item->face().isNull() &&
+             item->face().tagId() == album->id())
+        {
+            item->updateCurrentTag();
+        }
+    }
+}
+
+void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const QVariant& faceIdentifier)
 {
     FaceItem* const item    = d->items[faceIdentifier.toInt()];
     FaceTagsIface face      = item->face();
     TagRegion currentRegion = TagRegion(item->originalRect());
 
-    if (!face.isConfirmedName() || face.region() != currentRegion || action.shallCreateNewTag() || (action.shallAssignTag() && action.tagId() != face.tagId()))
+    if (!face.isConfirmedName() || face.region() != currentRegion ||
+        action.shallCreateNewTag() || (action.shallAssignTag() && action.tagId() != face.tagId()))
     {
         int tagId = 0;
 
@@ -701,7 +740,7 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ImageInfo&, cons
     item->switchMode(AssignNameWidget::ConfirmedMode);
 }
 
-void FaceGroup::slotRejected(const ImageInfo&, const QVariant& faceIdentifier)
+void FaceGroup::slotRejected(const ItemInfo&, const QVariant& faceIdentifier)
 {
     FaceItem* const item = d->items[faceIdentifier.toInt()];
     d->editPipeline.remove(d->info, item->face());
@@ -710,7 +749,7 @@ void FaceGroup::slotRejected(const ImageInfo&, const QVariant& faceIdentifier)
     d->visibilityController->hideAndRemoveItem(item);
 }
 
-void FaceGroup::slotLabelClicked(const ImageInfo&, const QVariant& faceIdentifier)
+void FaceGroup::slotLabelClicked(const ItemInfo&, const QVariant& faceIdentifier)
 {
     FaceItem* const item = d->items[faceIdentifier.toInt()];
     item->switchMode(AssignNameWidget::ConfirmedEditMode);
@@ -796,7 +835,7 @@ void FaceGroup::cancelAddItem()
 
 void FaceGroup::applyItemGeometryChanges()
 {
-    foreach(FaceItem* const item, d->items)
+    foreach (FaceItem* const item, d->items)
     {
         if (item->face().isNull())
         {
@@ -813,40 +852,39 @@ void FaceGroup::applyItemGeometryChanges()
 }
 
 /*
-void ImagePreviewView::trainFaces()
+void ItemPreviewView::trainFaces()
 {
     QList<Face> trainList;
-    foreach(Face f, d->currentFaces)
+
+    foreach (Face f, d->currentFaces)
     {
-        if(f.name() != "" && !d->faceIface->isFaceTrained(getImageInfo().id(), f.toRect(), f.name()))
+        if (f.name() != "" && !d->faceIface->isFaceTrained(getItemInfo().id(), f.toRect(), f.name()))
             trainList += f;
     }
 
     qCDebug(DIGIKAM_GENERAL_LOG) << "Number of training faces" << trainList.size();
 
-    if(trainList.size()!=0)
+    if (trainList.size()!=0)
     {
         d->faceIface->trainWithFaces(trainList);
-        d->faceIface->markFacesAsTrained(getImageInfo().id(), trainList);
+        d->faceIface->markFacesAsTrained(getItemInfo().id(), trainList);
     }
 }
-* /
 
-void ImagePreviewView::suggestFaces()
+void ItemPreviewView::suggestFaces()
 {
-    / *
     // Assign tentative names to the face list
     QList<Face> recogList;
 
-    foreach(Face f, d->currentFaces)
+    foreach (Face f, d->currentFaces)
     {
-        if(!d->faceIface->isFaceRecognized(getImageInfo().id(), f.toRect(), f.name()) && f.name().isEmpty())
+        if (!d->faceIface->isFaceRecognized(getItemInfo().id(), f.toRect(), f.name()) && f.name().isEmpty())
         {
             f.setName(d->faceIface->recognizedName(f));
-            d->faceIface->markFaceAsRecognized(getImageInfo().id(), f.toRect(), f.name());
+            d->faceIface->markFaceAsRecognized(getItemInfo().id(), f.toRect(), f.name());
 
             // If the face wasn't recognized (too distant) don't suggest anything
-            if(f.name().isEmpty())
+            if (f.name().isEmpty())
                 continue;
             else
                 recogList += f;
@@ -857,11 +895,11 @@ void ImagePreviewView::suggestFaces()
     qCDebug(DIGIKAM_GENERAL_LOG) << "Number of faceitems = " << d->faceitems.size();
 
     // Now find the relevant face items and suggest faces
-    for(int i = 0; i < recogList.size(); ++i)
+    for (int i = 0 ; i < recogList.size() ; ++i)
     {
-        for(int j = 0; j < d->faceitems.size(); ++j)
+        for (int j = 0 ; j < d->faceitems.size() ; ++j)
         {
-            if(recogList[i].toRect() == d->faceitems[j]->originalRect())
+            if (recogList[i].toRect() == d->faceitems[j]->originalRect())
             {
                 qCDebug(DIGIKAM_GENERAL_LOG) << "Suggesting a name " << recogList[i].name();
                 d->faceitems[j]->suggest(recogList[i].name());
@@ -869,7 +907,6 @@ void ImagePreviewView::suggestFaces()
             }
         }
     }
-    * /
 }
 */
 
