@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-10-09
  * Description : Dialog to choose options for face scanning
  *
  * Copyright (C) 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2012-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,6 +49,7 @@
 
 // Local includes
 
+#include "digikam_config.h"
 #include "dlayoutbox.h"
 #include "dnuminput.h"
 #include "digikam_debug.h"
@@ -60,11 +61,11 @@
 namespace Digikam
 {
 
-class FaceScanDialog::Private
+class Q_DECL_HIDDEN FaceScanDialog::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : configName(QLatin1String("Face Detection Dialog")),
           configMainTask(QLatin1String("Face Scan Main Task")),
           configValueDetect(QLatin1String("Detect")),
@@ -72,7 +73,8 @@ public:
           configValueRecognizedMarkedFaces(QLatin1String("Recognize Marked Faces")),
           configAlreadyScannedHandling(QLatin1String("Already Scanned Handling")),
           configUseFullCpu(QLatin1String("Use Full CPU")),
-          configSettingsVisible(QLatin1String("Settings Widget Visible"))
+          configSettingsVisible(QLatin1String("Settings Widget Visible")),
+          configRecognizeAlgorithm(QLatin1String("Recognize Algorithm")) 
     {
         buttons                    = 0;
         optionGroupBox             = 0;
@@ -85,6 +87,7 @@ public:
         accuracyInput              = 0;
         useFullCpuButton           = 0;
         retrainAllButton           = 0;
+        recognizeBox               = 0;
     }
 
     QDialogButtonBox*            buttons;
@@ -104,6 +107,8 @@ public:
     QCheckBox*                   useFullCpuButton;
     QCheckBox*                   retrainAllButton;
 
+    QComboBox*                   recognizeBox;
+
     const QString                configName;
     const QString                configMainTask;
     const QString                configValueDetect;
@@ -112,6 +117,7 @@ public:
     const QString                configAlreadyScannedHandling;
     const QString                configUseFullCpu;
     const QString                configSettingsVisible;
+    const QString                configRecognizeAlgorithm;
 };
 
 FaceScanDialog::FaceScanDialog(QWidget* const parent)
@@ -119,7 +125,13 @@ FaceScanDialog::FaceScanDialog(QWidget* const parent)
       StateSavingObject(this),
       d(new Private)
 {
+    setWindowFlags((windowFlags() & ~Qt::Dialog) |
+                   Qt::Window                    |
+                   Qt::WindowCloseButtonHint     |
+                   Qt::WindowMinMaxButtonsHint);
+
     setWindowTitle(i18nc("@title:window", "Scanning faces"));
+    setModal(true);
 
     d->buttons = new QDialogButtonBox(QDialogButtonBox::Reset | QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->buttons->button(QDialogButtonBox::Ok)->setDefault(true);
@@ -182,6 +194,12 @@ void FaceScanDialog::doLoadState()
 
     d->useFullCpuButton->setChecked(group.readEntry(entryName(d->configUseFullCpu), false));
 
+    RecognitionDatabase::RecognizeAlgorithm algo =
+            (RecognitionDatabase::RecognizeAlgorithm)group.readEntry(entryName(d->configRecognizeAlgorithm),
+                                                                               (int)RecognitionDatabase::RecognizeAlgorithm::LBP);
+    int index = d->recognizeBox->findData(algo);
+    d->recognizeBox->setCurrentIndex(index == -1 ? (int)RecognitionDatabase::RecognizeAlgorithm::LBP : index);
+
     // do not load retrainAllButton state from config, dangerous
 
     d->tabWidget->setVisible(group.readEntry(entryName(d->configSettingsVisible), false));
@@ -233,8 +251,9 @@ void FaceScanDialog::doSaveState()
     ApplicationSettings::instance()->setFaceDetectionAccuracy(double(d->accuracyInput->value()) / 100);
     d->albumSelectors->saveState();
 
-    group.writeEntry(entryName(d->configUseFullCpu),      d->useFullCpuButton->isChecked());
-    group.writeEntry(entryName(d->configSettingsVisible), d->tabWidget->isVisible());
+    group.writeEntry(entryName(d->configUseFullCpu),         d->useFullCpuButton->isChecked());
+    group.writeEntry(entryName(d->configSettingsVisible),    d->tabWidget->isVisible());
+    group.writeEntry(entryName(d->configRecognizeAlgorithm), d->recognizeBox->itemData(d->recognizeBox->currentIndex()));
 }
 
 void FaceScanDialog::setupUi()
@@ -251,8 +270,8 @@ void FaceScanDialog::setupUi()
     QLabel* const introduction = new QLabel;
     introduction->setTextFormat(Qt::RichText);
     introduction->setText(i18nc("@info",
-                                "<qt>digiKam can search for faces in your photos.<br> "
-                                "When you have identified your friends on a number of photos,<br> "
+                                "<qt>digiKam can search for faces in your photos.<br/> "
+                                "When you have identified your friends on a number of photos,<br/> "
                                 "it can also recognize the people shown on your photos.</qt>"));
 
     // ---- Main option box --------
@@ -335,12 +354,23 @@ void FaceScanDialog::setupUi()
                                   "Face detection is a time-consuming task. "
                                   "You can choose if you wish to employ all processor cores "
                                   "on your system, or work in the background only on one core. "
-                                  "Warning: this features still experimental and it's disabled by default."));
+                                  "Warning: this features still experimental and it is disabled by default."));
     cpuExplanation->setWordWrap(true);
 
     d->useFullCpuButton = new QCheckBox(advancedTab);
     d->useFullCpuButton->setText(i18nc("@option:check", "Work on all processor cores (experimental)"));
 
+    // ---- Recognize algorithm ComboBox -----
+
+    d->recognizeBox        = new QComboBox;
+    d->recognizeBox->addItem(i18nc("@label:listbox", "Recognize faces using LBP algorithm"),           RecognitionDatabase::RecognizeAlgorithm::LBP);
+    //d->recognizeBox->addItem(i18nc("@label:listbox", "Recognize faces using EigenFaces algorithm"),    RecognitionDatabase::RecognizeAlgorithm::EigenFace);
+    //d->recognizeBox->addItem(i18nc("@label:listbox", "Recognize faces using FisherFaces algorithm"),   RecognitionDatabase::RecognizeAlgorithm::FisherFace);
+#ifdef HAVE_FACESENGINE_DNN
+    d->recognizeBox->addItem(i18nc("@label:listbox", "Recognize faces using Deep Learning algorithm"), RecognitionDatabase::RecognizeAlgorithm::DNN);
+#endif
+    d->recognizeBox->setCurrentIndex(RecognitionDatabase::RecognizeAlgorithm::LBP);
+
     d->retrainAllButton = new QCheckBox(advancedTab);
     d->retrainAllButton->setText(i18nc("@option:check", "Clear and rebuild all training data"));
     d->retrainAllButton->setToolTip(i18nc("@info:tooltip",
@@ -351,7 +381,8 @@ void FaceScanDialog::setupUi()
     advancedLayout->addWidget(d->useFullCpuButton,             1, 0);
     advancedLayout->addWidget(new DLineWidget(Qt::Horizontal), 2, 0);
     advancedLayout->addWidget(d->retrainAllButton,             3, 0);
-    advancedLayout->setRowStretch(4, 10);
+    advancedLayout->addWidget(d->recognizeBox,                 4, 0);
+    advancedLayout->setRowStretch(5, 10);
 
     d->tabWidget->addTab(advancedTab, i18nc("@title:tab", "Advanced"));
 
@@ -409,6 +440,7 @@ void FaceScanDialog::retrainAllButtonToggled(bool on)
 {
     d->optionGroupBox->setEnabled(!on);
     d->albumSelectors->setEnabled(!on);
+    d->recognizeBox->setEnabled(!on);
 }
 
 FaceScanSettings FaceScanDialog::settings() const
@@ -419,7 +451,7 @@ FaceScanSettings FaceScanDialog::settings() const
     {
         settings.task = FaceScanSettings::RetrainAll;
     }
-    else if(d->detectButton->isChecked())
+    else if (d->detectButton->isChecked())
     {
         settings.task = FaceScanSettings::Detect;
     }
@@ -444,6 +476,9 @@ FaceScanSettings FaceScanDialog::settings() const
 
     settings.useFullCpu             = d->useFullCpuButton->isChecked();
 
+    settings.recognizeAlgorithm     = (RecognitionDatabase::RecognizeAlgorithm)
+                                      d->recognizeBox->itemData(d->recognizeBox->currentIndex()).toInt();
+
     return settings;
 }
 
