@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-19
  * Description : Find Duplicates tree-view search album.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -41,12 +41,12 @@
 namespace Digikam
 {
 
-class FindDuplicatesAlbum::Private
+class Q_DECL_HIDDEN FindDuplicatesAlbum::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
         : iconSize(64)
     {
         thumbLoadThread = 0;
@@ -177,4 +177,4 @@ void FindDuplicatesAlbum::drawRow(QPainter* p,
     QTreeWidget::drawRow(p, opt, index);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
