@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-19
  * Description : Find Duplicates tree-view search album.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef FIND_DUPLICATES_ALBUM_H
-#define FIND_DUPLICATES_ALBUM_H
+#ifndef DIGIKAM_FIND_DUPLICATES_ALBUM_H
+#define DIGIKAM_FIND_DUPLICATES_ALBUM_H
 
 // Qt includes
 
@@ -70,6 +70,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // FIND_DUPLICATES_ALBUM_H
+#endif // DIGIKAM_FIND_DUPLICATES_ALBUM_H
