@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-06-17
  * Description : Find Duplicates tree-view search album item.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,13 +38,13 @@
 namespace Digikam
 {
 
-class FindDuplicatesAlbumItem::Private
+class Q_DECL_HIDDEN FindDuplicatesAlbumItem::Private
 {
 
 public:
 
-    Private() :
-        hasThumb(false),
+    explicit Private()
+      : hasThumb(false),
         album(0),
         itemCount(0)
     {
@@ -55,7 +55,7 @@ public:
     SAlbum*   album;
     int       itemCount;
 
-    ImageInfo refImgInfo;
+    ItemInfo refImgInfo;
 };
 
 FindDuplicatesAlbumItem::FindDuplicatesAlbumItem(QTreeWidget* const parent, SAlbum* const album)
@@ -67,7 +67,7 @@ FindDuplicatesAlbumItem::FindDuplicatesAlbumItem(QTreeWidget* const parent, SAlb
     if (d->album)
     {
         qlonglong refImage = d->album->title().toLongLong();
-        d->refImgInfo      = ImageInfo(refImage);
+        d->refImgInfo      = ItemInfo(refImage);
         setText(Column::REFERENCE_IMAGE, d->refImgInfo.name());
 
         calculateInfos();
@@ -108,7 +108,7 @@ void FindDuplicatesAlbumItem::calculateInfos(const QList<qlonglong>& deletedImag
 
         foreach (int imageId, list)
         {
-            ImageInfo info(imageId);
+            ItemInfo info(imageId);
 
             // If image is not deleted in this moment and was also not
             // removed before.
@@ -211,4 +211,4 @@ bool FindDuplicatesAlbumItem::operator<(const QTreeWidgetItem& other) const
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
