@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-19
  * Description : Find Duplicates View.
  *
  * Copyright (C) 2016-2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -61,12 +61,12 @@
 namespace Digikam
 {
 
-class FindDuplicatesView::Private
+class Q_DECL_HIDDEN FindDuplicatesView::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
     {
         includeAlbumsLabel      = 0;
         listView                = 0;
@@ -160,7 +160,7 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
     d->restrictResultsLabel->setBuddy(d->searchResultRestriction);
 
     d->searchResultRestriction = new SqueezedComboBox();
-    d->searchResultRestriction->addSqueezedItem(i18nc("@label:listbox", "None"),                                 HaarIface::DuplicatesSearchRestrictions::None);
+    d->searchResultRestriction->addSqueezedItem(i18nc("@label:listbox", "None"),                        HaarIface::DuplicatesSearchRestrictions::None);
     d->searchResultRestriction->addSqueezedItem(i18nc("@label:listbox", "Restrict to reference album"), HaarIface::DuplicatesSearchRestrictions::SameAlbum);
     d->searchResultRestriction->addSqueezedItem(i18nc("@label:listbox", "Exclude reference album"),     HaarIface::DuplicatesSearchRestrictions::DifferentAlbum);
     d->searchResultRestriction->setToolTip(i18n("Use this option to restrict the duplicate search "
@@ -169,13 +169,17 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
                                                 "reference image of the search."));
 
     // Load the last choice from application settings.
-    HaarIface::DuplicatesSearchRestrictions restrictions = (HaarIface::DuplicatesSearchRestrictions) d->settings->getDuplicatesSearchRestrictions();
+
+    HaarIface::DuplicatesSearchRestrictions restrictions
+        = d->settings ? (HaarIface::DuplicatesSearchRestrictions) d->settings->getDuplicatesSearchRestrictions()
+                      : HaarIface::DuplicatesSearchRestrictions::None;
+
     d->searchResultRestriction->setCurrentIndex(d->searchResultRestriction->findData(restrictions));
 
-    d->albumTagRelationLabel    = new QLabel(i18n("Restrict to:"));
+    d->albumTagRelationLabel = new QLabel(i18n("Restrict to:"));
     d->albumTagRelationLabel->setBuddy(d->albumTagRelation);
 
-    d->albumTagRelation = new SqueezedComboBox();
+    d->albumTagRelation      = new SqueezedComboBox();
     d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox", "Only selected tab") ,  HaarIface::AlbumTagRelation::NoMix);
     d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox", "One of"),              HaarIface::AlbumTagRelation::Union);
     d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox", "Both"),                HaarIface::AlbumTagRelation::Intersection);
@@ -191,7 +195,10 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
                                          "<i>Only selected tab</i> means that only the selected tab is used."));
 
     // Load the last choice from application settings.
-    HaarIface::AlbumTagRelation relation = (HaarIface::AlbumTagRelation) d->settings->getDuplicatesAlbumTagRelation();
+    HaarIface::AlbumTagRelation relation
+        = d->settings ? (HaarIface::AlbumTagRelation) d->settings->getDuplicatesAlbumTagRelation()
+                      : HaarIface::AlbumTagRelation::NoMix;
+
     d->albumTagRelation->setCurrentIndex(d->albumTagRelation->findData(relation));
 
     // ---------------------------------------------------------------
@@ -257,9 +264,8 @@ void FindDuplicatesView::initAlbumUpdateConnections()
     connect(AlbumManager::instance(), SIGNAL(signalAlbumsCleared()),
             this, SLOT(slotClear()));
 
-    connect(AlbumManager::instance(),SIGNAL(signalUpdateDuplicatesAlbums(QList<SAlbum*>, QList<qlonglong>)),
+    connect(AlbumManager::instance(),SIGNAL(signalUpdateDuplicatesAlbums(QList<SAlbum*>,QList<qlonglong>)),
             this,SLOT(slotUpdateDuplicates(QList<SAlbum*>,QList<qlonglong>)));
-
 }
 
 void FindDuplicatesView::setActive(bool val)
@@ -307,7 +313,7 @@ QList<SAlbum*> FindDuplicatesView::currentFindDuplicatesAlbums() const
 
     QList<SAlbum*> albumList;
 
-    foreach(QTreeWidgetItem* const item, selectedItems)
+    foreach (QTreeWidgetItem* const item, selectedItems)
     {
         FindDuplicatesAlbumItem* const albumItem = dynamic_cast<FindDuplicatesAlbumItem*>(item);
 
@@ -456,7 +462,7 @@ void FindDuplicatesView::slotUpdateDuplicates(const QList<SAlbum*>& sAlbumsToReb
 
 void FindDuplicatesView::slotApplicationSettingsChanged()
 {
-    d->similarityRange->setRange(d->settings->getMinimumSimilarityBound(),100);
+    d->similarityRange->setRange(d->settings->getMinimumSimilarityBound(), 100);
 }
 
 void FindDuplicatesView::slotComplete()
@@ -468,9 +474,14 @@ void FindDuplicatesView::slotComplete()
 
 void FindDuplicatesView::slotDuplicatesAlbumActived()
 {
+    if (!d->active)
+    {
+        return;
+    }
+
     QList<Album*> albums;
 
-    foreach(QTreeWidgetItem* const item, d->listView->selectedItems())
+    foreach (QTreeWidgetItem* const item, d->listView->selectedItems())
     {
         FindDuplicatesAlbumItem* const albumItem = dynamic_cast<FindDuplicatesAlbumItem*>(item);
 
@@ -480,7 +491,7 @@ void FindDuplicatesView::slotDuplicatesAlbumActived()
         }
     }
 
-    if (!albums.empty())
+    if (!albums.isEmpty())
     {
         AlbumManager::instance()->setCurrentAlbums(QList<Album*>() << albums);
     }
@@ -513,12 +524,12 @@ void FindDuplicatesView::slotSetSelectedAlbum(PAlbum* album)
     slotCheckForValidSettings();
 }
 
-void FindDuplicatesView::slotSetSelectedAlbums(QList<PAlbum*> albums)
+void FindDuplicatesView::slotSetSelectedAlbums(const QList<PAlbum*>& albums)
 {
     // @ODD : Why is singleton set to true? resetAlbumsAndTags already clears the selection.
     resetAlbumsAndTags();
 
-    foreach(PAlbum* const album, albums)
+    foreach (PAlbum* const album, albums)
     {
         d->albumSelectors->setAlbumSelected(album, false);
     }
@@ -527,11 +538,11 @@ void FindDuplicatesView::slotSetSelectedAlbums(QList<PAlbum*> albums)
     slotCheckForValidSettings();
 }
 
-void FindDuplicatesView::slotSetSelectedAlbums(QList<TAlbum*> albums)
+void FindDuplicatesView::slotSetSelectedAlbums(const QList<TAlbum*>& albums)
 {
     resetAlbumsAndTags();
 
-    foreach(TAlbum* const album, albums)
+    foreach (TAlbum* const album, albums)
     {
         d->albumSelectors->setTagSelected(album, false);
     }
@@ -546,4 +557,4 @@ void FindDuplicatesView::resetAlbumsAndTags()
     slotCheckForValidSettings();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
