@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-19
  * Description : Fuzzy search sidebar tab contents.
  *
- * Copyright (C) 2016-2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -28,8 +28,6 @@
 
 // Qt includes
 
-#include <QEvent>
-#include <QDragEnterEvent>
 #include <QFrame>
 #include <QImage>
 #include <QLabel>
@@ -59,30 +57,32 @@
 #include "albummanager.h"
 #include "albummodel.h"
 #include "albumselectors.h"
+#include "searchtreeview.h"
 #include "coredbaccess.h"
 #include "ddragobjects.h"
 #include "editablesearchtreeview.h"
 #include "findduplicatesview.h"
 #include "haariface.h"
-#include "imageinfo.h"
-#include "imagelister.h"
+#include "iteminfo.h"
+#include "itemlister.h"
 #include "searchmodificationhelper.h"
 #include "searchtextbar.h"
 #include "coredbsearchxml.h"
 #include "sketchwidget.h"
 #include "thumbnailloadthread.h"
 #include "thumbnailsize.h"
-#include "fingerprintsgenerator.h"
 #include "dhuesaturationselect.h"
 #include "dcolorvalueselector.h"
 #include "dexpanderbox.h"
 #include "applicationsettings.h"
 #include "drangebox.h"
+#include "similaritydbaccess.h"
+#include "similaritydb.h"
 
 namespace Digikam
 {
 
-class FuzzySearchView::Private
+class Q_DECL_HIDDEN FuzzySearchView::Private
 {
 
 public:
@@ -96,7 +96,7 @@ public:
 
 public:
 
-    Private() :
+    explicit Private() :
         // initially be active to update sketch panel when the search list is restored
         active(false),
         fingerprintsChecked(false),
@@ -178,7 +178,7 @@ public:
     DAdjustableLabel*         labelFile;
     DAdjustableLabel*         labelFolder;
 
-    ImageInfo                 imageInfo;
+    ItemInfo                 imageInfo;
     QUrl                      imageUrl;
 
     SearchTextBar*            searchFuzzyBar;
@@ -590,8 +590,6 @@ void FuzzySearchView::setupConnections()
 
 FuzzySearchView::~FuzzySearchView()
 {
-    delete d->timerSketch;
-    delete d->timerImage;
     delete d;
 }
 
@@ -615,7 +613,7 @@ void FuzzySearchView::newDuplicatesSearch(PAlbum* const album)
     d->tabWidget->setCurrentIndex(Private::DUPLICATES);
 }
 
-void FuzzySearchView::newDuplicatesSearch(QList<PAlbum*> const albums)
+void FuzzySearchView::newDuplicatesSearch(const QList<PAlbum*>& albums)
 {
     if (!albums.isEmpty())
     {
@@ -625,7 +623,7 @@ void FuzzySearchView::newDuplicatesSearch(QList<PAlbum*> const albums)
     d->tabWidget->setCurrentIndex(Private::DUPLICATES);
 }
 
-void FuzzySearchView::newDuplicatesSearch(QList<TAlbum*> const albums)
+void FuzzySearchView::newDuplicatesSearch(const QList<TAlbum*>& albums)
 {
     if (!albums.isEmpty())
     {
@@ -692,21 +690,13 @@ void FuzzySearchView::setActive(bool val)
     // at first occasion, warn if no fingerprints are available
     if (val && !d->fingerprintsChecked && isVisible())
     {
-        if (!CoreDbAccess().db()->hasHaarFingerprints())
+        if (!SimilarityDbAccess().db()->hasFingerprints())
         {
             QString msg = i18n("Image fingerprints have not yet been generated for your collection. "
                                "The Similarity Search Tools will not be operational "
-                               "without pre-generated fingerprints.\n"
-                               "Do you want to build fingerprints now?\n"
-                               "Note: This process can take a while. You can run it "
-                               "any time later using 'Tools/Rebuild all Fingerprints'.");
-            int result = QMessageBox::question(this, i18n("No Fingerprints"), msg);
-
-            if (result == QMessageBox::Yes)
-            {
-                FingerPrintsGenerator* const tool = new FingerPrintsGenerator(true);
-                tool->start();
-            }
+                               "without pre-generated fingerprints. Please generate "
+                               "the fingerprints first.");
+            QMessageBox::information(this, i18n("No Fingerprints"), msg);
         }
 
         d->fingerprintsChecked = true;
@@ -809,7 +799,7 @@ void FuzzySearchView::slotAlbumSelected(Album* album)
 
 void FuzzySearchView::slotApplicationSettingsChanged()
 {
-    d->similarityRange->setRange(d->settings->getMinimumSimilarityBound(),100);
+    d->similarityRange->setRange(d->settings->getMinimumSimilarityBound(), 100);
 }
 
 // Sketch Searches methods -----------------------------------------------------------------------
@@ -938,30 +928,45 @@ void FuzzySearchView::slotCheckNameEditSketchConditions()
 
 void FuzzySearchView::dragEnterEvent(QDragEnterEvent* e)
 {
-    if (DItemDrag::canDecode(e->mimeData()))
+    if (dragEventWrapper(e->mimeData()))
     {
         e->acceptProposedAction();
     }
-    else if (e->mimeData()->hasUrls())
+}
+
+void FuzzySearchView::dragMoveEvent(QDragMoveEvent* e)
+{
+    if (dragEventWrapper(e->mimeData()))
     {
-        QList<QUrl> urls = e->mimeData()->urls();
+        e->acceptProposedAction();
+    }
+}
+
+bool FuzzySearchView::dragEventWrapper(const QMimeData* data) const
+{
+    if (DItemDrag::canDecode(data))
+    {
+        return true;
+    }
+    else if (data->hasUrls())
+    {
+        QList<QUrl> urls = data->urls();
 
         // If there is at least one URL and the URL is a local file.
-        if (!urls.empty())
+        if (!urls.isEmpty() && urls.first().isLocalFile())
         {
-            if (urls.first().isLocalFile())
-            {
-                HaarIface haarIface;
-                QString path       = urls.first().toLocalFile();
-                const QImage image = haarIface.loadQImage(path);
+            HaarIface haarIface;
+            QString path       = urls.first().toLocalFile();
+            const QImage image = haarIface.loadQImage(path);
 
-                if (!image.isNull())
-                {
-                    e->acceptProposedAction();
-                }
+            if (!image.isNull())
+            {
+                return true;
             }
         }
     }
+
+    return false;
 }
 
 void FuzzySearchView::dropEvent(QDropEvent* e)
@@ -969,11 +974,10 @@ void FuzzySearchView::dropEvent(QDropEvent* e)
     if (DItemDrag::canDecode(e->mimeData()))
     {
         QList<QUrl>      urls;
-        QList<QUrl>      ioURLs;
         QList<int>       albumIDs;
         QList<qlonglong> imageIDs;
 
-        if (!DItemDrag::decode(e->mimeData(), urls, ioURLs, albumIDs, imageIDs))
+        if (!DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs))
         {
             return;
         }
@@ -983,7 +987,7 @@ void FuzzySearchView::dropEvent(QDropEvent* e)
             return;
         }
 
-        setImageInfo(ImageInfo(imageIDs.first()));
+        setItemInfo(ItemInfo(imageIDs.first()));
 
         e->acceptProposedAction();
     }
@@ -994,37 +998,34 @@ void FuzzySearchView::dropEvent(QDropEvent* e)
         QList<QUrl> urls = e->mimeData()->urls();
 
         // If there is at least one URL and the URL is a local file.
-        if (!urls.empty())
+        if (!urls.isEmpty() && urls.first().isLocalFile())
         {
-            if (urls.first().isLocalFile())
+            HaarIface haarIface;
+            QString path       = urls.first().toLocalFile();
+            const QImage image = haarIface.loadQImage(path);
+
+            if (!image.isNull())
             {
-                HaarIface haarIface;
-                QString path       = urls.first().toLocalFile();
-                const QImage image = haarIface.loadQImage(path);
+                // Set a temporary image id
+                d->imageInfo = ItemInfo(-1);
+                d->imageUrl  = urls.first();
 
-                if (!image.isNull())
-                {
-                    // Set a temporary image id
-                    d->imageInfo = ImageInfo(-1);
-                    d->imageUrl  = urls.first();
+                d->imageWidget->setPixmap(QPixmap::fromImage(image).scaled(256, 256, Qt::KeepAspectRatio, Qt::SmoothTransformation));
 
-                    d->imageWidget->setPixmap(QPixmap::fromImage(image).scaled(256, 256, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+                AlbumManager::instance()->setCurrentAlbums(QList<Album*>());
+                QString haarTitle = SAlbum::getTemporaryHaarTitle(DatabaseSearch::HaarImageSearch);
 
-                    AlbumManager::instance()->setCurrentAlbums(QList<Album*>());
-                    QString haarTitle = SAlbum::getTemporaryHaarTitle(DatabaseSearch::HaarImageSearch);
+                QList<int> albums = d->fuzzySearchAlbumSelectors->selectedAlbumIds();
 
-                    QList<int> albums = d->fuzzySearchAlbumSelectors->selectedAlbumIds();
+                d->imageSAlbum = d->searchModificationHelper->createFuzzySearchFromDropped(haarTitle, path,
+                                                                                           d->similarityRange->minValue() / 100.0,
+                                                                                           d->similarityRange->maxValue() / 100.0,
+                                                                                           albums, true);
+                d->searchTreeView->setCurrentAlbums(QList<Album*>() << d->imageSAlbum);
+                d->labelFile->setAdjustedText(urls.first().fileName());
+                d->labelFolder->setAdjustedText(urls.first().adjusted(QUrl::RemoveFilename).toLocalFile());
 
-                    d->imageSAlbum = d->searchModificationHelper->createFuzzySearchFromDropped(haarTitle, path,
-                                                                                               d->similarityRange->minValue() / 100.0,
-                                                                                               d->similarityRange->maxValue() / 100.0,
-                                                                                               albums, true);
-                    d->searchTreeView->setCurrentAlbums(QList<Album*>() << d->imageSAlbum);
-                    d->labelFile->setAdjustedText(urls.first().fileName());
-                    d->labelFolder->setAdjustedText(urls.first().adjusted(QUrl::RemoveFilename).toLocalFile());
-
-                    e->acceptProposedAction();
-                }
+                e->acceptProposedAction();
             }
         }
     }
@@ -1074,16 +1075,16 @@ void FuzzySearchView::slotTimerImageDone()
 
     if (!d->imageInfo.isNull() && d->active)
     {
-        setImageInfo(d->imageInfo);
+        setItemInfo(d->imageInfo);
     }
 }
 
 void FuzzySearchView::setCurrentImage(qlonglong imageid)
 {
-    setCurrentImage(ImageInfo(imageid));
+    setCurrentImage(ItemInfo(imageid));
 }
 
-void FuzzySearchView::setCurrentImage(const ImageInfo& info)
+void FuzzySearchView::setCurrentImage(const ItemInfo& info)
 {
     d->imageInfo = info;
     d->imageUrl  = info.fileUrl();
@@ -1092,7 +1093,7 @@ void FuzzySearchView::setCurrentImage(const ImageInfo& info)
     d->thumbLoadThread->find(d->imageInfo.thumbnailIdentifier());
 }
 
-void FuzzySearchView::setImageInfo(const ImageInfo& info)
+void FuzzySearchView::setItemInfo(const ItemInfo& info)
 {
     setCurrentImage(info);
     slotCheckNameEditImageConditions();
@@ -1143,4 +1144,4 @@ void FuzzySearchView::slotSaveImageSAlbum()
     createNewFuzzySearchAlbumFromImage(d->nameEditImage->text());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
