@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-19
  * Description : Fuzzy search sidebar tab contents.
  *
- * Copyright (C) 2016-2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -23,19 +23,21 @@
  *
  * ============================================================ */
 
-#ifndef FUZZY_SEARCH_VIEW_H
-#define FUZZY_SEARCH_VIEW_H
+#ifndef DIGIKAM_FUZZY_SEARCH_VIEW_H
+#define DIGIKAM_FUZZY_SEARCH_VIEW_H
 
 // Qt includes
 
+#include <QDragEnterEvent>
+#include <QDragMoveEvent>
 #include <QScrollArea>
+#include <QDropEvent>
 
-// Local includs
+// Local includes
 
 #include "statesavingobject.h"
 
-class QDragEnterEvent;
-class QDropEvent;
+class QMimeData;
 class QPixmap;
 
 namespace Digikam
@@ -43,7 +45,7 @@ namespace Digikam
 
 class Album;
 class FuzzySearchFolderView;
-class ImageInfo;
+class ItemInfo;
 class LoadingDescription;
 class SAlbum;
 class PAlbum;
@@ -67,11 +69,11 @@ public:
     void setCurrentAlbum(SAlbum* const album);
 
     void setActive(bool val);
-    void setImageInfo(const ImageInfo& info);
+    void setItemInfo(const ItemInfo& info);
 
-    void newDuplicatesSearch(PAlbum* const);
-    void newDuplicatesSearch(QList<PAlbum*> const);
-    void newDuplicatesSearch(QList<TAlbum*> const);
+    void newDuplicatesSearch(PAlbum* const album);
+    void newDuplicatesSearch(const QList<PAlbum*>& albums);
+    void newDuplicatesSearch(const QList<TAlbum*>& albums);
 
     virtual void setConfigGroup(const KConfigGroup& group);
     void doLoadState();
@@ -80,6 +82,7 @@ public:
 protected:
 
     void dragEnterEvent(QDragEnterEvent* e);
+    void dragMoveEvent(QDragMoveEvent* e);
     void dropEvent(QDropEvent* e);
 
 private Q_SLOTS:
@@ -113,10 +116,11 @@ private Q_SLOTS:
 private:
 
     void setCurrentImage(qlonglong imageid);
-    void setCurrentImage(const ImageInfo& info);
+    void setCurrentImage(const ItemInfo& info);
 
     void createNewFuzzySearchAlbumFromSketch(const QString& name, bool force = false);
     void createNewFuzzySearchAlbumFromImage(const QString& name, bool force = false);
+    bool dragEventWrapper(const QMimeData* data) const;
 
     void setColor(QColor c);
 
@@ -130,6 +134,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // FUZZY_SEARCH_VIEW_H
+#endif // DIGIKAM_FUZZY_SEARCH_VIEW_H
