@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : Google-Maps-backend for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C) 2014      by Justus Schwartz <justus at gmx dot li>
  *
@@ -46,16 +46,22 @@
 
 // Local includes
 
-#include "htmlwidget.h"
+#include "digikam_config.h"
+#include "digikam_debug.h"
 #include "mapwidget.h"
 #include "abstractmarkertiler.h"
 #include "geomodelhelper.h"
-#include "digikam_debug.h"
+
+#ifdef HAVE_QWEBENGINE
+#   include "htmlwidget_qwebengine.h"
+#else
+#   include "htmlwidget.h"
+#endif
 
 namespace Digikam
 {
 
-class GMInternalWidgetInfo
+class Q_DECL_HIDDEN GMInternalWidgetInfo
 {
 public:
 
@@ -74,31 +80,31 @@ Q_DECLARE_METATYPE(Digikam::GMInternalWidgetInfo)
 namespace Digikam
 {
 
-class BackendGoogleMaps::Private
+class Q_DECL_HIDDEN BackendGoogleMaps::Private
 {
 public:
 
-    Private()
-    : htmlWidget(0),
-      htmlWidgetWrapper(0),
-      isReady(false),
-      mapTypeActionGroup(0),
-      floatItemsActionGroup(0),
-      showMapTypeControlAction(0),
-      showNavigationControlAction(0),
-      showScaleControlAction(0),
-      cacheMapType(QLatin1String("ROADMAP")),
-      cacheShowMapTypeControl(true),
-      cacheShowNavigationControl(true),
-      cacheShowScaleControl(true),
-      cacheZoom(8),
-      cacheMaxZoom(0),
-      cacheMinZoom(0),
-      cacheCenter(52.0, 6.0),
-      cacheBounds(),
-      activeState(false),
-      widgetIsDocked(false),
-      trackChangeTracker()
+    explicit Private()
+      : htmlWidget(0),
+        htmlWidgetWrapper(0),
+        isReady(false),
+        mapTypeActionGroup(0),
+        floatItemsActionGroup(0),
+        showMapTypeControlAction(0),
+        showNavigationControlAction(0),
+        showScaleControlAction(0),
+        cacheMapType(QLatin1String("ROADMAP")),
+        cacheShowMapTypeControl(true),
+        cacheShowNavigationControl(true),
+        cacheShowScaleControl(true),
+        cacheZoom(8),
+        cacheMaxZoom(0),
+        cacheMinZoom(0),
+        cacheCenter(52.0, 6.0),
+        cacheBounds(),
+        activeState(false),
+        widgetIsDocked(false),
+        trackChangeTracker()
     {
     }
 
@@ -683,7 +689,7 @@ void BackendGoogleMaps::slotHTMLEvents(const QStringList& events)
 
     if (zoomProbablyChanged && !mapTypeChanged)
     {
-        d->cacheZoom = d->htmlWidget->runScript(QLatin1String("kgeomapGetZoom();")).toInt();
+        d->cacheZoom = d->htmlWidget->runScript(QLatin1String("kgeomapGetZoom();"), false).toInt();
         emit signalZoomChanged(QString::fromLatin1("googlemaps:%1").arg(d->cacheZoom));
     }
 
@@ -701,7 +707,7 @@ void BackendGoogleMaps::slotHTMLEvents(const QStringList& events)
 
     if (mapBoundsProbablyChanged)
     {
-        const QString mapBoundsString = d->htmlWidget->runScript(QLatin1String("kgeomapGetBounds();")).toString();
+        const QString mapBoundsString = d->htmlWidget->runScript(QLatin1String("kgeomapGetBounds();"), false).toString();
         GeoIfaceHelperParseBoundsString(mapBoundsString, &d->cacheBounds);
     }
 
@@ -764,11 +770,12 @@ bool BackendGoogleMaps::screenCoordinates(const GeoCoordinates& coordinates, QPo
     if (!d->isReady)
         return false;
 
-    const QString pointStringResult=d->htmlWidget->runScript(
+    const QString pointStringResult = d->htmlWidget->runScript(
                 QString::fromLatin1("kgeomapLatLngToPixel(%1, %2);")
                     .arg(coordinates.latString())
-                    .arg(coordinates.lonString())
-                    ).toString();
+                    .arg(coordinates.lonString()),
+                false
+                ).toString();
     const bool isValid = GeoIfaceHelperParseXYStringToPoint(
             pointStringResult,
             point);
@@ -994,8 +1001,8 @@ void BackendGoogleMaps::updateActionAvailability()
 void BackendGoogleMaps::updateZoomMinMaxCache()
 {
     // TODO: these functions seem to cause problems, the map is not fully updated after a few calls
-//     d->cacheMaxZoom = d->htmlWidget->runScript("kgeomapGetMaxZoom();").toInt();
-//     d->cacheMinZoom = d->htmlWidget->runScript("kgeomapGetMinZoom();").toInt();
+//     d->cacheMaxZoom = d->htmlWidget->runScript("kgeomapGetMaxZoom();", false).toInt();
+//     d->cacheMinZoom = d->htmlWidget->runScript("kgeomapGetMinZoom();", false).toInt();
 }
 
 void BackendGoogleMaps::slotThumbnailAvailableForIndex(const QVariant& index, const QPixmap& pixmap)
@@ -1040,6 +1047,7 @@ void BackendGoogleMaps::setClusterPixmap(const int clusterId, const QPoint& cent
     QBuffer buffer(&bytes);
     buffer.open(QIODevice::WriteOnly);
     clusterPixmap.save(&buffer, "PNG");
+    buffer.close();
 
     // http://www.faqs.org/rfcs/rfc2397.html
     const QString imageData = QString::fromLatin1("data:image/png;base64,%1").arg(QString::fromLatin1(bytes.toBase64()));
@@ -1060,6 +1068,7 @@ void BackendGoogleMaps::setMarkerPixmap(const int modelId, const int markerId,
     QBuffer buffer(&bytes);
     buffer.open(QIODevice::WriteOnly);
     markerPixmap.save(&buffer, "PNG");
+    buffer.close();
 
     // http://www.faqs.org/rfcs/rfc2397.html
     const QString imageData = QString::fromLatin1("data:image/png;base64,%1").arg(QString::fromLatin1(bytes.toBase64()));
@@ -1285,8 +1294,8 @@ void BackendGoogleMaps::slotTrackManagerChanged()
 
     if (s->trackManager)
     {
-        connect(s->trackManager, SIGNAL(signalTracksChanged(const QList<TrackManager::TrackChanges>)),
-                this, SLOT(slotTracksChanged(const QList<TrackManager::TrackChanges>)));
+        connect(s->trackManager, SIGNAL(signalTracksChanged(QList<TrackManager::TrackChanges>)),
+                this, SLOT(slotTracksChanged(QList<TrackManager::TrackChanges>)));
 
         connect(s->trackManager, SIGNAL(signalVisibilityChanged(bool)),
                 this, SLOT(slotTrackVisibilityChanged(bool)));
@@ -1294,7 +1303,7 @@ void BackendGoogleMaps::slotTrackManagerChanged()
         // store all tracks which are already in the manager as changed
         const TrackManager::Track::List trackList = s->trackManager->getTrackList();
 
-        Q_FOREACH(const TrackManager::Track& t, trackList)
+        foreach(const TrackManager::Track& t, trackList)
         {
             storeTrackChanges(TrackManager::TrackChanges(t.id, TrackManager::ChangeAdd));
         }
@@ -1312,7 +1321,7 @@ void BackendGoogleMaps::slotTracksChanged(const QList<TrackManager::TrackChanges
 
     if (needToTrackChanges)
     {
-        Q_FOREACH(const TrackManager::TrackChanges& tc, trackChanges)
+        foreach(const TrackManager::TrackChanges& tc, trackChanges)
         {
             storeTrackChanges(tc);
         }
@@ -1321,19 +1330,19 @@ void BackendGoogleMaps::slotTracksChanged(const QList<TrackManager::TrackChanges
     }
 
     /// @TODO We have to re-read the tracks after being inactive.
-    /// @TODO Tracks have to be cleared in JavaScript everytime the
+    /// @TODO Tracks have to be cleared in JavaScript every time the
     ///       htmlwidget is passed to another mapwidget.
     /// @TODO Clearing all tracks and re-adding them takes too long. We
     ///       have to see which track changed, and whether coordinates or only properties changed.
     if (!s->trackManager)
     {
         // no track manager, clear all tracks
-        const QVariant successClear = d->htmlWidget->runScript(QString::fromLatin1("kgeomapClearTracks();"));
+        const QVariant successClear = d->htmlWidget->runScript(QString::fromLatin1("kgeomapClearTracks();"), false);
 
         return;
     }
 
-    Q_FOREACH(const TrackManager::TrackChanges& tc, trackChanges)
+    foreach(const TrackManager::TrackChanges& tc, trackChanges)
     {
         if (tc.second & TrackManager::ChangeRemoved)
         {
@@ -1415,7 +1424,7 @@ void BackendGoogleMaps::slotTrackVisibilityChanged(const bool newState)
         const TrackManager::Track::List trackList = s->trackManager->getTrackList();
         QList<TrackManager::TrackChanges> trackChanges;
 
-        Q_FOREACH(const TrackManager::Track& t, trackList)
+        foreach(const TrackManager::Track& t, trackList)
         {
             trackChanges << TrackManager::TrackChanges(t.id, TrackManager::ChangeAdd);
         }
@@ -1424,7 +1433,7 @@ void BackendGoogleMaps::slotTrackVisibilityChanged(const bool newState)
     }
     else if (d->htmlWidget)
     {
-        const QVariant successClear = d->htmlWidget->runScript(QString::fromLatin1("kgeomapClearTracks();"));
+        const QVariant successClear = d->htmlWidget->runScript(QString::fromLatin1("kgeomapClearTracks();"), false);
     }
 }
 
