@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : Google-Maps-backend for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C) 2014      by Justus Schwartz <justus at gmx dot li>
  *
@@ -23,24 +23,26 @@
  *
  * ============================================================ */
 
-#ifndef BACKEND_MAP_GOOGLEMAPS_H
-#define BACKEND_MAP_GOOGLEMAPS_H
+#ifndef DIGIKAM_BACKEND_GOOGLE_MAPS_H
+#define DIGIKAM_BACKEND_GOOGLE_MAPS_H
 
 // Local includes
 
 #include "mapbackend.h"
 #include "trackmanager.h"
+#include "digikam_export.h"
 
 namespace Digikam
 {
 
-class BackendGoogleMaps : public MapBackend
+class DIGIKAM_EXPORT BackendGoogleMaps : public MapBackend
 {
     Q_OBJECT
 
 public:
 
-    explicit BackendGoogleMaps(const QExplicitlySharedDataPointer<GeoIfaceSharedData>& sharedData, QObject* const parent = 0);
+    explicit BackendGoogleMaps(const QExplicitlySharedDataPointer<GeoIfaceSharedData>& sharedData,
+                               QObject* const parent = 0);
     virtual ~BackendGoogleMaps();
 
     virtual QString backendName() const;
@@ -133,4 +135,4 @@ private:
 
 } // namespace Digikam
 
-#endif // BACKEND_MAP_GOOGLEMAPS_H
+#endif // DIGIKAM_BACKEND_GOOGLE_MAPS_H
