@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-08
  * Description : Marble-backend for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C) 2014      by Justus Schwartz <justus at gmx dot li>
  *
@@ -46,7 +46,7 @@
 #include <marble/MarbleWidget.h>
 #include <marble/ViewportParams.h>
 #include <marble/AbstractFloatItem.h>
-#include <marble/MarbleWidgetInputHandler.h>
+#include <marble/MarbleWidgetPopupMenu.h>
 
 // Local includes
 
@@ -60,11 +60,11 @@
 namespace Digikam
 {
 
-class BMInternalWidgetInfo
+class Q_DECL_HIDDEN BMInternalWidgetInfo
 {
 public:
 
-    BMInternalWidgetInfo()
+    explicit BMInternalWidgetInfo()
     {
         bmLayer = 0;
     }
@@ -79,11 +79,11 @@ Q_DECLARE_METATYPE(Digikam::BMInternalWidgetInfo)
 namespace Digikam
 {
 
-class BackendMarble::Private
+class Q_DECL_HIDDEN BackendMarble::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : marbleWidget(0),
         actionGroupMapTheme(0),
         actionGroupProjection(0),
@@ -104,7 +104,7 @@ public:
         mouseMoveClusterIndex(-1),
         mouseMoveMarkerIndex(),
         mouseMoveObjectCoordinates(),
-        mouseMoveCenterOffset(0,0),
+        mouseMoveCenterOffset(0, 0),
         dragDropMarkerCount(0),
         dragDropMarkerPos(),
         clustersDirtyCacheProjection(),
@@ -212,7 +212,15 @@ QWidget* BackendMarble::mapWidget()
             d->marbleWidget                    = qobject_cast<Marble::MarbleWidget*>(info.widget);
             const BMInternalWidgetInfo intInfo = info.backendData.value<BMInternalWidgetInfo>();
             d->bmLayer                         = intInfo.bmLayer;
-            d->bmLayer->setBackend(this);
+
+            if (d->bmLayer)
+            {
+                d->bmLayer->setBackend(this);
+            }
+            else
+            {
+                qCWarning(DIGIKAM_GEOIFACE_LOG) << "Marble widget instance is null!";
+            }
         }
         else
         {
@@ -221,8 +229,16 @@ QWidget* BackendMarble::mapWidget()
 
             d->marbleWidget->addLayer(d->bmLayer);
         }
-        // hide Marble widget right button context menu
-        d->marbleWidget->inputHandler()->setMouseButtonPopupEnabled(Qt::RightButton, false);
+
+        // hide Marble bookmark action in the right button context menu
+        // TODO: check with a new Marble version if the bookmark action position is still valid
+        if (d->marbleWidget->popupMenu())
+        {
+            QList<QAction*> actions = d->marbleWidget->popupMenu()->findChildren<QAction*>();
+
+            if (actions.count() > 4 && actions[4])
+                actions[4]->setVisible(false);
+        }
 
         d->marbleWidget->installEventFilter(this);
 
@@ -437,6 +453,7 @@ void BackendMarble::setMapTheme(const QString& newMapTheme)
 
     // Changing the map theme changes the zoom - we want to try to keep the zoom constant
     d->blockingZoomWhileChangingTheme = true;
+
     // Remember the zoom from the cache. The zoom of the widget may not have been set yet!
     const int oldMarbleZoom           = d->cacheZoom;
 
@@ -612,7 +629,7 @@ void BackendMarble::GeoPainter_drawPixmapAtCoordinates(Marble::GeoPainter* const
     // therefore we calculate the pixel position of the center of the image if its offsetPoint
     // is to be at pointOnScreen:
     const QSize pixmapSize      = pixmap.size();
-    const QPoint pixmapHalfSize = QPoint(pixmapSize.width()/2, pixmapSize.height()/2);
+    const QPoint pixmapHalfSize = QPoint(pixmapSize.width() / 2, pixmapSize.height() / 2);
     const QPoint drawPoint      = pointOnScreen + pixmapHalfSize - offsetPoint;
 
     // now re-calculate the coordinates of the new pixel coordinates:
@@ -659,7 +676,7 @@ void BackendMarble::marbleCustomPaint(Marble::GeoPainter* painter)
         {
             TrackManager::Track::List const& tracks = s->trackManager->getTrackList();
 
-            for (int trackIdx = 0; trackIdx < tracks.count(); ++trackIdx)
+            for (int trackIdx = 0 ; trackIdx < tracks.count() ; ++trackIdx)
             {
                 TrackManager::Track const& track = tracks.at(trackIdx);
 
@@ -676,7 +693,7 @@ void BackendMarble::marbleCustomPaint(Marble::GeoPainter* painter)
                 }
                 else
                 {
-                    for (int coordIdx = 0; coordIdx < track.points.count(); ++coordIdx)
+                    for (int coordIdx = 0 ; coordIdx < track.points.count() ; ++coordIdx)
                     {
                         GeoCoordinates const& coordinates                  = track.points.at(coordIdx).coordinates;
                         const Marble::GeoDataCoordinates marbleCoordinates = coordinates.toMarbleCoordinates();
@@ -837,7 +854,7 @@ void BackendMarble::marbleCustomPaint(Marble::GeoPainter* painter)
             }
 
             const QPixmap& markerPixmap = GeoIfaceGlobalObject::instance()->getMarkerPixmap(pixmapName);
-            painter->drawPixmap(clusterPoint.x() - markerPixmap.width() / 2,
+            painter->drawPixmap(clusterPoint.x() - markerPixmap.width()  / 2,
                                 clusterPoint.y() - markerPixmap.height() - 1,
                                 markerPixmap);
         }
@@ -860,7 +877,7 @@ void BackendMarble::marbleCustomPaint(Marble::GeoPainter* painter)
         pixmapName                 += QLatin1String("-selected");
         const QPixmap& markerPixmap = GeoIfaceGlobalObject::instance()->getMarkerPixmap(pixmapName);
 
-        painter->drawPixmap(d->dragDropMarkerPos.x() - markerPixmap.width() / 2,
+        painter->drawPixmap(d->dragDropMarkerPos.x() - markerPixmap.width()  / 2,
                             d->dragDropMarkerPos.y() - markerPixmap.height() - 1,
                             markerPixmap);
     }
@@ -1145,7 +1162,7 @@ GeoCoordinates::PairList BackendMarble::getNormalizedBounds()
     }
 
     const Marble::GeoDataLatLonAltBox marbleBounds = d->marbleWidget->viewport()->viewLatLonAltBox();
-//     qCDebug(DIGIKAM_GEOIFACE_LOG)<<marbleBounds.toString(GeoDataCoordinates::Degree);
+//     qCDebug(DIGIKAM_GEOIFACE_LOG) << marbleBounds.toString(GeoDataCoordinates::Degree);
 
     const GeoCoordinates::Pair boundsPair = GeoCoordinates::makePair(
             marbleBounds.south(Marble::GeoDataCoordinates::Degree),
@@ -1153,13 +1170,13 @@ GeoCoordinates::PairList BackendMarble::getNormalizedBounds()
             marbleBounds.north(Marble::GeoDataCoordinates::Degree),
             marbleBounds.east(Marble::GeoDataCoordinates::Degree));
 
-//     qCDebug(DIGIKAM_GEOIFACE_LOG)<<boundsPair.first<<boundsPair.second;
-//     qCDebug(DIGIKAM_GEOIFACE_LOG)<<GeoIfaceHelperNormalizeBounds(boundsPair);
+//     qCDebug(DIGIKAM_GEOIFACE_LOG) << boundsPair.first<<boundsPair.second;
+//     qCDebug(DIGIKAM_GEOIFACE_LOG) << GeoIfaceHelperNormalizeBounds(boundsPair);
 
     return GeoIfaceHelperNormalizeBounds(boundsPair);
 }
 
-bool BackendMarble::eventFilter(QObject *object, QEvent *event)
+bool BackendMarble::eventFilter(QObject* object, QEvent* event)
 {
     if (object != d->marbleWidget)
     {
@@ -1186,8 +1203,8 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
 
     if (s->currentMouseMode == MouseModeRegionSelection)
     {
-        if ((event->type() == QEvent::MouseButtonPress) &&
-            (mouseEvent->button()==Qt::LeftButton))
+        if ((event->type()        == QEvent::MouseButtonPress) &&
+            (mouseEvent->button() == Qt::LeftButton))
         {
             // we need to filter this event because otherwise Marble displays
             // a left click context menu
@@ -1240,7 +1257,7 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
 
             doFilterEvent = true;
         }
-        else if ((event->type() == QEvent::MouseButtonRelease) &&
+        else if ((event->type()        == QEvent::MouseButtonRelease) &&
                  (mouseEvent->button() == Qt::LeftButton))
         {
             if (!d->firstSelectionPoint.hasCoordinates())
@@ -1295,8 +1312,8 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
     }
     else
     {
-        if ((event->type() == QEvent::MouseButtonPress) &&
-            (mouseEvent->button()==Qt::LeftButton))
+        if ((event->type()        == QEvent::MouseButtonPress) &&
+            (mouseEvent->button() == Qt::LeftButton))
         {
             // check whether the user clicked on one of our items:
             // scan in reverse order, because the user would expect
@@ -1334,7 +1351,7 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
     //             }
     //         }
 
-            if (/*s->inEditMode&&*/!doFilterEvent)
+            if (/*s->inEditMode &&*/ !doFilterEvent)
             {
                 // scan in reverse order of painting!
                 for (int clusterIndex = s->clusterList.count()-1 ;
@@ -1377,7 +1394,7 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
         else if ((event->type() == QEvent::MouseMove) &&
                  (d->havePotentiallyMouseMovingObject || d->haveMouseMovingObject))
         {
-            if ((!s->modificationsAllowed) ||
+            if ((!s->modificationsAllowed)                                                 ||
                 (!s->markerModel->tilerFlags().testFlag(AbstractMarkerTiler::FlagMovable)) ||
                 ((d->mouseMoveClusterIndex >= 0) && s->showThumbnails))
             {
@@ -1396,7 +1413,7 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
                 d->haveMouseMovingObject            = true;
 
                 // a cluster or marker is being moved. update its position:
-                QPoint newMarkerPoint = mouseEvent->pos() - d->mouseMoveCenterOffset;
+                QPoint newMarkerPoint               = mouseEvent->pos() - d->mouseMoveCenterOffset;
                 QPoint snapPoint;
 
                 if (findSnapPoint(newMarkerPoint, &snapPoint, 0, 0))
@@ -1596,8 +1613,8 @@ void BackendMarble::slotTrackManagerChanged()
 
     if (s->trackManager)
     {
-        connect(s->trackManager, SIGNAL(signalTracksChanged(const QList<TrackManager::TrackChanges>)),
-                this, SLOT(slotTracksChanged(const QList<TrackManager::TrackChanges>)));
+        connect(s->trackManager, SIGNAL(signalTracksChanged(QList<TrackManager::TrackChanges>)),
+                this, SLOT(slotTracksChanged(QList<TrackManager::TrackChanges>)));
 
         // when the visibility of the tracks is changed, we simple schedule a redraw
         connect(s->trackManager, SIGNAL(signalVisibilityChanged(bool)),
@@ -1607,7 +1624,10 @@ void BackendMarble::slotTrackManagerChanged()
     slotScheduleUpdate();
 }
 
-bool BackendMarble::findSnapPoint(const QPoint& actualPoint, QPoint* const snapPoint, GeoCoordinates* const snapCoordinates, QPair<int, QModelIndex>* const snapTargetIndex)
+bool BackendMarble::findSnapPoint(const QPoint& actualPoint,
+                                  QPoint* const snapPoint,
+                                  GeoCoordinates* const snapCoordinates,
+                                  QPair<int, QModelIndex>* const snapTargetIndex)
 {
     QPoint bestSnapPoint;
     GeoCoordinates bestSnapCoordinates;
@@ -1765,7 +1785,8 @@ void BackendMarble::setActive(const bool state)
             info.widget                    = d->marbleWidget;
             info.currentOwner              = this;
             info.backendName               = backendName();
-            info.state                     = d->widgetIsDocked ? GeoIfaceInternalWidgetInfo::InternalWidgetStillDocked : GeoIfaceInternalWidgetInfo::InternalWidgetUndocked;
+            info.state                     = d->widgetIsDocked ? GeoIfaceInternalWidgetInfo::InternalWidgetStillDocked
+                                                               : GeoIfaceInternalWidgetInfo::InternalWidgetUndocked;
 
             BMInternalWidgetInfo intInfo;
             intInfo.bmLayer                = d->bmLayer;
@@ -1872,7 +1893,7 @@ void BackendMarble::applyCacheToWidget()
 void BackendMarble::slotTracksChanged(const QList<TrackManager::TrackChanges> trackChanges)
 {
     // invalidate the cache for all changed tracks
-    Q_FOREACH(const TrackManager::TrackChanges& tc, trackChanges)
+    foreach (const TrackManager::TrackChanges& tc, trackChanges)
     {
         if (tc.second & (TrackManager::ChangeTrackPoints | TrackManager::ChangeRemoved))
         {
