@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-08
  * Description : Marble-backend for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C) 2014      by Justus Schwartz <justus at gmx dot li>
  *
@@ -23,13 +23,14 @@
  *
  * ============================================================ */
 
-#ifndef BACKEND_MAP_MARBLE_H
-#define BACKEND_MAP_MARBLE_H
+#ifndef DIGIKAM_BACKEND_MARBLE_H
+#define DIGIKAM_BACKEND_MARBLE_H
 
 // Local includes
 
 #include "mapbackend.h"
 #include "trackmanager.h"
+#include "digikam_export.h"
 
 /// @cond false
 namespace Marble
@@ -41,7 +42,7 @@ namespace Marble
 namespace Digikam
 {
 
-class BackendMarble : public MapBackend
+class DIGIKAM_EXPORT BackendMarble : public MapBackend
 {
     Q_OBJECT
 
@@ -141,4 +142,4 @@ private:
 
 } // namespace Digikam
 
-#endif // BACKEND_MAP_MARBLE_H
+#endif // DIGIKAM_BACKEND_MARBLE_H
