@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-08
  * Description : Internal part of the Marble-backend for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef BACKEND_MAP_MARBLE_LAYER_H
-#define BACKEND_MAP_MARBLE_LAYER_H
+#ifndef DIGIKAM_BACKEND_MARBLE_LAYER_H
+#define DIGIKAM_BACKEND_MARBLE_LAYER_H
 
 // Qt includes
 
@@ -33,6 +33,10 @@
 
 #include <marble/LayerInterface.h>
 
+// Local includes
+
+#include "digikam_export.h"
+
 /// @cond false
 namespace Marble
 {
@@ -47,7 +51,7 @@ namespace Digikam
 
 class BackendMarble;
 
-class BackendMarbleLayer : public Marble::LayerInterface
+class DIGIKAM_EXPORT BackendMarbleLayer : public Marble::LayerInterface
 {
 public:
 
@@ -56,7 +60,7 @@ public:
 
     virtual bool render(Marble::GeoPainter* painter,
                         Marble::ViewportParams* viewport,
-                        const QString& renderPos = QLatin1String( "NONE"),
+                        const QString& renderPos = QLatin1String("NONE"),
                         Marble::GeoSceneLayer* layer = 0);
     virtual QStringList renderPosition () const;
 
@@ -69,4 +73,4 @@ private:
 
 } // namespace Digikam
 
-#endif // BACKEND_MAP_MARBLE_LAYER_H
+#endif // DIGIKAM_BACKEND_MARBLE_LAYER_H
