@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-16
  * Description : GeoCoordinates class
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GEO_COORDINATES_H
-#define GEO_COORDINATES_H
+#ifndef DIGIKAM_GEO_COORDINATES_H
+#define DIGIKAM_GEO_COORDINATES_H
 
 // Qt includes
 
@@ -121,4 +121,4 @@ Q_DECLARE_METATYPE(Digikam::GeoCoordinates::PairList)
 
 DIGIKAM_EXPORT QDebug operator<<(QDebug debug, const Digikam::GeoCoordinates& coordinate);
 
-#endif // GEO_COORDINATES_H
+#endif // DIGIKAM_GEO_COORDINATES_H
