@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-03-18
  * Description : Drag-and-drop handler for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GEO_DRAG_DROP_HANDLER_H
-#define GEO_DRAG_DROP_HANDLER_H
+#ifndef DIGIKAM_GEO_DRAG_DROP_HANDLER_H
+#define DIGIKAM_GEO_DRAG_DROP_HANDLER_H
 
 // Local includes
 
@@ -52,4 +52,4 @@ public:
 
 } // namespace Digikam
 
-#endif // GEO_DRAG_DROP_HANDLER_H
+#endif // DIGIKAM_GEO_DRAG_DROP_HANDLER_H
