@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-07-14
  * Description : Common internal data structures for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C)      2014 by Justus Schwartz <justus at gmx dot li>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef GEO_IFACE_COMMON_H
-#define GEO_IFACE_COMMON_H
+#ifndef DIGIKAM_GEO_IFACE_COMMON_H
+#define DIGIKAM_GEO_IFACE_COMMON_H
 
 // Qt includes
 
@@ -300,4 +300,4 @@ DIGIKAM_EXPORT void GeoIface_assert(const char* const condition,
 
 #define GEOIFACE_ASSERT(cond) ((!(cond)) ? Digikam::GeoIface_assert(#cond,__FILE__,__LINE__) : qt_noop())
 
-#endif // GEO_IFACE_COMMON_H
+#endif // DIGIKAM_GEO_IFACE_COMMON_H
