@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : Primitive datatypes for geolocation interface
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GEO_IFACE_TYPES_H
-#define GEO_IFACE_TYPES_H
+#ifndef DIGIKAM_GEO_IFACE_TYPES_H
+#define DIGIKAM_GEO_IFACE_TYPES_H
 
 // Qt includes
 
@@ -63,4 +63,4 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::GeoExtraActions)
 
 Q_DECLARE_METATYPE(Digikam::GeoMouseModes)
 
-#endif // GEO_IFACE_TYPES_H
+#endif // DIGIKAM_GEO_IFACE_TYPES_H
