@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : Helper class to access models
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GEO_MODEL_HELPER_H
-#define GEO_MODEL_HELPER_H
+#ifndef DIGIKAM_GEO_MODEL_HELPER_H
+#define DIGIKAM_GEO_MODEL_HELPER_H
 
 // Qt includes
 
@@ -107,4 +107,4 @@ Q_SIGNALS:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::GeoModelHelper::PropertyFlags)
 
-#endif // GEO_MODEL_HELPER_H
+#endif // DIGIKAM_GEO_MODEL_HELPER_H
