@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-04-30
  * Description : Class for geonames.org based altitude lookup
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -40,7 +40,7 @@
 namespace Digikam
 {
 
-class MergedRequests
+class Q_DECL_HIDDEN MergedRequests
 {
 public:
 
@@ -69,22 +69,24 @@ class Q_DECL_HIDDEN LookupAltitudeGeonames::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : status(StatusSuccess),
         currentMergedRequestIndex(0),
-        netReply(0)
+        netReply(0),
+        mngr(0)
 
     {
     }
 
-    Request::List        requests;
-    MergedRequests::List mergedRequests;
-    StatusAltitude       status;
-    QString              errorMessage;
+    Request::List          requests;
+    MergedRequests::List   mergedRequests;
+    StatusAltitude         status;
+    QString                errorMessage;
 
-    int                  currentMergedRequestIndex;
+    int                    currentMergedRequestIndex;
 
-    QNetworkReply*       netReply;
+    QNetworkReply*         netReply;
+    QNetworkAccessManager* mngr;
 };
 
 // ------------------------------------------------------------
@@ -93,6 +95,10 @@ LookupAltitudeGeonames::LookupAltitudeGeonames(QObject* const parent)
     : LookupAltitude(parent),
       d(new Private)
 {
+    d->mngr = new QNetworkAccessManager(this);
+
+    connect(d->mngr, SIGNAL(finished(QNetworkReply*)),
+            this, SLOT(slotFinished(QNetworkReply*)));
 }
 
 LookupAltitudeGeonames::~LookupAltitudeGeonames()
@@ -169,7 +175,7 @@ void LookupAltitudeGeonames::startNextRequest()
     if (d->currentMergedRequestIndex >= d->mergedRequests.count())
     {
         d->status = StatusSuccess;
-        emit(signalDone());
+        emit signalDone();
         return;
     }
 
@@ -201,12 +207,7 @@ void LookupAltitudeGeonames::startNextRequest()
     q.addQueryItem(QLatin1String("username"), QLatin1String("digikam"));
     netUrl.setQuery(q);
 
-    QNetworkAccessManager* const mngr = new QNetworkAccessManager(this);
-
-    connect(mngr, SIGNAL(finished(QNetworkReply*)),
-            this, SLOT(slotFinished(QNetworkReply*)));
-
-    d->netReply = mngr->get(QNetworkRequest(netUrl));
+    d->netReply = d->mngr->get(QNetworkRequest(netUrl));
 }
 
 void LookupAltitudeGeonames::slotFinished(QNetworkReply* reply)
@@ -218,7 +219,7 @@ void LookupAltitudeGeonames::slotFinished(QNetworkReply* reply)
 
         // after an error, we abort:
         reply->deleteLater();
-        emit(signalDone());
+        emit signalDone();
         return;
     }
 
@@ -260,7 +261,7 @@ void LookupAltitudeGeonames::slotFinished(QNetworkReply* reply)
         readyRequests << currentRequestIndexes;
     }
 
-    emit(signalRequestsReady(readyRequests));
+    emit signalRequestsReady(readyRequests);
 
     reply->deleteLater();
 
@@ -286,7 +287,7 @@ void LookupAltitudeGeonames::cancel()
 
     d->status = StatusCanceled;
 
-    emit(signalDone());
+    emit signalDone();
 }
 
 } // namespace Digikam
