@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-04-30
  * Description : Class for geonames.org based altitude lookup
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef LOOKUP_ALTITUDE_GEONAMES_H
-#define LOOKUP_ALTITUDE_GEONAMES_H
+#ifndef DIGIKAM_LOOKUP_ALTITUDE_GEONAMES_H
+#define DIGIKAM_LOOKUP_ALTITUDE_GEONAMES_H
 
 // Qt includes
 
@@ -74,4 +74,4 @@ private:
 
 } // namespace Digikam
 
-#endif // LOOKUP_ALTITUDE_GEONAMES_H
+#endif // DIGIKAM_LOOKUP_ALTITUDE_GEONAMES_H
