@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : An abstract base class for tiling of markers
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -36,11 +36,11 @@
 namespace Digikam
 {
 
-class AbstractMarkerTiler::Private
+class Q_DECL_HIDDEN AbstractMarkerTiler::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : rootTile(0),
           isDirty(true)
     {
@@ -137,7 +137,7 @@ void AbstractMarkerTiler::tileDeleteChildren(AbstractMarkerTiler::Tile* const ti
 
     QVector<Tile*> tileChildren = tile->takeChildren();
 
-    foreach(Tile* tilec, tileChildren)
+    foreach (Tile* tilec, tileChildren)
     {
         tileDelete(tilec);
     }
@@ -176,7 +176,7 @@ class Q_DECL_HIDDEN AbstractMarkerTiler::NonEmptyIterator::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : model(0),
           level(0),
           startIndex(),
@@ -216,7 +216,7 @@ AbstractMarkerTiler::NonEmptyIterator::NonEmptyIterator(AbstractMarkerTiler* con
     TileIndex startIndex;
     TileIndex endIndex;
 
-    for (int i = 0 ; i <= level ; i++)
+    for (int i = 0 ; i <= level ; ++i)
     {
         startIndex.appendLinearIndex(0);
         endIndex.appendLinearIndex(TileIndex::Tiling * TileIndex::Tiling - 1);
@@ -255,7 +255,7 @@ AbstractMarkerTiler::NonEmptyIterator::NonEmptyIterator(AbstractMarkerTiler* con
     d->level = level;
 
     // store the coordinates of the bounds as indices:
-    for (int i = 0 ; i < normalizedMapBounds.count() ; i++)
+    for (int i = 0 ; i < normalizedMapBounds.count() ; ++i)
     {
         GeoCoordinates::Pair currentBounds = normalizedMapBounds.at(i);
         GEOIFACE_ASSERT(currentBounds.first.lat() < currentBounds.second.lat());
@@ -332,7 +332,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
             // check limit on the left side:
             bool onLimit = true;
 
-            for (int i=0; onLimit && (i <= compareLevel); ++i)
+            for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
             {
                 onLimit = d->currentIndex.indexLat(i) == d->startIndex.indexLat(i);
             }
@@ -345,7 +345,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
             // check limit on the bottom side:
             onLimit = true;
 
-            for (int i=0; onLimit && (i <= compareLevel); ++i)
+            for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
             {
                 onLimit = d->currentIndex.indexLon(i) == d->startIndex.indexLon(i);
             }
@@ -358,7 +358,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
             // check limit on the right side:
             onLimit = true;
 
-            for (int i=0; onLimit && (i <= compareLevel); ++i)
+            for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
             {
                 onLimit = d->currentIndex.indexLat(i) == d->endIndex.indexLat(i);
             }
@@ -371,7 +371,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
             // check limit on the top side:
             onLimit = true;
 
-            for (int i=0; onLimit && (i <= compareLevel); ++i)
+            for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
             {
                 onLimit = d->currentIndex.indexLon(i) == d->endIndex.indexLon(i);
             }
@@ -450,7 +450,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
         // check limit on the left side:
         bool onLimit   = true;
 
-        for (int i=0; onLimit&&(i<=compareLevel); ++i)
+        for (int i = 0 ; onLimit&&(i <= compareLevel) ; ++i)
         {
             onLimit = d->currentIndex.indexLat(i)==d->startIndex.indexLat(i);
         }
@@ -463,7 +463,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
         // check limit on the bottom side:
         onLimit = true;
 
-        for (int i=0; onLimit && (i <= compareLevel); ++i)
+        for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
         {
             onLimit = d->currentIndex.indexLon(i)==d->startIndex.indexLon(i);
         }
@@ -476,7 +476,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
         // check limit on the right side:
         onLimit = true;
 
-        for (int i=0; onLimit && (i <= compareLevel); ++i)
+        for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
         {
             onLimit = d->currentIndex.indexLat(i) == d->endIndex.indexLat(i);
         }
@@ -489,7 +489,7 @@ TileIndex AbstractMarkerTiler::NonEmptyIterator::nextIndex()
         // check limit on the top side:
         onLimit = true;
 
-        for (int i=0; onLimit && (i <= compareLevel); ++i)
+        for (int i = 0 ; onLimit && (i <= compareLevel) ; ++i)
         {
             onLimit = d->currentIndex.indexLon(i) == d->endIndex.indexLon(i);
         }
@@ -551,7 +551,7 @@ AbstractMarkerTiler::Tile* AbstractMarkerTiler::Tile::getChild(const int linearI
 
 void AbstractMarkerTiler::Tile::addChild(const int linearIndex, Tile* const tilePointer)
 {
-    if ( (tilePointer==0) && children.isEmpty() )
+    if ((tilePointer==0) && children.isEmpty())
     {
         return;
     }
