@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : An abstract base class for tiling of markers
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef ABSTRACT_MARKER_TILER_H
-#define ABSTRACT_MARKER_TILER_H
+#ifndef DIGIKAM_ABSTRACT_MARKER_TILER_H
+#define DIGIKAM_ABSTRACT_MARKER_TILER_H
 
 // Qt includes
 
@@ -61,10 +61,10 @@ public:
     {
     public:
 
-        TileIndex::List   tileIndicesList;
-        QVariant          representativeIndex;
-        GeoGroupState        groupSelectionState;
-        GeoMouseModes        currentMouseMode;
+        TileIndex::List tileIndicesList;
+        QVariant        representativeIndex;
+        GeoGroupState   groupSelectionState;
+        GeoMouseModes   currentMouseMode;
     };
 
 public:
@@ -73,7 +73,7 @@ public:
     {
     public:
 
-        Tile();
+        explicit Tile();
 
         /**
          * NOTE: Tile is only deleted by AbstractMarkerTiler::tileDelete.
@@ -115,7 +115,6 @@ public:
     private:
 
         QVector<Tile*> children;
-
     };
 
 public:
@@ -140,6 +139,8 @@ public:
 
     private:
 
+        NonEmptyIterator(const NonEmptyIterator&); // Disable
+
         class Private;
         Private* const d;
     };
@@ -205,4 +206,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::AbstractMarkerTiler::TilerFlags)
 
-#endif // ABSTRACT_MARKER_TILER_H
+#endif // DIGIKAM_ABSTRACT_MARKER_TILER_H
