@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-07-17
  * Description : A marker tiler operating on item models
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -33,7 +33,7 @@
 namespace Digikam
 {
 
-class ItemMarkerTiler::MyTile : public Tile
+class Q_DECL_HIDDEN ItemMarkerTiler::MyTile : public Tile
 {
 public:
 
@@ -66,7 +66,7 @@ public:
 
 void ItemMarkerTiler::MyTile::removeMarkerIndexOrInvalidIndex(const QModelIndex& indexToRemove)
 {
-    int i=0;
+    int i = 0;
 
     while (i < markerIndices.count())
     {
@@ -76,13 +76,13 @@ void ItemMarkerTiler::MyTile::removeMarkerIndexOrInvalidIndex(const QModelIndex&
         //       an aboutToRemove-signal. It is possible that the persistent
         //       marker index became invalid before the caller received the signal.
         //       we remove any invalid indices as we find them.
-        if ( !currentIndex.isValid() )
+        if (!currentIndex.isValid())
         {
             markerIndices.takeAt(i);
             continue;
         }
 
-        if ( currentIndex == indexToRemove )
+        if (currentIndex == indexToRemove)
         {
             markerIndices.takeAt(i);
             return;
@@ -98,7 +98,7 @@ class Q_DECL_HIDDEN ItemMarkerTiler::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : modelHelper(0),
         selectionModel(0),
         markerModel(0),
