@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-12-05
  * Description : Merges tiles into groups
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -37,11 +37,11 @@
 namespace Digikam
 {
 
-class TileGrouper::Private
+class Q_DECL_HIDDEN TileGrouper::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : clustersDirty(true),
           currentBackend(0)
     {
@@ -157,7 +157,7 @@ void TileGrouper::updateClusters()
     int debugTilesSearched      = 0;
 
     /// @todo Review this
-    for(int i = 0 ; i < mapBounds.count() ; ++i)
+    for (int i = 0 ; i < mapBounds.count() ; ++i)
     {
         s->markerModel->prepareTiles(mapBounds.at(i).first, mapBounds.at(i).second, markerLevel);
     }
