@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-09-19
  * Description : Track file loading and managing
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -50,7 +50,7 @@ class Q_DECL_HIDDEN TrackManager::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : trackLoadFutureWatcher(0),
         trackLoadFuture(),
         trackList(),
@@ -155,7 +155,7 @@ void TrackManager::slotTrackFilesFinished()
     d->trackList << d->trackPendingList;
     QList<TrackChanges> trackChanges;
 
-    Q_FOREACH(const Track& track, d->trackPendingList)
+    foreach(const Track& track, d->trackPendingList)
     {
         trackChanges << TrackChanges(track.id, ChangeAdd);
     }
@@ -194,7 +194,7 @@ quint64 TrackManager::getNextFreeTrackId()
 
 TrackManager::Track TrackManager::getTrackById(const quint64 trackId) const
 {
-    Q_FOREACH(const Track& track, d->trackList)
+    foreach(const Track& track, d->trackList)
     {
         if (track.id == trackId)
         {
