@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-09-19
  * Description : Track file loading and managing
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef TRACK_MANAGER_H
-#define TRACK_MANAGER_H
+#ifndef DIGIKAM_TRACK_MANAGER_H
+#define DIGIKAM_TRACK_MANAGER_H
 
 // Qt includes
 
@@ -52,7 +52,7 @@ public:
     {
     public:
 
-        TrackPoint()
+        explicit TrackPoint()
           : dateTime(),
             coordinates(),
             nSatellites(-1),
@@ -95,7 +95,7 @@ public:
 
     public:
 
-        Track()
+        explicit Track()
           : url(),
             points(),
             id(0),
@@ -166,4 +166,4 @@ private:
 
 } // namespace Digikam
 
-#endif // TRACK_MANAGER_H
+#endif // DIGIKAM_TRACK_MANAGER_H
