@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-09-19
  * Description : Track file reader
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -36,14 +36,14 @@
 namespace Digikam
 {
 
-static QString GPX10(QString::fromLatin1("http://www.topografix.com/GPX/1/0"));
-static QString GPX11(QString::fromLatin1("http://www.topografix.com/GPX/1/1"));
+static QString GPX10(QLatin1String("http://www.topografix.com/GPX/1/0"));
+static QString GPX11(QLatin1String("http://www.topografix.com/GPX/1/1"));
 
 class Q_DECL_HIDDEN TrackReader::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : fileData(0),
           verifyFoundGPXElement(false)
     {
@@ -85,8 +85,8 @@ QDateTime TrackReader::ParseTime(QString timeString)
 
     // does the string contain a timezone offset?
     int timeZoneOffsetSeconds       = 0;
-    const int timeZonePlusPosition  = timeString.lastIndexOf(QString::fromLatin1("+"));
-    const int timeZoneMinusPosition = timeString.lastIndexOf(QString::fromLatin1("-"));
+    const int timeZonePlusPosition  = timeString.lastIndexOf(QLatin1Char('+'));
+    const int timeZoneMinusPosition = timeString.lastIndexOf(QLatin1Char('-'));
 
     if ( (timeZonePlusPosition == timeZoneSignPosition) || (timeZoneMinusPosition == timeZoneSignPosition) )
     {
@@ -95,7 +95,7 @@ QDateTime TrackReader::ParseTime(QString timeString)
         // cut off the last digits:
         const QString timeZoneString = timeString.right(6);
         timeString.chop(6);
-        timeString                  += QChar::fromLatin1('Z');
+        timeString                  += QLatin1Char('Z');
 
         // determine the time zone offset:
         bool okayHour                = false;
@@ -130,7 +130,7 @@ QString TrackReader::myQName(const QString& namespaceURI, const QString& localNa
     if ( (namespaceURI == GPX10)  ||
          (namespaceURI == GPX11) )
     {
-        return QString::fromLatin1("gpx:") + localName;
+        return QLatin1String("gpx:") + localName;
     }
 
     return namespaceURI+localName;
@@ -148,7 +148,7 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
     d->currentText.clear();
     rebuildElementPath();
 
-    if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt"))
+    if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt"))
     {
         if (d->currentDataPoint.dateTime.isValid() && d->currentDataPoint.coordinates.hasCoordinates())
         {
@@ -157,11 +157,11 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
 
         d->currentDataPoint = TrackManager::TrackPoint();
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:time"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:time"))
     {
         d->currentDataPoint.dateTime = ParseTime(eText.trimmed());
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:sat"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:sat"))
     {
         bool okay       = false;
         int nSatellites = eText.toInt(&okay);
@@ -169,7 +169,7 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
         if (okay && (nSatellites >= 0))
             d->currentDataPoint.nSatellites = nSatellites;
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:hdop"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:hdop"))
     {
         bool okay  = false;
         qreal hDop = eText.toDouble(&okay);
@@ -177,7 +177,7 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
         if (okay)
             d->currentDataPoint.hDop = hDop;
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:pdop"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:pdop"))
     {
         bool okay  = false;
         qreal pDop = eText.toDouble(&okay);
@@ -185,15 +185,15 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
         if (okay)
             d->currentDataPoint.pDop = pDop;
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:fix"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:fix"))
     {
         int fixType = -1;
 
-        if (eText == QString::fromLatin1("2d"))
+        if (eText == QLatin1String("2d"))
         {
             fixType = 2;
         }
-        else if (eText == QString::fromLatin1("3d"))
+        else if (eText == QLatin1String("3d"))
         {
             fixType = 3;
         }
@@ -203,7 +203,7 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
             d->currentDataPoint.fixType = fixType;
         }
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:ele"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:ele"))
     {
         bool haveAltitude = false;
         const qreal alt   = eText.toDouble(&haveAltitude);
@@ -213,7 +213,7 @@ bool TrackReader::endElement(const QString& namespaceURI, const QString& localNa
             d->currentDataPoint.coordinates.setAlt(alt);
         }
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:speed"))
+    else if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt/gpx:speed"))
     {
         bool haveSpeed    = false;
         const qreal speed = eText.toDouble(&haveSpeed);
@@ -236,7 +236,7 @@ bool TrackReader::startElement(const QString& namespaceURI, const QString& local
     rebuildElementPath();
     const QString& ePath = d->currentElementPath;
 
-    if (ePath == QString::fromLatin1("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt"))
+    if (ePath == QLatin1String("gpx:gpx/gpx:trk/gpx:trkseg/gpx:trkpt"))
     {
         qreal lat    = 0.0;
         qreal lon    = 0.0;
@@ -248,11 +248,11 @@ bool TrackReader::startElement(const QString& namespaceURI, const QString& local
             const QString attName  = myQName(atts.uri(i), atts.localName(i));
             const QString attValue = atts.value(i);
 
-            if (attName == QString::fromLatin1("lat"))
+            if (attName == QLatin1String("lat"))
             {
                 lat = attValue.toDouble(&haveLat);
             }
-            else if (attName == QString::fromLatin1("lon"))
+            else if (attName == QLatin1String("lon"))
             {
                 lon = attValue.toDouble(&haveLon);
             }
@@ -263,7 +263,7 @@ bool TrackReader::startElement(const QString& namespaceURI, const QString& local
             d->currentDataPoint.coordinates.setLatLon(lat, lon);
         }
     }
-    else if (ePath == QString::fromLatin1("gpx:gpx"))
+    else if (ePath == QLatin1String("gpx:gpx"))
     {
         d->verifyFoundGPXElement = true;
     }
@@ -273,7 +273,7 @@ bool TrackReader::startElement(const QString& namespaceURI, const QString& local
 
 void TrackReader::rebuildElementPath()
 {
-    d->currentElementPath = d->currentElements.join(QString::fromLatin1("/"));
+    d->currentElementPath = d->currentElements.join(QLatin1Char('/'));
 }
 
 TrackReader::TrackReadResult TrackReader::loadTrackFile(const QUrl& url)
