@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-09-19
  * Description : Track file reader
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef TRACK_READER_H
-#define TRACK_READER_H
+#ifndef DIGIKAM_TRACK_READER_H
+#define DIGIKAM_TRACK_READER_H
 
 // Qt includes
 
@@ -47,7 +47,7 @@ public:
     {
     public:
 
-        TrackReadResult()
+        explicit TrackReadResult()
           : track(),
             isValid(false),
             loadError()
@@ -87,4 +87,4 @@ private:
 
 } // namespace Digikam
 
-#endif // TRACK_READER_H
+#endif // DIGIKAM_TRACK_READER_H
