@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : Widget for displaying HTML in the backends
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2015      by Mohamed Anwer <mohammed dot ahmed dot anwer at gmail dot com>
+ * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,8 +29,7 @@
 
 #include <QTimer>
 #include <QResizeEvent>
-#include <QWebView>
-#include <QWebFrame>
+#include <qwebframe.h>
 
 // Local includes
 
@@ -41,11 +40,11 @@
 namespace Digikam
 {
 
-class HTMLWidget::Private
+class Q_DECL_HIDDEN HTMLWidget::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : parent(0),
         isReady(false),
         selectionStatus(false),
@@ -114,7 +113,7 @@ void HTMLWidget::slotHTMLCompleted(bool ok)
 
 void HTMLWidget::mousePressEvent(QMouseEvent* e)
 {
-    slotScanForJSMessages(QString::fromLatin1("(event)"));
+    slotScanForJSMessages(QLatin1String("(event)"));
     QWebView::mousePressEvent(e);
 }
 
@@ -173,8 +172,7 @@ void HTMLWidget::mouseReleaseEvent(QMouseEvent* e)
 
             const GeoCoordinates::Pair selectionCoordinates(
                     GeoCoordinates(latNorth, lonWest),
-                    GeoCoordinates(latSouth, lonEast)
-                );
+                    GeoCoordinates(latSouth, lonEast));
 
             d->firstSelectionPoint.clear();
             d->intermediateSelectionPoint.clear();
@@ -183,7 +181,7 @@ void HTMLWidget::mouseReleaseEvent(QMouseEvent* e)
         }
     }
 
-    slotScanForJSMessages(QString::fromLatin1("(event)"));
+    slotScanForJSMessages(QLatin1String("(event)"));
     QWebView::mouseReleaseEvent(e);
 }
 
@@ -199,7 +197,8 @@ void HTMLWidget::mouseMoveEvent(QMouseEvent *e)
 
         d->intermediateSelectionScreenPoint = QPoint(e->x(), e->y());
 
-        qCDebug(DIGIKAM_GEOIFACE_LOG) << d->firstSelectionScreenPoint << QLatin1String(" ") << d->intermediateSelectionScreenPoint;
+        qCDebug(DIGIKAM_GEOIFACE_LOG) << d->firstSelectionScreenPoint << QLatin1Char(' ')
+                                      << d->intermediateSelectionScreenPoint;
 
         qreal lonWest, latNorth, lonEast, latSouth;
 
@@ -240,7 +239,7 @@ void HTMLWidget::slotScanForJSMessages(const QString& message)
     if (message != QLatin1String("(event)"))
         return;
 
-//    qCDebug(DIGIKAM_GEOIFACE_LOG) << message;
+    //qCDebug(DIGIKAM_GEOIFACE_LOG) << message;
 
     const QString eventBufferString = runScript(QLatin1String("kgeomapReadEventStrings();")).toString();
 
@@ -255,14 +254,14 @@ void HTMLWidget::slotScanForJSMessages(const QString& message)
 /**
  * @brief Wrapper around executeScript to catch more errors
  */
-QVariant HTMLWidget::runScript(const QString& scriptCode)
+QVariant HTMLWidget::runScript(const QString& scriptCode, bool /*async*/)
 {
     GEOIFACE_ASSERT(d->isReady);
 
     if (!d->isReady)
         return QVariant();
 
-//     qCDebug(DIGIKAM_GEOIFACE_LOG) << scriptCode;
+    //qCDebug(DIGIKAM_GEOIFACE_LOG) << scriptCode;
     return page()->mainFrame()->evaluateJavaScript(scriptCode);
 }
 
@@ -299,7 +298,7 @@ void HTMLWidget::setSelectionRectangle(const GeoCoordinates::Pair& searchCoordin
 {
     if (!searchCoordinates.first.hasCoordinates())
     {
-        runScript(QString::fromLatin1("kgeomapRemoveSelectionRectangle();"));
+        runScript(QLatin1String("kgeomapRemoveSelectionRectangle();"));
         return;
     }
 
