@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : Widget for displaying HTML in the backends
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2015      by Mohamed Anwer <mohammed dot ahmed dot anwer at gmail dot com>
+ * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,12 +23,12 @@
  *
  * ============================================================ */
 
-#ifndef HTML_WIDGET_H
-#define HTML_WIDGET_H
+#ifndef DIGIKAM_HTML_WIDGET_H
+#define DIGIKAM_HTML_WIDGET_H
 
 // Qt includes
 
-#include <QWebView>
+#include <qwebview.h>
 
 // Local includes
 
@@ -49,7 +49,7 @@ public:
     ~HTMLWidget();
 
     void loadInitialHTML(const QString& initialHTML);
-    QVariant runScript(const QString& scriptCode);
+    QVariant runScript(const QString& scriptCode, bool async = true);
     bool runScript2Coordinates(const QString& scriptCode, GeoCoordinates* const coordinates);
     void mouseModeChanged(const GeoMouseModes mouseMode);
     void setSelectionRectangle(const GeoCoordinates::Pair& searchCoordinates);
@@ -87,4 +87,4 @@ private:
 
 } // namespace Digikam
 
-#endif // HTML_WIDGET_H
+#endif // DIGIKAM_HTML_WIDGET_H
