@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : world map widget library
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C)      2014 by Justus Schwartz <justus at gmx dot li>
  *
@@ -102,7 +102,7 @@ class Q_DECL_HIDDEN MapWidget::Private
 {
 public:
 
-    Private()
+    explicit Private()
       : loadedBackends(),
         currentBackend(0),
         currentBackendName(),
@@ -1531,18 +1531,17 @@ void MapWidget::dragEnterEvent(QDragEnterEvent* event)
 
     /// @todo need data about the dragged object: #markers, selected, icon, ...
     event->accept();
-
-//     if (!dragData->haveDragPixmap)
-//         d->currentBackend->updateDragDropMarker(event->pos(), dragData);
 }
 
 void MapWidget::dragMoveEvent(QDragMoveEvent* event)
 {
-    Q_UNUSED(event);
+    if (!d->dragDropHandler)
+    {
+        event->ignore();
+        return;
+    }
 
-    /// @todo update the position of the drag marker if it is to be shown
-//     if (!dragData->haveDragPixmap)
-//         d->currentBackend->updateDragDropMarkerPosition(event->pos());
+    event->accept();
 }
 
 void MapWidget::dropEvent(QDropEvent* event)
@@ -2203,7 +2202,7 @@ void MapWidget::adjustBoundariesToGroupedMarkers(const bool useSaneZoomLevel)
     {
         const TileIndex tileIndex = tileIterator.currentIndex();
 
-        for(int corner = 1 ; corner <= 4 ; corner++)
+        for (int corner = 1 ; corner <= 4 ; ++corner)
         {
             const GeoCoordinates currentTileCoordinate =
                 tileIndex.toCoordinates(TileIndex::CornerPosition(corner));
@@ -2326,7 +2325,7 @@ void MapWidget::setTrackManager(TrackManager* const trackManager)
 
     // Some backends track the track manager activity even when not active
     // therefore they have to be notified.
-    Q_FOREACH(MapBackend* const backend, d->loadedBackends)
+    foreach(MapBackend* const backend, d->loadedBackends)
     {
         backend->slotTrackManagerChanged();
     }
