@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : world map widget library
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C)      2014 by Justus Schwartz <justus at gmx dot li>
  *
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef MAP_WIDGET_H
-#define MAP_WIDGET_H
+#ifndef DIGIKAM_MAP_WIDGET_H
+#define DIGIKAM_MAP_WIDGET_H
 
 // Qt includes
 
@@ -230,4 +230,4 @@ private:
 
 } // namespace Digikam
 
-#endif // MAP_WIDGET_H
+#endif // DIGIKAM_MAP_WIDGET_H
