@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-12-05
  * Description : Placeholder widget for when backends are activated
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -36,11 +36,11 @@
 namespace Digikam
 {
 
-class PlaceholderWidget::Private
+class Q_DECL_HIDDEN PlaceholderWidget::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         messageLabel = 0;
     }
