@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-12-05
  * Description : Placeholder widget for when backends are activated
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef PLACE_HOLDER_WIDGET_H
-#define PLACE_HOLDER_WIDGET_H
+#ifndef DIGIKAM_PLACE_HOLDER_WIDGET_H
+#define DIGIKAM_PLACE_HOLDER_WIDGET_H
 
 // Qt includes
 
@@ -57,4 +57,4 @@ private:
 
 } // namespace Digikam
 
-#endif // PLACE_HOLDER_WIDGET_H
+#endif // DIGIKAM_PLACE_HOLDER_WIDGET_H
