@@ -1,15 +1,15 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-30
  * Description : GPS search sidebar tab contents.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2009 by Johannes Wienke <languitar at semipol dot de>
  * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C)      2014 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C)      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,22 +46,23 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "searchtreeview.h"
 #include "editablesearchtreeview.h"
-#include "imageinfojob.h"
+#include "iteminfojob.h"
 #include "coredbsearchxml.h"
 #include "gpsmarkertiler.h"
-#include "gpsimageinfosorter.h"
+#include "gpsiteminfosorter.h"
 
 namespace Digikam
 {
 
-class GPSSearchView::Private
+class Q_DECL_HIDDEN GPSSearchView::Private
 {
 
 public:
 
-    Private() :
-        saveBtn(0),
+    explicit Private()
+      : saveBtn(0),
         nameEdit(0),
         imageInfoJob(),
         searchGPSBar(0),
@@ -80,17 +81,17 @@ public:
     static const QString        configSplitterStateEntry;
     QToolButton*                saveBtn;
     QLineEdit*                  nameEdit;
-    ImageInfoJob                imageInfoJob;
+    ItemInfoJob                imageInfoJob;
     SearchTextBar*              searchGPSBar;
     EditableSearchTreeView*     searchTreeView;
     QSplitter*                  splitter;
-    MapWidget*        mapSearchWidget;
+    MapWidget*                  mapSearchWidget;
     GPSMarkerTiler*             gpsMarkerTiler;
-    ImageAlbumModel*            imageAlbumModel;
-    ImageFilterModel*           imageFilterModel;
+    ItemAlbumModel*            imageAlbumModel;
+    ItemFilterModel*           imageFilterModel;
     QItemSelectionModel*        selectionModel;
     SearchModel*                searchModel;
-    GPSImageInfoSorter*         sortOrderOptionsHelper;
+    GPSItemInfoSorter*         sortOrderOptionsHelper;
     QString                     nonGeonlocatedItemsXml;
 };
 
@@ -106,7 +107,7 @@ const QString GPSSearchView::Private::configSplitterStateEntry(QLatin1String("Sp
 GPSSearchView::GPSSearchView(QWidget* const parent,
                              SearchModel* const searchModel,
                              SearchModificationHelper* const searchModificationHelper,
-                             ImageFilterModel* const imageFilterModel,
+                             ItemFilterModel* const imageFilterModel,
                              QItemSelectionModel* const itemSelectionModel)
     : QWidget(parent),
       StateSavingObject(this),
@@ -117,7 +118,7 @@ GPSSearchView::GPSSearchView(QWidget* const parent,
     /// @todo Really?
     setAcceptDrops(true);
 
-    d->imageAlbumModel        = qobject_cast<ImageAlbumModel*>(imageFilterModel->sourceModel());
+    d->imageAlbumModel        = qobject_cast<ItemAlbumModel*>(imageFilterModel->sourceModel());
     d->selectionModel         = itemSelectionModel;
     d->imageFilterModel       = imageFilterModel;
     d->searchModel            = searchModel;
@@ -140,7 +141,7 @@ GPSSearchView::GPSSearchView(QWidget* const parent,
     mapPanel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     mapPanel->setLineWidth(style()->pixelMetric(QStyle::PM_DefaultFrameWidth));
 
-    d->sortOrderOptionsHelper = new GPSImageInfoSorter(this);
+    d->sortOrderOptionsHelper = new GPSItemInfoSorter(this);
     d->sortOrderOptionsHelper->addToMapWidget(d->mapSearchWidget);
 
     vlay2->addWidget(d->mapSearchWidget);
@@ -319,7 +320,7 @@ void GPSSearchView::doLoadState()
         }
     }
 
-    d->sortOrderOptionsHelper->setSortOptions(GPSImageInfoSorter::SortOptions(group.readEntry(entryName(QLatin1String("Sort Order")), int(d->sortOrderOptionsHelper->getSortOptions()))));
+    d->sortOrderOptionsHelper->setSortOptions(GPSItemInfoSorter::SortOptions(group.readEntry(entryName(QLatin1String("Sort Order")), int(d->sortOrderOptionsHelper->getSortOptions()))));
 
     const KConfigGroup groupMapWidget = KConfigGroup(&group, entryName(QLatin1String("GPSSearch Map Widget")));
 
@@ -614,7 +615,7 @@ void GPSSearchView::slotMapSoloItems(const QList<qlonglong>& idList)
 
 void GPSSearchView::showNonGeolocatedItems()
 {
-    if(d->nonGeonlocatedItemsXml.isEmpty())
+    if (d->nonGeonlocatedItemsXml.isEmpty())
     {
         SearchXmlWriter writer;
         writer.setFieldOperator((SearchXml::standardFieldOperator()));
@@ -635,12 +636,12 @@ void GPSSearchView::showNonGeolocatedItems()
     {
         id = album->id();
         CoreDbAccess().db()->updateSearch(id,DatabaseSearch::AdvancedSearch,
-                                            SAlbum::getTemporaryTitle(DatabaseSearch::AdvancedSearch), d->nonGeonlocatedItemsXml);
+                                          SAlbum::getTemporaryTitle(DatabaseSearch::AdvancedSearch), d->nonGeonlocatedItemsXml);
     }
     else
     {
         id = CoreDbAccess().db()->addSearch(DatabaseSearch::AdvancedSearch,
-                                              SAlbum::getTemporaryTitle(DatabaseSearch::AdvancedSearch), d->nonGeonlocatedItemsXml);
+                                            SAlbum::getTemporaryTitle(DatabaseSearch::AdvancedSearch), d->nonGeonlocatedItemsXml);
     }
 
     album = new SAlbum(i18n("Non Geo-located Items"), id);
@@ -661,7 +662,7 @@ void GPSSearchView::slotClearImages()
 {
     if (d->mapSearchWidget->getActiveState())
     {
-        d->imageAlbumModel->clearImageInfos();
+        d->imageAlbumModel->clearItemInfos();
     }
 }
 
