@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-01-15
  * Description : DImg interface for image editor
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,6 +23,7 @@
  * ============================================================ */
 
 #include "editorcore.h"
+#include "editorcore_p.h"
 
 // C++ includes
 
@@ -43,31 +44,6 @@
 #include <QImageReader>
 #include <QPainter>
 
-// Local includes
-
-#include "digikam_debug.h"
-#include "colorcorrectiondlg.h"
-#include "dimgbuiltinfilter.h"
-#include "undomanager.h"
-#include "undoaction.h"
-#include "undostate.h"
-#include "iccmanager.h"
-#include "iccsettingscontainer.h"
-#include "icctransform.h"
-#include "exposurecontainer.h"
-#include "iofilesettings.h"
-#include "sharedloadsavethread.h"
-#include "dmetadata.h"
-#include "rawimport.h"
-#include "editortooliface.h"
-#include "dimg.h"
-#include "dimgfiltergenerator.h"
-#include "bcgfilter.h"
-#include "equalizefilter.h"
-#include "dimgfiltermanager.h"
-#include "versionmanager.h"
-#include "editorcore_p.h"
-
 namespace Digikam
 {
 
@@ -84,7 +60,8 @@ void EditorCore::setDefaultInstance(EditorCore* const instance)
 }
 
 EditorCore::EditorCore()
-    : QObject(), d(new Private)
+    : QObject(),
+      d(new Private)
 {
     d->undoMan = new UndoManager(this);
     d->thread  = new SharedLoadSaveThread;
@@ -186,7 +163,7 @@ void EditorCore::slotLoadRawFromTool()
 
 void EditorCore::slotLoadRaw()
 {
-    //    qCDebug(DIGIKAM_GENERAL_LOG) << d->nextRawDescription.rawDecodingSettings;
+    //qCDebug(DIGIKAM_GENERAL_LOG) << d->nextRawDescription.rawDecodingSettings;
     d->load(d->nextRawDescription);
     d->nextRawDescription = LoadingDescription();
 }
@@ -446,7 +423,7 @@ QString EditorCore::ensureHasCurrentUuid() const
 {
     /*
      * 1) An image is loaded. The DImgLoader adds the HistoryImageId of the loaded file as "Current" entry.
-     * 2) The loaded image has no UUID (created by camera etc.). Highler level calls ensureHasCurrentUuid
+     * 2) The loaded image has no UUID (created by camera etc.). Higher level calls ensureHasCurrentUuid
      *    before any saving is started
      * 3) We create a new UUID and add it to the image's history. When the new image is saved,
      *    it references the original by UUID. Because we, here, do not touch the original,
@@ -455,21 +432,21 @@ QString EditorCore::ensureHasCurrentUuid() const
      * 4) When the image is saved, DImg::updateMetadata will create a new UUID for the saved
      *    image, which is then of course written to the newly saved file.
      */
-    if (!d->image.getImageHistory().currentReferredImage().hasUuid())
+    if (!d->image.getItemHistory().currentReferredImage().hasUuid())
     {
         // if there is no uuid in the image, we create one.
         QString uuid = QString::fromUtf8(d->image.createImageUniqueId());
         d->image.addCurrentUniqueImageId(uuid);
     }
 
-    return d->image.getImageHistory().currentReferredImage().uuid();
+    return d->image.getItemHistory().currentReferredImage().uuid();
 }
 
 void EditorCore::provideCurrentUuid(const QString& uuid)
 {
     // If the (original) image did not yet have a UUID, one is provided by higher level
-    // Higher level decides how this UUID is stored; we dont touch the original here.
-    if (!d->image.getImageHistory().currentReferredImage().hasUuid())
+    // Higher level decides how this UUID is stored; we don't touch the original here.
+    if (!d->image.getItemHistory().currentReferredImage().hasUuid())
     {
         d->image.addCurrentUniqueImageId(uuid);
     }
@@ -523,7 +500,7 @@ void EditorCore::setModified()
 void EditorCore::readMetadataFromFile(const QString& file)
 {
     DMetadata meta(file);
-    // This can overwrite metadata changes introduced by imageplugins.
+    // This can overwrite metadata changes introduced by tools.
     // Currently, this is ProfileConversion and lensfun.
     // ProfileConversion's changes is redone when saving by DImgLoader.
     // Lensfun is not critical.
@@ -532,7 +509,7 @@ void EditorCore::readMetadataFromFile(const QString& file)
     // If we are editing, and someone else at the same time, there's nothing we can do.
     if (!d->undoMan->hasChanges())
     {
-        d->image.setImageHistory(DImageHistory::fromXml(meta.getImageHistory()));
+        d->image.setItemHistory(DImageHistory::fromXml(meta.getItemHistory()));
     }
 }
 
@@ -671,9 +648,9 @@ DImg* EditorCore::getImg() const
     }
 }
 
-DImageHistory EditorCore::getImageHistory() const
+DImageHistory EditorCore::getItemHistory() const
 {
-    return d->image.getImageHistory();
+    return d->image.getItemHistory();
 }
 
 DImageHistory EditorCore::getInitialImageHistory() const
@@ -843,7 +820,7 @@ QPixmap EditorCore::convertToPixmap(DImg& img) const
 
         if (d->doSoftProofing)
         {
-            transform = manager.displaySoftProofingTransform(d->cmSettings.defaultProofProfile);
+            transform = manager.displaySoftProofingTransform(IccProfile(d->cmSettings.defaultProofProfile));
         }
         else
         {
@@ -882,4 +859,4 @@ UndoState EditorCore::undoState() const
     return state;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
