@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-01-15
  * Description : DImg interface for image editor
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef EDITOR_CORE_H
-#define EDITOR_CORE_H
+#ifndef DIGIKAM_IMAGE_EDITOR_CORE_H
+#define DIGIKAM_IMAGE_EDITOR_CORE_H
 
 // Qt includes
 
@@ -65,7 +65,7 @@ public:
 
 public:
 
-    EditorCore();
+    explicit EditorCore();
     ~EditorCore();
 
     void    load(const QString& filename, IOFileSettings* const iofileSettings);
@@ -162,8 +162,8 @@ public:
     int                   availableUndoSteps()        const;
     int                   availableRedoSteps()        const;
     IccProfile            getEmbeddedICC()            const;
-    MetaEngineData            getMetadata()               const;
-    DImageHistory         getImageHistory()           const;
+    MetaEngineData        getMetadata()               const;
+    DImageHistory         getItemHistory()            const;
     DImageHistory         getInitialImageHistory()    const;
     DImageHistory         getImageHistoryOfFullRedo() const;
     DImageHistory         getResolvedInitialHistory() const;
@@ -202,6 +202,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* EDITOR_CORE_H */
+#endif // DIGIKAM_IMAGE_EDITOR_CORE_H
