@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-01-15
  * Description : DImg interface for image editor
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,20 +21,44 @@
  *
  * ============================================================ */
 
-#ifndef EDITORCORE_P_H
-#define EDITORCORE_P_H
+#ifndef DIGIKAM_IMAGE_EDITOR_CORE_PRIVATE_H
+#define DIGIKAM_IMAGE_EDITOR_CORE_PRIVATE_H
+
+// Local includes
+
+#include "digikam_debug.h"
+#include "dimgbuiltinfilter.h"
+#include "undomanager.h"
+#include "undoaction.h"
+#include "undostate.h"
+#include "iccmanager.h"
+#include "iccsettingscontainer.h"
+#include "icctransform.h"
+#include "exposurecontainer.h"
+#include "iofilesettings.h"
+#include "sharedloadsavethread.h"
+#include "dmetadata.h"
+#include "rawimport.h"
+#include "editortooliface.h"
+#include "dimg.h"
+#include "dimgfiltergenerator.h"
+#include "bcgfilter.h"
+#include "equalizefilter.h"
+#include "dimgfiltermanager.h"
+#include "versionmanager.h"
+#include "colorcorrectiondlg.h"
 
 namespace Digikam
 {
 
 class UndoManager;
 
-class EditorCore::Private
+class Q_DECL_HIDDEN EditorCore::Private
 {
 
 public:
 
-    class FileToSave
+    class Q_DECL_HIDDEN FileToSave
     {
     public:
 
@@ -51,8 +75,8 @@ public:
 
 public:
 
-    Private() :
-        valid(false),
+    Private()
+      : valid(false),
         rotatedOrFlipped(false),
         exifOrient(false),
         doSoftProofing(false),
@@ -182,7 +206,7 @@ void EditorCore::Private::saveNext()
     if (file.historyStep != -1)
     {
         // intermediate. Need to get data from undo manager
-        int currentStep = EditorCore::defaultInstance()->getImageHistory().size() - 1;
+        int currentStep = EditorCore::defaultInstance()->getItemHistory().size() - 1;
         //qCDebug(DIGIKAM_GENERAL_LOG) << "Requesting from undo manager data" << currentStep - file.historyStep << "steps back";
         undoMan->putImageDataAndHistory(&file.image, currentStep - file.historyStep);
     }
@@ -303,14 +327,14 @@ void EditorCore::Private::saveAs(const QString& filePath, IOFileSettings* const
         op.tasks & VersionFileOperation::SaveAndDelete)
     {
         // The current file will stored away at a different name. Adjust history.
-        image.getImageHistory().moveCurrentReferredImage(op.intermediateForLoadedFile.path,
+        image.getItemHistory().moveCurrentReferredImage(op.intermediateForLoadedFile.path,
                                                          op.intermediateForLoadedFile.fileName);
     }
 
     if (op.tasks & VersionFileOperation::Replace)
     {
         // The current file will be replaced. Remove hint at file path (file path will be a different image)
-        image.getImageHistory().purgePathFromReferredImages(op.saveFile.path, op.saveFile.fileName);
+        image.getItemHistory().purgePathFromReferredImages(op.saveFile.path, op.saveFile.fileName);
     }
 
     QMap<int, VersionFileInfo>::const_iterator it;
@@ -377,6 +401,6 @@ void EditorCore::Private::load(const LoadingDescription& description)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // EDITORCORE_P_H
+#endif // DIGIKAM_IMAGE_EDITOR_CORE_PRIVATE_H
