@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-08-12
  * Description : methods that implement color management tasks
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -40,7 +40,8 @@ namespace Digikam
 {
 
 IccPostLoadingManager::IccPostLoadingManager(DImg& image, const QString& filePath, const ICCSettingsContainer& settings)
-    : IccManager(image, settings), m_filePath(filePath)
+    : IccManager(image, settings),
+      m_filePath(filePath)
 {
 }
 
@@ -89,4 +90,4 @@ IccTransform IccPostLoadingManager::postLoadingManage(QWidget* const parent)
     return IccTransform();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
