@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-10-29
  * Description : extension to IccManager providing UI
  *
  * Copyright (C) 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef ICCPOSTLOADINGMANAGER_H
-#define ICCPOSTLOADINGMANAGER_H
+#ifndef DIGIKAM_ICC_POST_LOADING_MANAGER_H
+#define DIGIKAM_ICC_POST_LOADING_MANAGER_H
 
 // Local includes
 
@@ -57,6 +57,6 @@ protected:
     QString m_filePath;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif   // ICCMANAGER_H
+#endif // DIGIKAM_ICC_POST_LOADING_MANAGER_H
