@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-20
  * Description : image editor GUI saving context container
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SAVING_CONTEXT_H
-#define SAVING_CONTEXT_H
+#ifndef DIGIKAM_SAVING_CONTEXT_H
+#define DIGIKAM_SAVING_CONTEXT_H
 
 // Qt includes
 
@@ -94,4 +94,4 @@ public:
 
 } // namespace Digikam
 
-#endif /* SAVING_CONTEXT_H */
+#endif // DIGIKAM_SAVING_CONTEXT_H
