@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-02-06
  * Description : undo actions manager for image editor.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2005      by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -33,11 +33,11 @@
 namespace Digikam
 {
 
-class UndoAction::Private
+class Q_DECL_HIDDEN UndoAction::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
     }
 
@@ -51,14 +51,14 @@ public:
 UndoMetadataContainer UndoMetadataContainer::fromImage(const DImg& img)
 {
     UndoMetadataContainer container;
-    container.history = img.getImageHistory();
+    container.history = img.getItemHistory();
     container.profile = img.getIccProfile();
     return container;
 }
 
 void UndoMetadataContainer::toImage(DImg& img) const
 {
-    img.setImageHistory(history);
+    img.setItemHistory(history);
     img.setIccProfile(profile);
 }
 
@@ -150,4 +150,4 @@ UndoActionIrreversible::~UndoActionIrreversible()
 {
 }
 
-}  // namespace Digikam
+} // namespace Digikam
