@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date   : 2005-02-06
  * Description : an image editor actions undo/redo manager
  *
  * Copyright (C) 2005-2006 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2005-2006 Joern Ahrens <joern dot ahrens at kdemail dot net>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,12 +44,12 @@
 namespace Digikam
 {
 
-class UndoManager::Private
+class Q_DECL_HIDDEN UndoManager::Private
 {
 public:
 
-    Private() :
-        origin(0),
+    explicit Private()
+      : origin(0),
         undoCache(0),
         core(0)
     {
@@ -194,7 +194,7 @@ void UndoManager::rollbackToOrigin()
 
 void UndoManager::undoStep(bool saveRedo, bool execute, bool flyingRollback)
 {
-    UndoAction* const action                   = d->undoActions.back();
+    UndoAction* const action                   = d->undoActions.last();
     UndoMetadataContainer dataBeforeStep       = action->getMetadata();
     UndoMetadataContainer dataAfterStep        = UndoMetadataContainer::fromImage(*d->core->getImg());
     UndoActionIrreversible* const irreversible = dynamic_cast<UndoActionIrreversible*>(action);
@@ -295,7 +295,7 @@ void UndoManager::undoStep(bool saveRedo, bool execute, bool flyingRollback)
 
 void UndoManager::redoStep(bool execute, bool flyingRollback)
 {
-    UndoAction* const action                   = d->redoActions.back();
+    UndoAction* const action                   = d->redoActions.last();
     UndoMetadataContainer dataBeforeStep       = UndoMetadataContainer::fromImage(*d->core->getImg());
     UndoMetadataContainer dataAfterStep        = action->getMetadata();
     QVariant originDataBeforeStep              = d->core->getImg()->fileOriginData();
@@ -550,7 +550,7 @@ bool UndoManager::hasChanges() const
     }
     else
     {
-        DImageHistory currentHistory = d->core->getImageHistory();
+        DImageHistory currentHistory = d->core->getItemHistory();
         DImageHistory initialHistory = d->core->getInitialImageHistory();
 
         if (currentHistory == initialHistory)
@@ -576,7 +576,7 @@ DImageHistory UndoManager::getImageHistoryOfFullRedo() const
         return d->redoActions.first()->getMetadata().history;
     }
 
-    return d->core->getImageHistory();
+    return d->core->getItemHistory();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
