@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-05-15
  * Description : a dialog to see preview ICC color correction
  *               before to apply color profile.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -56,17 +56,15 @@
 #include "dxmlguiwindow.h"
 #include "dexpanderbox.h"
 
-
-
 namespace Digikam
 {
 
-class ColorCorrectionDlg::Private
+class Q_DECL_HIDDEN ColorCorrectionDlg::Private
 {
 public:
 
-    Private() :
-        imageProfileTitle(0),
+    explicit Private()
+      : imageProfileTitle(0),
         imageProfileDesc(0),
         previewTarget(0),
         keepProfile(0),
@@ -111,8 +109,10 @@ public:
     IccProfile               outputProfile;
 };
 
-ColorCorrectionDlg::ColorCorrectionDlg(Mode mode, const DImg& preview,
-                                       const QString& file, QWidget* const parent)
+ColorCorrectionDlg::ColorCorrectionDlg(Mode mode,
+                                       const DImg& preview,
+                                       const QString& file,
+                                       QWidget* const parent)
     : QDialog(parent),
       d(new Private)
 {
@@ -120,7 +120,7 @@ ColorCorrectionDlg::ColorCorrectionDlg(Mode mode, const DImg& preview,
 
     d->buttons = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->buttons->button(QDialogButtonBox::Ok)->setDefault(true);
-    d->buttons->button(QDialogButtonBox::Cancel)->setText(i18n("Don't know"));
+    d->buttons->button(QDialogButtonBox::Cancel)->setText(i18n("Do not know"));
     d->buttons->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Take the safest and most appropriate action"));
 
     d->mode                          = mode;
@@ -248,7 +248,7 @@ QLayout* ColorCorrectionDlg::createHeading() const
     QLabel* const logo      = new QLabel;
     logo->setPixmap(QIcon::fromTheme(QLatin1String("digikam")).pixmap(QSize(48,48)));
 
-    DLineWidget* const line  = new DLineWidget(Qt::Horizontal);
+    DLineWidget* const line = new DLineWidget(Qt::Horizontal);
 
     QGridLayout* const grid = new QGridLayout;
     grid->addWidget(icon,    0, 0);
@@ -256,6 +256,7 @@ QLayout* ColorCorrectionDlg::createHeading() const
     grid->addWidget(logo,    0, 2);
     grid->addWidget(line,    1, 0, 1, 3);
     grid->setColumnStretch(1, 1);
+
     return grid;
 }
 
@@ -372,11 +373,11 @@ QLayout* ColorCorrectionDlg::createPreviews() const
 
 QWidget* ColorCorrectionDlg::createOptions() const
 {
-    QGroupBox* const box    = new QGroupBox;
-    QVBoxLayout* const vbox = new QVBoxLayout(box);
+    QGroupBox* const box = new QGroupBox;
 
     if (d->mode == ProfileMismatch)
     {
+        QVBoxLayout* const vbox  = new QVBoxLayout(box);
         d->keepProfile           = new QRadioButton(i18n("Keep the embedded profile, do not convert"));
         d->convertToWorkingSpace = new QRadioButton(i18n("Convert to working color space"));
         d->thirdOption           = new QRadioButton(i18n("Ignore embedded profile, assign this profile:"));
@@ -422,6 +423,7 @@ QWidget* ColorCorrectionDlg::createOptions() const
     }
     else if (d->mode == MissingProfile)
     {
+        QVBoxLayout* const vbox  = new QVBoxLayout(box);
         d->convertToWorkingSpace = new QRadioButton(i18n("Assign profile and convert to working color space"));
         d->keepProfile           = new QRadioButton(i18n("Assign and keep color profile"));
         d->thirdOption           = new QRadioButton(i18n("Leave the file untagged, do not color manage"));
@@ -445,8 +447,9 @@ QWidget* ColorCorrectionDlg::createOptions() const
     {
         // empty
 /*
+        QVBoxLayout* const vbox  = new QVBoxLayout(box);
         d->convertToWorkingSpace = new QRadioButton(i18n("Convert to working color space"));
-        d->thirdOption         = new QRadioButton(i18n("Convert to this profile:"));
+        d->thirdOption           = new QRadioButton(i18n("Convert to this profile:"));
         d->otherProfileBox       = new IccProfilesComboBox;
         d->otherProfileBox->addProfilesSqueezed(IccSettings::instance()->workspaceProfiles());
 
@@ -462,7 +465,6 @@ QWidget* ColorCorrectionDlg::createOptions() const
 QWidget* ColorCorrectionDlg::createAssumeOptions() const
 {
     QGroupBox* const box    = new QGroupBox;
-    QGridLayout* const grid = new QGridLayout(box);
 
     if (d->mode == ProfileMismatch)
     {
@@ -470,7 +472,8 @@ QWidget* ColorCorrectionDlg::createAssumeOptions() const
     }
     else if (d->mode == MissingProfile)
     {
-        QLabel* const label = new QLabel(i18n("Which color space shall be used to interpret the colors of this image?"));
+        QGridLayout* const grid = new QGridLayout(box);
+        QLabel* const label     = new QLabel(i18n("Which color space shall be used to interpret the colors of this image?"));
         label->setWordWrap(true);
 
         d->imageSRGB         = new QRadioButton(i18n("sRGB (Internet standard)"));
@@ -517,12 +520,14 @@ QWidget* ColorCorrectionDlg::createAssumeOptions() const
     }
     else if (d->mode == UncalibratedColor)
     {
-        QLabel* const label = new QLabel(i18n("Please select the input color profile of the device (camera) used to create this image:"));
+        QGridLayout* const grid = new QGridLayout(box);
+        QLabel* const label     = new QLabel(i18n("Please select the input color profile of the device (camera) "
+                                                  "used to create this image:"));
         label->setWordWrap(true);
 
         d->imageProfileBox = new IccProfilesComboBox;
         d->imageProfileBox->addProfilesSqueezed(IccSettings::instance()->inputProfiles());
-        d->imageProfileBox->setCurrentProfile(IccSettings::instance()->settings().defaultInputProfile);
+        d->imageProfileBox->setCurrentProfile(IccProfile(IccSettings::instance()->settings().defaultInputProfile));
         d->imageProfileBox->setNoProfileIfEmpty(i18n("No Input Profile Available"));
 
         grid->addWidget(label);
@@ -785,7 +790,7 @@ void ColorCorrectionDlg::readSettings()
 
         if (!settings.lastSpecifiedAssignProfile.isEmpty())
         {
-            d->otherProfileBox->setCurrentProfile(settings.lastSpecifiedAssignProfile);
+            d->otherProfileBox->setCurrentProfile(IccProfile(settings.lastSpecifiedAssignProfile));
         }
     }
     else if (d->mode == MissingProfile)
@@ -828,12 +833,12 @@ void ColorCorrectionDlg::readSettings()
 
         if (!settings.lastSpecifiedInputProfile.isEmpty())
         {
-            d->imageProfileBox->setCurrentProfile(settings.lastSpecifiedInputProfile);
+            d->imageProfileBox->setCurrentProfile(IccProfile(settings.lastSpecifiedInputProfile));
         }
     }
     else if (d->mode == UncalibratedColor)
     {
-        d->imageProfileBox->setCurrentProfile(settings.lastSpecifiedInputProfile);
+        d->imageProfileBox->setCurrentProfile(IccProfile(settings.lastSpecifiedInputProfile));
         d->imageProfileBox->setFocus();
     }
 }
@@ -866,4 +871,4 @@ void ColorCorrectionDlg::slotHelp()
     DXmlGuiWindow::openHandbook();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
