@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-09-16
  * Description : Dialog to adjust soft proofing settings
  *
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SOFTPROOFDIALOG_H
-#define SOFTPROOFDIALOG_H
+#ifndef DIGIKAM_SOFT_PROOF_DIALOG_H
+#define DIGIKAM_SOFT_PROOF_DIALOG_H
 
 // Qt includes
 
@@ -71,4 +71,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SOFTPROOFDIALOG_H
+#endif // DIGIKAM_SOFT_PROOF_DIALOG_H
