@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-20
  * Description : A widget stack to embed editor view.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,13 +34,13 @@
 namespace Digikam
 {
 
-class EditorStackView::Private
+class Q_DECL_HIDDEN EditorStackView::Private
 {
 
 public:
 
-    Private() :
-        toolView(0),
+    explicit Private()
+      : toolView(0),
         canvas(0)
     {
     }
@@ -50,7 +50,8 @@ public:
 };
 
 EditorStackView::EditorStackView(QWidget* const parent)
-    : QStackedWidget(parent), d(new Private)
+    : QStackedWidget(parent),
+      d(new Private)
 {
 }
 
@@ -164,7 +165,7 @@ void EditorStackView::decreaseZoom()
 void EditorStackView::toggleFitToWindow()
 {
     // Fit to window action is common place to switch view in this mode.
-    // User want to see the same behavors between canvas and tool preview.
+    // User want to see the same behaviors between canvas and tool preview.
     // Both are toggle at the same time.
     d->canvas->layout()->toggleFitToWindow();
 
@@ -332,4 +333,4 @@ bool EditorStackView::isZoomablePreview() const
     return previewWidget();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
