@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-20
  * Description : editor tool template class.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,18 +49,19 @@
 namespace Digikam
 {
 
-class EditorTool::Private
+class Q_DECL_HIDDEN EditorTool::Private
 {
 
 public:
 
-    Private() :
-        initPreview(false),
+    explicit Private()
+      : initPreview(false),
         version(0),
         view(0),
         timer(0),
         settings(0),
-        category(FilterAction::ReproducibleFilter)
+        category(FilterAction::ReproducibleFilter),
+        plugin(0)
     {
     }
 
@@ -76,6 +77,8 @@ public:
     EditorToolSettings*    settings;
 
     FilterAction::Category category;
+    
+    DPluginEditor*         plugin;
 };
 
 EditorTool::EditorTool(QObject* const parent)
@@ -95,6 +98,19 @@ EditorTool::~EditorTool()
     delete d;
 }
 
+void EditorTool::setPlugin(DPluginEditor* const plugin)
+{
+    d->plugin = plugin;
+    setToolName(d->plugin->name());
+    setToolIcon(d->plugin->icon());
+    d->settings->setTool(this);
+}
+
+DPluginEditor* EditorTool::plugin() const
+{
+    return d->plugin;
+}
+
 void EditorTool::init()
 {
     QTimer::singleShot(0, this, SLOT(slotInit()));
@@ -182,8 +198,7 @@ EditorToolSettings* EditorTool::toolSettings() const
 void EditorTool::setToolSettings(EditorToolSettings* const settings)
 {
     d->settings = settings;
-    d->settings->setToolIcon(toolIcon());
-    d->settings->setToolName(toolName());
+    d->settings->setTool(this);
 
     connect(d->settings, SIGNAL(signalOkClicked()),
             this, SLOT(slotOk()));
@@ -365,13 +380,13 @@ void EditorTool::slotUpdateSpotInfo(const DColor& col, const QPoint& point)
 
 // ----------------------------------------------------------------
 
-class EditorToolThreaded::Private
+class Q_DECL_HIDDEN EditorToolThreaded::Private
 {
 
 public:
 
-    Private() :
-        delFilter(true),
+    explicit Private()
+      : delFilter(true),
         currentRenderingMode(EditorToolThreaded::NoneRendering),
         threadedFilter(0),
         threadedAnalyser(0)
@@ -678,4 +693,4 @@ void EditorToolThreaded::deleteFilterInstance(bool b)
     d->delFilter = b;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
