@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-20
  * Description : editor tool template class.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef EDITORTOOL_H
-#define EDITORTOOL_H
+#ifndef DIGIKAM_IMAGE_EDITOR_TOOL_H
+#define DIGIKAM_IMAGE_EDITOR_TOOL_H
 
 // Qt includes
 
@@ -37,6 +37,7 @@
 #include "dcolor.h"
 #include "previewtoolbar.h"
 #include "filteraction.h"
+#include "dplugineditor.h"
 
 namespace Digikam
 {
@@ -54,6 +55,9 @@ public:
     explicit EditorTool(QObject* const parent);
     virtual ~EditorTool();
 
+    void setPlugin(DPluginEditor* const plugin);
+    DPluginEditor* plugin() const;
+
     /** Caller by editor tool interface to initialized tool when all is ready, through slotInit().
      */
     void init();
@@ -214,4 +218,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* EDITORTOOL_H */
+#endif // DIGIKAM_IMAGE_EDITOR_TOOL_H
