@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-20
  * Description : Image editor interface used by editor tools.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,13 +44,13 @@
 namespace Digikam
 {
 
-class EditorToolIface::Private
+class Q_DECL_HIDDEN EditorToolIface::Private
 {
 
 public:
 
-    Private() :
-        toolsIconView(0),
+    explicit Private()
+      : toolsIconView(0),
         tool(0),
         editor(0),
         sidebarWasExpanded(false),
@@ -329,4 +329,4 @@ void EditorToolIface::slotToolApplied()
     emit(d->editor->signalToolApplied());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
