@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-20
  * Description : core image editor GUI implementation private data.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef EDITOR_WINDOW_PRIVATE_H
-#define EDITOR_WINDOW_PRIVATE_H
+#ifndef DIGIKAM_IMAGE_EDITOR_WINDOW_PRIVATE_H
+#define DIGIKAM_IMAGE_EDITOR_WINDOW_PRIVATE_H
 
 // Qt includes
 
@@ -63,20 +63,17 @@ class PreviewToolBar;
 class DAdjustableLabel;
 class IccProfilesMenuAction;
 
-class EditorWindow::Private
+class Q_DECL_HIDDEN EditorWindow::Private
 {
-
 public:
 
-    Private() :
-        cmViewIndicator(0),
+    Private()
+      : cmViewIndicator(0),
         underExposureIndicator(0),
         overExposureIndicator(0),
         infoLabel(0),
         copyAction(0),
         cropAction(0),
-        autoCropAction(0),
-        filePrintAction(0),
         flipHorizAction(0),
         flipVertAction(0),
         rotateLeftAction(0),
@@ -90,50 +87,6 @@ public:
         zoomPlusAction(0),
         zoomTo100percents(0),
         openWithAction(0),
-        textureAction(0),
-        borderAction(0),
-        insertTextAction(0),
-        filmgrainAction(0),
-        raindropAction(0),
-        distortionfxAction(0),
-        blurfxAction(0),
-        oilpaintAction(0),
-        embossAction(0),
-        charcoalAction(0),
-        colorEffectsAction(0),
-        BCGAction(0),
-        HSLAction(0),
-        CBAction(0),
-        autoCorrectionAction(0),
-        invertAction(0),
-        BWAction(0),
-        convertTo8Bits(0),
-        convertTo16Bits(0),
-        whitebalanceAction(0),
-        channelMixerAction(0),
-        curvesAction(0),
-        levelsAction(0),
-        filmAction(0),
-        profileMenuAction(0),
-        colorSpaceConverter(0),
-        hotpixelsAction(0),
-        lensdistortionAction(0),
-        antivignettingAction(0),
-        lensAutoFixAction(0),
-        redeyeAction(0),
-        restorationAction(0),
-        blurAction(0),
-        healCloneAction(0),
-        sharpenAction(0),
-        noiseReductionAction(0),
-        localContrastAction(0),
-        inPaintingAction(0),
-        aspectRatioCropAction(0),
-        resizeAction(0),
-        contentAwareResizingAction(0),
-        sheartoolAction(0),
-        freerotationAction(0),
-        perspectiveAction(0),
         undoSignalMapper(0),
         redoSignalMapper(0),
         formatMenuActionMapper(0),
@@ -193,8 +146,6 @@ public:
 
     QAction*                     copyAction;
     QAction*                     cropAction;
-    QAction*                     autoCropAction;
-    QAction*                     filePrintAction;
     QAction*                     flipHorizAction;
     QAction*                     flipVertAction;
     QAction*                     rotateLeftAction;
@@ -209,52 +160,6 @@ public:
     QAction*                     zoomTo100percents;
     QAction*                     openWithAction;
 
-    // Tools Actions
-    QAction*                     textureAction;
-    QAction*                     borderAction;
-    QAction*                     insertTextAction;
-    QAction*                     filmgrainAction;
-    QAction*                     raindropAction;
-    QAction*                     distortionfxAction;
-    QAction*                     blurfxAction;
-    QAction*                     oilpaintAction;
-    QAction*                     embossAction;
-    QAction*                     charcoalAction;
-    QAction*                     colorEffectsAction;
-    QAction*                     BCGAction;
-    QAction*                     HSLAction;
-    QAction*                     CBAction;
-    QAction*                     autoCorrectionAction;
-    QAction*                     invertAction;
-    QAction*                     BWAction;
-    QAction*                     convertTo8Bits;
-    QAction*                     convertTo16Bits;
-    QAction*                     whitebalanceAction;
-    QAction*                     channelMixerAction;
-    QAction*                     curvesAction;
-    QAction*                     levelsAction;
-    QAction*                     filmAction;
-    IccProfilesMenuAction*       profileMenuAction;
-    QAction*                     colorSpaceConverter;
-    QAction*                     hotpixelsAction;
-    QAction*                     lensdistortionAction;
-    QAction*                     antivignettingAction;
-    QAction*                     lensAutoFixAction;
-    QAction*                     redeyeAction;
-    QAction*                     restorationAction;
-    QAction*                     blurAction;
-    QAction*                     healCloneAction;
-    QAction*                     sharpenAction;
-    QAction*                     noiseReductionAction;
-    QAction*                     localContrastAction;
-    QAction*                     inPaintingAction;
-    QAction*                     aspectRatioCropAction;
-    QAction*                     resizeAction;
-    QAction*                     contentAwareResizingAction;
-    QAction*                     sheartoolAction;
-    QAction*                     freerotationAction;
-    QAction*                     perspectiveAction;
-
     QSignalMapper*               undoSignalMapper;
     QSignalMapper*               redoSignalMapper;
     QSignalMapper*               formatMenuActionMapper;
@@ -380,6 +285,6 @@ void EditorWindow::Private::plugNewVersionInFormatAction(EditorWindow* const q,
     menuAction->addAction(action);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // EDITOR_WINDOW_PRIVATE_H
+#endif // DIGIKAM_IMAGE_EDITOR_WINDOW_PRIVATE_H
