@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-02-14
- * Description : image data interface for image plugins
+ * Description : image data interface for image tools
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,12 +45,12 @@
 namespace Digikam
 {
 
-class ImageIface::Private
+class Q_DECL_HIDDEN ImageIface::Private
 {
 public:
 
-    Private() :
-        previewType(FullImage),
+    explicit Private()
+      : previewType(FullImage),
         originalWidth(0),
         originalHeight(0),
         originalBytesDepth(0),
@@ -264,6 +264,11 @@ void ImageIface::setPreviewIccProfile(const IccProfile& profile)
     d->targetPreviewImage.setIccProfile(profile);
 }
 
+void ImageIface::crop(const QRect& region)
+{
+    d->core->crop(region);
+}
+
 void ImageIface::setOriginalIccProfile(const IccProfile& profile)
 {
     d->core->putIccProfile(profile);
@@ -382,7 +387,7 @@ void ImageIface::paint(QPaintDevice* const device, const QRect& rect, QPainter*
 
             if (doSoftProofing)
             {
-                monitorICCtrans = manager.displaySoftProofingTransform(iccSettings.defaultProofProfile);
+                monitorICCtrans = manager.displaySoftProofingTransform(IccProfile(iccSettings.defaultProofProfile));
             }
             else
             {
@@ -469,4 +474,4 @@ void ImageIface::setOriginal(const QString& caller, const FilterAction& action,
     d->core->putImg(caller, action, img);
 }
 
-}   // namespace Digikam
+} // namespace Digikam
