@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-02-14
- * Description : image data interface for image plugins
+ * Description : image data interface for image tools
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEIFACE_H
-#define IMAGEIFACE_H
+#ifndef DIGIKAM_IMAGE_IFACE_H
+#define DIGIKAM_IMAGE_IFACE_H
 
 // Qt includes
 
@@ -35,7 +35,8 @@
 #include "dimg.h"
 #include "dcolor.h"
 #include "filteraction.h"
-#include "infocontainer.h"
+#include "photoinfocontainer.h"
+#include "videoinfocontainer.h"
 #include "digikam_export.h"
 #include "digikam_globals.h"
 
@@ -82,7 +83,7 @@ public:
     /** Return a pointer to the DImg object representing the preview image.
      *  This function is a backdoor for preview editing.
      */
-    DImg * previewReference();
+    DImg* previewReference();
 
     /** Return a DImg object representing the preview image.
      */
@@ -96,6 +97,10 @@ public:
      */
     DImg  selection()                       const;
 
+    /** Crop the original image currently hosted by editor to the region.
+     */
+    void crop(const QRect& region);
+
     /** Get colors from original, (unchanged) preview
      *  or target preview (set by setPreviewImage) image.
      */
@@ -171,10 +176,12 @@ public:
 
 private:
 
+    ImageIface(const ImageIface&); // Disable
+
     class Private;
     Private* const d;
 };
 
 } // namespace Digikam
 
-#endif /* IMAGEIFACE_H */
+#endif // DIGIKAM_IMAGE_IFACE_H
