@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-02-12
  * Description : digiKam image editor GUI
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGE_WINDOW_H
-#define IMAGE_WINDOW_H
+#ifndef DIGIKAM_IMAGE_WINDOW_H
+#define DIGIKAM_IMAGE_WINDOW_H
 
 // Qt includes
 
@@ -34,7 +34,7 @@
 // Local includes
 
 #include "editorwindow.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 
 class QDragMoveEvent;
 class QDropEvent;
@@ -59,16 +59,17 @@ public:
     bool queryClose();
     void toggleTag(int tagID);
 
+public:
+
+    DInfoInterface* infoIface(DPluginAction* const ac);
+
     virtual VersionManager* versionManager() const;
 
 public Q_SLOTS:
 
-    void slotSetup();
-    void slotSetupICC();
-
-    void loadImageInfos(const ImageInfoList& imageInfoList,
-                        const ImageInfo& imageInfoCurrent, const QString& caption);
-    void openImage(const ImageInfo& info);
+    void loadItemInfos(const ItemInfoList& imageInfoList,
+                        const ItemInfo& imageInfoCurrent, const QString& caption);
+    void openImage(const ItemInfo& info);
 
     void slotAssignPickLabel(int pickId);
     void slotAssignColorLabel(int colorId);
@@ -90,10 +91,6 @@ private:
     void dragMoveEvent(QDragMoveEvent* e);
     void dropEvent(QDropEvent* e);
 
-    void setupActions();
-    void setupConnections();
-    void setupUserArea();
-
     bool save();
     bool saveAs();
     bool saveNewVersion();
@@ -101,13 +98,12 @@ private:
     bool saveNewVersionAs();
     bool saveNewVersionInFormat(const QString& format);
 
-    void addServicesMenu();
-
     QUrl saveDestinationUrl();
     bool hasOriginalToRestore();
     DImageHistory resolvedImageHistory(const DImageHistory& history);
 
     void prepareImageToSave();
+    void saveFaceTagsToImage(const ItemInfo& info);
 
     void saveIsComplete();
     void saveAsIsComplete();
@@ -116,12 +112,10 @@ private:
     void deleteCurrentItem(bool ask, bool permanently);
     void removeCurrent();
 
-    void slideShow(SlideShowSettings& settings);
-
-    void assignPickLabel(const ImageInfo& info, int pickId);
-    void assignColorLabel(const ImageInfo& info, int colorId);
-    void assignRating(const ImageInfo& info, int rating);
-    void toggleTag(const ImageInfo& info, int tagID);
+    void assignPickLabel(const ItemInfo& info, int pickId);
+    void assignColorLabel(const ItemInfo& info, int colorId);
+    void assignRating(const ItemInfo& info, int rating);
+    void toggleTag(const ItemInfo& info, int tagID);
 
     ThumbBarDock* thumbBar()     const;
     Sidebar*      rightSideBar() const;
@@ -132,19 +126,18 @@ Q_SIGNALS: // private signals
 
 private Q_SLOTS:
 
-    void slotLoadImageInfosStage2();
+    void slotLoadItemInfosStage2();
     void slotThumbBarModelReady();
 
     void slotForward();
     void slotBackward();
     void slotFirst();
     void slotLast();
-    void slotFilePrint();
     void slotFileWithDefaultApplication();
 
     void slotToMainWindow();
 
-    void slotThumbBarImageSelected(const ImageInfo&);
+    void slotThumbBarImageSelected(const ItemInfo&);
     void slotLoadCurrent();
     void slotDeleteCurrentItem();
     void slotDeleteCurrentItemPermanently();
@@ -155,7 +148,6 @@ private Q_SLOTS:
     void slotUpdateItemInfo();
     void slotFileOriginChanged(const QString&);
 
-    void slotContextMenu();
     void slotRevert();
     void slotOpenOriginal();
 
@@ -170,13 +162,11 @@ private Q_SLOTS:
     void slotFileMetadataChanged(const QUrl&);
     //void slotCollectionImageChange(const CollectionImageChangeset&);
     //void slotRowsAboutToBeRemoved(const QModelIndex& parent, int start, int end);
-    void slotDroppedOnThumbbar(const QList<ImageInfo>& infos);
+    void slotDroppedOnThumbbar(const QList<ItemInfo>& infos);
 
     void slotComponentsInfo();
     void slotDBStat();
 
-    void slotSetupChanged();
-
     void slotAddedDropedItems(QDropEvent*);
     void slotOpenWith(QAction* action=0);
 
@@ -184,20 +174,42 @@ private Q_SLOTS:
     void slotRightSideBarActivateComments();
     void slotRightSideBarActivateAssignedTags();
 
-    void slotImportFromScanner();
+// -- Internal setup methods implemented in imagewindow_config.cpp ----------------------------------------
+
+public Q_SLOTS:
+
+    void slotSetup();
+    void slotSetupICC();
+
+    void slotSetupChanged();
+
+// -- Internal setup methods implemented in imagewindow_setup.cpp ----------------------------------------
+
+private:
+
+    void setupActions();
+    void setupConnections();
+    void setupUserArea();
+
+    void addServicesMenu();
+
+private Q_SLOTS:
+
+    void slotContextMenu();
+
+// -- Extra tool methods implemented in imagewindow_tools.cpp ----------------------------------------
+
+private:
+
+    void slideShow(SlideShowSettings& settings);
+
+// -- Import tools methods implemented in imagewindow_import.cpp -------------------------------------
+
+private Q_SLOTS:
+
     void slotImportedImagefromScanner(const QUrl& url);
 
-    void slotEditMetadata();
-    void slotEditGeolocation();
-    void slotPresentation();
-    void slotHtmlGallery();
-    void slotCalendar();
-    void slotExpoBlending();
-    void slotPanorama();
-    void slotVideoSlideshow();
-    void slotSendByMail();
-    void slotPrintCreator();
-    void slotMediaServer();
+// -- Internal private container --------------------------------------------------------------------
 
 private:
 
@@ -209,4 +221,4 @@ private:
 
 } // namespace Digikam
 
-#endif // IMAGE_WINDOW_H
+#endif // DIGIKAM_IMAGE_WINDOW_H
