@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-11
  * Description : Raw import settings box
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -59,7 +59,7 @@
 namespace Digikam
 {
 
-class RawSettingsBox::Private
+class Q_DECL_HIDDEN RawSettingsBox::Private
 {
 public:
 
@@ -72,8 +72,8 @@ public:
 
 public:
 
-    Private() :
-        optionGroupName(QLatin1String("RAW Import Settings")),
+    explicit Private()
+      : optionGroupName(QLatin1String("RAW Import Settings")),
         optionHistogramChannelEntry(QLatin1String("Histogram Channel")),
         optionHistogramScaleEntry(QLatin1String("Histogram Scale")),
         optionBrightnessEntry(QLatin1String("Brightness")),
