@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-11
  * Description : Raw import settings box
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -20,8 +20,8 @@
  *
  * ============================================================ */
 
-#ifndef RAW_SETTINGS_BOX_H
-#define RAW_SETTINGS_BOX_H
+#ifndef DIGIKAM_RAW_SETTINGS_BOX_H
+#define DIGIKAM_RAW_SETTINGS_BOX_H
 
 // Qt includes
 
@@ -83,4 +83,4 @@ private:
 
 } // namespace Digikam
 
-#endif // RAW_SETTINGS_BOX_H
+#endif // DIGIKAM_RAW_SETTINGS_BOX_H
