@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-04
  * Description : image editor canvas management class
  *
  * Copyright (C) 2013-2014 by Yiou Wang <geow812 at gmail dot com>
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef CANVAS_H
-#define CANVAS_H
+#ifndef DIGIKAM_IMAGE_EDITOR_CANVAS_H
+#define DIGIKAM_IMAGE_EDITOR_CANVAS_H
 
 // Qt includes
 
@@ -163,7 +163,6 @@ public Q_SLOTS:
     void slotFlipHoriz();
     void slotFlipVert();
     void slotCrop();
-    void slotAutoCrop();
 
     void slotRestore();
     void slotUndo(int steps = 1);
@@ -207,6 +206,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* CANVAS_H */
+#endif // DIGIKAM_IMAGE_EDITOR_CANVAS_H
