@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-11-16
  * Description : a widget to display an image with guides
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -52,12 +52,12 @@ namespace Digikam
 static const KLocalizedString beforeLabel = ki18nc("Preview image (before filter has been applied)", "Before");
 static const KLocalizedString afterLabel  = ki18nc("Preview image (after filter has been applied)",  "After");
 
-class ImageGuideWidget::Private
+class Q_DECL_HIDDEN ImageGuideWidget::Private
 {
 public:
 
-    Private() :
-        sixteenBit(false),
+    explicit Private()
+      : sixteenBit(false),
         focus(false),
         spotVisible(false),
         onMouseMovePreviewToggled(true),
@@ -321,7 +321,7 @@ void ImageGuideWidget::updatePixmap()
         }
 
         // Drawing information and others stuff.
-        p.fillRect(d->rect.right(), 0, width(), height(), palette().color(QPalette::Background));
+        p.fillRect(d->rect.right(), 0, width(), height(), palette().color(QPalette::Window));
 
         p.setPen(QPen(Qt::white, 2, Qt::SolidLine));
         p.drawLine(d->rect.x() + d->rect.width() / 2 - 1, d->rect.y(),
@@ -354,7 +354,7 @@ void ImageGuideWidget::updatePixmap()
                          0, 0, d->rect.width(), d->rect.height() / 2);
         }
 
-        p.fillRect(0, d->rect.bottom(), width(), height(), palette().color(QPalette::Background));
+        p.fillRect(0, d->rect.bottom(), width(), height(), palette().color(QPalette::Window));
 
         p.setPen(QPen(Qt::white, 2, Qt::SolidLine));
         p.drawLine(d->rect.x(),
@@ -409,7 +409,7 @@ void ImageGuideWidget::updatePixmap()
         }
     }
 
-    // draw additional points added by the image plugin
+    // draw additional points added by the image tool
     if (d->selectedPoints.count() > 0)
     {
         QPainter::RenderHints hints = p.renderHints();
@@ -800,8 +800,10 @@ QImage ImageGuideWidget::getMask() const
 
 QPoint ImageGuideWidget::translatePointPosition(const QPoint& point) const
 {
-    int x  = (int)(point.x() * (float)(d->preview.width())  / (float) d->iface->originalSize().width());
-    int y  = (int)(point.y() * (float)(d->preview.height()) / (float) d->iface->originalSize().height());
+    int x = d->rect.x() + 1 + (int)(point.x() * (float)d->preview.width()  /
+                                                (float)d->iface->originalSize().width());
+    int y = d->rect.y() + 1 + (int)(point.y() * (float)d->preview.height() /
+                                                (float)d->iface->originalSize().height());
 
     return (QPoint(x, y));
 }
@@ -837,7 +839,7 @@ void ImageGuideWidget::updateMaskCursor()
     d->maskCursor = QCursor(pix);
 }
 
-void ImageGuideWidget::setSpotPosition(QPoint &point)
+void ImageGuideWidget::setSpotPosition(const QPoint& point)
 {
     d->spot.setX(point.x());
     d->spot.setY(point.y());
@@ -854,10 +856,12 @@ void ImageGuideWidget::updateSpotPosition(int x, int y)
     updatePreview();
 }
 
-QPoint ImageGuideWidget::translateImagePosition(const QPoint& point, bool src) const
+QPoint ImageGuideWidget::translateItemPosition(const QPoint& point, bool src) const
 {
-    int x = (int)(point.x() * (float)(d->preview.width())  / (float) d->iface->originalSize().width());
-    int y = (int)(point.y() * (float)(d->preview.height()) / (float) d->iface->originalSize().height());
+    int x = (int)(point.x() * (float)d->preview.width()  /
+                              (float) d->iface->originalSize().width());
+    int y = (int)(point.y() * (float)d->preview.height() /
+                              (float) d->iface->originalSize().height());
 
     if (!src)
     {
@@ -880,4 +884,4 @@ void ImageGuideWidget::setMaskCursor()
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
