@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-20
  * Description : a widget to display an image with guides
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEGUIDEWIDGET_H
-#define IMAGEGUIDEWIDGET_H
+#ifndef DIGIKAM_IMAGE_GUIDE_WIDGET_H
+#define DIGIKAM_IMAGE_GUIDE_WIDGET_H
 
 // Qt includes
 
@@ -127,9 +127,9 @@ protected:
     QPoint translatePointPosition(const QPoint& point) const;
     void   drawText(QPainter* const p, const QPoint& corner, const QString& text);
     void   updateMaskCursor();
-    void   setSpotPosition(QPoint& point);
+    void   setSpotPosition(const QPoint& point);
     void   updateSpotPosition(int x, int y);
-    QPoint translateImagePosition(const QPoint& point, bool src) const;
+    QPoint translateItemPosition(const QPoint& point, bool src) const;
 
 private:
 
@@ -137,6 +137,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // IMAGEGUIDEWIDGET_H
+#endif // DIGIKAM_IMAGE_GUIDE_WIDGET_H
