@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-04-27
  * Description : image preview item for image editor.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,7 +39,7 @@
 #include "iccsettingscontainer.h"
 #include "icctransform.h"
 #include "editorcore.h"
-#include "dimgitemspriv.h"
+#include "dimgitems_p.h"
 
 namespace Digikam
 {
@@ -125,7 +125,7 @@ void ImagePreviewItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*
 
             if (doSoftProofing)
             {
-                monitorICCtrans = manager.displaySoftProofingTransform(iccSettings.defaultProofProfile, widget);
+                monitorICCtrans = manager.displaySoftProofingTransform(IccProfile(iccSettings.defaultProofProfile), widget);
             }
             else
             {
@@ -159,4 +159,4 @@ void ImagePreviewItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
