@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-04-27
  * Description : image preview item for image editor.
  *
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEPREVIEWITEM_H
-#define IMAGEPREVIEWITEM_H
+#ifndef DIGIKAM_IMAGE_PREVIEW_ITEM_H
+#define DIGIKAM_IMAGE_PREVIEW_ITEM_H
 
 // Local includes
 
@@ -41,12 +41,12 @@ class DIGIKAM_EXPORT ImagePreviewItem : public GraphicsDImgItem
 
 public:
 
-    ImagePreviewItem();
+    explicit ImagePreviewItem();
     virtual ~ImagePreviewItem();
 
     void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget);
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* IMAGEPREVIEWITEM_H */
+#endif // DIGIKAM_IMAGE_PREVIEW_ITEM_H
