@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-07-25
  * Description : image region widget item for image editor.
  *
- * Copyright (C) 2013-2014 Yiou Wang <geow812 at gmail dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2014 by Yiou Wang <geow812 at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  *
  * This program is free software; you can redistribute it
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEREGIONITEM_H
-#define IMAGEREGIONITEM_H
+#ifndef DIGIKAM_IMAGE_REGION_ITEM_H
+#define DIGIKAM_IMAGE_REGION_ITEM_H
 
 // Qt includes
 
@@ -45,7 +45,7 @@ class DIGIKAM_EXPORT ImageRegionItem : public GraphicsDImgItem
 
 public:
 
-    ImageRegionItem(ImageRegionWidget* const view);
+    explicit ImageRegionItem(ImageRegionWidget* const view);
     virtual ~ImageRegionItem();
 
     void setTargetImage(DImg& img);
@@ -65,6 +65,6 @@ private:
     Private* const d_ptr;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // IMAGEREGIONITEM_H
+#endif // DIGIKAM_IMAGE_REGION_ITEM_H
