@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-07-15
  * Description : a widget to draw an image clip region.
  *
  * Copyright (C) 2013-2014 by Yiou Wang <geow812 at gmail dot com>
  * Copyright (C) 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,18 +44,18 @@
 #include "imageregionitem.h"
 #include "previewtoolbar.h"
 #include "previewlayout.h"
-#include "dimgitemspriv.h"
+#include "dimgitems_p.h"
 
 namespace Digikam
 {
 
-class ImageRegionWidget::Private
+class Q_DECL_HIDDEN ImageRegionWidget::Private
 {
 
 public:
 
-    Private() :
-        capturePtMode(false),
+    explicit Private()
+      : capturePtMode(false),
         renderingPreviewMode(PreviewToolBar::PreviewBothImagesVertCont),
         oldRenderingPreviewMode(PreviewToolBar::PreviewBothImagesVertCont),
         delay(0),
@@ -76,7 +76,8 @@ public:
 };
 
 ImageRegionWidget::ImageRegionWidget(QWidget* const parent)
-    : GraphicsDImgView(parent), d_ptr(new Private)
+    : GraphicsDImgView(parent),
+      d_ptr(new Private)
 {
     d_ptr->item = new ImageRegionItem(this);
     setItem(d_ptr->item);
@@ -96,7 +97,7 @@ ImageRegionWidget::ImageRegionWidget(QWidget* const parent)
     connect(d_ptr->delay, SIGNAL(timeout()),
             this, SLOT(slotOriginalImageRegionChanged()));
 
-    connect(this, SIGNAL(viewportRectChanged(const QRectF&)),
+    connect(this, SIGNAL(viewportRectChanged(QRectF)),
             this, SLOT(slotOriginalImageRegionChangedDelayed()));
 
     layout()->fitToWindow();
@@ -166,10 +167,10 @@ void ImageRegionWidget::setPreviewImage(const DImg& img)
     QRect r    = d_ptr->item->getImageRegion();
     image.resize(r.width(), r.height());
 
-    // Because image plugins are tool which only work on image data, the DImg container
+    // Because tool which only work on image data, the DImg container
     // do not contain metadata from original image. About Color Managed View, we need to
     // restore the embedded ICC color profile.
-    // However, some plugins may set a profile on the preview image, which we accept of course.
+    // However, some tools may set a profile on the preview image, which we accept of course.
     if (image.getIccProfile().isNull())
     {
         image.setIccProfile(d_ptr->item->image().getIccProfile());
@@ -256,4 +257,4 @@ void ImageRegionWidget::emitCapturedPointFromOriginal(const QPointF& pt)
     emit signalCapturedPointFromOriginal(color, imgPt);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
