@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-07-15
  * Description : a widget to draw an image clip region.
  *
  * Copyright (C) 2013-2014 by Yiou Wang <geow812 at gmail dot com>
  * Copyright (C) 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEREGIONWIDGET_H
-#define IMAGEREGIONWIDGET_H
+#ifndef DIGIKAM_IMAGE_REGION_WIDGET_H
+#define DIGIKAM_IMAGE_REGION_WIDGET_H
 
 // Qt includes
 
@@ -108,6 +108,6 @@ private:
     Private* const d_ptr;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* IMAGEREGIONWIDGET_H */
+#endif // DIGIKAM_IMAGE_REGION_WIDGET_H
