@@ -1,7 +1,7 @@
 /* ============================================================
 *
 * This file is a part of digiKam project
-* http://www.digikam.org
+* https://www.digikam.org
 *
 * Date        : 2013-09-13
 * Description : rubber item for Canvas
@@ -21,8 +21,8 @@
 *
 * ============================================================ */
 
-#ifndef RUBBER_ITEM_H
-#define RUBBER_ITEM_H
+#ifndef DIGIKAM_RUBBER_ITEM_H
+#define DIGIKAM_RUBBER_ITEM_H
 
 // Qt includes
 
@@ -46,7 +46,7 @@ class DIGIKAM_EXPORT RubberItem : public RegionFrameItem
 
 public:
 
-    RubberItem(ImagePreviewItem* const item);
+    explicit RubberItem(ImagePreviewItem* const item);
     virtual ~RubberItem();
 
     void setCanvas(Canvas* const canvas);
@@ -64,4 +64,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* RUBBER_ITEM_H */
+#endif // DIGIKAM_RUBBER_ITEM_H
