@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-21-12
  * Description : digiKam light table preview item.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef LIGHTTABLEPREVIEW_H
-#define LIGHTTABLEPREVIEW_H
+#ifndef DIGIKAM_LIGHT_TABLE_PREVIEW_H
+#define DIGIKAM_LIGHT_TABLE_PREVIEW_H
 
 // Qt includes
 
@@ -33,13 +33,13 @@
 
 // Local includes
 
-#include "imageinfo.h"
-#include "imagepreviewview.h"
+#include "iteminfo.h"
+#include "itempreviewview.h"
 
 namespace Digikam
 {
 
-class LightTablePreview : public ImagePreviewView
+class LightTablePreview : public ItemPreviewView
 {
     Q_OBJECT
 
@@ -53,7 +53,7 @@ public:
 
 Q_SIGNALS:
 
-    void signalDroppedItems(const ImageInfoList&);
+    void signalDroppedItems(const ItemInfoList&);
 
 private:
 
@@ -63,6 +63,6 @@ private:
     bool dragEventWrapper(const QMimeData*) const;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* LIGHTTABLEPREVIEW_H */
+#endif // DIGIKAM_LIGHT_TABLE_PREVIEW_H
