@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-04-11
  * Description : light table thumbs bar
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,19 +21,19 @@
  *
  * ============================================================ */
 
-#ifndef LIGHTTABLETHUMBBAR_H
-#define LIGHTTABLETHUMBBAR_H
+#ifndef DIGIKAM_LIGHT_TABLE_THUMB_BAR_H
+#define DIGIKAM_LIGHT_TABLE_THUMB_BAR_H
 
 // Local includes
 
-#include "imagethumbnailbar.h"
-#include "imageinfo.h"
-#include "imagelistmodel.h"
+#include "itemthumbnailbar.h"
+#include "iteminfo.h"
+#include "itemlistmodel.h"
 
 namespace Digikam
 {
 
-class LightTableThumbBar : public ImageThumbnailBar
+class LightTableThumbBar : public ItemThumbnailBar
 {
     Q_OBJECT
 
@@ -44,27 +44,27 @@ public:
 
     void clear();
 
-    void setItems(const ImageInfoList& list);
-    void setOnLeftPanel(const ImageInfo& info);
-    void setOnRightPanel(const ImageInfo& info);
+    void setItems(const ItemInfoList& list);
+    void setOnLeftPanel(const ItemInfo& info);
+    void setOnRightPanel(const ItemInfo& info);
     void setNavigateByPair(bool b);
 
-    void removeItemByInfo(const ImageInfo& info);
+    void removeItemByInfo(const ItemInfo& info);
     void toggleTag(int tagID);
 
-    bool isOnLeftPanel(const ImageInfo& info)             const;
-    bool isOnRightPanel(const ImageInfo& info)            const;
+    bool isOnLeftPanel(const ItemInfo& info)             const;
+    bool isOnRightPanel(const ItemInfo& info)            const;
     int  countItems()                                     const;
-    QModelIndex findItemByInfo(const ImageInfo& info)     const;
-    ImageInfo   findItemByIndex(const QModelIndex& index) const;
+    QModelIndex findItemByInfo(const ItemInfo& info)     const;
+    ItemInfo   findItemByIndex(const QModelIndex& index) const;
 
 Q_SIGNALS:
 
-    void signalSetItemOnLeftPanel(const ImageInfo&);
-    void signalSetItemOnRightPanel(const ImageInfo&);
-    void signalEditItem(const ImageInfo&);
-    void signalRemoveItem(const ImageInfo&);
-    void signalDroppedItems(const QList<ImageInfo>&);
+    void signalSetItemOnLeftPanel(const ItemInfo&);
+    void signalSetItemOnRightPanel(const ItemInfo&);
+    void signalEditItem(const ItemInfo&);
+    void signalRemoveItem(const ItemInfo&);
+    void signalDroppedItems(const QList<ItemInfo>&);
     void signalClearAll();
     void signalContentChanged();
 
@@ -82,11 +82,11 @@ public Q_SLOTS:
 private:
 
     void paintEvent(QPaintEvent*);
-    void showContextMenuOnInfo(QContextMenuEvent* e, const ImageInfo& info);
-    void assignPickLabel(const ImageInfo& info, int pickId);
-    void assignColorLabel(const ImageInfo& info, int colorId);
-    void assignRating(const ImageInfo& info, int rating);
-    void toggleTag(const ImageInfo& info, int tagID);
+    void showContextMenuOnInfo(QContextMenuEvent* e, const ItemInfo& info);
+    void assignPickLabel(const ItemInfo& info, int pickId);
+    void assignColorLabel(const ItemInfo& info, int colorId);
+    void assignRating(const ItemInfo& info, int rating);
+    void toggleTag(const ItemInfo& info, int tagID);
 
 private Q_SLOTS:
 
@@ -98,6 +98,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* LIGHTTABLETHUMBBAR_H */
+#endif // DIGIKAM_LIGHT_TABLE_THUMB_BAR_H
