@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-05
  * Description : a widget to display 2 preview image on
  *               lightable to compare pictures.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef LIGHTTABLEVIEW_H
-#define LIGHTTABLEVIEW_H
+#ifndef DIGIKAM_LIGHT_TABLE_VIEW_H
+#define DIGIKAM_LIGHT_TABLE_VIEW_H
 
 // Qt includes
 
@@ -32,7 +32,7 @@
 
 // Local includes
 
-#include "imageinfo.h"
+#include "iteminfo.h"
 
 namespace Digikam
 {
@@ -51,15 +51,15 @@ public:
     void   setSyncPreview(bool sync);
     void   setNavigateByPair(bool b);
 
-    void   setLeftImageInfo(const ImageInfo& info = ImageInfo());
-    void   setRightImageInfo(const ImageInfo& info = ImageInfo());
+    void   setLeftItemInfo(const ItemInfo& info = ItemInfo());
+    void   setRightItemInfo(const ItemInfo& info = ItemInfo());
 
-    ImageInfo leftImageInfo() const;
-    ImageInfo rightImageInfo() const;
+    ItemInfo leftItemInfo() const;
+    ItemInfo rightItemInfo() const;
 
     void setPreviewSettings(const PreviewSettings& settings);
 
-    void   checkForSelection(const ImageInfo& info);
+    void   checkForSelection(const ItemInfo& info);
     void   toggleFullScreen(bool set);
 
     double leftZoomMax()  const;
@@ -85,8 +85,8 @@ Q_SIGNALS:
     void signalLeftZoomFactorChanged(double);
     void signalRightZoomFactorChanged(double);
 
-    void signalLeftDroppedItems(const ImageInfoList&);
-    void signalRightDroppedItems(const ImageInfoList&);
+    void signalLeftDroppedItems(const ItemInfoList&);
+    void signalRightDroppedItems(const ItemInfoList&);
 
     void signalLeftPanelLeftButtonClicked();
     void signalRightPanelLeftButtonClicked();
@@ -97,9 +97,8 @@ Q_SIGNALS:
     void signalLeftSlideShowCurrent();
     void signalRightSlideShowCurrent();
 
-    void signalSlideShow();
-    void signalDeleteItem(const ImageInfo&);
-    void signalEditItem(const ImageInfo&);
+    void signalDeleteItem(const ItemInfo&);
+    void signalEditItem(const ItemInfo&);
     void signalToggleOnSyncPreview(bool);
 
 public Q_SLOTS:
@@ -145,6 +144,6 @@ private :
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* LIGHTTABLEVIEW_H */
+#endif // DIGIKAM_LIGHT_TABLE_VIEW_H
