@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-05
  * Description : digiKam light table GUI
  *
- * Copyright (C) 2007-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef LIGHT_TABLE_WINDOW_H
-#define LIGHT_TABLE_WINDOW_H
+#ifndef DIGIKAM_LIGHT_TABLE_WINDOW_H
+#define DIGIKAM_LIGHT_TABLE_WINDOW_H
 
 // Qt includes
 
@@ -33,7 +33,7 @@
 // Local includes
 
 #include "dxmlguiwindow.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 
 namespace Digikam
 {
@@ -51,14 +51,17 @@ public:
     static LightTableWindow* lightTableWindow();
     static bool              lightTableWindowCreated();
 
-    void loadImageInfos(const ImageInfoList& list, const ImageInfo& imageInfoCurrent, bool addTo);
-    void setLeftRightItems(const ImageInfoList& list, bool addTo);
-    void applySettings();
+    void loadItemInfos(const ItemInfoList& list, const ItemInfo& imageInfoCurrent, bool addTo);
+    void setLeftRightItems(const ItemInfoList& list, bool addTo);
     void refreshView();
     bool isEmpty() const;
 
     void toggleTag(int tagID);
 
+public:
+
+    DInfoInterface* infoIface(DPluginAction* const ac);
+
 Q_SIGNALS:
 
     void signalWindowHasMoved();
@@ -80,15 +83,9 @@ private:
     void showSideBars(bool visible);
     void closeEvent(QCloseEvent* e);
     void showEvent(QShowEvent*);
-    void setupActions();
-    void setupConnections();
-    void setupUserArea();
-    void setupStatusBar();
-    void readSettings();
-    void writeSettings();
 
     void deleteItem(bool permanently);
-    void deleteItem(const ImageInfo& info, bool permanently);
+    void deleteItem(const ItemInfo& info, bool permanently);
 
     LightTableWindow();
 
@@ -101,10 +98,10 @@ private Q_SLOTS:
 
     void slotSetItemLeft();
     void slotSetItemRight();
-    void slotSetItemOnLeftPanel(const ImageInfo&);
-    void slotSetItemOnRightPanel(const ImageInfo&);
-    void slotLeftDroppedItems(const ImageInfoList&);
-    void slotRightDroppedItems(const ImageInfoList&);
+    void slotSetItemOnLeftPanel(const ItemInfo&);
+    void slotSetItemOnRightPanel(const ItemInfo&);
+    void slotLeftDroppedItems(const ItemInfoList&);
+    void slotRightDroppedItems(const ItemInfoList&);
 
     void slotLeftPanelLeftButtonClicked();
     void slotRightPanelLeftButtonClicked();
@@ -115,45 +112,29 @@ private Q_SLOTS:
     void slotLeftZoomFactorChanged(double);
     void slotRightZoomFactorChanged(double);
 
-    void slotLeftSlideShowManualFromCurrent();
-    void slotRightSlideShowManualFromCurrent();
-
-    void slotSlideShowLastItemUrl(const QUrl&);
-    void slotSlideShowManualFrom(const ImageInfo&);
-    void slotSlideShowBuilderComplete(const SlideShowSettings&);
-
     void slotToggleOnSyncPreview(bool);
     void slotToggleSyncPreview();
     void slotToggleNavigateByPair();
 
-    void slotEditItem();
-    void slotEditItem(const ImageInfo&);
-
     void slotDeleteItem();
-    void slotDeleteItem(const ImageInfo&);
+    void slotDeleteItem(const ItemInfo&);
 
     void slotDeleteFinalItem();
-    void slotDeleteFinalItem(const ImageInfo&);
+    void slotDeleteFinalItem(const ItemInfo&);
 
     void slotRemoveItem();
-    void slotRemoveItem(const ImageInfo&);
+    void slotRemoveItem(const ItemInfo&);
 
-    void slotItemSelected(const ImageInfo&);
+    void slotItemSelected(const ItemInfo&);
     void slotClearItemsList();
 
-    void slotThumbbarDroppedItems(const QList<ImageInfo>&);
+    void slotThumbbarDroppedItems(const QList<ItemInfo>&);
 
-    void slotPresentation();
-    void slotSlideShowAll();
-    void slotSetup();
-    void slotColorManagementOptionsChanged();
     void slotToggleColorManagedView();
     void slotComponentsInfo();
     void slotDBStat();
 
     void slotFileWithDefaultApplication();
-    void slotApplicationSettingsChanged();
-    void slotThemeChanged();
 
     void slotRefreshStatusBar();
 
@@ -171,18 +152,55 @@ private Q_SLOTS:
     void slotLeftSideBarActivateComments();
     void slotLeftSideBarActivateAssignedTags();
 
-    void slotImportFromScanner();
+// -- Internal setup methods implemented in lighttablewindow_config.cpp ----------------------------------------
+
+public:
+
+    void applySettings();
+
+private:
+
+    void readSettings();
+    void writeSettings();
+
+public Q_SLOTS:
+
+    void slotSetup();
+    void slotColorManagementOptionsChanged();
+
+    void slotThemeChanged();
+    void slotApplicationSettingsChanged();
+
+// -- Internal setup methods implemented in lighttablewindow_setup.cpp ----------------------------------------
+
+private:
+
+    void setupActions();
+    void setupConnections();
+    void setupUserArea();
+    void setupStatusBar();
+
+// -- Extra tool methods implemented in lighttablewindow_tools.cpp ----------------------------------------
+
+private Q_SLOTS:
+
+    void slotEditItem();
+    void slotEditItem(const ItemInfo&);
+
+    void slotSlideShowAll();
+    void slotLeftSlideShowManualFromCurrent();
+    void slotRightSlideShowManualFromCurrent();
+    void slotSlideShowLastItemUrl(const QUrl&);
+    void slotSlideShowManualFrom(const ItemInfo&);
+    void slotSlideShowBuilderComplete(const SlideShowSettings&);
+
+// -- Import tools methods implemented in lighttablewindow_import.cpp -------------------------------------
+
+private Q_SLOTS:
+
     void slotImportedImagefromScanner(const QUrl& url);
 
-    void slotEditMetadata();
-    void slotEditGeolocation();
-    void slotHtmlGallery();
-    void slotCalendar();
-    void slotExpoBlending();
-    void slotPanorama();
-    void slotVideoSlideshow();
-    void slotSendByMail();
-    void slotPrintCreator();
+// -- Internal private container --------------------------------------------------------------------
 
 private:
 
@@ -194,4 +212,4 @@ private:
 
 } // namespace Digikam
 
-#endif // LIGHT_TABLE_WINDOW_H
+#endif // DIGIKAM_LIGHT_TABLE_WINDOW_H
