@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-03-05
  * Description : digiKam light table GUI
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,36 +21,81 @@
  *
  * ============================================================ */
 
-#ifndef LIGHTTABLEWINDOWPRIVATE_H
-#define LIGHTTABLEWINDOWPRIVATE_H
+#ifndef DIGIKAM_LIGHT_TABLE_WINDOW_PRIVATE_H
+#define DIGIKAM_LIGHT_TABLE_WINDOW_PRIVATE_H
 
 // Qt includes
 
-#include <QSplitter>
+#include <QApplication>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 #include <QAction>
+#include <QMenuBar>
+#include <QStatusBar>
+#include <QMenu>
+#include <QSplitter>
+
+// KDE includes
+
+#include <klocalizedstring.h>
+#include <kactioncollection.h>
 
 // Local includes
 
 #include "digikam_globals.h"
-#include "imagepropertiessidebardb.h"
+#include "itempropertiessidebardb.h"
 #include "statusprogressbar.h"
 #include "dzoombar.h"
 #include "lighttableview.h"
 #include "lighttablethumbbar.h"
 #include "thumbbardock.h"
+#include "drawdecoder.h"
+#include "digikam_debug.h"
+#include "componentsinfodlg.h"
+#include "digikamapp.h"
+#include "thememanager.h"
+#include "dimg.h"
+#include "dio.h"
+#include "dmetadata.h"
+#include "dfileoperations.h"
+#include "metaenginesettings.h"
+#include "applicationsettings.h"
+#include "albummanager.h"
+#include "loadingcacheinterface.h"
+#include "deletedialog.h"
+#include "iccsettings.h"
+#include "imagewindow.h"
+#include "itemgps.h"
+#include "itemdescedittab.h"
+#include "slideshowbuilder.h"
+#include "slideshow.h"
+#include "setup.h"
+#include "syncjob.h"
+#include "lighttablepreview.h"
+#include "albummodel.h"
+#include "albumfiltermodel.h"
+#include "coredbchangesets.h"
+#include "collectionscanner.h"
+#include "scancontroller.h"
+#include "tagsactionmngr.h"
+#include "thumbnailsize.h"
+#include "thumbnailloadthread.h"
+#include "dexpanderbox.h"
+#include "dbinfoiface.h"
 
 namespace Digikam
 {
 
 class DAdjustableLabel;
 
-class LightTableWindow::Private
+class Q_DECL_HIDDEN LightTableWindow::Private
 {
 
 public:
 
-    Private() :
-        autoLoadOnRightPanel(true),
+    Private()
+      : autoLoadOnRightPanel(true),
         autoSyncPreview(true),
         fromLeftPreview(true),
         setItemLeftAction(0),
@@ -92,7 +137,13 @@ public:
     {
     }
 
-    void addPageUpDownActions(LightTableWindow* const q, QWidget* const w);
+    void addPageUpDownActions(LightTableWindow* const q, QWidget* const w)
+    {
+        defineShortcut(w, Qt::Key_Down,  q, SLOT(slotForward()));
+        defineShortcut(w, Qt::Key_Right, q, SLOT(slotForward()));
+        defineShortcut(w, Qt::Key_Up,    q, SLOT(slotBackward()));
+        defineShortcut(w, Qt::Key_Left,  q, SLOT(slotBackward()));
+    }
 
 public:
 
@@ -143,18 +194,10 @@ public:
 
     StatusProgressBar*        statusProgressBar;
 
-    ImagePropertiesSideBarDB* leftSideBar;
-    ImagePropertiesSideBarDB* rightSideBar;
+    ItemPropertiesSideBarDB* leftSideBar;
+    ItemPropertiesSideBarDB* rightSideBar;
 };
 
-void LightTableWindow::Private::addPageUpDownActions(LightTableWindow* const q, QWidget* const w)
-{
-    defineShortcut(w, Qt::Key_Down,  q, SLOT(slotForward()));
-    defineShortcut(w, Qt::Key_Right, q, SLOT(slotForward()));
-    defineShortcut(w, Qt::Key_Up,    q, SLOT(slotBackward()));
-    defineShortcut(w, Qt::Key_Left,  q, SLOT(slotBackward()));
-}
+} // namespace Digikam
 
-}  // namespace Digikam
-
-#endif /* LIGHTTABLEWINDOWPRIVATE_H */
+#endif // DIGIKAM_LIGHT_TABLE_WINDOW_PRIVATE_H
