@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-01-29
  * Description : Thread actions task for database cleanup.
  *
- * Copyright (C) 2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
+ * Copyright (C) 2017-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +30,7 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "thumbsdb.h"
 #include "thumbsdbaccess.h"
 #include "coredb.h"
@@ -38,17 +38,20 @@
 #include "recognitiondatabase.h"
 #include "facetagseditor.h"
 #include "maintenancedata.h"
+#include "similaritydb.h"
+#include "similaritydbaccess.h"
 
 namespace Digikam
 {
 
-class DatabaseTask::Private
+class Q_DECL_HIDDEN DatabaseTask::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : scanThumbsDb(false),
           scanRecognitionDb(false),
+          scanSimilarityDb(false),
           mode(Mode::Unknown),
           data(0)
     {
@@ -58,8 +61,10 @@ public:
 
     bool             scanThumbsDb;
     bool             scanRecognitionDb;
+    bool             scanSimilarityDb;
 
     Mode             mode;
+
     MaintenanceData* data;
 };
 
@@ -77,10 +82,11 @@ DatabaseTask::~DatabaseTask()
     delete d;
 }
 
-void DatabaseTask::computeDatabaseJunk(bool thumbsDb, bool facesDb)
+void DatabaseTask::computeDatabaseJunk(bool thumbsDb, bool facesDb, bool similarityDb)
 {
     d->scanThumbsDb      = thumbsDb;
     d->scanRecognitionDb = facesDb;
+    d->scanSimilarityDb  = similarityDb;
 }
 
 void DatabaseTask::setMode(Mode mode)
@@ -107,6 +113,7 @@ void DatabaseTask::run()
     if (d->mode == Mode::ShrinkDatabases)
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Shrinking databases";
+
         if (CoreDbAccess().db()->integrityCheck())
         {
             CoreDbAccess().db()->vacuum();
@@ -115,19 +122,19 @@ void DatabaseTask::run()
             {
                 qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for core DB failed after vacuum. Something went wrong.";
                 // Signal that the database was vacuumed but failed the integrity check afterwards.
-                emit signalFinished(true,false);
+                emit signalFinished(true, false);
             }
             else
             {
                 qCDebug(DIGIKAM_DATABASE_LOG) << "Finished vacuuming of core DB. Integrity check after vacuuming was positive.";
-                emit signalFinished(true,true);
+                emit signalFinished(true, true);
             }
         }
         else
         {
             qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for core DB failed. Will not vacuum.";
             // Signal that the integrity check failed and thus the vacuum was skipped
-            emit signalFinished(false,false);
+            emit signalFinished(false, false);
         }
 
         QThread::sleep(1);
@@ -147,25 +154,25 @@ void DatabaseTask::run()
                 {
                     qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for thumbnails DB failed after vacuum. Something went wrong.";
                     // Signal that the database was vacuumed but failed the integrity check afterwards.
-                    emit signalFinished(true,false);
+                    emit signalFinished(true, false);
                 }
                 else
                 {
                     qCDebug(DIGIKAM_DATABASE_LOG) << "Finished vacuuming of thumbnails DB. Integrity check after vacuuming was positive.";
-                    emit signalFinished(true,true);
+                    emit signalFinished(true, true);
                 }
             }
             else
             {
                 qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for thumbnails DB failed. Will not vacuum.";
                 // Signal that the integrity check failed and thus the vacuum was skipped
-                emit signalFinished(false,false);
+                emit signalFinished(false, false);
             }
         }
         else
         {
             qCWarning(DIGIKAM_DATABASE_LOG) << "Thumbnails DB is not initialised. Will not vacuum.";
-            emit signalFinished(false,false);
+            emit signalFinished(false, false);
         }
 
         QThread::sleep(1);
@@ -183,37 +190,73 @@ void DatabaseTask::run()
             {
                 qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for recognition DB failed after vacuum. Something went wrong.";
                 // Signal that the database was vacuumed but failed the integrity check afterwards.
-                emit signalFinished(true,false);
+                emit signalFinished(true, false);
             }
             else
             {
                 qCDebug(DIGIKAM_DATABASE_LOG) << "Finished vacuuming of recognition DB. Integrity check after vacuuming was positive.";
-                emit signalFinished(true,true);
+                emit signalFinished(true, true);
             }
         }
         else
         {
             qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for recognition DB failed. Will not vacuum.";
             // Signal that the integrity check failed and thus the vacuum was skipped
-            emit signalFinished(false,false);
+            emit signalFinished(false, false);
+        }
+
+        QThread::sleep(1);
+
+        if (m_cancel)
+        {
+            return;
+        }
+
+        if (SimilarityDbAccess::isInitialized())
+        {
+            if (SimilarityDbAccess().db()->integrityCheck())
+            {
+                SimilarityDbAccess().db()->vacuum();
+
+                if (!SimilarityDbAccess().db()->integrityCheck())
+                {
+                    qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for similarity DB failed after vacuum. Something went wrong.";
+                    // Signal that the database was vacuumed but failed the integrity check afterwards.
+                    emit signalFinished(true, false);
+                }
+                else
+                {
+                    qCDebug(DIGIKAM_DATABASE_LOG) << "Finished vacuuming of similarity DB. Integrity check after vacuuming was positive.";
+                    emit signalFinished(true, true);
+                }
+            }
+            else
+            {
+                qCWarning(DIGIKAM_DATABASE_LOG) << "Integrity check for recognition DB failed. Will not vacuum.";
+                // Signal that the integrity check failed and thus the vacuum was skipped
+                emit signalFinished(false, false);
+            }
         }
 
         QThread::sleep(1);
     }
     else if (d->mode == Mode::ComputeDatabaseJunk)
     {
-        QList<qlonglong>              staleImageIds;
-        QList<int>                    staleThumbIds;
+        QList<qlonglong> staleImageIds;
+        QList<int>       staleThumbIds;
         QList<Identity>  staleIdentities;
+        QList<qlonglong> staleSimilarityImageIds;
         int additionalItemsToProcess = 0;
 
+        QList<qlonglong> coredbItems = CoreDbAccess().db()->getAllItems();
+
         // Get the count of image entries in DB to delete.
-        staleImageIds   = CoreDbAccess().db()->getImageIds(DatabaseItem::Status::Obsolete);
+        staleImageIds                = CoreDbAccess().db()->getImageIds(DatabaseItem::Status::Obsolete);
 
         // get the count of items to process for thumbnails cleanup it enabled.
         if (d->scanThumbsDb && ThumbsDbAccess::isInitialized())
         {
-            additionalItemsToProcess += CoreDbAccess().db()->getAllItems().size();
+            additionalItemsToProcess += coredbItems.size();
         }
 
         // get the count of items to process for identities cleanup it enabled.
@@ -222,6 +265,11 @@ void DatabaseTask::run()
             additionalItemsToProcess += RecognitionDatabase().allIdentities().size();
         }
 
+        if (d->scanSimilarityDb)
+        {
+            additionalItemsToProcess += coredbItems.size();
+        }
+
         if (additionalItemsToProcess > 0)
         {
             emit signalAddItemsToProcess(additionalItemsToProcess);
@@ -240,35 +288,31 @@ void DatabaseTask::run()
             // OR
             // The thumbnail is stale, i.e. no thumbs db table references it.
 
-            QSet<int> thumbIds     = ThumbsDbAccess().db()->findAll().toSet();
-
-            // Get all items, i.e. images, videos, ...
-            QList<qlonglong> items = CoreDbAccess().db()->getAllItems();
+            QSet<int> thumbIds = ThumbsDbAccess().db()->findAll().toSet();
 
             FaceTagsEditor editor;
 
-            foreach(qlonglong item, items)
+            foreach (const qlonglong& item, coredbItems)
             {
                 if (m_cancel)
                 {
                     return;
                 }
 
-                ImageInfo info(item);
+                ItemInfo info(item);
 
                 if (!info.isNull())
                 {
-                    QString hash       = CoreDbAccess().db()->getImagesFields(item,DatabaseFields::ImagesField::UniqueHash).first().toString();
+                    QString hash       = CoreDbAccess().db()->getImagesFields(item, DatabaseFields::ImagesField::UniqueHash).first().toString();
                     qlonglong fileSize = info.fileSize();
-                    bool removed       = false;
 
                     // Remove the id that is found by the file path. Finding the id -1 does no harm
-                    removed            = thumbIds.remove(ThumbsDbAccess().db()->findByFilePath(info.filePath()).id);
+                    bool removed       = thumbIds.remove(ThumbsDbAccess().db()->findByFilePath(info.filePath()).id);
 
                     if (!removed)
                     {
                         // Remove the id that is found by the hash and file size. Finding the id -1 does no harm
-                        thumbIds.remove(ThumbsDbAccess().db()->findByHash(hash,fileSize).id);
+                        thumbIds.remove(ThumbsDbAccess().db()->findByHash(hash, fileSize).id);
                     }
 
                     // Add the custom identifier.
@@ -278,7 +322,7 @@ void DatabaseTask::run()
                     url.setPath(info.filePath());
                     QList<FaceTagsIface> faces = editor.databaseFaces(item);
 
-                    foreach(FaceTagsIface face, faces)
+                    foreach (const FaceTagsIface& face, faces)
                     {
                         QRect rect = face.region().toRect();
                         QString r  = QString::fromLatin1("%1,%2-%3x%4").arg(rect.x()).arg(rect.y()).arg(rect.width()).arg(rect.height());
@@ -291,7 +335,7 @@ void DatabaseTask::run()
 
                         //qCDebug(DIGIKAM_GENERAL_LOG) << "URL: " << url.toString(); 
 
-                        // Remove the id that is found by the custom identifyer. Finding the id -1 does no harm
+                        // Remove the id that is found by the custom identifier. Finding the id -1 does no harm
                         thumbIds.remove(ThumbsDbAccess().db()->findByCustomIdentifier(url.toString()).id);
                     }
                 }
@@ -318,16 +362,16 @@ void DatabaseTask::run()
             QList<TagProperty> properties = CoreDbAccess().db()->getTagProperties(TagPropertyName::faceEngineUuid());
             QSet<QString> uuidSet;
 
-            foreach(TagProperty prop, properties)
+            foreach (const TagProperty& prop, properties)
             {
                 uuidSet << prop.value;
             }
 
             QList<Identity> identities = RecognitionDatabase().allIdentities();
 
-            // Get all identitites to remove. Don't remove now in order to make sure no side effects occur.
+            // Get all identities to remove. Don't remove now in order to make sure no side effects occur.
 
-            foreach(Identity identity, identities)
+            foreach (const Identity& identity, identities)
             {
                 QString value = identity.attribute(QLatin1String("uuid"));
 
@@ -344,7 +388,32 @@ void DatabaseTask::run()
             emit signalFinished();
         }
 
-        emit signalData(staleImageIds,staleThumbIds,staleIdentities);
+        if (m_cancel)
+        {
+            return;
+        }
+
+        if (d->scanSimilarityDb)
+        {
+            // Get all registered image ids from the similarity db.
+            QSet<qlonglong> similarityDbItems = SimilarityDbAccess().db()->registeredImageIds();
+
+            // Remove all image ids that are existent in the core db
+            foreach (const qlonglong& imageId, coredbItems)
+            {
+                similarityDbItems.remove(imageId);
+
+                // Signal that this image id was processed.
+                signalFinished();
+            }
+            // The remaining image ids should be removed from the similarity db.
+            staleSimilarityImageIds = similarityDbItems.toList();
+
+            // Signal that the database was processed.
+            signalFinished();
+        }
+
+        emit signalData(staleImageIds, staleThumbIds, staleIdentities, staleSimilarityImageIds);
     }
     else if (d->mode == Mode::CleanCoreDb)
     {
@@ -357,20 +426,20 @@ void DatabaseTask::run()
             }
 
             qlonglong imageId = d->data->getImageId();
+
             if (imageId == -1)
             {
                 break;
             }
 
             CoreDbAccess().db()->deleteItem(imageId);
-            CoreDbAccess().db()->removeImagePropertyByName(QLatin1String("similarityTo_")+QString::number(imageId));
 
             emit signalFinished();
         }
     }
     else if (d->mode == Mode::CleanThumbsDb)
     {
-        BdEngineBackend::QueryState lastQueryState = BdEngineBackend::ConnectionError;
+        BdEngineBackend::QueryState lastQueryState = BdEngineBackend::QueryState(BdEngineBackend::ConnectionError);
 
         // Connect to the database
         lastQueryState                             = ThumbsDbAccess().backend()->beginTransaction();
@@ -402,22 +471,28 @@ void DatabaseTask::run()
 
             if (BdEngineBackend::NoErrors == lastQueryState)
             {
-                // Commit the removel if everything was fine.
+                // Commit the removal if everything was fine.
                 lastQueryState = ThumbsDbAccess().backend()->commitTransaction();
 
                 if (BdEngineBackend::NoErrors != lastQueryState)
                 {
-                    qCWarning(DIGIKAM_THUMBSDB_LOG) << "Could not commit the removal of " << d->objectIdentification << " due to error ";
+                    qCWarning(DIGIKAM_THUMBSDB_LOG) << "Could not commit the removal of "
+                                                    << d->objectIdentification
+                                                    << " due to error ";
                 }
             }
             else
             {
-                qCWarning(DIGIKAM_THUMBSDB_LOG) << "Could not start the removal of " << d->objectIdentification << " due to error ";
+                qCWarning(DIGIKAM_THUMBSDB_LOG) << "Could not start the removal of "
+                                                << d->objectIdentification
+                                                << " due to error ";
             }
         }
         else
         {
-            qCWarning(DIGIKAM_THUMBSDB_LOG) << "Could not begin the transaction for the removal of " << d->objectIdentification << " due to error ";
+            qCWarning(DIGIKAM_THUMBSDB_LOG) << "Could not begin the transaction for the removal of "
+                                            << d->objectIdentification
+                                            << " due to error ";
         }
     }
     else if (d->mode == Mode::CleanRecognitionDb)
@@ -441,6 +516,29 @@ void DatabaseTask::run()
             emit signalFinished();
         }
     }
+    else if (d->mode == Mode::CleanSimilarityDb)
+    {
+        // While we have data (using this as check for non-null)
+        while (d->data)
+        {
+            if (m_cancel)
+            {
+                return;
+            }
+
+            qlonglong imageId = d->data->getSimilarityImageId();
+
+            if (imageId == -1)
+            {
+                break;
+            }
+
+            SimilarityDbAccess().db()->removeImageFingerprint(imageId, FuzzyAlgorithm::Haar);
+            SimilarityDbAccess().db()->removeImageFingerprint(imageId, FuzzyAlgorithm::TfIdf);
+
+            emit signalFinished();
+        }
+    }
 
     emit signalDone();
 }
