@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-01-29
  * Description : Database cleaner.
  *
- * Copyright (C) 2017      by Mario Frank <mario dot frank at uni minus potsdam dot de>
+ * Copyright (C) 2017-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,6 +30,8 @@
 #include <QMessageBox>
 #include <QThread>
 #include <QVBoxLayout>
+#include <QTimer>
+#include <QListWidget>
 
 // KDE includes
 
@@ -44,14 +46,15 @@
 namespace Digikam
 {
 
-class DbCleaner::Private
+class Q_DECL_HIDDEN DbCleaner::Private
 {
 public:
 
-    Private() :
-        thread(0),
+    explicit Private()
+      : thread(0),
         cleanThumbsDb(false),
         cleanFacesDb(false),
+        cleanSimilarityDb(false),
         shrinkDatabases(false),
         databasesToAnalyseCount(1),
         databasesToShrinkCount(0),
@@ -59,52 +62,60 @@ public:
     {
     }
 
-    ~Private()
-    {
-        delete shrinkDlg;
-    }
+    MaintenanceThread* thread;
+    bool               cleanThumbsDb;
+    bool               cleanFacesDb;
+    bool               cleanSimilarityDb;
+    bool               shrinkDatabases;
 
-    MaintenanceThread*           thread;
-    bool                         cleanThumbsDb;
-    bool                         cleanFacesDb;
-    bool                         shrinkDatabases;
+    QList<qlonglong>   imagesToRemove;
+    QList<int>         staleThumbnails;
+    QList<Identity>    staleIdentities;
+    QList<qlonglong>   staleImageSimilarities;
 
-    QList<qlonglong>             imagesToRemove;
-    QList<int>                   staleThumbnails;
-    QList<Identity>              staleIdentities;
+    int                databasesToAnalyseCount;
+    int                databasesToShrinkCount;
 
-    int                          databasesToAnalyseCount;
-    int                          databasesToShrinkCount;
-
-    DbShrinkDialog*              shrinkDlg;
+    DbShrinkDialog*    shrinkDlg;
 };
 
-DbCleaner::DbCleaner(bool cleanThumbsDb, bool cleanFacesDb, bool shrinkDatabases, ProgressItem* const parent)
+DbCleaner::DbCleaner(bool cleanThumbsDb,
+                     bool cleanFacesDb,
+                     bool cleanSimilarityDb,
+                     bool shrinkDatabases,
+                     ProgressItem* const parent)
     : MaintenanceTool(QLatin1String("DbCleaner"), parent),
       d(new Private)
 {
     // register the identity list as meta type to be able to use it in signal/slot connection
     qRegisterMetaType<QList<Identity>>("QList<Identity>");
 
-    d->cleanThumbsDb   = cleanThumbsDb;
+    d->cleanThumbsDb     = cleanThumbsDb;
 
     if (cleanThumbsDb)
     {
         d->databasesToAnalyseCount = d->databasesToAnalyseCount + 1;
     }
 
-    d->cleanFacesDb    = cleanFacesDb;
+    d->cleanFacesDb      = cleanFacesDb;
 
     if (cleanFacesDb)
     {
         d->databasesToAnalyseCount = d->databasesToAnalyseCount + 1;
     }
 
+    d->cleanSimilarityDb = cleanSimilarityDb;
+
+    if (cleanSimilarityDb)
+    {
+        d->databasesToAnalyseCount = d->databasesToAnalyseCount + 1;
+    }
+
     d->shrinkDatabases = shrinkDatabases;
 
     if (shrinkDatabases)
     {
-        d->databasesToShrinkCount = 3;
+        d->databasesToShrinkCount = 4;
         d->shrinkDlg = new DbShrinkDialog(DigikamApp::instance());
     }
 
@@ -116,6 +127,7 @@ DbCleaner::DbCleaner(bool cleanThumbsDb, bool cleanFacesDb, bool shrinkDatabases
 
 DbCleaner::~DbCleaner()
 {
+    delete d->shrinkDlg;
     delete d;
 }
 
@@ -137,12 +149,12 @@ void DbCleaner::slotStart()
             this, SLOT(slotAddItemsToProcess(int)));
 
     // Set the wiring from the data signal to the data slot.
-    connect(d->thread,SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>)),
-            this, SLOT(slotFetchedData(QList<qlonglong>,QList<int>,QList<Identity>)));
+    connect(d->thread,SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>,QList<qlonglong>)),
+            this, SLOT(slotFetchedData(QList<qlonglong>,QList<int>,QList<Identity>,QList<qlonglong>)));
 
     // Compute the database junk. This will lead to the call of the slot
     // slotFetchedData.
-    d->thread->computeDatabaseJunk(d->cleanThumbsDb,d->cleanFacesDb);
+    d->thread->computeDatabaseJunk(d->cleanThumbsDb,d->cleanFacesDb,d->cleanSimilarityDb);
     d->thread->start();
 }
 
@@ -153,12 +165,14 @@ void DbCleaner::slotAddItemsToProcess(int count)
 
 void DbCleaner::slotFetchedData(const QList<qlonglong>& staleImageIds,
                                 const QList<int>& staleThumbIds,
-                                const QList<Identity>& staleIdentities)
+                                const QList<Identity>& staleIdentities,
+                                const QList<qlonglong>& staleImageSimilarities)
 {
     // We have data now. Store it and trigger the core db cleaning
-    d->imagesToRemove  = staleImageIds;
-    d->staleThumbnails = staleThumbIds;
-    d->staleIdentities = staleIdentities;
+    d->imagesToRemove         = staleImageIds;
+    d->staleThumbnails        = staleThumbIds;
+    d->staleIdentities        = staleIdentities;
+    d->staleImageSimilarities = staleImageSimilarities;
 
     // If we have nothing to do, finish.
     // Signal done if no elements cleanup is necessary
@@ -169,8 +183,8 @@ void DbCleaner::slotFetchedData(const QList<qlonglong>& staleImageIds,
 
         if (d->shrinkDatabases)
         {
-            disconnect(d->thread, SIGNAL(signalData(QList<qlonglong>, QList<int>, QList<Identity>)),
-                       this, SLOT(slotFetchedData(QList<qlonglong>, QList<int>, QList<Identity>)));
+            disconnect(d->thread, SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>)),
+                       this, SLOT(slotFetchedData(QList<qlonglong>,QList<int>,QList<Identity>)));
 
             disconnect(d->thread, SIGNAL(signalCompleted()),
                         this, SLOT(slotCleanItems()));
@@ -226,7 +240,7 @@ void DbCleaner::slotCleanedItems()
 
     if (d->cleanThumbsDb)
     {
-        if (d->staleThumbnails.size() > 0)
+        if (!d->staleThumbnails.isEmpty())
         {
             qCDebug(DIGIKAM_GENERAL_LOG) << "Found " << d->staleThumbnails.size() << " stale thumbnails.";
             setLabel(i18n("Clean up the databases : ") + i18n("cleaning thumbnails db"));
@@ -282,7 +296,43 @@ void DbCleaner::slotCleanedThumbnails()
 
 void DbCleaner::slotCleanedFaces()
 {
-    // We cleaned the recognition db. We are done.
+    // We cleaned the recognition db. Now clean the similarity db
+    disconnect(d->thread, SIGNAL(signalCompleted()),
+               this, SLOT(slotCleanedFaces()));
+
+    if (d->cleanSimilarityDb)
+    {
+        // TODO: implement similarity db cleanup
+        if (!d->staleImageSimilarities.isEmpty())
+        {
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Found " << d->staleImageSimilarities.size() << " image ids that are referenced in similarity db but not used.";
+            setLabel(i18n("Clean up the databases : ") + i18n("cleaning similarity db"));
+
+            // GO! and don't forget the signal!
+            connect(d->thread, SIGNAL(signalCompleted()),
+                    this, SLOT(slotCleanedSimilarity()));
+
+            // We cleaned the thumbs db. Now clean the faces db.
+            d->thread->cleanSimilarityDb(d->staleImageSimilarities);
+            d->thread->start();
+        }
+        else
+        {
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Similarity DB is clean.";
+            slotCleanedSimilarity();
+        }
+    }
+    else
+    {
+        slotCleanedSimilarity();
+    }
+
+    slotDone();
+}
+
+void DbCleaner::slotCleanedSimilarity()
+{
+    // We cleaned the similarity db. We are done.
     if (d->shrinkDatabases)
     {
         slotShrinkDatabases();
@@ -302,7 +352,7 @@ void DbCleaner::slotShrinkDatabases()
             d->shrinkDlg, SLOT(exec()));
 
     connect(d->thread, SIGNAL(signalFinished(bool,bool)),
-            this, SLOT(slotShrinkNextDBInfo(bool, bool)));
+            this, SLOT(slotShrinkNextDBInfo(bool,bool)));
 
     connect(d->thread, SIGNAL(signalCompleted()),
             this, SLOT(slotDone()));
@@ -346,18 +396,23 @@ void DbCleaner::slotShrinkNextDBInfo(bool done, bool passed)
 
     switch(d->databasesToShrinkCount)
     {
-        case 2:
+        case 3:
             d->shrinkDlg->setIcon(0, statusIcon);
             d->shrinkDlg->setActive(1);
             break;
 
-        case 1:
+        case 2:
             d->shrinkDlg->setIcon(1, statusIcon);
             d->shrinkDlg->setActive(2);
             break;
 
-        case 0:
+        case 1:
             d->shrinkDlg->setIcon(2, statusIcon);
+            d->shrinkDlg->setActive(3);
+            break;
+
+        case 0:
+            d->shrinkDlg->setIcon(3, statusIcon);
             d->shrinkDlg->setActive(-1);
             break;
     }
@@ -386,106 +441,128 @@ void DbCleaner::slotDone()
 
 //----------------------------------------------------------------------------
 
+class Q_DECL_HIDDEN DbShrinkDialog::Private
+{
+public:
+
+    explicit Private()
+      : active(-1),
+        progressTimer(0),
+        progressIndex(1),
+        statusList(0)
+    {
+    }
+
+    int            active;
+    DWorkingPixmap progressPix;
+    QTimer*        progressTimer;
+    int            progressIndex;
+    QListWidget*   statusList;
+};
+
 DbShrinkDialog::DbShrinkDialog(QWidget* const parent)
     : QDialog(parent),
-      active(-1),
-      progressPix(DWorkingPixmap()),
-      progressTimer(new QTimer(parent)),
-      progressIndex(1),
-      statusList(new QListWidget(this))
+      d(new Private)
 {
-    QVBoxLayout* statusLayout = new QVBoxLayout(this);
+    d->progressPix   = DWorkingPixmap();
+    d->progressTimer = new QTimer(parent);
+    d->statusList    = new QListWidget(this);
 
-    QLabel* infos = new QLabel(i18n("<p>Database shrinking in progress.</p>"
-                                    "<p>Currently, your databases are being shrunk. "
-                                    "This will take some time - depending on "
-                                    "your databases size.</p>"
-                                    "<p>We have to freeze digiKam in order to "
-                                    "prevent database corruption. This info box "
-                                    "will vanish when the shrinking process is "
-                                    "finished.</p>"
-                                    "Current Status:"),
-                               this);
+    QVBoxLayout* const statusLayout = new QVBoxLayout(this);
+
+    QLabel* const infos = new QLabel(i18n("<p>Database shrinking in progress.</p>"
+                                          "<p>Currently, your databases are being shrunk. "
+                                          "This will take some time - depending on "
+                                          "your databases size.</p>"
+                                          "<p>We have to freeze digiKam in order to "
+                                          "prevent database corruption. This info box "
+                                          "will vanish when the shrinking process is "
+                                          "finished.</p>"
+                                          "Current Status:"),
+                                     this);
     infos->setWordWrap(true);
     statusLayout->addWidget(infos);
 
-    statusList->addItem(i18n("Core DB"));
-    statusList->addItem(i18n("Thumbnails DB"));
-    statusList->addItem(i18n("Face Recognition DB"));
+    d->statusList->addItem(i18n("Core DB"));
+    d->statusList->addItem(i18n("Thumbnails DB"));
+    d->statusList->addItem(i18n("Face Recognition DB"));
+    d->statusList->addItem(i18n("Similarity DB"));
 
-    for (int i = 0 ; i < 3 ; ++i)
+    for (int i = 0 ; i < 4 ; ++i)
     {
-        statusList->item(i)->setIcon(QIcon::fromTheme(QLatin1String("system-run")));
+        d->statusList->item(i)->setIcon(QIcon::fromTheme(QLatin1String("system-run")));
     }
-//    statusList->setMinimumSize(0, 0);
-//    statusList->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
-//    statusList->adjustSize();
-    statusList->setMaximumHeight(3 * statusList->sizeHintForRow(0)
-                                 + 2 * statusList->frameWidth());
-    statusLayout->addWidget(statusList);
+//    d->statusList->setMinimumSize(0, 0);
+//    d->statusList->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
+//    d->statusList->adjustSize();
+    d->statusList->setMaximumHeight(4 * d->statusList->sizeHintForRow(0) +
+                                    2 * d->statusList->frameWidth());
+    statusLayout->addWidget(d->statusList);
 
-    connect(progressTimer, SIGNAL(timeout()),
+    connect(d->progressTimer, SIGNAL(timeout()),
             this, SLOT(slotProgressTimerDone()));
 }
 
 DbShrinkDialog::~DbShrinkDialog()
 {
-    progressTimer->stop();
+    d->progressTimer->stop();
+    delete d;
 }
 
 void DbShrinkDialog::setActive(const int pos)
 {
-    active = pos;
+    d->active = pos;
 
-    if (progressTimer->isActive())
+    if (d->progressTimer->isActive())
     {
-        if (active < 0)
+        if (d->active < 0)
         {
-            progressTimer->stop();
+            d->progressTimer->stop();
         }
     }
     else
     {
-        if (active >= 0)
+        if (d->active >= 0)
         {
-            statusList->item(active)->setIcon(progressPix.frameAt(0));
-            progressTimer->start(300);
-            progressIndex = 1;
+            d->statusList->item(d->active)->setIcon(d->progressPix.frameAt(0));
+            d->progressTimer->start(300);
+            d->progressIndex = 1;
         }
     }
 }
 
 void DbShrinkDialog::setIcon(const int pos, const QIcon& icon)
 {
-    if (active == pos)
+    if (d->active == pos)
     {
-        active = -1;
+        d->active = -1;
     }
 
-    statusList->item(pos)->setIcon(icon);
+    d->statusList->item(pos)->setIcon(icon);
 }
 
 int DbShrinkDialog::exec()
 {
-    active = 0;
-    progressTimer->start(300);
+    d->active = 0;
+    d->progressTimer->start(300);
+
     return QDialog::exec();
 }
 
 void DbShrinkDialog::slotProgressTimerDone()
 {
-    if (active < 0)
+    if (d->active < 0)
     {
         return;
     }
 
-    if (progressIndex == progressPix.frameCount())
+    if (d->progressIndex == d->progressPix.frameCount())
     {
-        progressIndex = 0;
+        d->progressIndex = 0;
     }
 
-    statusList->item(active)->setIcon(progressPix.frameAt(progressIndex));
-    ++progressIndex;
+    d->statusList->item(d->active)->setIcon(d->progressPix.frameAt(d->progressIndex));
+    ++d->progressIndex;
 }
 
 } // namespace Digikam
