@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-20
  * Description : Duplicates items finder.
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2015      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,7 +38,7 @@
 
 #include "digikam_debug.h"
 #include "albummanager.h"
-#include "imagelister.h"
+#include "itemlister.h"
 #include "dnotificationwrapper.h"
 #include "digikamapp.h"
 #include "dbjobsthread.h"
@@ -48,12 +48,12 @@
 namespace Digikam
 {
 
-class DuplicatesFinder::Private
+class Q_DECL_HIDDEN DuplicatesFinder::Private
 {
 public:
 
-    Private() :
-        minSimilarity(90),
+    explicit Private()
+      : minSimilarity(90),
         maxSimilarity(100),
         albumTagRelation(0),
         searchResultRestriction(0),
@@ -73,7 +73,8 @@ public:
     SearchesDBJobsThread* job;
 };
 
-DuplicatesFinder::DuplicatesFinder(const QList<qlonglong>& imageIds, int minSimilarity, int maxSimilarity, int searchResultRestriction, ProgressItem* const parent)
+DuplicatesFinder::DuplicatesFinder(const QList<qlonglong>& imageIds, int minSimilarity, int maxSimilarity,
+                                   int searchResultRestriction, ProgressItem* const parent)
     : MaintenanceTool(QLatin1String("DuplicatesFinder"), parent),
       d(new Private)
 {
@@ -85,7 +86,8 @@ DuplicatesFinder::DuplicatesFinder(const QList<qlonglong>& imageIds, int minSimi
     d->searchResultRestriction  = searchResultRestriction;
 }
 
-DuplicatesFinder::DuplicatesFinder(const AlbumList& albums, const AlbumList& tags, int albumTagRelation,int minSimilarity, int maxSimilarity, int searchResultRestriction, ProgressItem* const parent)
+DuplicatesFinder::DuplicatesFinder(const AlbumList& albums, const AlbumList& tags, int albumTagRelation,int minSimilarity,
+                                   int maxSimilarity, int searchResultRestriction, ProgressItem* const parent)
     : MaintenanceTool(QLatin1String("DuplicatesFinder"), parent),
       d(new Private)
 {
@@ -101,7 +103,8 @@ DuplicatesFinder::DuplicatesFinder(const AlbumList& albums, const AlbumList& tag
         d->tagsIdList << a->id();
 }
 
-DuplicatesFinder::DuplicatesFinder(const int minSimilarity, int maxSimilarity, int searchResultRestriction, ProgressItem* const parent)
+DuplicatesFinder::DuplicatesFinder(const int minSimilarity, int maxSimilarity,
+                                   int searchResultRestriction, ProgressItem* const parent)
     : MaintenanceTool(QLatin1String("DuplicatesFinder"), parent),
       d(new Private)
 {
@@ -200,4 +203,4 @@ void DuplicatesFinder::slotCancel()
     MaintenanceTool::slotCancel();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
