@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-20
  * Description : Duplicates items finder.
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2015      by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef DUPLICATESFINDER_H
-#define DUPLICATESFINDER_H
+#ifndef DIGIKAM_DUPLICATES_FINDER_H
+#define DIGIKAM_DUPLICATES_FINDER_H
 
 // Qt includes
 
@@ -46,13 +46,28 @@ public:
 
     /** Version to find all duplicates in the set of images
      */
-    DuplicatesFinder(const QList<qlonglong>& imageIds, int minSimilarity = 90, int maxSimilarity = 100, int searchResultRestriction = 0, ProgressItem* const parent = 0);
+    explicit DuplicatesFinder(const QList<qlonglong>& imageIds,
+                              int minSimilarity = 90,
+                              int maxSimilarity = 100,
+                              int searchResultRestriction = 0,
+                              ProgressItem* const parent = 0);
+
     /** Version to find all duplicates over a specific list to PAlbums and TAlbums
      */
-    DuplicatesFinder(const AlbumList& albums, const AlbumList& tags, int albumTagRelation = 0, int minSimilarity = 90, int maxSimilarity = 100, int searchResultRestriction = 0, ProgressItem* const parent = 0);
+    DuplicatesFinder(const AlbumList& albums,
+                     const AlbumList& tags,
+                     int albumTagRelation = 0,
+                     int minSimilarity = 90,
+                     int maxSimilarity = 100,
+                     int searchResultRestriction = 0,
+                     ProgressItem* const parent = 0);
+
     /** Version to find all duplicates over whole collections
      */
-    explicit DuplicatesFinder(const int minSimilarity = 90, int maxSimilarity = 100, int searchResultRestriction = 0, ProgressItem* const parent = 0);
+    explicit DuplicatesFinder(const int minSimilarity = 90,
+                              int maxSimilarity = 100,
+                              int searchResultRestriction = 0,
+                              ProgressItem* const parent = 0);
     ~DuplicatesFinder();
 
 private Q_SLOTS:
@@ -71,4 +86,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* DUPLICATESFINDER_H */
+#endif // DIGIKAM_DUPLICATES_FINDER_H
