@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-07-18
  * Description : batch face detection
  *
  * Copyright (C) 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -47,15 +47,16 @@
 #include "coredb.h"
 #include "album.h"
 #include "albummanager.h"
+#include "albumpointer.h"
 #include "facepipeline.h"
 #include "facescansettings.h"
-#include "imageinfo.h"
-#include "imageinfojob.h"
+#include "iteminfo.h"
+#include "iteminfojob.h"
 
 namespace Digikam
 {
 
-class BenchmarkMessageDisplay : public QWidget
+class Q_DECL_HIDDEN BenchmarkMessageDisplay : public QWidget
 {
 public:
 
@@ -86,32 +87,23 @@ public:
 
 // --------------------------------------------------------------------------
 
-class FacesDetector::Private
+class Q_DECL_HIDDEN FacesDetector::Private
 {
 public:
 
-    Private() :
+    explicit Private() :
         benchmark(false),
-        total(0),
-        progressValue(0),
-        currentProgressChunk(0),
-        currentScheduled(0),
-        currentFinished(0)
+        useItemInfos(false)
     {
     }
 
-    bool                benchmark;
+    bool                 benchmark;
+    bool                 useItemInfos;
 
-    int                 total;
-
-    AlbumPointerList<>  albumTodoList;
-    ImageInfoJob        albumListing;
-    FacePipeline        pipeline;
-    QMap<Album*,double> relativeProgressValue;
-    double              progressValue;
-    double              currentProgressChunk;
-    int                 currentScheduled;
-    int                 currentFinished;
+    AlbumPointerList<>   albumTodoList;
+    ItemInfoList        infoTodoList;
+    ItemInfoJob         albumListing;
+    FacePipeline         pipeline;
 };
 
 FacesDetector::FacesDetector(const FaceScanSettings& settings, ProgressItem* const parent)
@@ -133,7 +125,7 @@ FacesDetector::FacesDetector(const FaceScanSettings& settings, ProgressItem* con
     {
         d->benchmark = true;
         d->pipeline.plugDatabaseFilter(FacePipeline::ScanAll);
-        d->pipeline.plugPreviewLoader();
+        d->pipeline.plugFacePreviewLoader();
 
         if (settings.useFullCpu)
         {
@@ -178,7 +170,7 @@ FacesDetector::FacesDetector(const FaceScanSettings& settings, ProgressItem* con
         }
 
         d->pipeline.plugDatabaseFilter(filterMode);
-        d->pipeline.plugPreviewLoader();
+        d->pipeline.plugFacePreviewLoader();
 
         if (settings.useFullCpu)
         {
@@ -192,7 +184,9 @@ FacesDetector::FacesDetector(const FaceScanSettings& settings, ProgressItem* con
         if (settings.task == FaceScanSettings::DetectAndRecognize)
         {
             //d->pipeline.plugRerecognizingDatabaseFilter();
+            qCDebug(DIGIKAM_GENERAL_LOG) << "recognize algorithm: " << (int)settings.recognizeAlgorithm;
             d->pipeline.plugFaceRecognizer();
+            d->pipeline.activeFaceRecognizer(settings.recognizeAlgorithm);
         }
 
         d->pipeline.plugDatabaseWriter(writeMode);
@@ -203,13 +197,14 @@ FacesDetector::FacesDetector(const FaceScanSettings& settings, ProgressItem* con
     {
         d->pipeline.plugRerecognizingDatabaseFilter();
         d->pipeline.plugFaceRecognizer();
+        d->pipeline.activeFaceRecognizer(settings.recognizeAlgorithm);
         d->pipeline.plugDatabaseWriter(FacePipeline::NormalWrite);
         d->pipeline.setDetectionAccuracy(settings.accuracy);
         d->pipeline.construct();
     }
 
-    connect(&d->albumListing, SIGNAL(signalItemsInfo(ImageInfoList)),
-            this, SLOT(slotItemsInfo(ImageInfoList)));
+    connect(&d->albumListing, SIGNAL(signalItemsInfo(ItemInfoList)),
+            this, SLOT(slotItemsInfo(ItemInfoList)));
 
     connect(&d->albumListing, SIGNAL(signalCompleted()),
             this, SLOT(slotContinueAlbumListing()));
@@ -220,20 +215,26 @@ FacesDetector::FacesDetector(const FaceScanSettings& settings, ProgressItem* con
     connect(&d->pipeline, SIGNAL(processed(FacePipelinePackage)),
             this, SLOT(slotShowOneDetected(FacePipelinePackage)));
 
-    connect(&d->pipeline, SIGNAL(skipped(QList<ImageInfo>)),
-            this, SLOT(slotImagesSkipped(QList<ImageInfo>)));
+    connect(&d->pipeline, SIGNAL(skipped(QList<ItemInfo>)),
+            this, SLOT(slotImagesSkipped(QList<ItemInfo>)));
 
     connect(this, SIGNAL(progressItemCanceled(ProgressItem*)),
             this, SLOT(slotCancel()));
 
-    if (settings.albums.isEmpty() || settings.task == FaceScanSettings::RetrainAll)
+    if ((settings.albums.isEmpty() && settings.infos.isEmpty()) ||
+         settings.task == FaceScanSettings::RetrainAll)
     {
         d->albumTodoList = AlbumManager::instance()->allPAlbums();
     }
-    else
+    else if (!settings.albums.isEmpty())
     {
         d->albumTodoList = settings.albums;
     }
+    else
+    {
+        d->infoTodoList  = settings.infos;
+        d->useItemInfos = true;
+    }
 }
 
 FacesDetector::~FacesDetector()
@@ -246,10 +247,22 @@ void FacesDetector::slotStart()
     MaintenanceTool::slotStart();
 
     setThumbnail(QIcon::fromTheme(QLatin1String("edit-image-face-show")).pixmap(22));
+
+    if (d->useItemInfos)
+    {
+        int total = d->infoTodoList.count();
+        qCDebug(DIGIKAM_GENERAL_LOG) << "Total is" << total;
+
+        setTotalItems(total);
+
+        return slotItemsInfo(d->infoTodoList);
+    }
+
     setUsesBusyIndicator(true);
 
     // get total count, cached by AlbumManager
-    QMap<int, int> palbumCounts, talbumCounts;
+    QMap<int, int> palbumCounts;
+    QMap<int, int> talbumCounts;
     bool hasPAlbums = false;
     bool hasTAlbums = false;
 
@@ -282,49 +295,49 @@ void FacesDetector::slotStart()
         QApplication::restoreOverrideCursor();
     }
 
-    // first, we use the relativeProgressValue map to store absolute counts
+    // first, we use the progressValueMap map to store absolute counts
 
-    foreach (Album* const album, d->albumTodoList)
+    QMap<Album*, int> progressValueMap;
+
+    foreach(Album* const album, d->albumTodoList)
     {
         if (album->type() == Album::PHYSICAL)
         {
-            d->relativeProgressValue[album] = palbumCounts.value(album->id());
+            progressValueMap[album] = palbumCounts.value(album->id());
         }
         else
         {
             // this is possibly broken of course because we do not know if images have multiple tags,
             // but there's no better solution without expensive operation
-            d->relativeProgressValue[album] = talbumCounts.value(album->id());
+            progressValueMap[album] = talbumCounts.value(album->id());
         }
     }
 
     // second, calculate (approximate) overall sum
 
-    d->total = 0;
+    int total = 0;
 
-    foreach (double count, d->relativeProgressValue)
+    foreach(int count, progressValueMap)
     {
-        d->total += (int)count;
+        total += count;
     }
 
-    d->total = qMax(1, d->total);
-    qCDebug(DIGIKAM_GENERAL_LOG) << "Total is" << d->total;
-
-    // third, break absolute to relative values
-
-    for (QMap<Album*,double>::iterator it = d->relativeProgressValue.begin(); it != d->relativeProgressValue.end(); ++it)
-    {
-        it.value() /= double(d->total);
-    }
+    total = qMax(1, total);
+    qCDebug(DIGIKAM_GENERAL_LOG) << "Total is" << total;
 
     setUsesBusyIndicator(false);
-    setTotalItems(d->total);
+    setTotalItems(total);
 
     slotContinueAlbumListing();
 }
 
 void FacesDetector::slotContinueAlbumListing()
 {
+    if (d->useItemInfos)
+    {
+        return slotDone();
+    }
+
     qCDebug(DIGIKAM_GENERAL_LOG) << d->albumListing.isRunning() << !d->pipeline.hasFinished();
 
     // we get here by the finished signal from both, and want both to have finished to continue
@@ -350,7 +363,7 @@ void FacesDetector::slotContinueAlbumListing()
     d->albumListing.allItemsFromAlbum(album);
 }
 
-void FacesDetector::slotItemsInfo(const ImageInfoList& items)
+void FacesDetector::slotItemsInfo(const ItemInfoList& items)
 {
     d->pipeline.process(items);
 }
@@ -374,7 +387,7 @@ void FacesDetector::slotCancel()
     MaintenanceTool::slotCancel();
 }
 
-void FacesDetector::slotImagesSkipped(const QList<ImageInfo>& infos)
+void FacesDetector::slotImagesSkipped(const QList<ItemInfo>& infos)
 {
     advance(infos.size());
 }
