@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-07-18
  * Description : batch face detection
  *
  * Copyright (C) 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef BATCHFACESDETECTOR_H
-#define BATCHFACESDETECTOR_H
+#ifndef DIGIKAM_FACES_DETECTOR_H
+#define DIGIKAM_FACES_DETECTOR_H
 
 // Qt includes
 
@@ -39,8 +39,8 @@ namespace Digikam
 class DImg;
 class FacePipelinePackage;
 class FaceScanSettings;
-class ImageInfo;
-class ImageInfoList;
+class ItemInfo;
+class ItemInfoList;
 
 class FacesDetector : public MaintenanceTool
 {
@@ -55,8 +55,8 @@ private Q_SLOTS:
 
     void slotStart();
     void slotContinueAlbumListing();
-    void slotItemsInfo(const ImageInfoList&);
-    void slotImagesSkipped(const QList<ImageInfo>&);
+    void slotItemsInfo(const ItemInfoList&);
+    void slotImagesSkipped(const QList<ItemInfo>&);
     void slotShowOneDetected(const FacePipelinePackage&);
     void slotDone();
     void slotCancel();
@@ -69,4 +69,4 @@ private:
 
 } // namespace Digikam
 
-#endif // BATCHFACESDETECTOR_H
+#endif // DIGIKAM_FACES_DETECTOR_H
