@@ -1,12 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-16
  * Description : fingerprints generator
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C)      2018 by Mario Frank    <mario dot frank at uni minus potsdam dot de>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -26,6 +27,7 @@
 
 // Qt includes
 
+#include <QApplication>
 #include <QString>
 #include <QIcon>
 
@@ -45,20 +47,18 @@
 namespace Digikam
 {
 
-class FingerPrintsGenerator::Private
+class Q_DECL_HIDDEN FingerPrintsGenerator::Private
 {
 public:
 
-    Private() :
-        rebuildAll(true),
+    explicit Private()
+      : rebuildAll(true),
         thread(0)
     {
     }
 
     bool               rebuildAll;
 
-    QStringList        allPicturesPath;
-
     AlbumList          albumList;
 
     MaintenanceThread* thread;
@@ -102,54 +102,41 @@ void FingerPrintsGenerator::slotStart()
 {
     MaintenanceTool::slotStart();
 
+    QApplication::setOverrideCursor(Qt::WaitCursor);
+
     if (d->albumList.isEmpty())
     {
         d->albumList = AlbumManager::instance()->allPAlbums();
     }
 
-    QStringList dirty = CoreDbAccess().db()->getDirtyOrMissingFingerprintURLs();
+    // Get all item IDs from albums.
 
-    // Get all digiKam albums collection pictures path, depending of d->rebuildAll flag.
+    QList<qlonglong> itemIds;
 
-    for (AlbumList::ConstIterator it = d->albumList.constBegin();
-         !canceled() && (it != d->albumList.constEnd()); ++it)
+    for (AlbumList::ConstIterator it = d->albumList.constBegin() ;
+         !canceled() && (it != d->albumList.constEnd()) ; ++it)
     {
-        QStringList aPaths;
-
         if ((*it)->type() == Album::PHYSICAL)
         {
-            aPaths = CoreDbAccess().db()->getItemURLsInAlbum((*it)->id());
+            itemIds << CoreDbAccess().db()->getItemIDsInAlbum((*it)->id());
         }
         else if ((*it)->type() == Album::TAG)
         {
-            aPaths = CoreDbAccess().db()->getItemURLsInTag((*it)->id());
-        }
-
-        if (!d->rebuildAll)
-        {
-            foreach(const QString& path, aPaths)
-            {
-                if (dirty.contains(path))
-                {
-                    d->allPicturesPath += path;
-                }
-            }
-        }
-        else
-        {
-            d->allPicturesPath += aPaths;
+            itemIds << CoreDbAccess().db()->getItemIDsInTag((*it)->id());
         }
     }
 
-    if (d->allPicturesPath.isEmpty())
+    QApplication::restoreOverrideCursor();
+
+    if (itemIds.isEmpty())
     {
         slotDone();
         return;
     }
 
-    setTotalItems(d->allPicturesPath.count());
+    setTotalItems(itemIds.count());
 
-    d->thread->generateFingerprints(d->allPicturesPath);
+    d->thread->generateFingerprints(itemIds, d->rebuildAll);
     d->thread->start();
 }
 
@@ -167,4 +154,4 @@ void FingerPrintsGenerator::slotDone()
     MaintenanceTool::slotDone();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
