@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-05-16
  * Description : finger-prints generator
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef FINGERPRINTSGENERATOR_H
-#define FINGERPRINTSGENERATOR_H
+#ifndef DIGIKAM_FINGERPRINTS_GENERATOR_H
+#define DIGIKAM_FINGERPRINTS_GENERATOR_H
 
 // Qt includes
 
@@ -68,6 +68,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* FINGERPRINTSGENERATOR_H */
+#endif // DIGIKAM_FINGERPRINTS_GENERATOR_H
