@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-14
  * Description : Thread actions task for finger-prints generator.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,6 +25,7 @@
 
 // Qt includes
 #include <QQueue>
+#include <QIcon>
 
 // Local includes
 
@@ -34,20 +35,23 @@
 #include "haariface.h"
 #include "previewloadthread.h"
 #include "maintenancedata.h"
+#include "similaritydb.h"
+#include "similaritydbaccess.h"
 
 namespace Digikam
 {
 
-class FingerprintsTask::Private
+class Q_DECL_HIDDEN FingerprintsTask::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : data(0)
     {
     }
 
     MaintenanceData* data;
+    QImage           okImage;
 };
 
 // -------------------------------------------------------
@@ -56,6 +60,8 @@ FingerprintsTask::FingerprintsTask()
     : ActionJob(),
       d(new Private)
 {
+    QPixmap okPix = QIcon::fromTheme(QLatin1String("dialog-ok")).pixmap(22, 22);
+    d->okImage    = okPix.toImage();
 }
 
 FingerprintsTask::~FingerprintsTask()
@@ -79,29 +85,41 @@ void FingerprintsTask::run()
             return;
         }
 
-        QString path = d->data->getImagePath();
+        qlonglong id = d->data->getImageId();
 
-        if (path.isEmpty())
+        if (id == -1)
         {
             break;
         }
 
-        qCDebug(DIGIKAM_GENERAL_LOG) << "Updating fingerprints for file: " << path ;
+        ItemInfo info(id);
 
-        DImg dimg = PreviewLoadThread::loadFastSynchronously(path, HaarIface::preferredSize());
-
-        if (!dimg.isNull())
+        if ((info.isVisible() && info.category() == DatabaseItem::Category::Image) &&
+            (d->data->getRebuildAllFingerprints()                                  ||
+             SimilarityDbAccess().db()->hasDirtyOrMissingFingerprint(info)))
         {
-            // compute Haar fingerprint and store it to DB
-            HaarIface haarIface;
-            haarIface.indexImage(path, dimg);
-        }
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Updating fingerprints for file:" << info.filePath();
 
-        QImage qimg = dimg.smoothScale(22, 22, Qt::KeepAspectRatio).copyQImage();
-        emit signalFinished(qimg);
+            DImg dimg = PreviewLoadThread::loadFastSynchronously(info.filePath(),
+                                                                 HaarIface::preferredSize());
+
+            if (!dimg.isNull())
+            {
+                // compute Haar fingerprint and store it to DB
+                HaarIface haarIface;
+                haarIface.indexImage(info.filePath(), dimg);
+            }
+
+            QImage qimg = dimg.smoothScale(22, 22, Qt::KeepAspectRatio).copyQImage();
+            emit signalFinished(qimg);
+        }
+        else
+        {
+            emit signalFinished(d->okImage);
+        }
     }
 
     emit signalDone();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
