@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-14
  * Description : Thread actions task for finger-prints generator.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef FINGERPRINTS_TASK_H
-#define FINGERPRINTS_TASK_H
+#ifndef DIGIKAM_FINGERPRINTS_TASK_H
+#define DIGIKAM_FINGERPRINTS_TASK_H
 
 // Qt includes
 
@@ -46,7 +46,7 @@ class FingerprintsTask : public ActionJob
 
 public:
 
-    FingerprintsTask();
+    explicit FingerprintsTask();
     ~FingerprintsTask();
 
     void setMaintenanceData(MaintenanceData* const data=0);
@@ -65,6 +65,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* FINGERPRINTS_TASK_H */
+#endif // DIGIKAM_FINGERPRINTS_TASK_H
