@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-19
  * Description : image quality sorter
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGEQUALITYSORTER_H
-#define IMAGEQUALITYSORTER_H
+#ifndef DIGIKAM_IMAGE_QUALITY_SORTER_H
+#define DIGIKAM_IMAGE_QUALITY_SORTER_H
 
 // Qt includes
 
@@ -32,7 +32,7 @@
 
 #include "album.h"
 #include "maintenancetool.h"
-#include "imagequalitysettings.h"
+#include "imagequalitycontainer.h"
 
 class QImage;
 
@@ -55,8 +55,9 @@ public:
 
     /** Constructor using AlbumList as argument. If list is empty, whole Albums collection is processed.
      */
-    explicit ImageQualitySorter(QualityScanMode mode, const AlbumList& list=AlbumList(),
-                                const ImageQualitySettings& quality=ImageQualitySettings(),
+    explicit ImageQualitySorter(QualityScanMode mode,
+                                const AlbumList& list=AlbumList(),
+                                const ImageQualityContainer& quality=ImageQualityContainer(),
                                 ProgressItem* const parent = 0);
     ~ImageQualitySorter();
 
@@ -78,6 +79,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* IMAGEQUALITYSORTER_H */
+#endif // DIGIKAM_IMAGE_QUALITY_SORTER_H
