@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-30
  * Description : maintenance dialog
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,7 +35,6 @@
 #include <QStandardPaths>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
-#include <QPushButton>
 
 // KDE includes
 
@@ -50,7 +49,7 @@
 #include "setup.h"
 #include "albumselectors.h"
 #include "facescansettings.h"
-#include "imagequalitysettings.h"
+#include "imagequalitycontainer.h"
 #include "metadatasynchronizer.h"
 #include "dxmlguiwindow.h"
 #include "applicationsettings.h"
@@ -59,7 +58,7 @@
 namespace Digikam
 {
 
-class MaintenanceDlg::Private
+class Q_DECL_HIDDEN MaintenanceDlg::Private
 {
 public:
 
@@ -79,8 +78,8 @@ public:
 
 public:
 
-    Private() :
-        buttons(0),
+    explicit Private()
+      : buttons(0),
         logo(0),
         title(0),
         scanThumbs(0),
@@ -183,7 +182,13 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
     : QDialog(parent),
       d(new Private)
 {
+    setWindowFlags((windowFlags() & ~Qt::Dialog) |
+                   Qt::Window                    |
+                   Qt::WindowCloseButtonHint     |
+                   Qt::WindowMinMaxButtonsHint);
+
     setWindowTitle(i18n("Maintenance"));
+    setModal(true);
 
     d->buttons = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->buttons->button(QDialogButtonBox::Cancel)->setDefault(true);
@@ -209,7 +214,7 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
 
     // --------------------------------------------------------------------------------------
 
-    d->expanderBox->insertItem(Private::NewItems, new QLabel(i18n("<qt>No option<br>"
+    d->expanderBox->insertItem(Private::NewItems, new QLabel(i18n("<qt>No option<br/>"
                                "<i>Note: only Albums Collection are processed by this tool.</i></qt>")),
                                QIcon::fromTheme(QLatin1String("view-refresh")), i18n("Scan for new items"), QLatin1String("NewItems"), false);
     d->expanderBox->setCheckBoxVisible(Private::NewItems, true);
@@ -223,8 +228,8 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
     d->cleanThumbsDb           = new QCheckBox(i18n("Also clean up the thumbnail database."), d->vbox3);
     d->cleanFacesDb            = new QCheckBox(i18n("Also clean up the faces database."), d->vbox3);
     d->shrinkDatabases         = new QCheckBox(i18n("Also shrink all databases if possible."), d->vbox3);
-    d->shrinkDatabases->setToolTip(i18n("This option leads to the vacuuming (shrinking) of the databases."
-                                        " Vacuuming is supported both for SQLite and MySQL."));
+    d->shrinkDatabases->setToolTip(i18n("This option leads to the vacuuming (shrinking) of the databases. "
+                                        "Vacuuming is supported both for SQLite and MySQL."));
     d->expanderBox->insertItem(Private::DbCleanup, d->vbox3,
                                QIcon::fromTheme(QLatin1String("run-build")),
                                i18n("Perform database cleaning"), QLatin1String("DbCleanup"), false);
@@ -420,13 +425,15 @@ MaintenanceSettings MaintenanceDlg::settings() const
     prm.duplicates                          = d->expanderBox->isChecked(Private::Duplicates);
     prm.minSimilarity                       = d->similarityRange->minValue();
     prm.maxSimilarity                       = d->similarityRange->maxValue();
-    prm.duplicatesRestriction               = (HaarIface::DuplicatesSearchRestrictions)d->searchResultRestriction->itemData(d->searchResultRestriction->currentIndex()).toInt();
+    prm.duplicatesRestriction               = (HaarIface::DuplicatesSearchRestrictions)
+                                                  d->searchResultRestriction->itemData(d->searchResultRestriction->currentIndex()).toInt();
     prm.faceManagement                      = d->expanderBox->isChecked(Private::FaceManagement);
-    prm.faceSettings.alreadyScannedHandling = (FaceScanSettings::AlreadyScannedHandling)d->faceScannedHandling->itemData(d->faceScannedHandling->currentIndex()).toInt();
+    prm.faceSettings.alreadyScannedHandling = (FaceScanSettings::AlreadyScannedHandling)
+                                                  d->faceScannedHandling->itemData(d->faceScannedHandling->currentIndex()).toInt();
     prm.faceSettings.albums                 = d->albumSelectors->selectedAlbums();
     prm.qualitySort                         = d->expanderBox->isChecked(Private::ImageQualitySorter);
     prm.qualityScanMode                     = d->qualityScanMode->itemData(d->qualityScanMode->currentIndex()).toInt();
-    ImageQualitySettings imgq;
+    ImageQualityContainer imgq;
     imgq.readFromConfig();
     prm.quality                             = imgq;
     prm.metadataSync                        = d->expanderBox->isChecked(Private::MetadataSync);
@@ -443,8 +450,8 @@ void MaintenanceDlg::readSettings()
 
     MaintenanceSettings prm;
 
-    d->useMutiCoreCPU->setChecked(group.readEntry(d->configUseMutiCoreCPU,                               prm.useMutiCoreCPU));
-    d->expanderBox->setChecked(Private::NewItems,           group.readEntry(d->configNewItems,           prm.newItems));
+    d->useMutiCoreCPU->setChecked(group.readEntry(d->configUseMutiCoreCPU,                                  prm.useMutiCoreCPU));
+    d->expanderBox->setChecked(Private::NewItems,           group.readEntry(d->configNewItems,              prm.newItems));
 
     d->expanderBox->setChecked(Private::DbCleanup,          group.readEntry(d->configCleanupDatabase,       prm.databaseCleanup));
     d->cleanThumbsDb->setChecked(group.readEntry(d->configCleanupThumbDatabase,                             prm.cleanThumbDb));
@@ -568,4 +575,4 @@ void MaintenanceDlg::slotHelp()
     DXmlGuiWindow::openHandbook();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
