@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-30
  * Description : maintenance dialog
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef MAINTENANCEDLG_H
-#define MAINTENANCEDLG_H
+#ifndef DIGIKAM_MAINTENANCE_DLG_H
+#define DIGIKAM_MAINTENANCE_DLG_H
 
 // Qt includes
 
@@ -66,6 +66,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif  // MAINTENANCEDLG_H
+#endif // DIGIKAM_MAINTENANCE_DLG_H
