@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-31
  * Description : maintenance manager
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -53,11 +53,11 @@
 namespace Digikam
 {
 
-class MaintenanceMngr::Private
+class Q_DECL_HIDDEN MaintenanceMngr::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         running               = false;
         newItemsFinder        = 0;
@@ -195,9 +195,10 @@ void MaintenanceMngr::stage1()
 
             foreach(Album* const a, d->settings.albums)
             {
-                PAlbum* const pa = dynamic_cast<PAlbum*>(a);
-                if (pa)
-                    paths << pa->folderPath();
+                PAlbum* const palbum = dynamic_cast<PAlbum*>(a);
+
+                if (palbum)
+                    paths << palbum->folderPath();
             }
 
             d->newItemsFinder = new NewItemsFinder(NewItemsFinder::ScheduleCollectionScan, paths);
@@ -372,4 +373,4 @@ void MaintenanceMngr::cancel()
     emit signalComplete();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
