@@ -1,12 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-09
  * Description : Thread actions manager for maintenance tools.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2017-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,7 +36,7 @@
 #include "thumbstask.h"
 #include "fingerprintstask.h"
 #include "imagequalitytask.h"
-#include "imagequalitysettings.h"
+#include "imagequalitycontainer.h"
 #include "databasetask.h"
 #include "maintenancedata.h"
 
@@ -46,6 +47,8 @@ MaintenanceThread::MaintenanceThread(QObject* const parent)
     : ActionThreadBase(parent),
       data(new MaintenanceData)
 {
+    setObjectName(QLatin1String("MaintenanceThread"));
+
     connect(this, SIGNAL(finished()),
             this, SLOT(slotThreadFinished()));
 }
@@ -70,13 +73,13 @@ void MaintenanceThread::setUseMultiCore(const bool b)
     }
 }
 
-void MaintenanceThread::syncMetadata(const ImageInfoList& items, MetadataSynchronizer::SyncDirection dir, bool tagsOnly)
+void MaintenanceThread::syncMetadata(const ItemInfoList& items, MetadataSynchronizer::SyncDirection dir, bool tagsOnly)
 {
     ActionJobCollection collection;
 
-    data->setImageInfos(items);
+    data->setItemInfos(items);
 
-    for (int i = 1; i <= maximumNumberOfThreads(); i++)
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
     {
         MetadataTask* const t = new MetadataTask();
         t->setTagsOnly(tagsOnly);
@@ -100,7 +103,7 @@ void MaintenanceThread::generateThumbs(const QStringList& paths)
 
     data->setImagePaths(paths);
 
-    for (int i = 1; i <= maximumNumberOfThreads(); i++)
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
     {
         ThumbsTask* const t = new ThumbsTask();
 
@@ -117,13 +120,14 @@ void MaintenanceThread::generateThumbs(const QStringList& paths)
     appendJobs(collection);
 }
 
-void MaintenanceThread::generateFingerprints(const QStringList& paths)
+void MaintenanceThread::generateFingerprints(const QList<qlonglong>& itemIds, bool rebuildAll)
 {
     ActionJobCollection collection;
 
-    data->setImagePaths(paths);
+    data->setImageIds(itemIds);
+    data->setRebuildAllFingerprints(rebuildAll);
 
-    for (int i = 1; i <= (maximumNumberOfThreads()); i++)
+    for (int i = 1 ; i <= (maximumNumberOfThreads()) ; ++i)
     {
         FingerprintsTask* const t = new FingerprintsTask();
 
@@ -134,19 +138,19 @@ void MaintenanceThread::generateFingerprints(const QStringList& paths)
 
         collection.insert(t, 0);
 
-        qCDebug(DIGIKAM_GENERAL_LOG) << "Creating a fingerprints task for generating fingerprints";// for items with a chunk size of " << chunk.size();
+        qCDebug(DIGIKAM_GENERAL_LOG) << "Creating a fingerprints task for generating fingerprints";
     }
 
     appendJobs(collection);
 }
 
-void MaintenanceThread::sortByImageQuality(const QStringList& paths, const ImageQualitySettings& quality)
+void MaintenanceThread::sortByImageQuality(const QStringList& paths, const ImageQualityContainer& quality)
 {
     ActionJobCollection collection;
 
     data->setImagePaths(paths);
 
-    for (int i = 1; i <= maximumNumberOfThreads(); i++)
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
     {
         ImageQualityTask* const t = new ImageQualityTask();
         t->setQuality(quality);
@@ -166,13 +170,13 @@ void MaintenanceThread::sortByImageQuality(const QStringList& paths, const Image
     appendJobs(collection);
 }
 
-void MaintenanceThread::computeDatabaseJunk(bool thumbsDb, bool facesDb)
+void MaintenanceThread::computeDatabaseJunk(bool thumbsDb, bool facesDb, bool similarityDb)
 {
     ActionJobCollection collection;
 
     DatabaseTask* const t = new DatabaseTask();
     t->setMode(DatabaseTask::Mode::ComputeDatabaseJunk);
-    t->computeDatabaseJunk(thumbsDb, facesDb);
+    t->computeDatabaseJunk(thumbsDb, facesDb, similarityDb);
 
     connect(t, SIGNAL(signalFinished()),
             this, SIGNAL(signalAdvance()));
@@ -180,8 +184,8 @@ void MaintenanceThread::computeDatabaseJunk(bool thumbsDb, bool facesDb)
     connect(t,SIGNAL(signalAddItemsToProcess(int)),
             this, SIGNAL(signalAddItemsToProcess(int)));
 
-    connect(t,SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>)),
-            this, SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>)));
+    connect(t,SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>,QList<qlonglong>)),
+            this, SIGNAL(signalData(QList<qlonglong>,QList<int>,QList<Identity>,QList<qlonglong>)));
 
     collection.insert(t, 0);
 
@@ -194,7 +198,7 @@ void MaintenanceThread::cleanCoreDb(const QList<qlonglong>& imageIds)
 
     data->setImageIds(imageIds);
 
-    for (int i = 1; i <= maximumNumberOfThreads(); i++)
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
     {
         DatabaseTask* const t = new DatabaseTask();
 
@@ -218,7 +222,7 @@ void MaintenanceThread::cleanThumbsDb(const QList<int>& thumbnailIds)
 
     data->setThumbnailIds(thumbnailIds);
 
-    for (int i = 1; i <= maximumNumberOfThreads(); i++)
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
     {
         DatabaseTask* const t = new DatabaseTask();
 
@@ -242,7 +246,7 @@ void MaintenanceThread::cleanFacesDb(const QList<Identity>& staleIdentities)
 
     data->setIdentities(staleIdentities);
 
-    for (int i = 1; i <= maximumNumberOfThreads(); i++)
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
     {
         DatabaseTask* const t = new DatabaseTask();
 
@@ -260,6 +264,33 @@ void MaintenanceThread::cleanFacesDb(const QList<Identity>& staleIdentities)
     appendJobs(collection);
 }
 
+void MaintenanceThread::cleanSimilarityDb(const QList<qlonglong>& imageIds)
+{
+    ActionJobCollection collection;
+
+    data->setSimilarityImageIds(imageIds);
+
+    for (int i = 1 ; i <= maximumNumberOfThreads() ; ++i)
+    {
+        DatabaseTask* const t = new DatabaseTask();
+
+        t->setMaintenanceData(data);
+        t->setMode(DatabaseTask::Mode::CleanSimilarityDb);
+
+        connect(t, SIGNAL(signalFinished()),
+                this, SIGNAL(signalAdvance()));
+
+        connect(this, SIGNAL(signalCanceled()),
+                t, SLOT(slotCancel()), Qt::QueuedConnection);
+
+        collection.insert(t, 0);
+
+        qCDebug(DIGIKAM_GENERAL_LOG) << "Creating a database task for removing stale image id entries from similarity db.";
+    }
+
+    appendJobs(collection);
+}
+
 void MaintenanceThread::shrinkDatabases()
 {
     ActionJobCollection collection;
