@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-02-02
  * Description : maintenance tool
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef MAINTENANCETOOL_H
-#define MAINTENANCETOOL_H
+#ifndef DIGIKAM_MAINTENANCE_TOOL_H
+#define DIGIKAM_MAINTENANCE_TOOL_H
 
 // Qt includes
 
@@ -79,4 +79,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* MAINTENANCETOOL_H */
+#endif // DIGIKAM_MAINTENANCE_TOOL_H
