@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-22-01
  * Description : batch sync pictures metadata with database
  *
- * Copyright (C) 2007-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -37,18 +37,18 @@
 // Local includes
 
 #include "albummanager.h"
-#include "imageinfojob.h"
+#include "iteminfojob.h"
 #include "maintenancethread.h"
 
 namespace Digikam
 {
 
-class MetadataSynchronizer::Private
+class Q_DECL_HIDDEN MetadataSynchronizer::Private
 {
 public:
 
-    Private() :
-        imageInfoJob(0),
+    explicit Private()
+      : imageInfoJob(0),
         thread(0),
         direction(MetadataSynchronizer::WriteFromDatabaseToFile),
         tagsOnly(false)
@@ -58,9 +58,9 @@ public:
     AlbumList                           palbumList;
     AlbumList::Iterator                 albumsIt;
 
-    ImageInfoJob*                       imageInfoJob;
+    ItemInfoJob*                       imageInfoJob;
 
-    ImageInfoList                       imageInfoList;
+    ItemInfoList                       imageInfoList;
 
     MaintenanceThread*                  thread;
 
@@ -80,7 +80,7 @@ MetadataSynchronizer::MetadataSynchronizer(const AlbumList& list, SyncDirection
     init(direction);
 }
 
-MetadataSynchronizer::MetadataSynchronizer(const ImageInfoList& list, SyncDirection direction, ProgressItem* const parent)
+MetadataSynchronizer::MetadataSynchronizer(const ItemInfoList& list, SyncDirection direction, ProgressItem* const parent)
     : MaintenanceTool(QLatin1String("MetadataSynchronizer"), parent),
       d(new Private)
 {
@@ -115,10 +115,10 @@ void MetadataSynchronizer::setUseMultiCoreCPU(bool b)
 void MetadataSynchronizer::slotStart()
 {
     MaintenanceTool::slotStart();
-    d->imageInfoJob = new ImageInfoJob;
+    d->imageInfoJob = new ItemInfoJob;
 
-    connect(d->imageInfoJob, SIGNAL(signalItemsInfo(ImageInfoList)),
-            this, SLOT(slotAlbumParsed(ImageInfoList)));
+    connect(d->imageInfoJob, SIGNAL(signalItemsInfo(ItemInfoList)),
+            this, SLOT(slotAlbumParsed(ItemInfoList)));
 
     connect(d->imageInfoJob, SIGNAL(signalCompleted()),
             this, SLOT(slotOneAlbumIsComplete()));
@@ -170,7 +170,7 @@ void MetadataSynchronizer::processOneAlbum()
     d->imageInfoJob->allItemsFromAlbum(*d->albumsIt);
 }
 
-void MetadataSynchronizer::slotAlbumParsed(const ImageInfoList& list)
+void MetadataSynchronizer::slotAlbumParsed(const ItemInfoList& list)
 {
     d->imageInfoList << list;
 }
@@ -215,4 +215,4 @@ void MetadataSynchronizer::slotAdvance()
     advance(1);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
