@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-22-01
  * Description : batch sync pictures metadata with database
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef METADATASYNCHRONIZER_H
-#define METADATASYNCHRONIZER_H
+#ifndef DIGIKAM_METADATA_SYNCHRONIZER_H
+#define DIGIKAM_METADATA_SYNCHRONIZER_H
 
 // Qt includes
 
@@ -31,7 +31,7 @@
 // Local includes
 
 #include "album.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "maintenancetool.h"
 
 namespace Digikam
@@ -53,13 +53,13 @@ public:
 
 public:
 
-    /** Constructor which sync all pictures metadata from an Albums list. If list is empty, whole Albums collection is procressed.
+    /** Constructor which sync all pictures metadata from an Albums list. If list is empty, whole Albums collection is processed.
      */
     explicit MetadataSynchronizer(const AlbumList& list=AlbumList(), SyncDirection direction = WriteFromDatabaseToFile, ProgressItem* const parent = 0);
 
     /** Constructor which sync all pictures metadata from an Images list
      */
-    explicit MetadataSynchronizer(const ImageInfoList& list, SyncDirection = WriteFromDatabaseToFile, ProgressItem* const parent = 0);
+    explicit MetadataSynchronizer(const ItemInfoList& list, SyncDirection = WriteFromDatabaseToFile, ProgressItem* const parent = 0);
 
     void setTagsOnly(bool value);
 
@@ -71,7 +71,7 @@ private Q_SLOTS:
 
     void slotStart();
     void slotParseAlbums();
-    void slotAlbumParsed(const ImageInfoList&);
+    void slotAlbumParsed(const ItemInfoList&);
     void slotAdvance();
     void slotOneAlbumIsComplete();
     void slotCancel();
@@ -89,6 +89,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* METADATASYNCHRONIZER_H */
+#endif // DIGIKAM_METADATA_SYNCHRONIZER_H
