@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-09
  * Description : Thread actions task for metadata synchronizer.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -33,11 +33,11 @@
 namespace Digikam
 {
 
-class MetadataTask::Private
+class Q_DECL_HIDDEN MetadataTask::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : tagsOnly(false),
           direction(MetadataSynchronizer::WriteFromDatabaseToFile),
           data(0)
@@ -90,7 +90,7 @@ void MetadataTask::run()
             return;
         }
 
-        ImageInfo item = d->data->getImageInfo();
+        ItemInfo item = d->data->getItemInfo();
 
         // If the item is null, we are done.
         if (item.isNull())
@@ -127,4 +127,4 @@ void MetadataTask::run()
     emit signalDone();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
