@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-09
  * Description : Thread actions task for metadata synchronizer.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef METADATA_TASK_H
-#define METADATA_TASK_H
+#ifndef DIGIKAM_METADATA_TASK_H
+#define DIGIKAM_METADATA_TASK_H
 
 // Qt includes
 
@@ -31,7 +31,7 @@
 // Local includes
 
 #include "actionthreadbase.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "metadatasynchronizer.h"
 
 namespace Digikam
@@ -45,7 +45,7 @@ class MetadataTask : public ActionJob
 
 public:
 
-    MetadataTask();
+    explicit MetadataTask();
     ~MetadataTask();
 
     void setTagsOnly(bool value);
@@ -66,6 +66,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* METADATA_TASK_H */
+#endif // DIGIKAM_METADATA_TASK_H
