@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-01-20
  * Description : new items finder.
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef NEWITEMSFINDER_H
-#define NEWITEMSFINDER_H
+#ifndef DIGIKAM_NEW_ITEMS_FINDER_H
+#define DIGIKAM_NEW_ITEMS_FINDER_H
 
 // Qt includes
 
@@ -45,9 +45,9 @@ public:
 
     enum FinderMode
     {
-        CompleteCollectionScan,   /** Scan whole collection imediatly.                  */
+        CompleteCollectionScan,   /** Scan whole collection immediately.                  */
         ScanDeferredFiles,        /** Defer whole collection scan.                      */
-        ScheduleCollectionScan    /** Scan imediatly folders list passed in contructor. */
+        ScheduleCollectionScan    /** Scan immediately folders list passed in constructor. */
     };
 
 public:
@@ -74,4 +74,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* NEWITEMSFINDER_H */
+#endif // DIGIKAM_NEW_ITEMS_FINDER_H
