@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-14
  * Description : Thread actions task for thumbs generator.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -36,11 +36,11 @@
 namespace Digikam
 {
 
-class ThumbsTask::Private
+class Q_DECL_HIDDEN ThumbsTask::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : catcher(0),
           data(0)
     {
@@ -114,4 +114,4 @@ void ThumbsTask::run()
     d->catcher->setActive(false);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
