@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-14
  * Description : Thread actions task for thumbs generator.
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef THUMBS_TASK_H
-#define THUMBS_TASK_H
+#ifndef DIGIKAM_THUMBS_TASK_H
+#define DIGIKAM_THUMBS_TASK_H
 
 // Qt includes
 
@@ -44,7 +44,7 @@ class ThumbsTask : public ActionJob
 
 public:
 
-    ThumbsTask();
+    explicit ThumbsTask();
     ~ThumbsTask();
 
     void setMaintenanceData(MaintenanceData* const data=0);
@@ -63,6 +63,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* THUMBS_TASK_H */
+#endif // DIGIKAM_THUMBS_TASK_H
