@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-21
  * Description : Batch Queue Manager GUI
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -52,7 +52,7 @@
 #include "digikam_debug.h"
 #include "actions.h"
 #include "album.h"
-#include "batchtoolsmanager.h"
+#include "batchtoolsfactory.h"
 #include "actionthread.h"
 #include "queuepool.h"
 #include "workflowmanager.h"
@@ -62,7 +62,7 @@
 #include "assignedlist.h"
 #include "toolsettingsview.h"
 #include "toolsview.h"
-#include "componentsinfo.h"
+#include "componentsinfodlg.h"
 #include "digikamapp.h"
 #include "thememanager.h"
 #include "dimg.h"
@@ -73,7 +73,6 @@
 #include "sidebar.h"
 #include "dnotificationwrapper.h"
 
-
 namespace Digikam
 {
 
@@ -105,7 +104,7 @@ QueueMgrWindow::QueueMgrWindow()
     qRegisterMetaType<BatchToolSet>("BatchToolSet");
 
     m_instance = this;
-    BatchToolsManager::instance();        // Create first instance here
+    BatchToolsFactory::instance();           // Create first instance here
     WorkflowManager::instance();             // Create first instance here
     d->thread  = new ActionThread(this);
 
@@ -164,8 +163,8 @@ void QueueMgrWindow::closeEvent(QCloseEvent* e)
     }
 
     writeSettings();
+
     DXmlGuiWindow::closeEvent(e);
-    e->accept();
 }
 
 void QueueMgrWindow::setupUserArea()
@@ -336,7 +335,7 @@ void QueueMgrWindow::setupActions()
     d->runAllAction->setEnabled(false);
     connect(d->runAllAction, SIGNAL(triggered()), this, SLOT(slotRunAll()));
     ac->addAction(QLatin1String("queuemgr_run_all"), d->runAllAction);
-    ac->setDefaultShortcut(d->runAllAction, Qt::ALT + Qt::CTRL + Qt::Key_P);
+    ac->setDefaultShortcut(d->runAllAction, Qt::CTRL + Qt::ALT + Qt::Key_P);
 
     d->stopAction = new QAction(QIcon::fromTheme(QLatin1String("media-playback-stop")), i18n("Stop"), this);
     d->stopAction->setEnabled(false);
@@ -501,7 +500,7 @@ void QueueMgrWindow::refreshStatusBar()
             break;
     }
 
-    message.append(i18n(" - Total: "));
+    message.append(QLatin1String(" - ") + i18n("Total: "));
 
     switch (totalItems)
     {
@@ -531,7 +530,7 @@ void QueueMgrWindow::refreshStatusBar()
 
     if (!d->busy)
     {
-        d->statusProgressBar->setProgressBarMode(StatusProgressBar::TextMode, i18n("Ready"));
+        d->statusProgressBar->setProgressBarMode(StatusProgressBar::TextMode, i18nc("batch queue manager is ready to use", "Ready"));
         d->removeItemsSelAction->setEnabled(items > 0);
         d->removeItemsDoneAction->setEnabled((items - pendingItems) > 0);
         d->clearQueueAction->setEnabled(items > 0);
@@ -591,7 +590,7 @@ int QueueMgrWindow::currentQueueId() const
     return (d->queuePool->currentIndex());
 }
 
-void QueueMgrWindow::loadImageInfos(const ImageInfoList& list, int queueId)
+void QueueMgrWindow::loadItemInfos(const ItemInfoList& list, int queueId)
 {
     QueueListView* const queue = d->queuePool->findQueueByIndex(queueId);
 
@@ -601,7 +600,7 @@ void QueueMgrWindow::loadImageInfos(const ImageInfoList& list, int queueId)
     }
 }
 
-void QueueMgrWindow::loadImageInfosToCurrentQueue(const ImageInfoList& list)
+void QueueMgrWindow::loadItemInfosToCurrentQueue(const ItemInfoList& list)
 {
     if (!d->queuePool->currentQueue())
     {
@@ -611,7 +610,7 @@ void QueueMgrWindow::loadImageInfosToCurrentQueue(const ImageInfoList& list)
     d->queuePool->currentQueue()->slotAddItems(list);
 }
 
-void QueueMgrWindow::loadImageInfosToNewQueue(const ImageInfoList& list)
+void QueueMgrWindow::loadItemInfosToNewQueue(const ItemInfoList& list)
 {
     QueueListView* const queue = d->queuePool->currentQueue();
 
@@ -647,7 +646,7 @@ void QueueMgrWindow::slotItemSelectionChanged()
 
 void QueueMgrWindow::populateToolsList()
 {
-    BatchToolsList list = BatchToolsManager::instance()->toolsList();
+    BatchToolsList list = BatchToolsFactory::instance()->toolsList();
 
     foreach(BatchTool* const tool, list)
     {
@@ -671,8 +670,8 @@ void QueueMgrWindow::slotRun()
         msg = i18n("There is no item to process in the current queue (%1).",
                    d->queuePool->currentTitle());
     }
-    else if (queue->settings().renamingRule == QueueSettings::CUSTOMIZE
-             && queue->settings().renamingParser.isEmpty())
+    else if (queue->settings().renamingRule == QueueSettings::CUSTOMIZE &&
+             queue->settings().renamingParser.isEmpty())
     {
         msg = i18n("Custom renaming rule is invalid for current queue (%1). "
                    "Please fix it.", d->queuePool->currentTitle());
@@ -693,7 +692,7 @@ void QueueMgrWindow::slotRun()
     // Take a look if general settings are changed, as we cannot do it when BQM is busy.
     applySettings();
 
-    d->statusProgressBar->setProgressTotalSteps(queue->pendingTasksCount());
+    d->statusProgressBar->setProgressTotalSteps(queue ? queue->pendingTasksCount() : 0);
     d->statusProgressBar->setProgressValue(0);
     d->statusProgressBar->setProgressBarMode(StatusProgressBar::ProgressBarMode);
     d->toolsView->showTab(ToolsView::HISTORY);
@@ -1070,4 +1069,4 @@ void QueueMgrWindow::customizedFullScreenMode(bool set)
     showMenuBarAction()->setEnabled(!set);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
