@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-21
  * Description : Batch Queue Manager GUI
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef QUEUEMGRWINDOWPRIVATE_H
-#define QUEUEMGRWINDOWPRIVATE_H
+#ifndef DIGIKAM_BQM_QUEUE_MGR_WINDOW_PRIVATE_H
+#define DIGIKAM_BQM_QUEUE_MGR_WINDOW_PRIVATE_H
 
 // Qt includes
 
@@ -45,17 +45,17 @@
 namespace Digikam
 {
 
-class BatchToolsManager;
+class BatchToolsFactory;
 
-class QueueMgrWindow::Private
+class Q_DECL_HIDDEN QueueMgrWindow::Private
 {
 
 public:
 
-    Private() :
-        TOP_SPLITTER_CONFIG_KEY(QLatin1String("BqmTopSplitter")),
-        BOTTOM_SPLITTER_CONFIG_KEY(QLatin1String("BqmBottomSplitter")),
-        VERTICAL_SPLITTER_CONFIG_KEY(QLatin1String("BqmVerticalSplitter"))
+    explicit Private()
+        : TOP_SPLITTER_CONFIG_KEY(QLatin1String("BqmTopSplitter")),
+          BOTTOM_SPLITTER_CONFIG_KEY(QLatin1String("BqmBottomSplitter")),
+          VERTICAL_SPLITTER_CONFIG_KEY(QLatin1String("BqmVerticalSplitter"))
     {
         busy                   = false;
         processingAllQueues    = false;
@@ -119,7 +119,7 @@ public:
     SidebarSplitter*         bottomSplitter;
     SidebarSplitter*         verticalSplitter;
 
-    BatchToolsManager*       batchToolsMgr;
+    BatchToolsFactory*       batchToolsMgr;
 
     StatusProgressBar*       statusProgressBar;
 
@@ -136,6 +136,6 @@ public:
     const QString            VERTICAL_SPLITTER_CONFIG_KEY;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* QUEUEMGRWINDOWPRIVATE_H */
+#endif // DIGIKAM_BQM_QUEUE_MGR_WINDOW_PRIVATE_H
