@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-24
  * Description : Batch Tool Container.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,26 +50,28 @@
 #include "jpegsettings.h"
 #include "pngsettings.h"
 #include "dmetadata.h"
+#include "dpluginbqm.h"
 
 namespace Digikam
 {
 
 class BatchToolObserver;
 
-class BatchTool::Private
+class Q_DECL_HIDDEN BatchTool::Private
 {
 
 public:
 
-    Private() :
-        exifResetOrientation(false),
+    explicit Private()
+      : exifResetOrientation(false),
         exifCanEditOrientation(true),
         branchHistory(true),
         cancel(false),
         last(false),
         observer(0),
         toolGroup(BaseTool),
-        rawLoadingRule(QueueSettings::DEMOSAICING)
+        rawLoadingRule(QueueSettings::DEMOSAICING),
+        plugin(0)
     {
     }
 
@@ -82,7 +84,7 @@ public:
     QString                       errorMessage;
     QString                       toolTitle;          // User friendly tool title.
     QString                       toolDescription;    // User friendly tool description.
-    QString                       toolIconName;
+    QIcon                         toolIcon;
 
     QUrl                          inputUrl;
     QUrl                          outputUrl;
@@ -90,7 +92,7 @@ public:
 
     DImg                          image;
 
-    ImageInfo                     imageinfo;
+    ItemInfo                      imageinfo;
 
     DRawDecoderSettings           rawDecodingSettings;
 
@@ -103,9 +105,11 @@ public:
     BatchTool::BatchToolGroup     toolGroup;
 
     QueueSettings::RawLoadingRule rawLoadingRule;
+
+    DPluginBqm*                   plugin;
 };
 
-class BatchToolObserver : public DImgLoaderObserver
+class Q_DECL_HIDDEN BatchToolObserver : public DImgLoaderObserver
 {
 
 public:
@@ -120,8 +124,9 @@ public:
     {
     }
 
-    bool continueQuery(const DImg* const)
+    bool continueQuery(DImg* const img)
     {
+        Q_UNUSED(img);
         return (!d->cancel);
     }
 
@@ -143,13 +148,28 @@ BatchTool::BatchTool(const QString& name, BatchToolGroup group, QObject* const p
 BatchTool::~BatchTool()
 {
     // NOTE: See bug #341566: no need to delete settings widget here.
-    // Owner is passed to ToolSettingsView, which will delete instance,
-    // even if Valgrind report a memory leak.
+    // We delete the settings widget now in the ToolSettingsView.
 
     delete d->observer;
     delete d;
 }
 
+void BatchTool::setPlugin(DPluginBqm* const plugin)
+{
+    d->plugin = plugin;
+    setToolTitle(d->plugin->name());
+    setToolDescription(d->plugin->description());
+    setToolIcon(d->plugin->icon());
+
+    connect(d->plugin, SIGNAL(signalVisible(bool)),
+            this, SIGNAL(signalVisible(bool)));
+}
+
+DPluginBqm* BatchTool::plugin() const
+{
+    return d->plugin;
+}
+
 QString BatchTool::errorDescription() const
 {
     return d->errorMessage;
@@ -165,6 +185,36 @@ BatchTool::BatchToolGroup BatchTool::toolGroup() const
     return d->toolGroup;
 }
 
+QString BatchTool::toolGroupToString() const
+{
+    switch (toolGroup())
+    {
+        case BaseTool:
+            return i18n("Base");
+        case CustomTool:
+            return i18n("Custom");
+        case ColorTool:
+            return i18n("Colors");
+        case EnhanceTool:
+            return i18n("Enhance");
+        case TransformTool:
+            return i18n("Transform");
+        case DecorateTool:
+            return i18n("Decorate");
+        case FiltersTool:
+            return i18n("Filters");
+        case ConvertTool:
+            return i18n("Convert");
+        case MetadataTool:
+            return i18n("Metadata");
+
+        default:
+            break;
+    }
+
+    return i18n("Invalid");
+}
+
 void BatchTool::setToolTitle(const QString& toolTitle)
 {
     d->toolTitle = toolTitle;
@@ -187,12 +237,17 @@ QString BatchTool::toolDescription() const
 
 void BatchTool::setToolIconName(const QString& iconName)
 {
-    d->toolIconName = iconName;
+    d->toolIcon = QIcon::fromTheme(iconName);
 }
 
-QString BatchTool::toolIconName() const
+void BatchTool::setToolIcon(const QIcon& icon)
 {
-    return d->toolIconName;
+    d->toolIcon = icon;
+}
+
+QIcon BatchTool::toolIcon() const
+{
+    return d->toolIcon;
 }
 
 void BatchTool::slotResetSettingsToDefault()
@@ -247,12 +302,12 @@ DImg BatchTool::imageData() const
     return d->image;
 }
 
-void BatchTool::setImageInfo(const ImageInfo& info)
+void BatchTool::setItemInfo(const ItemInfo& info)
 {
     d->imageinfo = info;
 }
 
-ImageInfo BatchTool::imageInfo() const
+ItemInfo BatchTool::imageInfo() const
 {
     return d->imageinfo;
 }
@@ -388,7 +443,7 @@ bool BatchTool::loadToDImg() const
         QImage img;
         bool   ret = DRawDecoder::loadRawPreview(img, inputUrl().toLocalFile());
         DMetadata meta(inputUrl().toLocalFile());
-        meta.setImageDimensions(QSize(img.width(), img.height()));
+        meta.setItemDimensions(QSize(img.width(), img.height()));
         d->image   = DImg(img);
         d->image.setMetadata(meta.data());
         return ret;
@@ -538,6 +593,12 @@ QWidget* BatchTool::settingsWidget() const
     return m_settingsWidget;
 }
 
+void BatchTool::deleteSettingsWidget()
+{
+    delete m_settingsWidget;
+    m_settingsWidget = 0;
+}
+
 void BatchTool::registerSettingsWidget()
 {
     // NOTE: see bug #209225 : signal/slot connection used internally to prevent crash when settings
@@ -556,4 +617,4 @@ void BatchTool::registerSettingsWidget()
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
