@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-24
  * Description : Batch Tool Container.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,36 +21,37 @@
  *
  * ============================================================ */
 
-#ifndef BATCH_TOOL_H
-#define BATCH_TOOL_H
+#ifndef DIGIKAM_BQM_BATCH_TOOL_H
+#define DIGIKAM_BQM_BATCH_TOOL_H
 
 // Qt includes
 
 #include <QObject>
+#include <QIcon>
 
 // Local includes
 
+#include "digikam_export.h"
 #include "drawdecodersettings.h"
 #include "dimg.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "queuesettings.h"
 #include "iofilesettings.h"
 
 class QWidget;
 
-
-
 namespace Digikam
 {
 
 class DImgBuiltinFilter;
 class DImgThreadedFilter;
+class DPluginBqm;
 
 /** A map of batch tool settings (setting key, setting value).
  */
 typedef QMap<QString, QVariant> BatchToolSettings;
 
-class BatchTool : public QObject
+class DIGIKAM_EXPORT BatchTool : public QObject
 {
     Q_OBJECT
 
@@ -77,6 +78,9 @@ public:
     explicit BatchTool(const QString& name, BatchToolGroup group, QObject* const parent = 0);
     ~BatchTool();
 
+    void setPlugin(DPluginBqm* const plugin);
+    DPluginBqm* plugin() const;
+
     /** Get description of an error which appear during apply() method.
      */
     QString errorDescription() const;
@@ -85,6 +89,10 @@ public:
      */
     BatchToolGroup toolGroup() const;
 
+    /** Return group of tool name as string.
+     */
+    QString toolGroupToString() const;
+
     /** Manage Tool title.
      */
     void setToolTitle(const QString& toolTitle);
@@ -98,7 +106,8 @@ public:
     /** Manage Tool icon name.
      */
     void setToolIconName(const QString& iconName);
-    QString toolIconName() const;
+    void setToolIcon(const QIcon& icon);
+    QIcon toolIcon() const;
 
     /** Manage settings values to tool. See BatchToolSettings container for details.
      */
@@ -127,8 +136,8 @@ public:
 
     /** Manage instance of current image info loaded by this tool.
      */
-    void setImageInfo(const ImageInfo& info);
-    ImageInfo imageInfo() const;
+    void setItemInfo(const ItemInfo& info);
+    ItemInfo imageInfo() const;
 
     /** Manage flag properties to indicate if this tool is last one to process on current item.
      */
@@ -229,6 +238,7 @@ public:
 Q_SIGNALS:
 
     void signalSettingsChanged(const BatchToolSettings&);
+    void signalVisible(bool);
 
 public Q_SLOTS:
 
@@ -278,6 +288,10 @@ public:
      */
     QWidget* settingsWidget() const;
 
+    /** Delete dedicated settings widget registered with registerSettingsWidget().
+     */
+    void deleteSettingsWidget();
+
     /** Setup dedicated settings widget. Default implementation assign no settings view (a message label is just displayed).
      *  You need to call default implementation in your child class to init default signals and slots connections,
      *  after to have instanced your dedicated settings widget.
@@ -317,4 +331,4 @@ private:
 
 } // namespace Digikam
 
-#endif // BATCH_TOOL_H
+#endif // DIGIKAM_BQM_BATCH_TOOL_H
