@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-24
  * Description : Batch Tool utils.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +30,7 @@
 // Local includes
 
 #include "batchtool.h"
-#include "batchtoolsmanager.h"
+#include "batchtoolsfactory.h"
 
 namespace Digikam
 {
@@ -82,7 +82,7 @@ QString AssignedBatchTools::targetSuffix(bool* const extSet) const
 
     foreach(const BatchToolSet& set, m_toolsList)
     {
-        BatchTool* const tool = BatchToolsManager::instance()->findTool(set.name, set.group);
+        BatchTool* const tool = BatchToolsFactory::instance()->findTool(set.name, set.group);
         if (tool)
         {
             QString s = tool->outputSuffix();
@@ -112,4 +112,4 @@ QString AssignedBatchTools::targetSuffix(bool* const extSet) const
     return suffix;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
