@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-24
  * Description : Batch Tool utils.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef BATCH_TOOL_UTILS_H
-#define BATCH_TOOL_UTILS_H
+#ifndef DIGIKAM_BQM_BATCH_TOOL_UTILS_H
+#define DIGIKAM_BQM_BATCH_TOOL_UTILS_H
 
 // Qt includes
 
@@ -100,4 +100,4 @@ public:
 
 } // namespace Digikam
 
-#endif // BATCHTOOLUTILS_H
+#endif // DIGIKAM_BQM_BATCH_TOOL_UTILS_H
