@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-02-06
  * Description : Thread actions task.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2012      by Pankaj Kumar <me at panks dot me>
  *
  * This program is free software; you can redistribute it
@@ -38,19 +38,19 @@
 #include "digikam_config.h"
 #include "dimg.h"
 #include "dmetadata.h"
-#include "imageinfo.h"
+#include "iteminfo.h"
 #include "batchtool.h"
-#include "batchtoolsmanager.h"
+#include "batchtoolsfactory.h"
 #include "dfileoperations.h"
 
 namespace Digikam
 {
 
-class Task::Private
+class Q_DECL_HIDDEN Task::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         cancel = false;
         tool   = 0;
@@ -96,6 +96,20 @@ void Task::slotCancel()
     d->cancel = true;
 }
 
+void Task::removeTempFiles(const QList<QUrl>& tmpList)
+{
+    foreach (const QUrl& url, tmpList)
+    {
+        QString tmpPath(url.toLocalFile());
+        QFile::remove(tmpPath);
+
+        tmpPath = DMetadata::sidecarPath(tmpPath);
+
+        if (QFile::exists(tmpPath))
+            QFile::remove(tmpPath);
+    }
+}
+
 void Task::emitActionData(ActionData::ActionStatus st, const QString& mess, const QUrl& dest)
 {
     ActionData ad;
@@ -127,13 +141,13 @@ void Task::run()
     DImg        tmpImage;
     QString     errMsg;
 
-    // ImageInfo must be tread-safe.
-    ImageInfo source = ImageInfo::fromUrl(d->tools.m_itemUrl);
+    // ItemInfo must be tread-safe.
+    ItemInfo source = ItemInfo::fromUrl(d->tools.m_itemUrl);
     bool timeAdjust  = false;
 
     foreach (const BatchToolSet& set, d->tools.m_toolsList)
     {
-        d->tool     = BatchToolsManager::instance()->findTool(set.name, set.group)->clone();
+        d->tool     = BatchToolsFactory::instance()->findTool(set.name, set.group)->clone();
         timeAdjust |= (set.name == QLatin1String("TimeAdjust"));
         inUrl       = outUrl;
         index       = set.index + 1;
@@ -144,7 +158,7 @@ void Task::run()
                  << " :: wurl= "     << workUrl;
 
         d->tool->setImageData(tmpImage);
-        d->tool->setImageInfo(source);
+        d->tool->setItemInfo(source);
         d->tool->setInputUrl(inUrl);
         d->tool->setWorkingUrl(workUrl);
         d->tool->setSettings(set.settings);
@@ -177,12 +191,14 @@ void Task::run()
         errMsg   = d->tool->errorDescription();
         tmp2del.append(outUrl);
 
+        delete d->tool;
+        d->tool = 0;
+
         if (d->cancel)
         {
             emitActionData(ActionData::BatchCanceled);
+            removeTempFiles(tmp2del);
             emit signalDone();
-            delete d->tool;
-            d->tool = 0;
             return;
         }
         else if (!success)
@@ -190,9 +206,6 @@ void Task::run()
             emitActionData(ActionData::BatchFailed, errMsg);
             break;
         }
-
-        delete d->tool;
-        d->tool = 0;
     }
 
     // Clean up all tmp url.
@@ -200,16 +213,7 @@ void Task::run()
     // We don't remove last output tmp url.
     tmp2del.removeAll(outUrl);
 
-    foreach (const QUrl& url, tmp2del)
-    {
-        QString tmpPath(url.toLocalFile());
-        QFile::remove(tmpPath);
-
-        tmpPath = DMetadata::sidecarPath(tmpPath);
-
-        if (QFile::exists(tmpPath))
-            QFile::remove(tmpPath);
-    }
+    removeTempFiles(tmp2del);
 
     // Move processed temp file to target
 
@@ -269,4 +273,4 @@ void Task::run()
     emit signalDone();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
