@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-21
  * Description : Batch Queue Manager items list.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,7 +47,7 @@
 #include "queuemgrwindow.h"
 #include "queuesettingsview.h"
 #include "toolslistview.h"
-#include "batchtoolsmanager.h"
+#include "batchtoolsfactory.h"
 
 namespace Digikam
 {
@@ -73,11 +73,11 @@ void AssignedListViewItem::setToolSet(const BatchToolSet& set)
     m_set = set;
     setIndex(m_set.index);
 
-    BatchTool* const tool = BatchToolsManager::instance()->findTool(m_set.name, m_set.group);
+    BatchTool* const tool = BatchToolsFactory::instance()->findTool(m_set.name, m_set.group);
 
     if (tool)
     {
-        setIcon(1, QIcon::fromTheme(tool->toolIconName()));
+        setIcon(1, tool->toolIcon());
         setText(1, tool->toolTitle());
     }
 }
@@ -229,7 +229,7 @@ void AssignedListView::slotMoveCurrentToolDown()
 
 AssignedListViewItem* AssignedListView::moveTool(AssignedListViewItem* const preceding, const BatchToolSet& set)
 {
-    BatchTool* const tool = BatchToolsManager::instance()->findTool(set.name, set.group);
+    BatchTool* const tool = BatchToolsFactory::instance()->findTool(set.name, set.group);
 
     if (!tool)
     {
@@ -258,6 +258,14 @@ AssignedListViewItem* AssignedListView::insertTool(AssignedListViewItem* const p
         item = new AssignedListViewItem(this);
     }
 
+    BatchTool* const tool = BatchToolsFactory::instance()->findTool(set.name, set.group);
+
+    // NOTE: Only now create the settings widget when needed.
+    if (tool && !tool->settingsWidget())
+    {
+        tool->registerSettingsWidget();
+    }
+
     item->setToolSet(set);
     refreshIndex();
 
@@ -500,16 +508,26 @@ void AssignedListView::assignTools(const QMap<int, QString>& map, AssignedListVi
     while (it.hasPrevious())
     {
         it.previous();
-        BatchTool::BatchToolGroup group  = (BatchTool::BatchToolGroup)(it.key());
-        QString name                     = it.value();
-        BatchTool* const tool            = BatchToolsManager::instance()->findTool(name, group);
-        BatchToolSet set;
-        set.name                         = tool->objectName();
-        set.group                        = tool->toolGroup();
-        set.version                      = tool->toolVersion();
-        set.settings                     = tool->defaultSettings();
-        AssignedListViewItem* const item = insertTool(preceding, set);
-        setCurrentItem(item);
+        BatchTool::BatchToolGroup group = (BatchTool::BatchToolGroup)(it.key());
+        QString name                    = it.value();
+        BatchTool* const tool           = BatchToolsFactory::instance()->findTool(name, group);
+
+        if (tool)
+        {
+            // NOTE: Only now create the settings widget when needed.
+            if (!tool->settingsWidget())
+            {
+                tool->registerSettingsWidget();
+            }
+
+            BatchToolSet set;
+            set.name                         = tool->objectName();
+            set.group                        = tool->toolGroup();
+            set.version                      = tool->toolVersion();
+            set.settings                     = tool->defaultSettings();
+            AssignedListViewItem* const item = insertTool(preceding, set);
+            setCurrentItem(item);
+        }
     }
 }
 
@@ -548,4 +566,4 @@ void AssignedListView::refreshIndex()
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
