@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-27
  * Description : batch tools list assigned to an queued item.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef ASSIGNED_LIST_H
-#define ASSIGNED_LIST_H
+#ifndef DIGIKAM_BQM_ASSIGNED_LIST_H
+#define DIGIKAM_BQM_ASSIGNED_LIST_H
 
 // Qt includes
 
@@ -45,7 +45,7 @@ class AssignedListViewItem : public QTreeWidgetItem
 
 public:
 
-    AssignedListViewItem(QTreeWidget* const parent);
+    explicit AssignedListViewItem(QTreeWidget* const parent);
     AssignedListViewItem(QTreeWidget* const parent, QTreeWidgetItem* const preceding);
     virtual ~AssignedListViewItem();
 
@@ -120,6 +120,6 @@ private:
     void dropEvent(QDropEvent*);
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // ASSIGNED_LIST_H
+#endif // DIGIKAM_BQM_ASSIGNED_LIST_H
