@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-21
  * Description : Batch Queue Manager items list.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2014 by Mohamed Anwer <m dot anwer at gmx dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C)      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,13 +62,13 @@
 namespace Digikam
 {
 
-class QueueListViewItem::Private
+class Q_DECL_HIDDEN QueueListViewItem::Private
 {
 
 public:
 
-    Private() :
-        isBusy(false),
+    explicit Private()
+      : isBusy(false),
         done(false),
         hasThumb(false),
         progressIndex(0),
@@ -88,10 +88,10 @@ public:
 
     QueueListView* view;
 
-    ImageInfo      info;
+    ItemInfo      info;
 };
 
-QueueListViewItem::QueueListViewItem(QueueListView* const view, const ImageInfo& info)
+QueueListViewItem::QueueListViewItem(QueueListView* const view, const ItemInfo& info)
     : QTreeWidgetItem(view),
       d(new Private)
 {
@@ -110,13 +110,13 @@ bool QueueListViewItem::hasValidThumbnail() const
     return d->hasThumb;
 }
 
-void QueueListViewItem::setInfo(const ImageInfo& info)
+void QueueListViewItem::setInfo(const ItemInfo& info)
 {
     d->info = info;
     setText(1, d->info.name());
 }
 
-ImageInfo QueueListViewItem::info() const
+ItemInfo QueueListViewItem::info() const
 {
     return d->info;
 }
@@ -241,7 +241,7 @@ QString QueueListViewItem::destSuffix() const
 
 // ---------------------------------------------------------------------------
 
-class QueueListView::Private
+class Q_DECL_HIDDEN QueueListView::Private
 {
 
 public:
@@ -255,7 +255,7 @@ public:
 
 public:
 
-    Private()
+    explicit Private()
         : iconSize(64)
     {
         showTips        = false;
@@ -363,24 +363,22 @@ Qt::DropActions QueueListView::supportedDropActions() const
 QMimeData* QueueListView::mimeData(const QList<QTreeWidgetItem*> items) const
 {
     QList<QUrl> urls;
-    QList<QUrl> kioURLs;
     QList<int> albumIDs;
     QList<qlonglong> imageIDs;
 
-    foreach(QTreeWidgetItem* const itm, items)
+    foreach (QTreeWidgetItem* const itm, items)
     {
         QueueListViewItem* const vitem = dynamic_cast<QueueListViewItem*>(itm);
 
         if (vitem)
         {
             urls.append(vitem->info().fileUrl());
-            kioURLs.append(vitem->info().databaseUrl());
             albumIDs.append(vitem->info().albumId());
             imageIDs.append(vitem->info().id());
         }
     }
 
-    DItemDrag* const mimeData = new DItemDrag(urls, kioURLs, albumIDs, imageIDs);
+    DItemDrag* const mimeData = new DItemDrag(urls, albumIDs, imageIDs);
     return mimeData;
 }
 
@@ -434,20 +432,19 @@ void QueueListView::dragMoveEvent(QDragMoveEvent* e)
     QList<int>       albumIDs;
     QList<qlonglong> imageIDs;
     QList<QUrl>      urls;
-    QList<QUrl>      kioURLs;
 
-    if (DItemDrag::decode(e->mimeData(), urls, kioURLs, albumIDs, imageIDs) ||
+    if (DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs) ||
         DAlbumDrag::decode(e->mimeData(), urls, albumID)                    ||
         DTagListDrag::canDecode(e->mimeData()))
     {
-        if (DItemDrag::decode(e->mimeData(), urls, kioURLs, albumIDs, imageIDs))
+        if (DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs))
         {
-            ImageInfoList imageInfoList;
+            ItemInfoList imageInfoList;
 
             for (QList<qlonglong>::const_iterator it = imageIDs.constBegin();
                  it != imageIDs.constEnd(); ++it)
             {
-                ImageInfo info(*it);
+                ItemInfo info(*it);
 
                 if (!findItemByInfo(info))
                 {
@@ -479,16 +476,15 @@ void QueueListView::dropEvent(QDropEvent* e)
     QList<int>       albumIDs;
     QList<qlonglong> imageIDs;
     QList<QUrl>      urls;
-    QList<QUrl>      kioURLs;
 
-    if (DItemDrag::decode(e->mimeData(), urls, kioURLs, albumIDs, imageIDs))
+    if (DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs))
     {
-        ImageInfoList imageInfoList;
+        ItemInfoList imageInfoList;
 
         for (QList<qlonglong>::const_iterator it = imageIDs.constBegin();
              it != imageIDs.constEnd(); ++it)
         {
-            ImageInfo info(*it);
+            ItemInfo info(*it);
 
             if (!findItemByInfo(info))
             {
@@ -505,7 +501,7 @@ void QueueListView::dropEvent(QDropEvent* e)
 
             if (vitem && vitem != this)
             {
-                foreach(const ImageInfo& info, imageInfoList)
+                foreach (const ItemInfo& info, imageInfoList)
                 {
                     vitem->removeItemByInfo(info);
                 }
@@ -515,12 +511,12 @@ void QueueListView::dropEvent(QDropEvent* e)
     else if (DAlbumDrag::decode(e->mimeData(), urls, albumID))
     {
         QList<qlonglong> itemIDs = CoreDbAccess().db()->getItemIDsInAlbum(albumID);
-        ImageInfoList imageInfoList;
+        ItemInfoList imageInfoList;
 
         for (QList<qlonglong>::const_iterator it = itemIDs.constBegin();
              it != itemIDs.constEnd(); ++it)
         {
-            ImageInfo info(*it);
+            ItemInfo info(*it);
 
             if (!findItemByInfo(info))
             {
@@ -544,12 +540,12 @@ void QueueListView::dropEvent(QDropEvent* e)
         }
 
         QList<qlonglong> itemIDs = CoreDbAccess().db()->getItemIDsInTag(tagIDs.first(), true);
-        ImageInfoList imageInfoList;
+        ItemInfoList imageInfoList;
 
         for (QList<qlonglong>::const_iterator it = itemIDs.constBegin();
              it != itemIDs.constEnd(); ++it)
         {
-            ImageInfo info(*it);
+            ItemInfo info(*it);
 
             if (!findItemByInfo(info))
             {
@@ -680,16 +676,16 @@ void QueueListView::leaveEvent(QEvent* e)
     QTreeWidget::leaveEvent(e);
 }
 
-void QueueListView::slotAddItems(const ImageInfoList& list)
+void QueueListView::slotAddItems(const ItemInfoList& list)
 {
     if (list.count() == 0)
     {
         return;
     }
 
-    for (ImageInfoList::ConstIterator it = list.begin(); it != list.end(); ++it)
+    for (ItemInfoList::ConstIterator it = list.begin(); it != list.end(); ++it)
     {
-        ImageInfo info = *it;
+        ItemInfo info = *it;
 
         // Check if the new item already exist in the list.
 
@@ -727,7 +723,7 @@ void QueueListView::drawRow(QPainter* p, const QStyleOptionViewItem& opt, const
 
     if (item && !item->hasValidThumbnail())
     {
-        ImageInfo info = item->info();
+        ItemInfo info = item->info();
         d->thumbLoadThread->find(ThumbnailIdentifier(info.fileUrl().toLocalFile()));
     }
 
@@ -834,7 +830,7 @@ void QueueListView::removeItems(int removeType)
     emit signalQueueContentsChanged();
 }
 
-void QueueListView::removeItemByInfo(const ImageInfo& info)
+void QueueListView::removeItemByInfo(const ItemInfo& info)
 {
     removeItemById(info.id());
 }
@@ -869,7 +865,7 @@ void QueueListView::removeItemById(qlonglong id)
     emit signalQueueContentsChanged();
 }
 
-bool QueueListView::findItemByInfo(const ImageInfo& info)
+bool QueueListView::findItemByInfo(const ItemInfo& info)
 {
     return (findItemById(info.id()) ? true : false);
 }
@@ -949,9 +945,9 @@ void QueueListView::cancelItems()
     }
 }
 
-ImageInfoList QueueListView::pendingItemsList()
+ItemInfoList QueueListView::pendingItemsList()
 {
-    ImageInfoList list;
+    ItemInfoList list;
     QTreeWidgetItemIterator it(this);
 
     while (*it)
@@ -1062,7 +1058,7 @@ void QueueListView::updateDestFileNames()
             if (item)
             {
                 // Update base name using queue renaming rules.
-                ImageInfo info = item->info();
+                ItemInfo info = item->info();
                 QFileInfo fi(info.filePath());
 
                 ParseSettings ps;
@@ -1089,7 +1085,7 @@ void QueueListView::updateDestFileNames()
         if (item)
         {
             // Update base name using queue renaming rules.
-            ImageInfo info    = item->info();
+            ItemInfo info    = item->info();
             QFileInfo fi(info.filePath());
 
             // Update suffix using assigned batch tool rules.
@@ -1144,10 +1140,11 @@ void QueueListView::slotCollectionImageChange(const CollectionImageChangeset& ch
 
     switch (changeset.operation())
     {
+        case CollectionImageChangeset::Deleted:
         case CollectionImageChangeset::Removed:
         case CollectionImageChangeset::RemovedAll:
         {
-            foreach(const qlonglong& id, changeset.ids())
+            foreach (const qlonglong& id, changeset.ids())
             {
                 removeItemById(id);
             }
@@ -1198,4 +1195,4 @@ void QueueListView::slotProgressTimerDone()
         d->progressTimer->stop();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
