@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-02-13
  * Description : tabbed queue items list.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef QUEUEPOOL_H
-#define QUEUEPOOL_H
+#ifndef DIGIKAM_BQM_QUEUE_POOL_H
+#define DIGIKAM_BQM_QUEUE_POOL_H
 
 // Qt includes
 
@@ -52,7 +52,7 @@ class QueuePoolBar : public QTabBar
 
 public:
 
-    QueuePoolBar(QWidget* const parent);
+    explicit QueuePoolBar(QWidget* const parent);
     ~QueuePoolBar();
 
 Q_SIGNALS:
@@ -112,7 +112,7 @@ public Q_SLOTS:
     void slotClearList();
     void slotRemoveSelectedItems();
     void slotRemoveItemsDone();
-    void slotAddItems(const ImageInfoList&, int queueId);
+    void slotAddItems(const ItemInfoList&, int queueId);
     void slotAssignedToolsChanged(const AssignedBatchTools&);
     void slotSettingsChanged(const QueueSettings&);
     void slotQueueSelected(int);
@@ -132,6 +132,6 @@ private Q_SLOTS:
     void slotTestCanDecode(const QDragMoveEvent*, bool&);
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // QUEUEPOOL_H
+#endif // DIGIKAM_BQM_QUEUE_POOL_H
