@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-02-21
  * Description : a view to show Queue Settings.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -65,7 +65,7 @@
 namespace Digikam
 {
 
-class QueueSettingsView::Private
+class Q_DECL_HIDDEN QueueSettingsView::Private
 {
 public:
 
@@ -80,8 +80,8 @@ public:
 
 public:
 
-    Private() :
-        rawLoadingLabel(0),
+    explicit Private()
+      : rawLoadingLabel(0),
         renamingButtonGroup(0),
         rawLoadingButtonGroup(0),
         renameOriginal(0),
