@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-02-21
  * Description : a view to show Queue Settings.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef QUEUE_SETTINGS_VIEW_H
-#define QUEUE_SETTINGS_VIEW_H
+#ifndef DIGIKAM_BQM_QUEUE_SETTINGS_VIEW_H
+#define DIGIKAM_BQM_QUEUE_SETTINGS_VIEW_H
 
 // Qt includes
 
@@ -70,4 +70,4 @@ private:
 
 } // namespace Digikam
 
-#endif // QUEUE_SETTINGS_VIEW_H
+#endif // DIGIKAM_BQM_QUEUE_SETTINGS_VIEW_H
