@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-03-03
  * Description : queue tool tip
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,12 +39,12 @@
 namespace Digikam
 {
 
-class QueueToolTip::Private
+class Q_DECL_HIDDEN QueueToolTip::Private
 {
 public:
 
-    Private() :
-        view(0),
+    explicit Private()
+      : view(0),
         item(0)
     {
     }
@@ -105,9 +105,9 @@ QString QueueToolTip::tipContents()
         return QString();
     }
 
-    ImageInfo info = d->item->info();
+    ItemInfo info = d->item->info();
 
     return ToolTipFiller::imageInfoTipContents(info);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
