@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-27
  * Description : a view to show Batch Tool Settings.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,14 +42,14 @@
 
 #include "dlayoutbox.h"
 #include "thememanager.h"
-#include "batchtoolsmanager.h"
-
-
+#include "batchtoolsfactory.h"
+#include "dpluginbqm.h"
+#include "dpluginaboutdlg.h"
 
 namespace Digikam
 {
 
-class ToolSettingsView::Private
+class Q_DECL_HIDDEN ToolSettingsView::Private
 {
 
 public:
@@ -62,11 +62,12 @@ public:
 
 public:
 
-    Private() :
-        messageView(0),
+    explicit Private()
+      : messageView(0),
         settingsViewIcon(0),
         settingsViewTitle(0),
         settingsViewReset(0),
+        settingsViewAbout(0),
         settingsView(0),
         tool(0)
     {
@@ -77,6 +78,7 @@ public:
     QLabel*      settingsViewTitle;
 
     QPushButton* settingsViewReset;
+    QPushButton* settingsViewAbout;
 
     QScrollArea* settingsView;
 
@@ -85,7 +87,8 @@ public:
 };
 
 ToolSettingsView::ToolSettingsView(QWidget* const parent)
-    : QStackedWidget(parent), d(new Private)
+    : QStackedWidget(parent),
+      d(new Private)
 {
     setAttribute(Qt::WA_DeleteOnClose);
 
@@ -110,6 +113,10 @@ ToolSettingsView::ToolSettingsView(QWidget* const parent)
     d->settingsViewReset->setIcon(QIcon::fromTheme(QLatin1String("document-revert")));
     d->settingsViewReset->setToolTip(i18n("Reset current tool settings to default values."));
 
+    d->settingsViewAbout = new QPushButton();
+    d->settingsViewAbout->setIcon(QIcon::fromTheme(QLatin1String("help-about")));
+    d->settingsViewAbout->setToolTip(i18n("About this tool..."));
+
     QString frameStyle = QString::fromUtf8("QFrame {"
                                  "color: %1;"
                                  "border: 1px solid %2;"
@@ -127,6 +134,7 @@ ToolSettingsView::ToolSettingsView(QWidget* const parent)
     d->settingsViewIcon->setStyleSheet(noFrameStyle);
     d->settingsViewTitle->setStyleSheet(noFrameStyle);
     d->settingsViewReset->setStyleSheet(noFrameStyle);
+    d->settingsViewAbout->setStyleSheet(noFrameStyle);
     toolDescriptor->setStyleSheet(frameStyle);
 
     d->settingsViewIcon->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
@@ -136,6 +144,7 @@ ToolSettingsView::ToolSettingsView(QWidget* const parent)
     descrLayout->addWidget(d->settingsViewIcon,  0, 0, 1, 1);
     descrLayout->addWidget(d->settingsViewTitle, 0, 1, 1, 1);
     descrLayout->addWidget(d->settingsViewReset, 0, 2, 1, 1);
+    descrLayout->addWidget(d->settingsViewAbout, 0, 3, 1, 1);
     descrLayout->setColumnStretch(1, 10);
     toolDescriptor->setLayout(descrLayout);
 
@@ -156,13 +165,31 @@ ToolSettingsView::ToolSettingsView(QWidget* const parent)
 
     connect(ThemeManager::instance(), SIGNAL(signalThemeChanged()),
             this, SLOT(slotThemeChanged()));
+
+    connect(d->settingsViewAbout, SIGNAL(clicked()),
+            this, SLOT(slotAboutPlugin()));
 }
 
 ToolSettingsView::~ToolSettingsView()
 {
+    foreach (BatchTool* const tool, BatchToolsFactory::instance()->toolsList())
+    {
+        tool->deleteSettingsWidget();
+    }
+
     delete d;
 }
 
+void ToolSettingsView::slotAboutPlugin()
+{
+    if (d->tool && d->tool->plugin())
+    {
+        QPointer<DPluginAboutDlg> dlg = new DPluginAboutDlg(dynamic_cast<DPlugin*>(d->tool->plugin()));
+        dlg->exec();
+        delete dlg;
+    }
+}
+
 void ToolSettingsView::setBusy(bool b)
 {
     d->settingsView->viewport()->setEnabled(!b);
@@ -236,17 +263,19 @@ void ToolSettingsView::slotToolSelected(const BatchToolSet& set)
                    d->tool, SLOT(slotResetSettingsToDefault()));
     }
 
-    d->tool = BatchToolsManager::instance()->findTool(d->set.name, d->set.group);
+    d->tool = BatchToolsFactory::instance()->findTool(d->set.name, d->set.group);
 
     if (d->tool)
     {
-        d->settingsViewIcon->setPixmap(QIcon::fromTheme(d->tool->toolIconName()).pixmap(22));
+        d->settingsViewIcon->setPixmap(d->tool->toolIcon().pixmap(22));
         d->settingsViewTitle->setText(d->tool->toolTitle());
         d->tool->setSettings(d->set.settings);
 
         // Only set on Reset button if Manager is not busy (settings widget is disabled in this case).
         d->settingsViewReset->setEnabled(d->settingsView->viewport()->isEnabled());
 
+        d->settingsViewAbout->setEnabled(d->tool->plugin());
+
         setToolSettingsWidget(d->tool->settingsWidget());
 
         connect(d->tool, SIGNAL(signalSettingsChanged(BatchToolSettings)),
@@ -270,4 +299,4 @@ void ToolSettingsView::slotSettingsChanged(const BatchToolSettings& settings)
     emit signalSettingsChanged(d->set);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
