@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-27
  * Description : a view to show Batch Tool Settings.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TOOL_SETTINGS_VIEW_H
-#define TOOL_SETTINGS_VIEW_H
+#ifndef DIGIKAM_BQM_TOOL_SETTINGS_VIEW_H
+#define DIGIKAM_BQM_TOOL_SETTINGS_VIEW_H
 
 // Qt includes
 
@@ -59,6 +59,7 @@ private Q_SLOTS:
 
     void slotSettingsChanged(const BatchToolSettings&);
     void slotThemeChanged();
+    void slotAboutPlugin();
 
 private:
 
@@ -72,6 +73,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* TOOL_SETTINGS_VIEW_H */
+#endif // DIGIKAM_BQM_TOOL_SETTINGS_VIEW_H
