@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-24
  * Description : Available batch tools list.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,6 +39,10 @@
 
 #include <klocalizedstring.h>
 
+// Local includes
+
+#include "dpluginbqm.h"
+
 namespace Digikam
 {
 
@@ -117,7 +121,7 @@ ToolListViewItem::ToolListViewItem(ToolListViewGroup* const parent, BatchTool* c
 
     if (m_tool)
     {
-        setIcon(0, QIcon::fromTheme(m_tool->toolIconName()));
+        setIcon(0, m_tool->toolIcon());
         setText(0, m_tool->toolTitle());
         setText(1, m_tool->toolDescription());
     }
@@ -188,7 +192,27 @@ void ToolsListView::addTool(BatchTool* const tool)
 
     if (parent)
     {
-        new ToolListViewItem(parent, tool);
+        ToolListViewItem* const item = new ToolListViewItem(parent, tool);
+
+        connect(tool, SIGNAL(signalVisible(bool)),
+                this, SLOT(slotToolVisible(bool)));
+
+        item->setHidden(!tool->plugin()->shouldLoaded());
+    }
+}
+
+void ToolsListView::slotToolVisible(bool b)
+{
+    BatchTool* const tool = dynamic_cast<BatchTool*>(sender());
+
+    if (tool)
+    {
+        ToolListViewItem* const item = findTool(tool);
+
+        if (item)
+        {
+            item->setHidden(!b);
+        }
     }
 }
 
@@ -231,7 +255,12 @@ ToolListViewGroup* ToolsListView::findToolGroup(BatchTool::BatchToolGroup group)
     return 0;
 }
 
-bool ToolsListView::findTool(BatchTool* tool)
+bool ToolsListView::hasTool(BatchTool* const tool)
+{
+    return (findTool(tool) ? true : false);
+}
+
+ToolListViewItem* ToolsListView::findTool(BatchTool* const tool)
 {
     QTreeWidgetItemIterator it(this);
 
@@ -241,13 +270,13 @@ bool ToolsListView::findTool(BatchTool* tool)
 
         if (item && item->tool() == tool)
         {
-            return true;
+            return item;
         }
 
         ++it;
     }
 
-    return false;
+    return 0;
 }
 
 void ToolsListView::startDrag(Qt::DropActions /*supportedActions*/)
@@ -356,4 +385,4 @@ void ToolsListView::slotContextMenu()
     popmenu.exec(QCursor::pos());
 }
 
-}  // namespace Digikam
+} // namespace Digikam
