@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-11-24
  * Description : Available batch tools list.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TOOLS_LIST_VIEW_H
-#define TOOLS_LIST_VIEW_H
+#ifndef DIGIKAM_BQM_TOOLS_LIST_VIEW_H
+#define DIGIKAM_BQM_TOOLS_LIST_VIEW_H
 
 // Qt includes
 
@@ -36,7 +36,7 @@
 // Local includes
 
 #include "batchtool.h"
-#include "batchtoolsmanager.h"
+#include "batchtoolsfactory.h"
 
 namespace Digikam
 {
@@ -47,7 +47,7 @@ class ToolListViewGroup : public QTreeWidgetItem
 public:
 
     ToolListViewGroup(QTreeWidget* const parent, BatchTool::BatchToolGroup group);
-    virtual ~ToolListViewGroup();
+    ~ToolListViewGroup();
 
     BatchTool::BatchToolGroup toolGroup() const;
 
@@ -63,9 +63,8 @@ class ToolListViewItem : public QTreeWidgetItem
 
 public:
 
-
     ToolListViewItem(ToolListViewGroup* const parent, BatchTool* const tool);
-    virtual ~ToolListViewItem();
+    ~ToolListViewItem();
 
     BatchTool* tool() const;
 
@@ -83,7 +82,7 @@ class ToolsListView : public QTreeWidget
 public:
 
     explicit ToolsListView(QWidget* const parent);
-    virtual ~ToolsListView();
+    ~ToolsListView();
 
     BatchToolsList toolsList();
 
@@ -98,10 +97,12 @@ private Q_SLOTS:
 
     void slotContextMenu();
     void slotAssignTools();
+    void slotToolVisible(bool);
 
 private:
 
-    bool findTool(BatchTool* const tool);
+    bool hasTool(BatchTool* const tool);
+    ToolListViewItem* findTool(BatchTool* const tool);
     ToolListViewGroup* findToolGroup(BatchTool::BatchToolGroup group);
 
     void startDrag(Qt::DropActions supportedActions);
@@ -112,6 +113,6 @@ private:
     QMap<int, QString> itemsToMap(const QList<QTreeWidgetItem*> items) const;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // TOOLS_LIST_VIEW_H
+#endif // DIGIKAM_BQM_TOOLS_LIST_VIEW_H
