@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-04-20
- * Description : a view to available tools in tab view.
+ * Description : a view to host all available tools.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,13 +43,13 @@
 namespace Digikam
 {
 
-class ToolsView::Private
+class Q_DECL_HIDDEN ToolsView::Private
 {
 
 public:
 
-    Private() :
-        baseTools(0),
+    explicit Private()
+      : baseTools(0),
         historyView(0),
         workflow(0)
     {
@@ -209,4 +209,4 @@ void ToolsView::slotHistoryEntryClicked(const QVariant& metadata)
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
