@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-04-20
- * Description : a view to available tools in tab view.
+ * Description : a view to host all available tools.
  *
- * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef TOOLS_VIEW_H
-#define TOOLS_VIEW_H
+#ifndef DIGIKAM_BQM_TOOLS_VIEW_H
+#define DIGIKAM_BQM_TOOLS_VIEW_H
 
 // Local includes
 
@@ -75,6 +75,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* QUEUE_SETTINGS_VIEW_H */
+#endif // DIGIKAM_BQM_TOOLS_VIEW_H
