@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-12-19
  * Description : Workflow properties dialog.
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,18 +49,16 @@
 #include "dxmlguiwindow.h"
 #include "dexpanderbox.h"
 
-
-
 namespace Digikam
 {
 
-class WorkflowDlg::Private
+class Q_DECL_HIDDEN WorkflowDlg::Private
 {
 
 public:
 
-    Private() :
-        buttons(0),
+    explicit Private()
+      : buttons(0),
         titleEdit(0),
         descEdit(0)
     {
@@ -227,4 +225,4 @@ void WorkflowDlg::slotHelp()
     DXmlGuiWindow::openHandbook();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
