@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2012-12-18
  * Description : Customized Workflow Settings list.
  *
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef WORKFLOW_LIST_H
-#define WORKFLOW_LIST_H
+#ifndef DIGIKAM_BQM_WORK_FLOW_LIST_H
+#define DIGIKAM_BQM_WORK_FLOW_LIST_H
 
 // Qt includes
 
@@ -36,7 +36,7 @@
 // Local includes
 
 #include "batchtool.h"
-#include "batchtoolsmanager.h"
+#include "batchtoolsfactory.h"
 
 namespace Digikam
 {
@@ -91,6 +91,6 @@ private:
     void mouseDoubleClickEvent(QMouseEvent*);
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // WORKFLOW_LIST_H
+#endif // DIGIKAM_BQM_WORK_FLOW_LIST_H
