@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-01-20
  * Description : User interface for searches
  *
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SEARCHFIELDS_H
-#define SEARCHFIELDS_H
+#ifndef DIGIKAM_SEARCH_FIELDS_H
+#define DIGIKAM_SEARCH_FIELDS_H
 
 // Qt includes
 
@@ -520,4 +520,4 @@ protected:
 
 } // namespace Digikam
 
-#endif /* SEARCHFIELDS_H */
+#endif // DIGIKAM_SEARCH_FIELDS_H
