@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-21
  * Description : Searches folder view
  *
  * Copyright (C) 2005      by Renchi Raju <renchi at pooh dot tam dot uiuc dot edu>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C) 2009      by Johannes Wienke <languitar at semipol dot de>
  *
@@ -39,12 +39,12 @@
 namespace Digikam
 {
 
-class NormalSearchTreeView::Private
+class Q_DECL_HIDDEN NormalSearchTreeView::Private
 {
 public:
 
-    Private() :
-        newAction(0),
+    explicit Private()
+      : newAction(0),
         editAction(0)
     {
     }
