@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-21
  * Description : Searches folder view
  *
  * Copyright (C) 2005      by Renchi Raju <renchi at pooh dot tam dot uiuc dot edu>
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Johannes Wienke <languitar at semipol dot de>
  *
  * This program is free software; you can redistribute it
@@ -24,8 +24,8 @@
  *
  * ============================================================ */
 
-#ifndef SEARCHFOLDERVIEW_H
-#define SEARCHFOLDERVIEW_H
+#ifndef DIGIKAM_SEARCH_FOLDER_VIEW_H
+#define DIGIKAM_SEARCH_FOLDER_VIEW_H
 
 // Local includes
 
@@ -89,4 +89,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* SEARCHFOLDERVIEW_H */
+#endif //  DIGIKAM_SEARCH_FOLDER_VIEW_H
