@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-01-20
  * Description : User interface for searches
  *
  * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -99,7 +99,7 @@ void SearchGroup::setup(Type type)
     group->addField(SearchField::createField(QLatin1String("albumcollection"), group));
     group->addField(SearchField::createField(QLatin1String("tagid"),           group));
     group->addField(SearchField::createField(QLatin1String("tagname"),         group));
-    group->addField(SearchField::createField(QLatin1String("notag"),           group));
+    group->addField(SearchField::createField(QLatin1String("nottagged"),       group));
     group->addField(SearchField::createField(QLatin1String("filename"),        group));
 
     m_fieldLabels << label;
@@ -138,7 +138,7 @@ void SearchGroup::setup(Type type)
     // ----- //
 
     label = new SearchFieldGroupLabel(this);
-    label->setTitle(i18n("Video Properties"));
+    label->setTitle(i18n("Audio/Video Properties"));
     group = new SearchFieldGroup(this);
     group->setLabel(label);
 
@@ -148,7 +148,7 @@ void SearchGroup::setup(Type type)
     group->addField(SearchField::createField(QLatin1String("videocodec"),            group));
     group->addField(SearchField::createField(QLatin1String("videoaudiobitrate"),     group));
     group->addField(SearchField::createField(QLatin1String("videoaudiochanneltype"), group));
-    group->addField(SearchField::createField(QLatin1String("videoaudiocompressor"),  group));
+    group->addField(SearchField::createField(QLatin1String("videoaudioCodec"),       group));
 
     m_fieldLabels << label;
     m_fieldGroups << group;
@@ -162,6 +162,7 @@ void SearchGroup::setup(Type type)
     group = new SearchFieldGroup(this);
     group->setLabel(label);
 
+    group->addField(SearchField::createField(QLatin1String("creator"),       group));
     group->addField(SearchField::createField(QLatin1String("comment"),       group));
     group->addField(SearchField::createField(QLatin1String("commentauthor"), group));
     group->addField(SearchField::createField(QLatin1String("headline"),      group));
@@ -378,7 +379,7 @@ QList<QRect> SearchGroup::startupAnimationArea() const
 
 // -------------------------------------------------------------------------
 
-class RadioButtonHBox : public QHBoxLayout
+class Q_DECL_HIDDEN RadioButtonHBox : public QHBoxLayout
 {
 public:
 
@@ -400,24 +401,24 @@ public:
     }
 };
 
-class SearchGroupLabel::Private
+class Q_DECL_HIDDEN SearchGroupLabel::Private
 {
 public:
 
-    Private() :
-      extended(false),
-      groupOp(SearchXml::And),
-      fieldOp(SearchXml::And),
-      layout(0),
-      groupOpLabel(0),
-      allBox(0),
-      anyBox(0),
-      noneBox(0),
-      oneNotBox(0),
-      optionsLabel(0),
-      removeLabel(0),
-      stackedLayout(0),
-      themeCache(0)
+    explicit Private()
+      : extended(false),
+        groupOp(SearchXml::And),
+        fieldOp(SearchXml::And),
+        layout(0),
+        groupOpLabel(0),
+        allBox(0),
+        anyBox(0),
+        noneBox(0),
+        oneNotBox(0),
+        optionsLabel(0),
+        removeLabel(0),
+        stackedLayout(0),
+        themeCache(0)
     {
     }
 
@@ -438,14 +439,15 @@ public:
 };
 
 SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache* const cache, SearchGroup::Type type, QWidget* const parent)
-    : QWidget(parent), d(new Private)
+    : QWidget(parent),
+      d(new Private)
 {
     d->themeCache = cache;
     d->layout     = new QGridLayout;
 
     // leave styling to style sheet (by object name)
 
-    QLabel* const mainLabel = new QLabel(i18n("Find Pictures"));
+    QLabel* const mainLabel = new QLabel(i18n("Find Items"));
     mainLabel->setObjectName(QLatin1String("SearchGroupLabel_MainLabel"));
 
     // Use radio button with a separate label to fix styling problem, see bug 195809
@@ -493,7 +495,7 @@ SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache* const cache, Sear
         QLabel* const simpleLabel1      = new QLabel;
         //simpleLabel->setText(i18n("Find Pictures meeting all of these conditions"));
         //simpleLabel->setPixmap(QIcon::fromTheme(QLatin1String("edit-find")).pixmap(128));
-        simpleLabel1->setText(i18n("<qt><p>Search your collection<br/>for pictures meeting the following conditions</p></qt>"));
+        simpleLabel1->setText(i18n("<qt><p>Search your collection<br/>for Items meeting the following conditions</p></qt>"));
         simpleLabel1->setObjectName(QLatin1String("SearchGroupLabel_SimpleLabel"));
         headerLayout->addStretch(3);
         headerLayout->addWidget(simpleLabel1);
@@ -503,9 +505,9 @@ SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache* const cache, Sear
 
         QWidget* const optionsBox        = new QWidget;
         QGridLayout* const optionsLayout = new QGridLayout;
-        optionsLayout->addLayout(new RadioButtonHBox(d->allBox, allBoxLabel, layoutDirection()),       0, 0);
-        optionsLayout->addLayout(new RadioButtonHBox(d->anyBox, anyBoxLabel, layoutDirection()),       1, 0);
-        optionsLayout->addLayout(new RadioButtonHBox(d->noneBox, noneBoxLabel, layoutDirection()),     0, 1);
+        optionsLayout->addLayout(new RadioButtonHBox(d->allBox,    allBoxLabel,    layoutDirection()), 0, 0);
+        optionsLayout->addLayout(new RadioButtonHBox(d->anyBox,    anyBoxLabel,    layoutDirection()), 1, 0);
+        optionsLayout->addLayout(new RadioButtonHBox(d->noneBox,   noneBoxLabel,   layoutDirection()), 0, 1);
         optionsLayout->addLayout(new RadioButtonHBox(d->oneNotBox, oneNotBoxLabel, layoutDirection()), 1, 1);
         optionsLayout->setContentsMargins(QMargins());
         optionsBox->setLayout(optionsLayout);
