@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-02-26
  * Description : Upper widget in the search sidebar
@@ -38,10 +38,13 @@
 #include <QLineEdit>
 #include <QInputDialog>
 #include <QIcon>
+#include <QMenu>
+#include <QContextMenuEvent>
 
 // KDE includes
 
 #include <klocalizedstring.h>
+#include <kconfiggroup.h>
 
 // Local includes
 
@@ -56,14 +59,18 @@
 namespace Digikam
 {
 
-class KeywordLineEdit : public QLineEdit
+class Q_DECL_HIDDEN KeywordLineEdit : public QLineEdit
 {
 public:
 
     explicit KeywordLineEdit(QWidget* const parent = 0)
         : QLineEdit(parent)
     {
-        m_hasAdvanced = false;
+        m_hasAdvanced             = false;
+
+        KSharedConfig::Ptr config = KSharedConfig::openConfig();
+        KConfigGroup group        = config->group(QLatin1String("KeywordSearchEdit Settings"));
+        m_autoSearch              = group.readEntry(QLatin1String("Autostart Search"), true);
     }
 
     void showAdvancedSearch(bool hasAdvanced)
@@ -97,6 +104,28 @@ public:
         }
     }
 
+    void contextMenuEvent(QContextMenuEvent* e)
+    {
+        QAction* const action = new QAction(i18nc("@action:inmenu",
+                                                  "Autostart Search"), this);
+        action->setCheckable(true);
+        action->setChecked(m_autoSearch);
+
+        connect(action, &QAction::triggered,
+                this, &KeywordLineEdit::toggleAutoSearch);
+
+        QMenu* const menu = createStandardContextMenu();
+        menu->addSeparator();
+        menu->addAction(action);
+        menu->exec(e->globalPos());
+        delete menu;
+    }
+
+    bool autoSearchEnabled() const
+    {
+        return m_autoSearch;
+    }
+
     void adjustStatus(bool adv)
     {
         if (adv)
@@ -118,18 +147,30 @@ public:
         }
     }
 
+public Q_SLOTS:
+
+    void toggleAutoSearch()
+    {
+        m_autoSearch              = !m_autoSearch;
+
+        KSharedConfig::Ptr config = KSharedConfig::openConfig();
+        KConfigGroup group        = config->group(QLatin1String("KeywordSearchEdit Settings"));
+        group.writeEntry(QLatin1String("Autostart Search"), m_autoSearch);
+    }
+
 protected:
 
     bool m_hasAdvanced;
+    bool m_autoSearch;
 };
 
 // -------------------------------------------------------------------------
 
-class SearchTabHeader::Private
+class Q_DECL_HIDDEN SearchTabHeader::Private
 {
 public:
 
-    Private() :
+    explicit Private() :
         newSearchWidget(0),
         saveAsWidget(0),
         editSimpleWidget(0),
@@ -186,6 +227,7 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
     const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     QVBoxLayout* const mainLayout = new QVBoxLayout(this);
+    mainLayout->setContentsMargins(QMargins());
     setLayout(mainLayout);
 
     // upper part
@@ -216,9 +258,9 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
 
     d->advancedEditLabel      = new QPushButton(i18n("Advanced Search..."), this);
 
-    grid1->addWidget(searchLabel,          0, 0);
-    grid1->addWidget(d->keywordEdit,       0, 1);
-    grid1->addWidget(d->advancedEditLabel, 1, 1);
+    grid1->addWidget(searchLabel,          0, 0, 1, 1);
+    grid1->addWidget(d->keywordEdit,       0, 1, 1, 1);
+    grid1->addWidget(d->advancedEditLabel, 1, 0, 1, 2);
     grid1->setContentsMargins(spacing, spacing, spacing, spacing);
     grid1->setSpacing(spacing);
 
@@ -298,7 +340,7 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
             d->keywordEditTimer, SLOT(start()));
 
     connect(d->keywordEditTimer, SIGNAL(timeout()),
-            this, SLOT(keywordChanged()));
+            this, SLOT(keywordChangedTimer()));
 
     connect(d->keywordEdit, SIGNAL(editingFinished()),
             this, SLOT(keywordChanged()));
@@ -346,7 +388,6 @@ SearchWindow* SearchTabHeader::searchWindow() const
 
 void SearchTabHeader::selectedSearchChanged(Album* a)
 {
-
     SAlbum* album = dynamic_cast<SAlbum*>(a);
 
     // Signal from SearchFolderView that a search has been selected.
@@ -451,6 +492,14 @@ void SearchTabHeader::keywordChanged()
     d->keywordEdit->setFocus();
 }
 
+void SearchTabHeader::keywordChangedTimer()
+{
+    if (d->keywordEdit->autoSearchEnabled())
+    {
+        keywordChanged();
+    }
+}
+
 void SearchTabHeader::editCurrentAdvancedSearch()
 {
     SAlbum* album        = AlbumManager::instance()->findSAlbum(SAlbum::getTemporaryTitle(DatabaseSearch::AdvancedSearch));
