@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-03-14
  * Description : User interface for searches
@@ -41,7 +41,6 @@
 #include <QPropertyAnimation>
 #include <QStyle>
 #include <QStyleOption>
-#include <QTextEdit>
 #include <QTimeLine>
 #include <QVBoxLayout>
 #include <QPushButton>
@@ -63,7 +62,7 @@
 namespace Digikam
 {
 
-class AnimatedClearButton::Private : public AnimatedVisibility
+class Q_DECL_HIDDEN AnimatedClearButton::Private : public AnimatedVisibility
 {
 public:
 
@@ -172,16 +171,16 @@ void AnimatedClearButton::mouseReleaseEvent(QMouseEvent* event)
 
 // ------------------------------------------------------------------------
 
-class CustomStepsDoubleSpinBox::Private
+class Q_DECL_HIDDEN CustomStepsDoubleSpinBox::Private
 {
 public:
 
-    Private() :
-      beforeInitialValue(true),
-      initialValue(0),
-      smallerStep(0),
-      largerStep(0),
-      invertStepping(false)
+    explicit Private()
+      : beforeInitialValue(true),
+        initialValue(0),
+        smallerStep(0),
+        largerStep(0),
+        invertStepping(false)
     {
     }
 
@@ -343,16 +342,16 @@ void CustomStepsDoubleSpinBox::slotValueChanged(double val)
 
 // ------------------------------------------------------------------------
 
-class CustomStepsIntSpinBox::Private
+class Q_DECL_HIDDEN CustomStepsIntSpinBox::Private
 {
 public:
 
-    Private() :
-      beforeInitialValue(true),
-      initialValue(0),
-      smallerStep(0),
-      largerStep(0),
-      invertStepping(false)
+    explicit Private()
+      : beforeInitialValue(true),
+        initialValue(0),
+        smallerStep(0),
+        largerStep(0),
+        invertStepping(false)
     {
     }
 
