@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-01
  * Description : album view configuration setup tab
  *
  * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -33,7 +33,6 @@
 #include <QLabel>
 #include <QRadioButton>
 #include <QVBoxLayout>
-#include <QApplication>
 #include <QStyle>
 #include <QComboBox>
 #include <QApplication>
@@ -58,12 +57,12 @@
 namespace Digikam
 {
 
-class SetupAlbumView::Private
+class Q_DECL_HIDDEN SetupAlbumView::Private
 {
 public:
 
-    Private() :
-        useLargeThumbsOriginal(false),
+    explicit Private()
+      : useLargeThumbsOriginal(false),
         useLargeThumbsShowedInfo(false),
         iconTreeThumbLabel(0),
         iconShowNameBox(0),
@@ -84,7 +83,6 @@ public:
         previewFullView(0),
         previewRawMode(0),
         previewConvertToEightBit(0),
-        previewZoomOrgSize(0),
         previewShowIcons(0),
         showFolderTreeViewItemsCount(0),
         largeThumbsBox(0),
@@ -122,7 +120,6 @@ public:
     QRadioButton*       previewFullView;
     QComboBox*          previewRawMode;
     QCheckBox*          previewConvertToEightBit;
-    QCheckBox*          previewZoomOrgSize;
     QCheckBox*          previewShowIcons;
     QCheckBox*          showFolderTreeViewItemsCount;
     QCheckBox*          largeThumbsBox;
@@ -168,7 +165,7 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
 
     d->iconShowModDateBox     = new QCheckBox(i18n("Show file &modification date"), iwpanel);
     d->iconShowModDateBox->setWhatsThis(i18n("Set this option to show the file modification date "
-                                             "below the image thumbnail if it's different than camera creation date. "
+                                             "below the image thumbnail if it is different than camera creation date. "
                                              "This option is useful to identify quickly which items have been modified."));
 
     d->iconShowResolutionBox  = new QCheckBox(i18n("Show ima&ge dimensions"), iwpanel);
@@ -263,6 +260,7 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     d->iconTreeThumbSize->addItem(QLatin1String("22"));
     d->iconTreeThumbSize->addItem(QLatin1String("32"));
     d->iconTreeThumbSize->addItem(QLatin1String("48"));
+    d->iconTreeThumbSize->addItem(QLatin1String("64"));
     d->iconTreeThumbSize->setToolTip(i18n("Set this option to configure the size in pixels of "
                                           "the Tree View icons in digiKam's sidebars."));
 
@@ -304,9 +302,6 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     d->previewConvertToEightBit   = new QCheckBox(i18n("Preview image is converted to 8 bits for a faster viewing"), pwpanel);
     d->previewConvertToEightBit->setWhatsThis(i18n("Uncheck this if you do not want to convert a 16 bits preview image to 8 bits."));
 
-    d->previewZoomOrgSize         = new QCheckBox(i18n("Preview is zoomed to the original image size"), pwpanel);
-    d->previewZoomOrgSize->setWhatsThis(i18n("Uncheck this if you do not want to zoom the preview to the original image size."));
-
     d->previewShowIcons           = new QCheckBox(i18n("Show icons and text over preview"), pwpanel);
     d->previewShowIcons->setWhatsThis(i18n("Uncheck this if you do not want to see icons and text in the image preview."));
 
@@ -317,9 +312,8 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     grid3->addWidget(rawPreviewLabel,             2, 0, 1, 1);
     grid3->addWidget(d->previewRawMode,           2, 1, 1, 1);
     grid3->addWidget(d->previewConvertToEightBit, 3, 0, 1, 2);
-    grid3->addWidget(d->previewZoomOrgSize,       4, 0, 1, 2);
-    grid3->addWidget(d->previewShowIcons,         5, 0, 1, 2);
-    grid3->setRowStretch(6, 10);
+    grid3->addWidget(d->previewShowIcons,         4, 0, 1, 2);
+    grid3->setRowStretch(5, 10);
 
     d->previewFastPreview->setChecked(true);
     d->previewRawMode->setCurrentIndex(0);
@@ -405,7 +399,6 @@ void SetupAlbumView::applySettings()
     previewSettings.quality           = d->previewFastPreview->isChecked() ? PreviewSettings::FastPreview : PreviewSettings::HighQualityPreview;
     previewSettings.rawLoading        = (PreviewSettings::RawLoading)d->previewRawMode->itemData(d->previewRawMode->currentIndex()).toInt();
     previewSettings.convertToEightBit = d->previewConvertToEightBit->isChecked();
-    previewSettings.zoomOrgSize       = d->previewZoomOrgSize->isChecked();
     settings->setPreviewSettings(previewSettings);
 
     settings->setPreviewShowIcons(d->previewShowIcons->isChecked());
@@ -446,10 +439,14 @@ void SetupAlbumView::readSettings()
     {
         d->iconTreeThumbSize->setCurrentIndex(2);
     }
-    else
+    else if (settings->getTreeViewIconSize() == 48)
     {
         d->iconTreeThumbSize->setCurrentIndex(3);
     }
+    else
+    {
+        d->iconTreeThumbSize->setCurrentIndex(4);
+    }
 
     d->treeViewFontSelect->setFont(settings->getTreeViewFont());
     d->iconShowNameBox->setChecked(settings->getIconShowName());
@@ -484,7 +481,6 @@ void SetupAlbumView::readSettings()
 
     d->previewRawMode->setCurrentIndex(d->previewRawMode->findData(previewSettings.rawLoading));
 
-    d->previewZoomOrgSize->setChecked(previewSettings.zoomOrgSize);
     d->previewShowIcons->setChecked(settings->getPreviewShowIcons());
     d->previewConvertToEightBit->setChecked(previewSettings.convertToEightBit);
     d->showFolderTreeViewItemsCount->setChecked(settings->getShowFolderTreeViewItemsCount());
