@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-01
  * Description : album view configuration setup tab
  *
  * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPALBUMVIEW_H
-#define SETUPALBUMVIEW_H
+#ifndef DIGIKAM_SETUP_ALBUM_VIEW_H
+#define DIGIKAM_SETUP_ALBUM_VIEW_H
 
 // Qt includes
 
@@ -73,4 +73,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SETUPALBUMVIEW_H
+#endif // DIGIKAM_SETUP_ALBUM_VIEW_H
