@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-01-02
  * Description : album category setup tab.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -31,7 +31,6 @@
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QLabel>
-#include <QLineEdit>
 #include <QPushButton>
 #include <QRadioButton>
 #include <QVBoxLayout>
@@ -54,12 +53,12 @@
 namespace Digikam
 {
 
-class SetupCategory::Private
+class Q_DECL_HIDDEN SetupCategory::Private
 {
 public:
 
-    Private() :
-        addCategoryButton(0),
+    explicit Private()
+      : addCategoryButton(0),
         delCategoryButton(0),
         repCategoryButton(0),
         albumCategoryBox(0),
