@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-05-03
  * Description : mime types setup tab
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -53,12 +53,12 @@
 namespace Digikam
 {
 
-class SetupMime::Private
+class Q_DECL_HIDDEN SetupMime::Private
 {
 public:
 
-    Private() :
-        imageFileFilterLabel(0),
+    explicit Private()
+      : imageFileFilterLabel(0),
         movieFileFilterLabel(0),
         audioFileFilterLabel(0),
         imageFileFilterEdit(0),
@@ -90,7 +90,7 @@ SetupMime::SetupMime(QWidget* const parent)
     // --------------------------------------------------------
 
     QLabel* const explanationLabel = new QLabel;
-    explanationLabel->setText(i18n("<p>Add new file types to show as album items. "
+    explanationLabel->setText(i18n("<p>Add new file types to show as album items.</p>"
                                    "<p>digiKam attempts to support all of the image formats that digital cameras produce, "
                                    "while being able to handle a few other important video and audio formats.</p> "
                                    "<p>You can add to the already-appreciable list of formats that digiKam handles by "
@@ -134,14 +134,14 @@ SetupMime::SetupMime(QWidget* const parent)
 
     // --------------------------------------------------------
 
-    QGroupBox* const movieFileFilterBox = new QGroupBox(i18n("Movie Files"), panel);
+    QGroupBox* const movieFileFilterBox = new QGroupBox(i18n("Video Files"), panel);
     QGridLayout* const grid2            = new QGridLayout(movieFileFilterBox);
 
     QLabel* const logoLabel2 = new QLabel(movieFileFilterBox);
     logoLabel2->setPixmap(QIcon::fromTheme(QLatin1String("video-x-matroska")).pixmap(48));
 
     d->movieFileFilterLabel  = new QLabel(movieFileFilterBox);
-    d->movieFileFilterLabel->setText(i18n("Additional &movie file extensions (<a href='video'>Currently-supported types</a>):"));
+    d->movieFileFilterLabel->setText(i18n("Additional &video file extensions (<a href='video'>Currently-supported types</a>):"));
 
     DHBox* const hbox2       = new DHBox(movieFileFilterBox);
     d->movieFileFilterEdit   = new QLineEdit(hbox2);
@@ -149,7 +149,7 @@ SetupMime::SetupMime(QWidget* const parent)
                                               "to be displayed in your Album view. Just write \"xyz abc\" "
                                               "to support files with the *.xyz and *.abc extensions. "
                                               "Clicking on these files will "
-                                              "play them in an embedded movie player.</p>"
+                                              "play them in an embedded video player.</p>"
                                               "<p>You can also remove file formats that are supported by default "
                                               "by putting a minus sign in front of the extension: e.g. \"-avi\" would remove "
                                               "all AVI files from your Album view and any trace of them in your database. "
@@ -157,7 +157,7 @@ SetupMime::SetupMime(QWidget* const parent)
                                               "<p><b>Warning:</b> Removing files from the database means losing "
                                               "all of their tags and ratings.</p>"));
     d->movieFileFilterEdit->setClearButtonEnabled(true);
-    d->movieFileFilterEdit->setPlaceholderText(i18n("Enter additional movie file extensions."));
+    d->movieFileFilterEdit->setPlaceholderText(i18n("Enter additional video file extensions."));
     d->movieFileFilterLabel->setBuddy(d->movieFileFilterEdit);
     hbox2->setStretchFactor(d->movieFileFilterEdit, 10);
 
@@ -261,7 +261,7 @@ void SetupMime::applySettings()
                                                "with these formats, they will be removed from the database and you will "
                                                "lose all information about them, including rating and tags.</p>"
                                                "<p>Are you sure you want to apply your changes and lose the support for these formats?</p>",
-                                               removedImageFormats.join(QLatin1String(" "))),
+                                               removedImageFormats.join(QLatin1Char(' '))),
                                           QMessageBox::Yes | QMessageBox::No);
 
         if (result != QMessageBox::Yes)
@@ -276,6 +276,10 @@ void SetupMime::applySettings()
 
     CoreDbAccess().db()->getUserFilterSettings(&imageFilterString, &movieFilterString, &audioFilterString);
 
+    imageFilterString.replace(QLatin1Char(';'), QLatin1Char(' '));
+    movieFilterString.replace(QLatin1Char(';'), QLatin1Char(' '));
+    audioFilterString.replace(QLatin1Char(';'), QLatin1Char(' '));
+
     if (d->imageFileFilterEdit->text() != imageFilterString ||
         d->movieFileFilterEdit->text() != movieFilterString ||
         d->audioFileFilterEdit->text() != audioFilterString)
@@ -306,7 +310,7 @@ void SetupMime::slotShowCurrentImageSettings()
     CoreDbAccess().db()->getFilterSettings(&imageList, 0, 0);
     QString text = i18n("<p>Files with these extensions will be recognized as images "
                         "and included into the database:<br/> <code>%1</code></p>",
-                        imageList.join(QLatin1String(" ")));
+                        imageList.join(QLatin1Char(' ')));
     QWhatsThis::showText(d->imageFileFilterLabel->mapToGlobal(QPoint(0, 0)), text, d->imageFileFilterLabel);
 }
 
@@ -314,9 +318,9 @@ void SetupMime::slotShowCurrentMovieSettings()
 {
     QStringList movieList;
     CoreDbAccess().db()->getFilterSettings(0, &movieList, 0);
-    QString text = i18n("<p>Files with these extensions will be recognized as movie files "
+    QString text = i18n("<p>Files with these extensions will be recognized as video files "
                         "and included into the database:<br/> <code>%1</code></p>",
-                        movieList.join(QLatin1String(" ")));
+                        movieList.join(QLatin1Char(' ')));
     QWhatsThis::showText(d->movieFileFilterLabel->mapToGlobal(QPoint(0, 0)), text, d->movieFileFilterLabel);
 }
 
@@ -326,7 +330,7 @@ void SetupMime::slotShowCurrentAudioSettings()
     CoreDbAccess().db()->getFilterSettings(0, 0, &audioList);
     QString text = i18n("<p>Files with these extensions will be recognized as audio files "
                         "and included into the database:<br/> <code>%1</code></p>",
-                        audioList.join(QLatin1String(" ")));
+                        audioList.join(QLatin1Char(' ')));
     QWhatsThis::showText(d->audioFileFilterLabel->mapToGlobal(QPoint(0, 0)), text, d->audioFileFilterLabel);
 }
 
