@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-03
  * Description : Cameras list container
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -56,12 +56,12 @@ CameraList* CameraList::defaultList()
     return m_defaultList;
 }
 
-class CameraList::Private
+class Q_DECL_HIDDEN CameraList::Private
 {
 public:
 
-    Private() :
-        modified(false)
+    explicit Private()
+      : modified(false)
     {
     }
 
@@ -111,6 +111,7 @@ bool CameraList::load()
 
     if (!doc.setContent(&cfile))
     {
+        cfile.close();
         return false;
     }
 
@@ -118,6 +119,7 @@ bool CameraList::load()
 
     if (docElem.tagName() != QLatin1String("cameralist"))
     {
+        cfile.close();
         return false;
     }
 
@@ -144,6 +146,7 @@ bool CameraList::load()
         insertPrivate(ctype);
     }
 
+    cfile.close();
     return true;
 }
 
@@ -335,4 +338,4 @@ bool CameraList::changeCameraStartIndex(const QString& cameraTitle, int startInd
     return false;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
