@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-10
  * Description : Camera type selection dialog
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +30,6 @@
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QLabel>
-#include <QPushButton>
 #include <QRadioButton>
 #include <QTreeWidget>
 #include <QUrl>
@@ -58,12 +57,12 @@
 namespace Digikam
 {
 
-class CameraSelection::Private
+class Q_DECL_HIDDEN CameraSelection::Private
 {
 public:
 
-    Private() :
-        buttons(0),
+    explicit Private()
+      : buttons(0),
         portButtonGroup(0),
         usbButton(0),
         serialButton(0),
@@ -206,7 +205,7 @@ CameraSelection::CameraSelection(QWidget* const parent)
 
     d->umsMountURL = new DFileSelector(umsMountBox);
     d->umsMountURL->setFileDlgPath(QLatin1String("/mnt/camera"));
-    d->umsMountURL->setFileDlgMode(DFileDialog::Directory);
+    d->umsMountURL->setFileDlgMode(QFileDialog::Directory);
     d->umsMountURL->setWhatsThis(i18n("<p>Set here the mount path to use on your computer. This "
                                       "option is only required if you use a <b>USB Mass Storage</b> "
                                       "camera.</p>"));
