@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-01-29
  * Description : Camera settings container.
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef CAMERATYPE_H
-#define CAMERATYPE_H
+#ifndef DIGIKAM_CAMERA_TYPE_H
+#define DIGIKAM_CAMERA_TYPE_H
 
 // Qt includes
 
@@ -74,6 +74,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* CAMERATYPE_H */
+#endif // DIGIKAM_CAMERA_TYPE_H
