@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-12-16
  * Description : Import filters configuration dialog
  *
  * Copyright (C) 2010-2011 by Petri Damstén <petri dot damsten at iki dot fi>
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef IMPORTFILTERS_H
-#define IMPORTFILTERS_H
+#ifndef DIGIKAM_IMPORT_FILTERS_H
+#define DIGIKAM_IMPORT_FILTERS_H
 
 // Qt includes
 
@@ -63,4 +63,4 @@ private:
 
 } // namespace Digikam
 
-#endif /* IMPORTFILTERS_H */
+#endif // DIGIKAM_IMPORT_FILTERS_H
