@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-10
  * Description : camera setup tab.
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -31,6 +31,7 @@
 #include <QGroupBox>
 #include <QHeaderView>
 #include <QPixmap>
+#include <QPointer>
 #include <QCheckBox>
 #include <QPushButton>
 #include <QRadioButton>
@@ -69,12 +70,12 @@
 namespace Digikam
 {
 
-class SetupCameraItem : public QTreeWidgetItem
+class Q_DECL_HIDDEN SetupCameraItem : public QTreeWidgetItem
 {
 
 public:
 
-    SetupCameraItem(QTreeWidget* const parent, CameraType* const ctype)
+    explicit SetupCameraItem(QTreeWidget* const parent, CameraType* const ctype)
         : QTreeWidgetItem(parent), m_ctype(0)
     {
         setCameraType(ctype);
@@ -112,11 +113,11 @@ private:
 
 // -------------------------------------------------------------------
 
-class CameraAutoDetectThread::Private
+class Q_DECL_HIDDEN CameraAutoDetectThread::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         result = 0;
     }
@@ -161,12 +162,12 @@ QString CameraAutoDetectThread::port() const
 
 // -------------------------------------------------------------------
 
-class SetupCamera::Private
+class Q_DECL_HIDDEN SetupCamera::Private
 {
 public:
 
-    Private() :
-        addButton(0),
+    explicit Private()
+      : addButton(0),
         removeButton(0),
         editButton(0),
         autoDetectButton(0),
@@ -534,7 +535,7 @@ SetupCamera::SetupCamera(QWidget* const parent)
     d->previewItemsWhileDownload->setWhatsThis(i18n("<p>Set this option to preview each item while downloading.</p>"));
 
     d->previewShowIcons          = new QCheckBox(i18n("Show icons and text over preview"), interfaceOptionsGroup);
-    d->previewShowIcons->setWhatsThis(i18n("Uncheck this if you don't want to see icons and text in the image preview."));
+    d->previewShowIcons->setWhatsThis(i18n("Uncheck this if you do not want to see icons and text in the image preview."));
 
     grid3->setContentsMargins(spacing, spacing, spacing, spacing);
     grid3->setSpacing(spacing);
@@ -830,8 +831,8 @@ void SetupCamera::slotAddCamera()
 {
     CameraSelection* const select = new CameraSelection;
 
-    connect(select, SIGNAL(signalOkClicked(QString, QString, QString, QString)),
-            this,   SLOT(slotAddedCamera(QString, QString, QString, QString)));
+    connect(select, SIGNAL(signalOkClicked(QString,QString,QString,QString)),
+            this,   SLOT(slotAddedCamera(QString,QString,QString,QString)));
 
     select->show();
 }
@@ -936,18 +937,20 @@ void SetupCamera::slotImportSelectionChanged()
 void SetupCamera::slotAddFilter()
 {
     Filter filter;
-    filter.name = i18n("Untitled");
-    ImportFilters dlg(this);
-    dlg.setData(filter);
+    filter.name                 = i18n("Untitled");
+    QPointer<ImportFilters> dlg = new ImportFilters(this);
+    dlg->setData(filter);
 
-    if (dlg.exec() == QDialog::Accepted)
+    if (dlg->exec() == QDialog::Accepted)
     {
         Filter* const f = new Filter;
-        dlg.getData(f);
+        dlg->getData(f);
         d->filters.append(f);
         new QListWidgetItem(f->name, d->importListView);
     }
 
+    delete dlg;
+
     slotImportSelectionChanged();
 }
 
@@ -956,7 +959,7 @@ void SetupCamera::slotRemoveFilter()
     QListWidgetItem* const item = d->importListView->currentItem();
     int current                 = d->importListView->currentRow();
 
-    for (int i = 0 ; i < d->filters.count() ; i++)
+    for (int i = 0 ; i < d->filters.count() ; ++i)
     {
         if (d->filters.at(i)->name == item->text())
         {
@@ -972,21 +975,22 @@ void SetupCamera::slotEditFilter()
 {
     QListWidgetItem* const item = d->importListView->currentItem();
 
-    for (int i = 0 ; i < d->filters.count() ; i++)
+    for (int i = 0 ; i < d->filters.count() ; ++i)
     {
         if (d->filters.at(i)->name == item->text())
         {
-            Filter filter = *d->filters.at(i);
-            ImportFilters dlg(this);
-            dlg.setData(filter);
+            Filter filter               = *d->filters.at(i);
+            QPointer<ImportFilters> dlg = new ImportFilters(this);
+            dlg->setData(filter);
 
-            if (dlg.exec() == QDialog::Accepted)
+            if (dlg->exec() == QDialog::Accepted)
             {
                 Filter* const f = d->filters.at(i);
-                dlg.getData(f);
+                dlg->getData(f);
                 item->setText(f->name);
             }
 
+            delete dlg;
             break;
         }
     }
@@ -1011,4 +1015,4 @@ void SetupCamera::slotPreviewFullImageSizeClicked()
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
