@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-11-15
  * Description : widget item delegate for setup collection view
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef DW_ITEM_DELEGATE_H
-#define DW_ITEM_DELEGATE_H
+#ifndef DIGIKAM_DW_ITEM_DELEGATE_H
+#define DIGIKAM_DW_ITEM_DELEGATE_H
 
 // Qt includes
 
@@ -36,6 +36,7 @@
 // Local includes
 
 #include "dwitemdelegate_p.h"
+#include "digikam_export.h"
 
 class QObject;
 class QPainter;
@@ -48,13 +49,14 @@ namespace Digikam
 {
 
 class DWItemDelegatePool;
+class DWItemDelegatePrivate;
 
 /**
  * This class allows to create item delegates embedding simple widgets to interact
  * with items. For instance you can add push buttons, line edits, etc. to your delegate
  * and use them to modify the state of your model.
  */
-class DWItemDelegate : public QAbstractItemDelegate
+class DIGIKAM_EXPORT DWItemDelegate : public QAbstractItemDelegate
 {
     Q_OBJECT
 
@@ -146,6 +148,7 @@ private:
 
     friend class DWItemDelegatePool;
     friend class DWItemDelegateEventListener;
+
     DWItemDelegatePrivate* const d;
 
     Q_PRIVATE_SLOT(d, void slotDWRowsInserted(const QModelIndex&,int,int))
@@ -161,4 +164,4 @@ private:
 
 Q_DECLARE_METATYPE(QList<QEvent::Type>)
 
-#endif // Digikam
+#endif // DIGIKAM_DW_ITEM_DELEGATE_H
