@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-11-15
  * Description : widget item delegate for setup collection view
@@ -23,21 +23,25 @@
  *
  * ============================================================ */
 
-#ifndef DW_ITEM_DELEGATE_P_H
-#define DW_ITEM_DELEGATE_P_H
+#ifndef DIGIKAM_DW_ITEM_DELEGATE_PRIVATE_H
+#define DIGIKAM_DW_ITEM_DELEGATE_PRIVATE_H
 
 // Qt includes
 
 #include <QObject>
 #include <QItemSelectionModel>
 
+// Local includes
+
+#include "dwitemdelegate.h"
+
 namespace Digikam
 {
 
 class DWItemDelegate;
 class DWItemDelegatePool;
 
-class DWItemDelegatePrivate : public QObject
+class Q_DECL_HIDDEN DWItemDelegatePrivate : public QObject
 {
     Q_OBJECT
 
@@ -77,4 +81,4 @@ public:
 
 } // namespace Digikam
 
-#endif // DW_ITEM_DELEGATE_P_H
+#endif // DIGIKAM_DW_ITEM_DELEGATE_PRIVATE_H
