@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-02-01
  * Description : collections setup tab
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,17 +21,21 @@
  *
  * ============================================================ */
 
-#ifndef SETUPCOLLECTIONS_H
-#define SETUPCOLLECTIONS_H
+#ifndef DIGIKAM_SETUP_COLLECTIONS_H
+#define DIGIKAM_SETUP_COLLECTIONS_H
 
 // Qt includes
 
 #include <QScrollArea>
 
+// Local includes
+
+#include "digikam_export.h"
+
 namespace Digikam
 {
 
-class SetupCollections : public QScrollArea
+class DIGIKAM_EXPORT SetupCollections : public QScrollArea
 {
 
 public:
@@ -51,6 +55,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // SETUPCOLLECTIONS_H
+#endif // DIGIKAM_SETUP_COLLECTIONS_H
