@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-03
  * Description : setup Image Editor interface.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,12 +54,12 @@
 namespace Digikam
 {
 
-class SetupEditorIface::Private
+class Q_DECL_HIDDEN SetupEditorIface::Private
 {
 public:
 
-    Private() :
-        themebackgroundColor(0),
+    explicit Private()
+      : themebackgroundColor(0),
         expoIndicatorMode(0),
         expoPreview(0),
         colorBox(0),
@@ -339,4 +339,4 @@ void SetupEditorIface::applySettings()
     group.sync();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
