@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-03
  * Description : setup Image Editor interface.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPEDITORIFACE_H
-#define SETUPEDITORIFACE_H
+#ifndef DIGIKAM_SETUP_EDITOR_IFACE_H
+#define DIGIKAM_SETUP_EDITOR_IFACE_H
 
 // Qt includes
 
@@ -63,6 +63,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // SETUPEDITORIFACE_H
+#endif // DIGIKAM_SETUP_EDITOR_IFACE_H
