@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-23
  * Description : setup image editor output files settings.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,12 +50,12 @@
 namespace Digikam
 {
 
-class SetupIOFiles::Private
+class Q_DECL_HIDDEN SetupIOFiles::Private
 {
 public:
 
-    Private() :
-        JPEGOptions(0),
+    explicit Private()
+      : JPEGOptions(0),
         PNGOptions(0),
         TIFFOptions(0),
 #ifdef HAVE_JASPER
@@ -192,4 +192,4 @@ void SetupIOFiles::readSettings()
     d->showImageSettingsDialog->setChecked(group.readEntry(d->configShowImageSettingsDialog,   true));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
