@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-01-23
  * Description : setup image editor output files settings.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPIOFILES_H
-#define SETUPIOFILES_H
+#ifndef DIGIKAM_SETUP_IOFILES_H
+#define DIGIKAM_SETUP_IOFILES_H
 
 // Qt includes
 
@@ -56,6 +56,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // SETUPIOFILES_H
+#endif // DIGIKAM_SETUP_IOFILES_H
