@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-08-06
  * Description : setup tab for image versioning
  *
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -51,11 +51,11 @@
 namespace Digikam
 {
 
-class SetupVersioning::Private
+class Q_DECL_HIDDEN SetupVersioning::Private
 {
 public:
 
-    Private()
+    explicit Private()
         : tab(0),
           nonDestructivePanel(0),
           workspaceGB(0),
