@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-06-16
  * Description : Advanced Configuration tab for metadata.
@@ -52,11 +52,11 @@
 namespace Digikam
 {
 
-class AdvancedMetadataTab::Private
+class Q_DECL_HIDDEN AdvancedMetadataTab::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         metadataType     = 0;
         operationType    = 0;
@@ -169,15 +169,15 @@ void AdvancedMetadataTab::slotAddNewNamespace()
 
     // Setting some default parameters;
 
-    if (d->metadataType->currentData().toString() == QLatin1String(DM_TAG_CONTAINER))
+    if (d->metadataType->currentData().toString() == QString::fromUtf8(DM_TAG_CONTAINER))
     {
         entry.nsType = NamespaceEntry::TAGS;
     }
-    else if (d->metadataType->currentData().toString() == QLatin1String(DM_RATING_CONTAINER))
+    else if (d->metadataType->currentData().toString() == QString::fromUtf8(DM_RATING_CONTAINER))
     {
         entry.nsType = NamespaceEntry::RATING;
     }
-    else if (d->metadataType->currentData().toString() == QLatin1String(DM_COMMENT_CONTAINER))
+    else if (d->metadataType->currentData().toString() == QString::fromUtf8(DM_COMMENT_CONTAINER))
     {
         entry.nsType = NamespaceEntry::COMMENT;
     }
@@ -226,16 +226,16 @@ void AdvancedMetadataTab::slotEditNamespace()
 
 void AdvancedMetadataTab::applySettings()
 {
-    QList<QLatin1String> keys = d->container.mappingKeys();
-    int index                 = 0;
+    QList<QString> keys = d->container.mappingKeys();
+    int index           = 0;
 
-    foreach(const QLatin1String& str, keys)
+    foreach(const QString& str, keys)
     {
         d->container.getReadMapping(str).clear();
         saveModelData(d->models.at(index++), d->container.getReadMapping(str));
     }
 
-    foreach(const QLatin1String& str, keys)
+    foreach(const QString& str, keys)
     {
         d->container.getWriteMapping(str).clear();
         saveModelData(d->models.at(index++), d->container.getWriteMapping(str));
@@ -292,7 +292,8 @@ void AdvancedMetadataTab::connectButtons()
             d->namespaceView, SLOT(slotMoveItemDown()));
 }
 
-void AdvancedMetadataTab::setModelData(QStandardItemModel* model, const QList<NamespaceEntry>& container)
+void AdvancedMetadataTab::setModelData(QStandardItemModel* model,
+                                       const QList<NamespaceEntry>& container)
 {
     QStandardItem* const root = model->invisibleRootItem();
 
@@ -319,7 +320,7 @@ void AdvancedMetadataTab::setUi()
     tipLabel->setTextFormat(Qt::RichText);
     tipLabel->setWordWrap(true);
     tipLabel->setText(i18n("Advanced configuration menu allow you to manage metadata namespaces"
-                           " used by digiKam to store and retrieve tags, rating and comments.<br>"
+                           " used by digiKam to store and retrieve tags, rating and comments.<br/>"
                            "<b>Note: </b>Order is important when reading metadata"
                           ));
 
@@ -441,38 +442,38 @@ QList<NamespaceEntry>& AdvancedMetadataTab::getCurrentContainer()
 
     if (currentIndex >= d->metadataTypeSize)
     {
-        return d->container.getWriteMapping(QLatin1String(d->metadataType->currentData().toByteArray()));
+        return d->container.getWriteMapping(QString::fromUtf8(d->metadataType->currentData().toByteArray()));
     }
     else
     {
-        return d->container.getReadMapping(QLatin1String(d->metadataType->currentData().toByteArray()));
+        return d->container.getReadMapping(QString::fromUtf8(d->metadataType->currentData().toByteArray()));
     }
 }
 
 void AdvancedMetadataTab::setModels()
 {
-    QList<QLatin1String> keys = d->container.mappingKeys();
+    QList<QString> keys = d->container.mappingKeys();
 
-    foreach(const QLatin1String& str, keys)
+    foreach(const QString& str, keys)
     {
-        d->metadataType->addItem(i18n(str.data()), str);
+        d->metadataType->addItem(str, str);
     }
 
     d->metadataTypeSize = keys.size();
 
-    for (int i = 0 ; i < keys.size() * 2; i++)
+    for (int i = 0 ; i < keys.size() * 2 ; ++i)
     {
         d->models.append(new QStandardItemModel(this));
     }
 
     int index = 0;
 
-    foreach(const QLatin1String& str, keys)
+    foreach(const QString& str, keys)
     {
         setModelData(d->models.at(index++), d->container.getReadMapping(str));
     }
 
-    foreach(const QLatin1String& str, keys)
+    foreach(const QString& str, keys)
     {
         setModelData(d->models.at(index++), d->container.getWriteMapping(str));
     }
@@ -480,7 +481,8 @@ void AdvancedMetadataTab::setModels()
     slotIndexChanged();
 }
 
-void AdvancedMetadataTab::saveModelData(QStandardItemModel* model, QList<NamespaceEntry>& container)
+void AdvancedMetadataTab::saveModelData(QStandardItemModel* model,
+                                        QList<NamespaceEntry>& container)
 {
     QStandardItem* const root = model->invisibleRootItem();
 
@@ -489,7 +491,7 @@ void AdvancedMetadataTab::saveModelData(QStandardItemModel* model, QList<Namespa
         return;
     }
 
-    for (int i = 0 ; i < root->rowCount(); i++)
+    for (int i = 0 ; i < root->rowCount() ; ++i)
     {
         NamespaceEntry ns;
         QStandardItem* const current = root->child(i);
