@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-06-16
  * Description : Advanced Configuration tab for metadata.
@@ -21,6 +21,9 @@
  *
  * ============================================================ */
 
+#ifndef DIGIKAM_ADVANCED_METADATA_TAB_H
+#define DIGIKAM_ADVANCED_METADATA_TAB_H
+
 // Qt includes
 
 #include <QWidget>
@@ -41,7 +44,7 @@ class AdvancedMetadataTab : public QWidget
 
 public:
 
-    AdvancedMetadataTab(QWidget* const parent = 0);
+    explicit AdvancedMetadataTab(QWidget* const parent = 0);
     virtual ~AdvancedMetadataTab();
 
     void applySettings();
@@ -132,3 +135,5 @@ private:
 };
 
 } // namespace Digikam
+
+#endif // DIGIKAM_ADVANCED_METADATA_TAB_H
