@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2015-07-03
  * Description : dialog to edit and create digiKam xmp namespaces
@@ -53,11 +53,11 @@
 namespace Digikam
 {
 
-class NamespaceEditDlg::Private
+class Q_DECL_HIDDEN NamespaceEditDlg::Private
 {
 public:
 
-    Private()
+    explicit Private()
     {
         buttons              = 0;
         create               = 0;
@@ -141,7 +141,9 @@ public:
     NamespaceEntry::NamespaceType   nsType;
 };
 
-NamespaceEditDlg::NamespaceEditDlg(bool create, NamespaceEntry& entry, QWidget* const parent)
+NamespaceEditDlg::NamespaceEditDlg(bool create,
+                                   NamespaceEntry& entry,
+                                   QWidget* const parent)
     : QDialog(parent),
       d(new Private())
 {
@@ -192,7 +194,9 @@ NamespaceEditDlg::NamespaceEditDlg(bool create, NamespaceEntry& entry, QWidget*
         makeReadOnly();
     }
 
-    qCDebug(DIGIKAM_GENERAL_LOG) << "Entry type" << entry.nsType << "subspace" << entry.subspace << entry.isDefault;
+    qCDebug(DIGIKAM_GENERAL_LOG) << "Entry type" << entry.nsType
+                                 << "subspace" << entry.subspace
+                                 << entry.isDefault;
     adjustSize();
 }
 
@@ -206,7 +210,7 @@ bool NamespaceEditDlg::create(QWidget* const parent, NamespaceEntry& entry)
     QPointer<NamespaceEditDlg> dlg = new NamespaceEditDlg(true,entry,parent);
 
     qCDebug(DIGIKAM_GENERAL_LOG) << "Name before save: " << entry.namespaceName;
-    bool valRet = dlg->exec();
+    bool valRet                    = dlg->exec();
 
     if (valRet == QDialog::Accepted)
     {
@@ -224,7 +228,7 @@ bool NamespaceEditDlg::edit(QWidget* const parent, NamespaceEntry& entry)
     QPointer<NamespaceEditDlg> dlg = new NamespaceEditDlg(false, entry, parent);
 
     qCDebug(DIGIKAM_GENERAL_LOG) << "Name before save: " << entry.namespaceName;
-    bool valRet = dlg->exec();
+    bool valRet                    = dlg->exec();
 
     if (valRet == QDialog::Accepted && !entry.isDefault)
     {
@@ -258,7 +262,7 @@ void NamespaceEditDlg::setupTagGui(NamespaceEntry& entry)
     d->subspaceCombo->addItem(QLatin1String("XMP"),  (int)NamespaceEntry::XMP);
     d->subspaceCombo->setCurrentIndex((int)entry.subspace);
 
-    qCDebug(DIGIKAM_GENERAL_LOG) << "Enrty subspace" << (int)entry.subspace;
+    qCDebug(DIGIKAM_GENERAL_LOG) << "Entry subspace" << (int)entry.subspace;
 
     // -------------------Tag Elements---------------------------------
 
@@ -425,16 +429,16 @@ void NamespaceEditDlg::setupTagGui(NamespaceEntry& entry)
 
     d->gridLayout->addWidget(d->alternativeNameLabel,       8, 0, 1, 2);
     d->gridLayout->addWidget(d->alternativeName,            8, 2, 1, 4);
-    d->gridLayout->addWidget(d->altspecialOptsLabel,        9, 0, 1, 3);
-    d->gridLayout->addWidget(d->altSpecialOptsCombo,        9, 3, 1, 3);
+    d->gridLayout->addWidget(d->altspecialOptsLabel,        9, 0, 1, 2);
+    d->gridLayout->addWidget(d->altSpecialOptsCombo,        9, 2, 1, 4);
 
     d->gridLayout->addWidget(d->separatorLabel,             10, 0, 1, 2);
     d->gridLayout->addWidget(d->nameSpaceSeparator,         10, 2, 1, 4);
     d->gridLayout->addWidget(d->isTagLabel,                 11, 0, 1, 2);
     d->gridLayout->addWidget(d->isPath,                     11, 2, 1, 3);
 
-    d->gridLayout->addWidget(d->ratingMappings,             14, 0, 2, 6);
-    d->gridLayout->addWidget(d->tipLabel2,                  15, 0, 1, 6);
+    d->gridLayout->addWidget(d->ratingMappings,             12, 0, 2, 6);
+    d->gridLayout->addWidget(d->tipLabel2,                  14, 0, 1, 6);
 
     d->gridLayout->setContentsMargins(cmargin, cmargin, cmargin, cmargin);
     d->gridLayout->setSpacing(spacing);
@@ -458,9 +462,9 @@ void NamespaceEditDlg::populateFields(NamespaceEntry& entry)
         d->isPath->setChecked(false);
     }
 
-    d->specialOptsCombo->setCurrentIndex((int)entry.specialOpts);
     d->alternativeName->setText(entry.alternativeName);
-    d->altSpecialOptsCombo->setCurrentIndex((int)entry.secondNameOpts);
+    d->specialOptsCombo->setCurrentIndex(d->specialOptsCombo->findData(entry.specialOpts));
+    d->altSpecialOptsCombo->setCurrentIndex(d->altSpecialOptsCombo->findData(entry.secondNameOpts));
 
     if (entry.convertRatio.size() == 6)
     {
@@ -549,14 +553,14 @@ bool NamespaceEditDlg::validifyCheck(QString& errMsg)
     {
         case NamespaceEntry::EXIF:
 
-            if (d->namespaceName->text().split(QLatin1String(".")).first() != QLatin1String("Exif"))
+            if (d->namespaceName->text().split(QLatin1Char('.')).first() != QLatin1String("Exif"))
             {
                 errMsg = i18n("EXIF namespace name must start with \"Exif\".");
                 return false;
             }
 
             if (!d->alternativeName->text().isEmpty() &&
-                d->alternativeName->text().split(QLatin1String(".")).first() != QLatin1String("Exif"))
+                d->alternativeName->text().split(QLatin1Char('.')).first() != QLatin1String("Exif"))
             {
                 errMsg = i18n("EXIF alternative namespace name must start with \"Exif\".");
                 return false;
@@ -566,14 +570,14 @@ bool NamespaceEditDlg::validifyCheck(QString& errMsg)
 
         case NamespaceEntry::IPTC:
 
-            if (d->namespaceName->text().split(QLatin1String(".")).first() != QLatin1String("Iptc"))
+            if (d->namespaceName->text().split(QLatin1Char('.')).first() != QLatin1String("Iptc"))
             {
                 errMsg = i18n("IPTC namespace name must start with \"Iptc\".");
                 return false;
             }
 
-            if(!d->alternativeName->text().isEmpty() &&
-               d->alternativeName->text().split(QLatin1String(".")).first() != QLatin1String("Iptc"))
+            if (!d->alternativeName->text().isEmpty() &&
+                d->alternativeName->text().split(QLatin1Char('.')).first() != QLatin1String("Iptc"))
             {
                 errMsg = i18n("IPTC alternative namespace name must start with \"Iptc\".");
                 return false;
@@ -583,14 +587,14 @@ bool NamespaceEditDlg::validifyCheck(QString& errMsg)
 
         case NamespaceEntry::XMP:
 
-            if (d->namespaceName->text().split(QLatin1String(".")).first() != QLatin1String("Xmp"))
+            if (d->namespaceName->text().split(QLatin1Char('.')).first() != QLatin1String("Xmp"))
             {
                 errMsg = i18n("XMP namespace name must start with \"Xmp\".");
                 return false;
             }
 
             if (!d->alternativeName->text().isEmpty() &&
-                d->alternativeName->text().split(QLatin1String(".")).first() != QLatin1String("Xmp"))
+                d->alternativeName->text().split(QLatin1Char('.')).first() != QLatin1String("Xmp"))
             {
                 errMsg = i18n("XMP alternative namespace name must start with \"Xmp\".");
                 return false;
