@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-08-03
  * Description : setup Metadata tab.
  *
  * Copyright (C) 2003-2004 by Ralf Holzer <ralf at well dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
@@ -39,6 +39,7 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QMessageBox>
+#include <QPointer>
 #include <QRadioButton>
 #include <QStandardPaths>
 #include <QStyle>
@@ -58,19 +59,20 @@
 #include "digikam_debug.h"
 #include "metaengine.h"
 #include "metadatapanel.h"
-#include "metadatasettings.h"
+#include "metaenginesettings.h"
 #include "setuputils.h"
 
 namespace Digikam
 {
 
-class SetupMetadata::Private
+class Q_DECL_HIDDEN SetupMetadata::Private
 {
 public:
 
-    Private() :
-        exifAutoRotateOriginal(false),
+    explicit Private()
+      : exifAutoRotateOriginal(false),
         exifAutoRotateShowedInfo(false),
+        clearMetadataShowedInfo(false),
         fieldsGroup(0),
         readWriteGroup(0),
         rotationGroup(0),
@@ -89,6 +91,7 @@ public:
         readXMPSidecarBox(0),
         updateFileTimeStampBox(0),
         rescanImageIfModifiedBox(0),
+        clearMetadataIfRescanBox(0),
         writingModeCombo(0),
         rotateByFlag(0),
         rotateByContents(0),
@@ -108,6 +111,7 @@ public:
 
     bool                 exifAutoRotateOriginal;
     bool                 exifAutoRotateShowedInfo;
+    bool                 clearMetadataShowedInfo;
 
     QGroupBox*           fieldsGroup;
     QGroupBox*           readWriteGroup;
@@ -129,6 +133,7 @@ public:
     QCheckBox*           readXMPSidecarBox;
     QCheckBox*           updateFileTimeStampBox;
     QCheckBox*           rescanImageIfModifiedBox;
+    QCheckBox*           clearMetadataIfRescanBox;
     QComboBox*           writingModeCombo;
 
     QRadioButton*        rotateByFlag;
@@ -167,12 +172,12 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     QGridLayout* const fieldsLayout = new QGridLayout;
 
     d->fieldsGroup->setWhatsThis(xi18nc("@info:whatsthis",
-                                       "<para>In addition to the pixel content, image files usually "
-                                       "contain a variety of metadata. A lot of the parameters you can use "
-                                       "in digiKam to manage files, such as rating or comment, can be written "
-                                       "to the files' metadata.</para> "
-                                       "<para>Storing in metadata allows one to preserve this information "
-                                       "when moving or sending the files to different systems.</para>"));
+                                        "<para>In addition to the pixel content, image files usually "
+                                        "contain a variety of metadata. A lot of the parameters you can use "
+                                        "in digiKam to manage files, such as rating or comment, can be written "
+                                        "to the files' metadata.</para> "
+                                        "<para>Storing in metadata allows one to preserve this information "
+                                        "when moving or sending the files to different systems.</para>"));
 
     QLabel* const fieldsIconLabel = new QLabel;
     fieldsIconLabel->setPixmap(QIcon::fromTheme(QLatin1String("format-list-unordered")).pixmap(32));
@@ -218,7 +223,7 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->saveFaceTags = new QCheckBox;
     d->saveFaceTags->setText(i18nc("@option:check", "Face Tags (including face areas)"));
     d->saveFaceTags->setWhatsThis(i18nc("@info:whatsthis", "Turn on this option to store face tags "
-                                           "with face rectangles in the XMP tags."));
+                                        "with face rectangles in the XMP tags."));
 
     fieldsLayout->addWidget(fieldsIconLabel,       0, 0, 2, 3);
     fieldsLayout->addWidget(fieldsLabel,           0, 1, 2, 3);
@@ -246,8 +251,8 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->useLazySync        = new QCheckBox;
     d->useLazySync->setText(i18nc("@option:check", "Use lazy synchronization"));
     d->useLazySync->setWhatsThis(i18nc("@info:whatsthis",
-                                             "Instead of synchronizing metadata, just schedule it for synchronization."
-                                             "Synchronization can be done later by triggering the apply pending, or at digikam exit"));
+                                       "Instead of synchronizing metadata, just schedule it for synchronization."
+                                       "Synchronization can be done later by triggering the apply pending, or at digikam exit"));
     d->writeRawFilesBox = new QCheckBox;
     d->writeRawFilesBox->setText(i18nc("@option:check", "If possible write Metadata to RAW files (experimental)"));
     d->writeRawFilesBox->setWhatsThis(i18nc("@info:whatsthis", "Turn on this option to write metadata into RAW TIFF/EP files. "
@@ -258,16 +263,27 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->updateFileTimeStampBox = new QCheckBox;
     d->updateFileTimeStampBox->setText(i18nc("@option:check", "&Update file timestamp when files are modified"));
     d->updateFileTimeStampBox->setWhatsThis(i18nc("@info:whatsthis",
-                                                  "Turn off this option to not update file timestamps when files are changed as when you update metadata or image data. "
-                                                  "Note: disabling this option can introduce some dysfunctions with applications which use file timestamps properties to "
-                                                  "detect file modifications automatically."));
+                                                  "Turn off this option to not update file timestamps when files are changed as "
+                                                  "when you update metadata or image data. Note: disabling this option can "
+                                                  "introduce some dysfunctions with applications which use file timestamps "
+                                                  "properties to detect file modifications automatically."));
 
     d->rescanImageIfModifiedBox = new QCheckBox;
     d->rescanImageIfModifiedBox->setText(i18nc("@option:check", "&Rescan file when files are modified"));
     d->rescanImageIfModifiedBox->setWhatsThis(i18nc("@info:whatsthis",
-                                                  "Turning this option on, will force digiKam to rescan files that has been modified outside digiKam. "
-                                                  "If a file has changed it's file size or if the last modified timestamp has changed, a rescan of that "
-                                                  "file will be performed when digiKam starts."));
+                                                    "Turning this option on, will force digiKam to rescan files that has been "
+                                                    "modified outside digiKam. If a file has changed it is file size or if "
+                                                    "the last modified timestamp has changed, a rescan of that "
+                                                    "file will be performed when digiKam starts."));
+
+    d->clearMetadataIfRescanBox    = new QCheckBox;
+    d->clearMetadataIfRescanBox->setText(i18nc("@option:check", "&Clean up the metadata from the database when rescan files"));
+    d->clearMetadataIfRescanBox->setWhatsThis(i18nc("@info:whatsthis",
+                                                    "Turning this option on, will force digiKam to delete the file metadata "
+                                                    "contained in the database before the file is rescanned. WARNING: "
+                                                    "if your metadata has been written to the database only and not "
+                                                    "to the file or sidecar, you will be able to lose inserted "
+                                                    "metadata such as tags, keywords, or geographic coordinates."));
 
     readWriteLayout->addWidget(readWriteIconLabel,          0, 0, 2, 3);
     readWriteLayout->addWidget(readWriteLabel,              0, 1, 2, 3);
@@ -275,6 +291,7 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     readWriteLayout->addWidget(d->writeRawFilesBox,         3, 0, 1, 3);
     readWriteLayout->addWidget(d->updateFileTimeStampBox,   4, 0, 1, 3);
     readWriteLayout->addWidget(d->rescanImageIfModifiedBox, 5, 0, 1, 3);
+    readWriteLayout->addWidget(d->clearMetadataIfRescanBox, 6, 0, 1, 3);
     readWriteLayout->setColumnStretch(3, 10);
     d->readWriteGroup->setLayout(readWriteLayout);
 
@@ -336,10 +353,10 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     QLabel* const rotationIcon        = new QLabel;
     rotationIcon->setPixmap(QIcon::fromTheme(QLatin1String("transform-rotate")).pixmap(32));
 
-    d->rotateByFlag             = new QRadioButton(i18nc("@option:radio", "Rotate by only setting a flag"));
-    d->rotateByContents         = new QRadioButton(i18nc("@option:radio", "Rotate by changing the content if possible"));
-    d->allowLossyRotate         = new QCheckBox(i18nc("@option:check", "Even allow lossy rotation if necessary"));
-    d->allowRotateByMetadata    = new QCheckBox(i18nc("@option:check", "Write flag to metadata if possible"));
+    d->rotateByFlag          = new QRadioButton(i18nc("@option:radio", "Rotate by only setting a flag"));
+    d->rotateByContents      = new QRadioButton(i18nc("@option:radio", "Rotate by changing the content if possible"));
+    d->allowLossyRotate      = new QCheckBox(i18nc("@option:check", "Even allow lossy rotation if necessary"));
+    d->allowRotateByMetadata = new QCheckBox(i18nc("@option:check", "Write flag to metadata if possible"));
 
     connect(d->rotateByContents, SIGNAL(toggled(bool)),
             d->allowLossyRotate, SLOT(setEnabled(bool)));
@@ -353,25 +370,25 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->rotateByFlag->setToolTip(i18nc("@info:tooltip",
                                       "Rotate files only by changing a flag, not touching the pixel data"));
     d->rotateByFlag->setWhatsThis(xi18nc("@info:whatsthis",
-                                        "<para>A file can be rotated in two ways:<nl/> "
-                                        "You can change the contents, rearranging the individual pixels of the image data.<nl/> "
-                                        "Or you can set a flag that the file is to be rotated before it is shown.</para> "
-                                        "<para>Select this option if you always want to set only a flag. "
-                                        "This is less obtrusive, but requires support if the file is accessed with another software. "
-                                        "Ensure to allow setting the flag in the metadata if you want to share your files "
-                                        "outside digiKam.</para>"));
+                                         "<para>A file can be rotated in two ways:<nl/> "
+                                         "You can change the contents, rearranging the individual pixels of the image data.<nl/> "
+                                         "Or you can set a flag that the file is to be rotated before it is shown.</para> "
+                                         "<para>Select this option if you always want to set only a flag. "
+                                         "This is less obtrusive, but requires support if the file is accessed with another software. "
+                                         "Ensure to allow setting the flag in the metadata if you want to share your files "
+                                         "outside digiKam.</para>"));
 
     d->rotateByContents->setToolTip(i18nc("@info:tooltip",
                                           "If possible rotate files by changing the pixel data"));
     d->rotateByContents->setWhatsThis(xi18nc("@info:whatsthis",
-                                            "<para>A file can be rotated in two ways:<nl/> "
-                                            "You can change the contents, rearranging the individual pixels of the image data.<nl/> "
-                                            "Or you can set a flag that the file is to be rotated before it is shown.</para> "
-                                            "<para>Select this option if you want the file to be rotated by changing the content. "
-                                            "This is a lossless operation for JPEG files. For other formats it is a lossy operation, "
-                                            "which you need to enable explicitly. "
-                                            "It is not support for RAW and other read-only formats, "
-                                            "which will be rotated by flag only.</para>"));
+                                             "<para>A file can be rotated in two ways:<nl/> "
+                                             "You can change the contents, rearranging the individual pixels of the image data.<nl/> "
+                                             "Or you can set a flag that the file is to be rotated before it is shown.</para> "
+                                             "<para>Select this option if you want the file to be rotated by changing the content. "
+                                             "This is a lossless operation for JPEG files. For other formats it is a lossy operation, "
+                                             "which you need to enable explicitly. "
+                                             "It is not support for RAW and other read-only formats, "
+                                             "which will be rotated by flag only.</para>"));
 
     d->allowLossyRotate->setToolTip(i18nc("@info:tooltip",
                                           "Rotate files by changing the pixel data even if the operation will incur quality loss"));
@@ -403,13 +420,13 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->rotationAdvGroup                  = new QGroupBox;
     QGridLayout* const rotationAdvLayout = new QGridLayout;
 
-    QLabel* const rotationAdvExpl  = new QLabel(i18nc("@label", "Rotate actions"));
-    QLabel* const rotationAdvIcon  = new QLabel;
+    QLabel* const rotationAdvExpl        = new QLabel(i18nc("@label", "Rotate actions"));
+    QLabel* const rotationAdvIcon        = new QLabel;
     rotationAdvIcon->setPixmap(QIcon::fromTheme(QLatin1String("configure")).pixmap(32));
 
-    d->exifRotateBox         = new QCheckBox;
+    d->exifRotateBox                     = new QCheckBox;
     d->exifRotateBox->setText(i18n("Show images/thumbnails &rotated according to orientation tag."));
-    d->exifSetOrientationBox = new QCheckBox;
+    d->exifSetOrientationBox             = new QCheckBox;
     d->exifSetOrientationBox->setText(i18n("Set orientation tag to normal after rotate/flip."));
 
     rotationAdvLayout->addWidget(rotationAdvIcon,          0, 0, 1, 1);
@@ -421,8 +438,17 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
 
     // --------------------------------------------------------
 
+    QLabel* const rotationNote = new QLabel(i18n("<b>Note: These settings affect the album view "
+                                                 "and not the image editor. The image editor always "
+                                                 "changes the image data during the rotation.</b>"));
+    rotationNote->setWordWrap(true);
+    rotationNote->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
+
+    // --------------------------------------------------------
+
     rotationLayout->addWidget(d->rotationGroup);
     rotationLayout->addWidget(d->rotationAdvGroup);
+    rotationLayout->addWidget(rotationNote);
     rotationLayout->addStretch();
     rotationPanel->setLayout(rotationLayout);
 
@@ -459,12 +485,12 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     QGroupBox* const balooGroup    = new QGroupBox(i18n("Baloo Desktop Search"), balooPanel);
     QVBoxLayout* const gLayout3    = new QVBoxLayout(balooGroup);
 
-    d->saveToBalooBox           = new QCheckBox;
+    d->saveToBalooBox              = new QCheckBox;
     d->saveToBalooBox->setText(i18n("Store metadata from digiKam in Baloo"));
     d->saveToBalooBox->setWhatsThis(i18n("Turn on this option to push rating, comments and tags "
-                                           "from digiKam into the Baloo storage"));
+                                         "from digiKam into the Baloo storage"));
 
-    d->readFromBalooBox         = new QCheckBox;
+    d->readFromBalooBox            = new QCheckBox;
     d->readFromBalooBox->setText(i18n("Read metadata from Baloo"));
     d->readFromBalooBox->setWhatsThis(i18n("Turn on this option if you want to apply changes to "
                                            "rating, comments and tags made in Baloo to digiKam's metadata storage. "
@@ -500,7 +526,6 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     balooGrid->addWidget(balooLogoLabel,   0, 0, 1, 1);
     balooGrid->addWidget(balooExplanation, 0, 1, 1, 2);
     balooGrid->setColumnStretch(1, 10);
-    balooGrid->setRowStretch(1, 10);
     balooGrid->setSpacing(0);
 
     // --------------------------------------------------------
@@ -542,9 +567,9 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->writeXMPSidecarBox->setEnabled(MetaEngine::supportXmp());
 
     d->writingModeCombo   = new QComboBox;
-    d->writingModeCombo->addItem(i18n("Write to XMP sidecar for read-only item only"), MetaEngine::WRITETOSIDECARONLY4READONLYFILES);
-    d->writingModeCombo->addItem(i18n("Write to XMP sidecar only"),                     MetaEngine::WRITETOSIDECARONLY);
-    d->writingModeCombo->addItem(i18n("Write to image and XMP Sidecar"),                MetaEngine::WRITETOSIDECARANDIMAGE);
+    d->writingModeCombo->addItem(i18n("Write to XMP sidecar for read-only item only"), MetaEngine::WRITE_TO_SIDECAR_ONLY_FOR_READ_ONLY_FILES);
+    d->writingModeCombo->addItem(i18n("Write to XMP sidecar only"),                    MetaEngine::WRITE_TO_SIDECAR_ONLY);
+    d->writingModeCombo->addItem(i18n("Write to item and XMP Sidecar"),                MetaEngine::WRITE_TO_SIDECAR_AND_FILE);
     d->writingModeCombo->setToolTip(i18nc("@info:tooltip", "Specify the exact mode of XMP sidecar writing"));
     d->writingModeCombo->setEnabled(false);
 
@@ -582,7 +607,7 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
     d->extensionsEdit = new QLineEdit(extensionsGroup);
     d->extensionsEdit->setWhatsThis(i18n("<p>Here you can add extra extensions "
                                          "of sidecars files to be processed alongside "
-                                         "regular items. These files won't be visible, "
+                                         "regular items. These files will not be visible, "
                                          "but regarded as an extension of the main file. "
                                          "Just write \"xyz abc\" to support files with "
                                          "the *.xyz and *.abc extensions. The internally "
@@ -614,6 +639,12 @@ SetupMetadata::SetupMetadata(QWidget* const parent)
 
     connect(d->exifRotateBox, SIGNAL(toggled(bool)),
             this, SLOT(slotExifAutoRotateToggled(bool)));
+
+    connect(d->clearMetadataIfRescanBox, SIGNAL(toggled(bool)),
+            this, SLOT(slotClearMetadataToggled(bool)));
+
+    connect(d->writeRawFilesBox, SIGNAL(toggled(bool)),
+            this, SLOT(slotWriteRawFilesToggled(bool)));
 }
 
 SetupMetadata::~SetupMetadata()
@@ -633,29 +664,29 @@ void SetupMetadata::setActiveSubTab(int tab)
 
 void SetupMetadata::applySettings()
 {
-    MetadataSettings* const mSettings = MetadataSettings::instance();
+    MetaEngineSettings* const mSettings = MetaEngineSettings::instance();
 
     if (!mSettings)
     {
         return;
     }
 
-    MetadataSettingsContainer set;
+    MetaEngineSettingsContainer set;
 
-    set.rotationBehavior = MetadataSettingsContainer::RotateByInternalFlag;
+    set.rotationBehavior = MetaEngineSettingsContainer::RotateByInternalFlag;
 
     if (d->allowRotateByMetadata->isChecked())
     {
-        set.rotationBehavior |= MetadataSettingsContainer::RotateByMetadataFlag;
+        set.rotationBehavior |= MetaEngineSettingsContainer::RotateByMetadataFlag;
     }
 
     if (d->rotateByContents->isChecked())
     {
-        set.rotationBehavior |= MetadataSettingsContainer::RotateByLosslessRotation;
+        set.rotationBehavior |= MetaEngineSettingsContainer::RotateByLosslessRotation;
 
         if (d->allowLossyRotate->isChecked())
         {
-            set.rotationBehavior |= MetadataSettingsContainer::RotateByLossyRotation;
+            set.rotationBehavior |= MetaEngineSettingsContainer::RotateByLossyRotation;
         }
     }
 
@@ -682,11 +713,12 @@ void SetupMetadata::applySettings()
     }
     else
     {
-        set.metadataWritingMode = MetaEngine::WRITETOIMAGEONLY;
+        set.metadataWritingMode = MetaEngine::WRITE_TO_FILE_ONLY;
     }
 
     set.updateFileTimeStamp   = d->updateFileTimeStampBox->isChecked();
     set.rescanImageIfModified = d->rescanImageIfModifiedBox->isChecked();
+    set.clearMetadataIfRescan = d->clearMetadataIfRescanBox->isChecked();
 
     set.sidecarExtensions = cleanUserFilterString(d->extensionsEdit->text());
     set.sidecarExtensions.removeAll(QLatin1String("xmp"));
@@ -718,16 +750,16 @@ void SetupMetadata::applySettings()
 
 void SetupMetadata::readSettings()
 {
-    MetadataSettings* const mSettings = MetadataSettings::instance();
+    MetaEngineSettings* const mSettings = MetaEngineSettings::instance();
 
     if (!mSettings)
     {
         return;
     }
 
-    MetadataSettingsContainer set = mSettings->settings();
+    MetaEngineSettingsContainer set = mSettings->settings();
 
-    if (set.rotationBehavior & MetadataSettingsContainer::RotatingPixels)
+    if (set.rotationBehavior & MetaEngineSettingsContainer::RotatingPixels)
     {
         d->rotateByContents->setChecked(true);
     }
@@ -736,8 +768,8 @@ void SetupMetadata::readSettings()
         d->rotateByFlag->setChecked(true);
     }
 
-    d->allowRotateByMetadata->setChecked(set.rotationBehavior & MetadataSettingsContainer::RotateByMetadataFlag);
-    d->allowLossyRotate->setChecked(set.rotationBehavior & MetadataSettingsContainer::RotateByLossyRotation);
+    d->allowRotateByMetadata->setChecked(set.rotationBehavior & MetaEngineSettingsContainer::RotateByMetadataFlag);
+    d->allowLossyRotate->setChecked(set.rotationBehavior & MetaEngineSettingsContainer::RotateByLossyRotation);
 
     d->exifAutoRotateOriginal = set.exifRotate;
     d->exifRotateBox->setChecked(d->exifAutoRotateOriginal);
@@ -757,8 +789,9 @@ void SetupMetadata::readSettings()
     d->readXMPSidecarBox->setChecked(set.useXMPSidecar4Reading);
     d->updateFileTimeStampBox->setChecked(set.updateFileTimeStamp);
     d->rescanImageIfModifiedBox->setChecked(set.rescanImageIfModified);
+    d->clearMetadataIfRescanBox->setChecked(set.clearMetadataIfRescan);
 
-    if (set.metadataWritingMode == MetaEngine::WRITETOIMAGEONLY)
+    if (set.metadataWritingMode == MetaEngine::WRITE_TO_FILE_ONLY)
     {
         d->writeXMPSidecarBox->setChecked(false);
     }
@@ -794,16 +827,73 @@ bool SetupMetadata::exifAutoRotateHasChanged() const
 void SetupMetadata::slotExifAutoRotateToggled(bool b)
 {
     // Show info if rotation was switched off, and only once.
-    if (!b && d->exifAutoRotateShowedInfo && exifAutoRotateHasChanged())
+    if (!b && !d->exifAutoRotateShowedInfo && exifAutoRotateHasChanged())
     {
         d->exifAutoRotateShowedInfo = true;
         QMessageBox::information(this, qApp->applicationName(),
                                  i18nc("@info",
-                                 "Switching off exif auto rotation will most probably show your images in a wrong orientation, "
-                                 "so only change this option if you explicitly require this. "
-                                 "Furthermore, you need to regenerate all already stored thumbnails via "
-                                 "the <interface>Tools / Maintenance</interface> menu."));
+                                       "Switching off exif auto rotation will most probably show your images "
+                                       "in a wrong orientation, so only change this option if you explicitly "
+                                       "require this. Furthermore, you need to regenerate all already stored "
+                                       "thumbnails via the <interface>Tools | Maintenance...</interface> menu."));
     }
 }
 
-}  // namespace Digikam
+void SetupMetadata::slotClearMetadataToggled(bool b)
+{
+    // Show info if delete metadata from the database was switched on, and only once.
+    if (b && !d->clearMetadataShowedInfo)
+    {
+        d->clearMetadataShowedInfo = true;
+        QMessageBox::information(this, qApp->applicationName(),
+                                 i18nc("@info",
+                                       "Switching on this option and your metadata has been written to the "
+                                       "database only and not to the file or sidecar, you will be able to "
+                                       "lose inserted metadata such as tags, keywords, or geographic "
+                                       "coordinates."));
+    }
+}
+
+void SetupMetadata::slotWriteRawFilesToggled(bool b)
+{
+    // Show info if write metadata to raw files was switched on
+    if (b)
+    {
+        QApplication::beep();
+
+        QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
+                 qApp->applicationName(),
+                 i18n("<p><b>Do you really want to enable metadata writing to RAW files?</b></p>"
+                      "<p>DigiKam delegates this task to the Exiv2 library. With different RAW "
+                      "formats, problems are known which can lead to the destruction of RAW "
+                      "files. If you decide to do so, make a backup of your RAW files.</p>"
+                      "<p><b>We strongly recommend not to enable this option.</b></p>"),
+                 QMessageBox::Yes | QMessageBox::No, this);
+
+        msgBox->button(QMessageBox::Yes)->setText(i18n("Yes I understand"));
+        msgBox->setDefaultButton(QMessageBox::No);
+
+        int result = msgBox->exec();
+        delete msgBox;
+
+        if (result == QMessageBox::Yes)
+        {
+            QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
+                     qApp->applicationName(),
+                     i18n("You would rather disable writing metadata to RAW files?"),
+                     QMessageBox::Yes | QMessageBox::No, this);
+
+            int result = msgBox->exec();
+            delete msgBox;
+
+            if (result == QMessageBox::No)
+            {
+                return;
+            }
+        }
+
+        d->writeRawFilesBox->setChecked(false);
+    }
+}
+
+} // namespace Digikam
