@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-03
  * Description : digiKam setup dialog.
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU Album
@@ -51,24 +51,19 @@
 #include "setupimagequalitysorter.h"
 #include "setuptooltip.h"
 #include "setupdatabase.h"
+#include "setupplugins.h"
 #include "importsettings.h"
 #include "dxmlguiwindow.h"
 
-#ifdef HAVE_KIPI
-
-#include "setupkipi.h"
-
-#endif /* HAVE_KIPI */
-
 namespace Digikam
 {
 
-class Setup::Private
+class Q_DECL_HIDDEN Setup::Private
 {
 public:
 
-    Private() :
-        page_database(0),
+    explicit Private()
+      : page_database(0),
         page_collections(0),
         page_albumView(0),
         page_tooltip(0),
@@ -80,11 +75,7 @@ public:
         page_imagequalitysorter(0),
         page_icc(0),
         page_camera(0),
-
-#ifdef HAVE_KIPI
         page_plugins(0),
-#endif /* HAVE_KIPI */
-
         page_misc(0),
         databasePage(0),
         collectionsPage(0),
@@ -98,11 +89,7 @@ public:
         imageQualitySorterPage(0),
         iccPage(0),
         cameraPage(0),
-
-#ifdef HAVE_KIPI
         pluginsPage(0),
-#endif /* HAVE_KIPI */
-
         miscPage(0)
     {
     }
@@ -119,12 +106,9 @@ public:
     DConfigDlgWdgItem*       page_imagequalitysorter;
     DConfigDlgWdgItem*       page_icc;
     DConfigDlgWdgItem*       page_camera;
-
-#ifdef HAVE_KIPI
     DConfigDlgWdgItem*       page_plugins;
-#endif /* HAVE_KIPI */
-
     DConfigDlgWdgItem*       page_misc;
+
     SetupDatabase*           databasePage;
     SetupCollections*        collectionsPage;
     SetupAlbumView*          albumViewPage;
@@ -137,11 +121,7 @@ public:
     SetupImageQualitySorter* imageQualitySorterPage;
     SetupICC*                iccPage;
     SetupCamera*             cameraPage;
-
-#ifdef HAVE_KIPI
-    SetupKipi*               pluginsPage;
-#endif /* HAVE_KIPI */
-
+    SetupPlugins*            pluginsPage;
     SetupMisc*               miscPage;
 
 public:
@@ -153,6 +133,11 @@ Setup::Setup(QWidget* const parent)
     : DConfigDlg(parent),
       d(new Private)
 {
+    setWindowFlags((windowFlags() & ~Qt::Dialog) |
+                   Qt::Window                    |
+                   Qt::WindowCloseButtonHint     |
+                   Qt::WindowMinMaxButtonsHint);
+
     setWindowTitle(i18n("Configure"));
     setStandardButtons(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     button(QDialogButtonBox::Ok)->setDefault(true);
@@ -221,7 +206,7 @@ Setup::Setup(QWidget* const parent)
 
     d->imageQualitySorterPage = new SetupImageQualitySorter();
     d->page_imagequalitysorter = addPage(d->imageQualitySorterPage, i18n("Image Quality Sorter"));
-    d->page_imagequalitysorter->setHeader(i18n("<qt>Image Quality Sorter Settings<br/>"));
+    d->page_imagequalitysorter->setHeader(i18n("<qt>Image Quality Sorter Settings</qt>"));
     d->page_imagequalitysorter->setIcon(QIcon::fromTheme(QLatin1String("flag-green")));
 
     d->cameraPage  = new SetupCamera();
@@ -233,21 +218,11 @@ Setup::Setup(QWidget* const parent)
     connect(d->cameraPage, SIGNAL(signalUseFileMetadataChanged(bool)),
             d->tooltipPage, SLOT(slotUseFileMetadataChanged(bool)));
 
-    connect(buttonBox(), SIGNAL(helpRequested()),
-            this, SLOT(slotHelp()));
-
-    connect(buttonBox()->button(QDialogButtonBox::Ok), &QPushButton::clicked,
-            this, &Setup::slotOkClicked);
-
-#ifdef HAVE_KIPI
-
-    d->pluginsPage  = new SetupKipi();
+    d->pluginsPage  = new SetupPlugins();
     d->page_plugins = addPage(d->pluginsPage, i18n("Plugins"));
-    d->page_plugins->setHeader(i18n("<qt>Main Interface Plug-in Settings<br/>"
-                                    "<i>Set which plugins will be accessible from the main interface</i></qt>"));
-    d->page_plugins->setIcon(QIcon(QLatin1String(":/icons/kipi-icon.svg")));
-
-#endif /* HAVE_KIPI */
+    d->page_plugins->setHeader(i18n("<qt>Plug-in Settings<br/>"
+                                    "<i>Set which plugins will be accessible from application</i></qt>"));
+    d->page_plugins->setIcon(QIcon::fromTheme(QLatin1String("preferences-plugin")));
 
     d->miscPage  = new SetupMisc();
     d->page_misc = addPage(d->miscPage, i18n("Miscellaneous"));
@@ -273,6 +248,12 @@ Setup::Setup(QWidget* const parent)
         }
     }
 
+    connect(buttonBox(), SIGNAL(helpRequested()),
+            this, SLOT(slotHelp()));
+
+    connect(buttonBox()->button(QDialogButtonBox::Ok), &QPushButton::clicked,
+            this, &Setup::slotOkClicked);
+
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("Setup Dialog"));
 
@@ -323,6 +304,7 @@ QSize Setup::sizeHint() const
             page == TemplatePage    ||
             page == LightTablePage  ||
             page == EditorPage      ||
+            page == PluginsPage     ||
             page == MiscellaneousPage)
         {
             DConfigDlgWdgItem* const item = d->pageItem((Page)page);
@@ -435,11 +417,8 @@ void Setup::slotOkClicked()
     d->slideshowPage->applySettings();
     d->imageQualitySorterPage->applySettings();
     d->iccPage->applySettings();
-    d->miscPage->applySettings();
-
-#ifdef HAVE_KIPI
     d->pluginsPage->applySettings();
-#endif /* HAVE_KIPI */
+    d->miscPage->applySettings();
 
     ApplicationSettings::instance()->emitSetupChanged();
     ImportSettings::instance()->emitSetupChanged();
@@ -550,18 +529,16 @@ Setup::Page Setup::activePageIndex() const
         return CameraPage;
     }
 
+    if (cur == d->page_plugins)
+    {
+        return PluginsPage;
+    }
+
     if (cur == d->page_misc)
     {
         return MiscellaneousPage;
     }
 
-#ifdef HAVE_KIPI
-    if (cur == d->page_plugins)
-    {
-        return KipiPluginsPage;
-    }
-#endif /* HAVE_KIPI */
-
     return DatabasePage;
 }
 
@@ -605,17 +582,15 @@ DConfigDlgWdgItem* Setup::Private::pageItem(Setup::Page page) const
         case Setup::CameraPage:
             return page_camera;
 
+        case Setup::PluginsPage:
+            return page_plugins;
+
         case Setup::MiscellaneousPage:
             return page_misc;
 
-#ifdef HAVE_KIPI
-        case Setup::KipiPluginsPage:
-            return page_plugins;
-#endif /* HAVE_KIPI */
-
         default:
             return 0;
     }
 }
 
-}  // namespace Digikam
+} // namespace Digikam
