@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2003-02-03
  * Description : digiKam setup dialog.
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -58,11 +58,7 @@ public:
         SlideshowPage,
         ImageQualityPage,
         CameraPage,
-
-#ifdef HAVE_KIPI
-        KipiPluginsPage,
-#endif /* HAVE_KIPI */
-
+        PluginsPage,
         MiscellaneousPage,
         SetupPageEnumLast
     };
@@ -108,6 +104,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif  // DIGIKAM_SETUP_H
+#endif // DIGIKAM_SETUP_H
