@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-14
  * Description : database setup tab
  *
  * Copyright (C) 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -68,12 +68,12 @@
 namespace Digikam
 {
 
-class SetupDatabase::Private
+class Q_DECL_HIDDEN SetupDatabase::Private
 {
 public:
 
-    Private() :
-        databaseWidget(0),
+    explicit Private()
+      : databaseWidget(0),
         updateBox(0),
         hashesButton(0),
         ignoreEdit(0),
@@ -187,6 +187,7 @@ void SetupDatabase::applySettings()
 
     QString ignoreDirectory;
     CoreDbAccess().db()->getUserIgnoreDirectoryFilterSettings(&ignoreDirectory);
+
     if (d->ignoreEdit->text() != ignoreDirectory)
     {
         CoreDbAccess().db()->setUserIgnoreDirectoryFilterSettings(
@@ -282,7 +283,7 @@ void SetupDatabase::createUpdateBox()
                                         "<qt>File hashes are used to identify identical files and to display thumbnails. "
                                         "A new, improved algorithm to create the hash is now used. "
                                         "The old algorithm, though, still works quite well, so it is recommended to "
-                                        "carry out this upgrade, but not required.<br> "
+                                        "carry out this upgrade, but not required.<br/> "
                                         "After the upgrade you cannot use your database with a digiKam version "
                                         "prior to 2.0.</qt>"));
 
