@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-11-14
  * Description : database setup tab
  *
  * Copyright (C) 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2012-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPDATABASE_H
-#define SETUPDATABASE_H
+#ifndef DIGIKAM_SETUP_DATABASE_H
+#define DIGIKAM_SETUP_DATABASE_H
 
 // Qt includes
 
@@ -37,6 +37,7 @@ class SetupDatabase : public QScrollArea
     Q_OBJECT
 
 public:
+
     enum AlbumTab
     {
         DbSettings = 0,
@@ -69,4 +70,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SETUPDATABASE_H
+#endif // DIGIKAM_SETUP_DATABASE_H
