@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-11-24
  * Description : Color management setup tab.
  *
  * Copyright (C) 2005-2007 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -45,7 +45,6 @@
 #include <QApplication>
 #include <QStyle>
 #include <QStandardPaths>
-#include <QIcon>
 #include <QMessageBox>
 #include <QDialogButtonBox>
 
@@ -69,12 +68,12 @@
 namespace Digikam
 {
 
-class SetupICC::Private
+class Q_DECL_HIDDEN SetupICC::Private
 {
 public:
 
-    Private() :
-        iccFolderLabel(0),
+    explicit Private()
+      : iccFolderLabel(0),
         enableColorManagement(0),
         defaultSRGBConvert(0),
         bpcAlgorithm(0),
@@ -210,7 +209,7 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     d->workProfilesKC          = new IccProfilesComboBox;
     d->workProfilesKC->setWhatsThis(i18n("<p>This is the color space all the images will be converted to when opened "
                                          "(if you choose to convert) and the profile that will be embedded when saving. "
-                                         "Good and safe choices are <b>Adobe RGB (1998)</b> and <b>sRGB IEC61966-2.1</b>"));
+                                         "Good and safe choices are <b>Adobe RGB (1998)</b> and <b>sRGB IEC61966-2.1</b></p>"));
 
     d->infoWorkProfiles        = new QPushButton;
     d->infoWorkProfiles->setIcon(QIcon::fromTheme(QLatin1String("dialog-information")));
@@ -455,7 +454,7 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     d->defaultPathKU            = new DFileSelector;
     d->iccFolderLabel->setBuddy(d->defaultPathKU);
     d->defaultPathKU->lineEdit()->setReadOnly(true);
-    d->defaultPathKU->setFileDlgMode(DFileDialog::Directory);
+    d->defaultPathKU->setFileDlgMode(QFileDialog::Directory);
     d->defaultPathKU->setWhatsThis(i18n("<p>digiKam searches ICC profiles in default system folders "
                                         "and ships itself a few selected profiles. "
                                         "Store all your additional color profiles in the directory set here.</p>"));
@@ -689,9 +688,9 @@ void SetupICC::readSettings(bool restore)
     d->defaultPathKU->setFileDlgPath(settings.iccFolder);
     fillCombos(false);
 
-    d->workProfilesKC->setCurrentProfile(settings.workspaceProfile);
-    d->inProfilesKC->setCurrentProfile(settings.defaultInputProfile);
-    d->proofProfilesKC->setCurrentProfile(settings.defaultProofProfile);
+    d->workProfilesKC->setCurrentProfile(IccProfile(settings.workspaceProfile));
+    d->inProfilesKC->setCurrentProfile(IccProfile(settings.defaultInputProfile));
+    d->proofProfilesKC->setCurrentProfile(IccProfile(settings.defaultProofProfile));
 
     if (IccSettings::instance()->monitorProfileFromSystem())
     {
@@ -700,7 +699,7 @@ void SetupICC::readSettings(bool restore)
     }
     else
     {
-        d->monitorProfilesKC->setCurrentProfile(settings.monitorProfile);
+        d->monitorProfilesKC->setCurrentProfile(IccProfile(settings.monitorProfile));
     }
 }
 
