@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-08-19
  * Description : Image Quality setup page
  *
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2013-2014 by Gowtham Ashok <gwty93 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPIMAGEQUALITYSORTER_H
-#define SETUPIMAGEQUALITYSORTER_H
+#ifndef DIGIKAM_SETUP_IMAGE_QUALITY_SORTER_H
+#define DIGIKAM_SETUP_IMAGE_QUALITY_SORTER_H
 
 // Qt includes
 
@@ -53,6 +53,6 @@ private:
     Private* const d;
 };
 
-}   // namespace Digikam
+} // namespace Digikam
 
-#endif /* SETUPIMAGEQUALITYSORTER_H */
+#endif // DIGIKAM_SETUP_IMAGE_QUALITY_SORTER_H
