@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-05-11
  * Description : setup Light Table tab.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,12 +46,12 @@
 namespace Digikam
 {
 
-class SetupLightTable::Private
+class Q_DECL_HIDDEN SetupLightTable::Private
 {
 public:
 
-    Private() :
-        autoSyncPreview(0),
+    explicit Private()
+      : autoSyncPreview(0),
         autoLoadOnRightPanel(0),
         clearOnClose(0),
         fullScreenSettings(0)
@@ -165,4 +165,4 @@ void SetupLightTable::applySettings()
     config->sync();
 }
 
-}  // namespace Digikam
+} // namespace Digikam
