@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-23
  * Description : mics configuration setup tab
  *
  * Copyright (C) 2004      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -40,6 +40,7 @@
 #include <QStyle>
 #include <QStyleFactory>
 #include <QVBoxLayout>
+#include <QTabWidget>
 
 // KDE includes
 
@@ -49,21 +50,22 @@
 
 #include "digikam_config.h"
 #include "dlayoutbox.h"
+#include "dfontselect.h"
 #include "applicationsettings.h"
 
 namespace Digikam
 {
 
-class SetupMisc::Private
+class Q_DECL_HIDDEN SetupMisc::Private
 {
 public:
 
-    Private() :
-        tab(0),
+    explicit Private()
+      : tab(0),
         sidebarTypeLabel(0),
         stringComparisonTypeLabel(0),
         applicationStyleLabel(0),
-        iconThemeLabel(0),
+        applicationIconLabel(0),
         minSimilarityBoundLabel(0),
         showSplashCheck(0),
         showTrashDeleteDialogCheck(0),
@@ -78,7 +80,8 @@ public:
         sidebarType(0),
         stringComparisonType(0),
         applicationStyle(0),
-        iconTheme(0),
+        applicationIcon(0),
+        applicationFont(0),
         minimumSimilarityBound(0),
         groupingButtons(QHash<int, QButtonGroup*>())
     {
@@ -89,7 +92,7 @@ public:
     QLabel*                   sidebarTypeLabel;
     QLabel*                   stringComparisonTypeLabel;
     QLabel*                   applicationStyleLabel;
-    QLabel*                   iconThemeLabel;
+    QLabel*                   applicationIconLabel;
     QLabel*                   minSimilarityBoundLabel;
 
     QCheckBox*                showSplashCheck;
@@ -106,7 +109,8 @@ public:
     QComboBox*                sidebarType;
     QComboBox*                stringComparisonType;
     QComboBox*                applicationStyle;
-    QComboBox*                iconTheme;
+    QComboBox*                applicationIcon;
+    DFontSelect*              applicationFont;
 
     QSpinBox*                 minimumSimilarityBound;
 
@@ -123,13 +127,11 @@ SetupMisc::SetupMisc(QWidget* const parent)
 
     const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
-    // --------------------------------------------------------
+    // -- Application Behavior Options --------------------------------------------------------
 
     QWidget* const behaviourPanel = new QWidget(d->tab);
     QVBoxLayout* const layout     = new QVBoxLayout(behaviourPanel);
 
-    // --------------------------------------------------------
-
     DHBox* const stringComparisonHbox = new DHBox(behaviourPanel);
     d->stringComparisonTypeLabel      = new QLabel(i18n("String comparison type:"), stringComparisonHbox);
     d->stringComparisonType           = new QComboBox(stringComparisonHbox);
@@ -154,10 +156,9 @@ SetupMisc::SetupMisc(QWidget* const parent)
                                     "the progress manager available in the statusbar\n when digiKam main interface\n"
                                     "is loaded. If your computer is fast enough, this will have no effect on usability\n"
                                     "of digiKam while scanning. If your collections are huge or if you use a remote database,\n"
-                                    "this can introduce low latency, and it's recommended to disable this option and to plan\n"
+                                    "this can introduce low latency, and it is recommended to disable this option and to plan\n"
                                     "a manual scan through the maintenance tool at the right moment."));
 
-    // ---------------------------------------------------------
 
     d->cleanAtStart                   = new QCheckBox(i18n("Remove obsolete core database objects (makes startup slower)"), behaviourPanel);
     d->cleanAtStart->setToolTip(i18n("Set this option to force digiKam to clean up the core database from obsolete item entries.\n"
@@ -166,18 +167,12 @@ SetupMisc::SetupMisc(QWidget* const parent)
                                      "This option does not clean up other databases as the thumbnails or recognition db.\n"
                                      "For clean up routines for other databases, please use the maintenance."));
 
-    // -- Application Behavior Options --------------------------------------------------------
+    d->scrollItemToCenterCheck                = new QCheckBox(i18n("Scroll current item to center of thumbbar"), behaviourPanel);
+    d->showOnlyPersonTagsInPeopleSidebarCheck = new QCheckBox(i18n("Show only face tags for assigning names in people sidebar"), behaviourPanel);
 
-    QGroupBox* const abOptionsGroup = new QGroupBox(i18n("Application Behavior"), behaviourPanel);
-    QVBoxLayout* const gLayout5     = new QVBoxLayout();
+    // ---------------------------------------------------------
 
-    d->showSplashCheck                        = new QCheckBox(i18n("&Show splash screen at startup"), abOptionsGroup);
-    d->useNativeFileDialogCheck               = new QCheckBox(i18n("Use file dialogs from the system"), abOptionsGroup);
-    d->drawFramesToGroupedCheck               = new QCheckBox(i18n("Draw frames around grouped items"), abOptionsGroup);
-    d->scrollItemToCenterCheck                = new QCheckBox(i18n("Scroll current item to center of thumbbar"), abOptionsGroup);
-    d->showOnlyPersonTagsInPeopleSidebarCheck = new QCheckBox(i18n("Show only face tags for assigning names in people sidebar"), abOptionsGroup);
-
-    DHBox* const minSimilarityBoundHbox       = new DHBox(abOptionsGroup);
+    DHBox* const minSimilarityBoundHbox       = new DHBox(behaviourPanel);
     d->minSimilarityBoundLabel                = new QLabel(i18n("Lower bound for minimum similarity:"), minSimilarityBoundHbox);
     d->minimumSimilarityBound                 = new QSpinBox(minSimilarityBoundHbox);
     d->minimumSimilarityBound->setSuffix(QLatin1String("%"));
@@ -191,7 +186,33 @@ SetupMisc::SetupMisc(QWidget* const parent)
                                                "a lower value than 40 can make the search <b>really</b> slow."));
     d->minSimilarityBoundLabel->setBuddy(d->minimumSimilarityBound);
 
-    DHBox* const tabStyleHbox = new DHBox(abOptionsGroup);
+    // ---------------------------------------------------------
+
+    layout->setContentsMargins(spacing, spacing, spacing, spacing);
+    layout->setSpacing(spacing);
+    layout->addWidget(stringComparisonHbox);
+    layout->addWidget(d->scanAtStart);
+    layout->addWidget(d->cleanAtStart);
+    layout->addWidget(d->showTrashDeleteDialogCheck);
+    layout->addWidget(d->showPermanentDeleteDialogCheck);
+    layout->addWidget(d->sidebarApplyDirectlyCheck);
+    layout->addWidget(d->scrollItemToCenterCheck);
+    layout->addWidget(d->showOnlyPersonTagsInPeopleSidebarCheck);
+    layout->addWidget(minSimilarityBoundHbox);
+    layout->addStretch();
+
+    d->tab->insertTab(Behaviour, behaviourPanel, i18nc("@title:tab", "Behaviour"));
+
+    // -- Application Appearance Options --------------------------------------------------------
+
+    QWidget* const appearancePanel = new QWidget(d->tab);
+    QVBoxLayout* const layout2     = new QVBoxLayout(appearancePanel);
+
+    d->showSplashCheck                        = new QCheckBox(i18n("&Show splash screen at startup"), appearancePanel);
+    d->useNativeFileDialogCheck               = new QCheckBox(i18n("Use native file dialogs from system"), appearancePanel);
+    d->drawFramesToGroupedCheck               = new QCheckBox(i18n("Draw frames around grouped items"), appearancePanel);
+
+    DHBox* const tabStyleHbox = new DHBox(appearancePanel);
     d->sidebarTypeLabel       = new QLabel(i18n("Sidebar tab title:"), tabStyleHbox);
     d->sidebarType            = new QComboBox(tabStyleHbox);
     d->sidebarType->addItem(i18n("Only For Active Tab"), 0);
@@ -199,7 +220,7 @@ SetupMisc::SetupMisc(QWidget* const parent)
     d->sidebarType->setToolTip(i18n("Set this option to configure how sidebar tab titles are visible. "
                                     "Use \"Only For Active Tab\" option if you use a small screen resolution as with a laptop computer."));
 
-    DHBox* const appStyleHbox = new DHBox(abOptionsGroup);
+    DHBox* const appStyleHbox = new DHBox(appearancePanel);
     d->applicationStyleLabel  = new QLabel(i18n("Widget style:"), appStyleHbox);
     d->applicationStyle       = new QComboBox(appStyleHbox);
     d->applicationStyle->setToolTip(i18n("Set this option to choose the default window decoration and looks."));
@@ -216,12 +237,12 @@ SetupMisc::SetupMisc(QWidget* const parent)
     appStyleHbox->setVisible(false);
 #endif
 
-    DHBox* const iconThemeHbox = new DHBox(abOptionsGroup);
-    d->iconThemeLabel          = new QLabel(i18n("Icon theme (changes after restart):"), iconThemeHbox);
-    d->iconTheme               = new QComboBox(iconThemeHbox);
-    d->iconTheme->setToolTip(i18n("Set this option to choose the default icon theme."));
+    DHBox* const iconThemeHbox = new DHBox(appearancePanel);
+    d->applicationIconLabel    = new QLabel(i18n("Icon theme (changes after restart):"), iconThemeHbox);
+    d->applicationIcon         = new QComboBox(iconThemeHbox);
+    d->applicationIcon->setToolTip(i18n("Set this option to choose the default icon theme."));
 
-    d->iconTheme->addItem(i18n("Use Icon Theme From System"), QString());
+    d->applicationIcon->addItem(i18n("Use Icon Theme From System"), QString());
 
     const QString indexTheme = QLatin1String("/index.theme");
     const QString breezeDark = QLatin1String("/breeze-dark");
@@ -230,48 +251,38 @@ SetupMisc::SetupMisc(QWidget* const parent)
     bool foundBreezeDark     = false;
     bool foundBreeze         = false;
 
-    foreach(const QString& path, QIcon::themeSearchPaths())
+    foreach (const QString& path, QIcon::themeSearchPaths())
     {
         if (!foundBreeze && QFile::exists(path + breeze + indexTheme))
         {
-            d->iconTheme->addItem(i18n("Breeze"), breeze.mid(1));
+            d->applicationIcon->addItem(i18n("Breeze"), breeze.mid(1));
             foundBreeze = true;
         }
 
         if (!foundBreezeDark && QFile::exists(path + breezeDark + indexTheme))
         {
-            d->iconTheme->addItem(i18n("Breeze Dark"), breezeDark.mid(1));
+            d->applicationIcon->addItem(i18n("Breeze Dark"), breezeDark.mid(1));
             foundBreezeDark = true;
         }
     }
 
-    gLayout5->addWidget(d->showSplashCheck);
-    gLayout5->addWidget(d->useNativeFileDialogCheck);
-    gLayout5->addWidget(d->drawFramesToGroupedCheck);
-    gLayout5->addWidget(d->scrollItemToCenterCheck);
-    gLayout5->addWidget(d->showOnlyPersonTagsInPeopleSidebarCheck);
-    gLayout5->addWidget(minSimilarityBoundHbox);
-    gLayout5->addWidget(tabStyleHbox);
-    gLayout5->addWidget(appStyleHbox);
-    gLayout5->addWidget(iconThemeHbox);
-    abOptionsGroup->setLayout(gLayout5);
+    d->applicationFont = new DFontSelect(i18n("Application font:"), appearancePanel);
+    d->applicationFont->setToolTip(i18n("Select here the font used to display text in whole application."));
 
     // --------------------------------------------------------
 
-    layout->setContentsMargins(spacing, spacing, spacing, spacing);
-    layout->setSpacing(spacing);
-    layout->addWidget(stringComparisonHbox);
-    layout->addWidget(d->scanAtStart);
-    layout->addWidget(d->cleanAtStart);
-    layout->addWidget(d->showTrashDeleteDialogCheck);
-    layout->addWidget(d->showPermanentDeleteDialogCheck);
-    layout->addWidget(d->sidebarApplyDirectlyCheck);
-    layout->addWidget(abOptionsGroup);
-    layout->addStretch();
+    layout2->setContentsMargins(spacing, spacing, spacing, spacing);
+    layout2->setSpacing(spacing);
+    layout2->addWidget(d->showSplashCheck);
+    layout2->addWidget(d->useNativeFileDialogCheck);
+    layout2->addWidget(d->drawFramesToGroupedCheck);
+    layout2->addWidget(tabStyleHbox);
+    layout2->addWidget(appStyleHbox);
+    layout2->addWidget(iconThemeHbox);
+    layout2->addWidget(d->applicationFont);
+    layout2->addStretch();
 
-    // --------------------------------------------------------
-
-    d->tab->insertTab(Behaviour, behaviourPanel, i18nc("@title:tab", "Behaviour"));
+    d->tab->insertTab(Appearance, appearancePanel, i18nc("@title:tab", "Appearance"));
 
     // --------------------------------------------------------
 
@@ -334,16 +345,12 @@ SetupMisc::SetupMisc(QWidget* const parent)
     grid->setColumnMinimumWidth(3, 30);
     grid->setRowStretch(20, 10);
 
-    // --------------------------------------------------------
-
     d->tab->insertTab(Grouping, groupingPanel, i18nc("@title:tab", "Grouping"));
 
     // --------------------------------------------------------
 
     readSettings();
     adjustSize();
-
-    // --------------------------------------------------------
 }
 
 SetupMisc::~SetupMisc()
@@ -380,7 +387,8 @@ void SetupMisc::applySettings()
     settings->setApplicationStyle(d->applicationStyle->currentText());
 #endif
 
-    settings->setIconTheme(d->iconTheme->currentData().toString());
+    settings->setIconTheme(d->applicationIcon->currentData().toString());
+    settings->setApplicationFont(d->applicationFont->font());
     settings->saveSettings();
 }
 
@@ -413,7 +421,8 @@ void SetupMisc::readSettings()
                                                                        Qt::MatchFixedString));
 #endif
 
-    d->iconTheme->setCurrentIndex(d->iconTheme->findData(settings->getIconTheme()));
+    d->applicationIcon->setCurrentIndex(d->applicationIcon->findData(settings->getIconTheme()));
+    d->applicationFont->setFont(settings->getApplicationFont());
 }
 
 } // namespace Digikam
