@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-08-23
  * Description : mics configuration setup tab
  *
  * Copyright (C) 2004      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -23,19 +23,13 @@
  *
  * ============================================================ */
 
-#ifndef SETUPMISC_H
-#define SETUPMISC_H
+#ifndef DIGIKAM_SETUP_MISC_H
+#define DIGIKAM_SETUP_MISC_H
 
 // Qt includes
 
 #include <QScrollArea>
 
-// local includes
-
-#include "applicationsettings.h"
-
-class QButtonGroup;
-
 namespace Digikam
 {
 
@@ -47,11 +41,12 @@ public:
     enum MiscTab
     {
         Behaviour = 0,
+        Appearance,
         Grouping
     };
 
     explicit SetupMisc(QWidget* const parent = 0);
-    virtual ~SetupMisc();
+    ~SetupMisc();
 
     void applySettings();
 
@@ -67,4 +62,4 @@ private:
 
 } // namespace Digikam
 
-#endif // SETUPMISC_H
+#endif // DIGIKAM_SETUP_MISC_H
