@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-21
  * Description : setup tab for slideshow options.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,18 +42,19 @@
 
 #include "dlayoutbox.h"
 #include "dnuminput.h"
+#include "dfontselect.h"
 #include "digikam_debug.h"
 #include "slideshowsettings.h"
 
 namespace Digikam
 {
 
-class SetupSlideShow::Private
+class Q_DECL_HIDDEN SetupSlideShow::Private
 {
 public:
 
-    Private() :
-        startWithCurrent(0),
+    explicit Private()
+      : startWithCurrent(0),
         loopMode(0),
         showName(0),
         showDate(0),
@@ -61,12 +62,14 @@ public:
         showExpoSensitivity(0),
         showMakeModel(0),
         showLabels(0),
+        showRating(0),
         showComment(0),
         showTitle(0),
         showTags(0),
         showCapIfNoTitle(0),
         showProgress(0),
         screenPlacement(0),
+        captionFont(0),
         delayInput(0)
     {
     }
@@ -79,6 +82,7 @@ public:
     QCheckBox*    showExpoSensitivity;
     QCheckBox*    showMakeModel;
     QCheckBox*    showLabels;
+    QCheckBox*    showRating;
     QCheckBox*    showComment;
     QCheckBox*    showTitle;
     QCheckBox*    showTags;
@@ -86,6 +90,8 @@ public:
     QCheckBox*    showProgress;
 
     QComboBox*    screenPlacement;
+
+    DFontSelect*  captionFont;
     DIntNumInput* delayInput;
 };
 
@@ -145,14 +151,20 @@ SetupSlideShow::SetupSlideShow(QWidget* const parent)
     d->showTitle           = new QCheckBox(i18n("Show image title"), panel);
     d->showTitle->setWhatsThis(i18n("Show the image title at the bottom of the screen."));
 
-    d->showCapIfNoTitle    = new QCheckBox(i18n("Show image caption if it hasn't title"), panel);
+    d->showCapIfNoTitle    = new QCheckBox(i18n("Show image caption if it has not title"), panel);
     d->showCapIfNoTitle->setWhatsThis(i18n("Show the image caption at the bottom of the screen if no titles existed."));
 
     d->showTags            = new QCheckBox(i18n("Show image tags"), panel);
     d->showTags->setWhatsThis(i18n("Show the digiKam image tag names at the bottom of the screen."));
 
     d->showLabels          = new QCheckBox(i18n("Show image labels"), panel);
-    d->showLabels->setWhatsThis(i18n("Show the digiKam image color label, pick label, and rating at the bottom of the screen."));
+    d->showLabels->setWhatsThis(i18n("Show the digiKam image color label and pick label at the bottom of the screen."));
+
+    d->showRating          = new QCheckBox(i18n("Show image rating"), panel);
+    d->showRating->setWhatsThis(i18n("Show the digiKam image rating at the bottom of the screen."));
+
+    d->captionFont         = new DFontSelect(i18n("Caption font:"), panel);
+    d->captionFont->setToolTip(i18n("Select here the font used to display text in the slideshow."));
 
     DHBox* const screenSelectBox = new DHBox(panel);
     new QLabel(i18n("Screen placement:"), screenSelectBox);
@@ -180,9 +192,10 @@ SetupSlideShow::SetupSlideShow(QWidget* const parent)
     // Only digiKam support this feature, showFoto do not support digiKam database information.
     if (qApp->applicationName() == QLatin1String("showfoto"))
     {
-        d->showTitle->hide();
         d->showCapIfNoTitle->hide();
         d->showLabels->hide();
+        d->showRating->hide();
+        d->showTitle->hide();
         d->showTags->hide();
     }
 
@@ -200,6 +213,8 @@ SetupSlideShow::SetupSlideShow(QWidget* const parent)
     layout->addWidget(d->showCapIfNoTitle);
     layout->addWidget(d->showTags);
     layout->addWidget(d->showLabels);
+    layout->addWidget(d->showRating);
+    layout->addWidget(d->captionFont);
     layout->addWidget(screenSelectBox);
     layout->addStretch();
     layout->setContentsMargins(spacing, spacing, spacing, spacing);
@@ -221,6 +236,7 @@ void SetupSlideShow::slotSetUnchecked(int)
 void SetupSlideShow::applySettings()
 {
     SlideShowSettings settings;
+
     settings.delay                 = d->delayInput->value();
     settings.startWithCurrent      = d->startWithCurrent->isChecked();
     settings.loop                  = d->loopMode->isChecked();
@@ -234,7 +250,9 @@ void SetupSlideShow::applySettings()
     settings.printCapIfNoTitle     = d->showCapIfNoTitle->isChecked();
     settings.printTags             = d->showTags->isChecked();
     settings.printLabels           = d->showLabels->isChecked();
+    settings.printRating           = d->showRating->isChecked();
     settings.showProgressIndicator = d->showProgress->isChecked();
+    settings.captionFont           = d->captionFont->font();
     settings.slideScreen           = d->screenPlacement->currentIndex() - 2;
     settings.writeToConfig();
 }
@@ -243,6 +261,7 @@ void SetupSlideShow::readSettings()
 {
     SlideShowSettings settings;
     settings.readFromConfig();
+
     d->delayInput->setValue(settings.delay);
     d->startWithCurrent->setChecked(settings.startWithCurrent);
     d->loopMode->setChecked(settings.loop);
@@ -256,7 +275,9 @@ void SetupSlideShow::readSettings()
     d->showCapIfNoTitle->setChecked(settings.printCapIfNoTitle);
     d->showTags->setChecked(settings.printTags);
     d->showLabels->setChecked(settings.printLabels);
+    d->showRating->setChecked(settings.printRating);
     d->showProgress->setChecked(settings.showProgressIndicator);
+    d->captionFont->setFont(settings.captionFont);
 
     const int screen = settings.slideScreen;
 
@@ -272,4 +293,4 @@ void SetupSlideShow::readSettings()
     }
 }
 
-}   // namespace Digikam
+} // namespace Digikam
