@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-05-21
  * Description : setup tab for slideshow options.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPSLIDESHOW_H
-#define SETUPSLIDESHOW_H
+#ifndef DIGIKAM_SETUP_SLIDESHOW_H
+#define DIGIKAM_SETUP_SLIDESHOW_H
 
 // Qt includes
 
@@ -60,6 +60,6 @@ private:
     Private* const d;
 };
 
-}   // namespace Digikam
+} // namespace Digikam
 
-#endif /* SETUPSLIDESHOW_H */
+#endif // DIGIKAM_SETUP_SLIDESHOW_H
