@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-07-04
  * Description : metadata template setup page.
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,11 +50,11 @@
 namespace Digikam
 {
 
-class SetupTemplate::Private
+class Q_DECL_HIDDEN SetupTemplate::Private
 {
 public:
 
-    Private() :
+    explicit Private() :
         addButton(0),
         delButton(0),
         repButton(0),
@@ -288,4 +288,4 @@ void SetupTemplate::slotRepTemplate()
     item->setTemplate(t);
 }
 
-}  // namespace Digikam
+} // namespace Digikam
