@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * Copyright (C) 2006-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SETUPTOOLTIP_H
-#define SETUPTOOLTIP_H
+#ifndef DIGIKAM_SETUP_TOOLTIP_H
+#define DIGIKAM_SETUP_TOOLTIP_H
 
 // Qt includes
 
@@ -61,6 +61,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // SETUPTOOLTIP_H
+#endif // DIGIKAM_SETUP_TOOLTIP_H
