@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-09-18
  * Description : slideshow end view
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef SLIDE_END_H
-#define SLIDE_END_H
+#ifndef DIGIKAM_SLIDE_END_H
+#define DIGIKAM_SLIDE_END_H
 
 // Qt includes
 
@@ -45,6 +45,6 @@ public:
     virtual ~SlideEnd();
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // SLIDE_END_H
+#endif // DIGIKAM_SLIDE_END_H
