@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-09-18
  * Description : slideshow error view
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,13 +38,13 @@
 namespace Digikam
 {
 
-class SlideError::Private
+class Q_DECL_HIDDEN SlideError::Private
 {
 
 public:
 
-    Private() :
-        errorMsg(0)
+    explicit Private()
+      : errorMsg(0)
     {
     }
 
@@ -88,4 +88,4 @@ void SlideError::setCurrentUrl(const QUrl& url)
     d->errorMsg->setText(i18n("An error has occurred to show item\n%1", url.fileName()));
 }
 
-}  // namespace Digikam
+} // namespace Digikam
