@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2014-09-18
  * Description : slideshow OSD widget
  *
- * Copyright (C) 2014-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2014-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -48,17 +48,18 @@
 #include "ratingwidget.h"
 #include "colorlabelwidget.h"
 #include "picklabelwidget.h"
+#include "dinfointerface.h"
 
 namespace Digikam
 {
 
-class SlideOSD::Private
+class Q_DECL_HIDDEN SlideOSD::Private
 {
-
 public:
 
-    Private() :
-        paused(false),
+    explicit Private()
+      : paused(false),
+        video(false),
         blink(false),
         refresh(1000),       // Progress bar refresh in ms
         progressBar(0),
@@ -75,6 +76,7 @@ public:
     }
 
     bool                paused;
+    bool                video;
     bool                blink;
     int const           refresh;
 
@@ -97,7 +99,8 @@ SlideOSD::SlideOSD(const SlideShowSettings& settings, SlideShow* const parent)
     : QWidget(parent),
       d(new Private)
 {
-    Qt::WindowFlags flags = Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint |
+    Qt::WindowFlags flags = Qt::FramelessWindowHint  |
+                            Qt::WindowStaysOnTopHint |
                             Qt::X11BypassWindowManagerHint;
 
     setWindowFlags(flags);
@@ -137,10 +140,14 @@ SlideOSD::SlideOSD(const SlideShowSettings& settings, SlideShow* const parent)
     d->ratingWidget->setMouseTracking(true);
 
     d->labelsBox->layout()->setAlignment(d->ratingWidget, Qt::AlignVCenter | Qt::AlignLeft);
-    d->labelsBox->setVisible(d->settings.printLabels);
     d->labelsBox->installEventFilter(d->parent);
     d->labelsBox->setMouseTracking(true);
 
+    d->labelsBox->setVisible(d->settings.printLabels || d->settings.printRating);
+    d->ratingWidget->setVisible(d->settings.printRating);
+    d->clWidget->setVisible(d->settings.printLabels);
+    d->plWidget->setVisible(d->settings.printLabels);
+
     connect(d->ratingWidget, SIGNAL(signalRatingChanged(int)),
             parent, SLOT(slotAssignRating(int)));
 
@@ -212,7 +219,6 @@ SlideOSD::~SlideOSD()
 {
     d->progressTimer->stop();
 
-    delete d->progressTimer;
     delete d;
 }
 
@@ -228,27 +234,34 @@ SlideToolBar* SlideOSD::toolBar() const
     return d->toolBar;
 }
 
-void SlideOSD::setCurrentInfo(const SlidePictureInfo& info, const QUrl& url)
+void SlideOSD::setCurrentUrl(const QUrl& url)
 {
+    DInfoInterface::DInfoMap info = d->settings.iface->itemInfo(url);
+    DItemInfo item(info);
+
     // Update info text.
 
-    d->slideProps->setCurrentInfo(info, url);
+    d->slideProps->setCurrentUrl(url);
 
     // Display Labels.
 
     if (d->settings.printLabels)
     {
-        d->ratingWidget->blockSignals(true);
         d->clWidget->blockSignals(true);
         d->plWidget->blockSignals(true);
-        d->ratingWidget->setRating(info.rating);
-        d->clWidget->setColorLabel((ColorLabel)info.colorLabel);
-        d->plWidget->setPickLabel((PickLabel)info.pickLabel);
-        d->ratingWidget->blockSignals(false);
+        d->clWidget->setColorLabel((ColorLabel)item.colorLabel());
+        d->plWidget->setPickLabel((PickLabel)item.pickLabel());
         d->clWidget->blockSignals(false);
         d->plWidget->blockSignals(false);
     }
 
+    if (d->settings.printRating)
+    {
+        d->ratingWidget->blockSignals(true);
+        d->ratingWidget->setRating(item.rating());
+        d->ratingWidget->blockSignals(false);
+    }
+
     // Make the OSD the proper size
     layout()->activate();
     resize(sizeHint());
@@ -307,6 +320,11 @@ void SlideOSD::slotProgressTimer()
 
         d->progressBar->setFormat(str);
     }
+    else if (d->video)
+    {
+        d->progressBar->setFormat(str);
+        return;
+    }
     else
     {
         d->progressBar->setFormat(str);
@@ -329,9 +347,28 @@ void SlideOSD::pause(bool b)
     }
 }
 
+void SlideOSD::video(bool b)
+{
+    d->video = b;
+}
+
 bool SlideOSD::isPaused() const
 {
     return d->toolBar->isPaused();
 }
 
-}  // namespace Digikam
+bool SlideOSD::isUnderMouse() const
+{
+    return (d->ratingWidget->underMouse() ||
+            d->progressBar->underMouse()  ||
+            d->clWidget->underMouse()     ||
+            d->plWidget->underMouse()     ||
+            d->toolBar->underMouse());
+}
+
+void SlideOSD::toggleProperties()
+{
+    d->slideProps->togglePaintEnabled();
+}
+
+} // namespace Digikam
