@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2005-04-21
  * Description : slide show tool using preview of pictures.
  *
- * Copyright (C) 2005-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2004      by Enrico Ros <eros dot kde at email dot it>
  *
  * This program is free software; you can redistribute it
@@ -27,16 +27,17 @@
 
 // Qt includes
 
-#include <QColor>
-#include <QCursor>
 #include <QDesktopWidget>
-#include <QFont>
-#include <QKeyEvent>
+#include <QMimeDatabase>
+#include <QApplication>
+#include <QWheelEvent>
 #include <QMouseEvent>
 #include <QPaintEvent>
+#include <QKeyEvent>
+#include <QCursor>
 #include <QTimer>
-#include <QWheelEvent>
-#include <QApplication>
+#include <QColor>
+#include <QFont>
 
 #ifdef HAVE_DBUS
 #   include <QDBusConnection>
@@ -52,9 +53,9 @@
 
 #include "digikam_debug.h"
 #include "slidetoolbar.h"
-#include "slideosd.h"
 #include "slideimage.h"
 #include "slideerror.h"
+#include "slideosd.h"
 #include "slideend.h"
 
 #ifdef HAVE_MEDIAPLAYER
@@ -64,12 +65,12 @@
 namespace Digikam
 {
 
-class SlideShow::Private
+class Q_DECL_HIDDEN SlideShow::Private
 {
 
 public:
 
-    Private()
+    explicit Private()
         : fileIndex(-1),
           screenSaverCookie(-1),
           mouseMoveTimer(0),
@@ -99,17 +100,19 @@ public:
     SlideShowSettings settings;
 };
 
-SlideShow::SlideShow(const SlideShowSettings& settings)
+SlideShow::SlideShow(DInfoInterface* const iface, const SlideShowSettings& settings)
     : QStackedWidget(0),
       d(new Private)
 {
-    d->settings = settings;
+    d->settings       = settings;
+    d->settings.iface = iface;
 
-    setWindowFlags(Qt::FramelessWindowHint);
     setAttribute(Qt::WA_DeleteOnClose);
-    setWindowState(windowState() | Qt::WindowFullScreen);
-    setWindowTitle(i18n("Slideshow"));
+    setWindowFlags(Qt::FramelessWindowHint);
     setContextMenuPolicy(Qt::PreventContextMenu);
+    setWindowState(windowState() | Qt::WindowFullScreen);
+
+    setWindowTitle(i18n("Slideshow"));
     setMouseTracking(true);
 
     // ---------------------------------------------------------------
@@ -134,6 +137,7 @@ SlideShow::SlideShow(const SlideShowSettings& settings)
 
 #ifdef HAVE_MEDIAPLAYER
     d->videoView = new SlideVideo(this);
+    d->videoView->setInfoInterface(d->settings.iface);
     d->videoView->installEventFilter(this);
 
     connect(d->videoView, SIGNAL(signalVideoLoaded(bool)),
@@ -160,6 +164,8 @@ SlideShow::SlideShow(const SlideShowSettings& settings)
     // ---------------------------------------------------------------
 
     d->mouseMoveTimer = new QTimer(this);
+    d->mouseMoveTimer->setSingleShot(true);
+    d->mouseMoveTimer->setInterval(1000);
 
     connect(d->mouseMoveTimer, SIGNAL(timeout()),
             this, SLOT(slotMouseMoveTimeOut()));
@@ -202,11 +208,10 @@ SlideShow::~SlideShow()
 {
     emit signalLastItemUrl(currentItem());
 
-    allowScreenSaver();
-
     d->mouseMoveTimer->stop();
 
-    delete d->mouseMoveTimer;
+    allowScreenSaver();
+
     delete d;
 }
 
@@ -215,30 +220,35 @@ void SlideShow::setCurrentView(SlideShowViewMode view)
     switch(view)
     {
         case ErrorView:
+            d->osd->video(false);
             d->errorView->setCurrentUrl(currentItem());
+
             setCurrentIndex(view);
-            d->osd->setCurrentInfo(d->settings.pictInfoMap[currentItem()], currentItem());
+            d->osd->setCurrentUrl(currentItem());
             break;
 
         case ImageView:
 #ifdef HAVE_MEDIAPLAYER
             d->videoView->stop();
+            d->osd->video(false);
 #endif
             setCurrentIndex(view);
-            d->osd->setCurrentInfo(d->settings.pictInfoMap[currentItem()], currentItem());
+            d->osd->setCurrentUrl(currentItem());
             break;
 
         case VideoView:
 #ifdef HAVE_MEDIAPLAYER
-            d->osd->pause(true);
+            d->osd->video(true);
+            d->osd->pause(false);
             setCurrentIndex(view);
-            d->osd->setCurrentInfo(d->settings.pictInfoMap[currentItem()], currentItem());
+            d->osd->setCurrentUrl(currentItem());
 #endif
             break;
 
         default : // EndView
 #ifdef HAVE_MEDIAPLAYER
             d->videoView->stop();
+            d->osd->video(false);
 #endif
             d->osd->pause(true);
             setCurrentIndex(view);
@@ -285,6 +295,18 @@ void SlideShow::slotLoadNextItem()
 
     if (d->fileIndex >= 0 && d->fileIndex < num)
     {
+
+#ifdef HAVE_MEDIAPLAYER
+        QMimeDatabase mimeDB;
+
+        if (mimeDB.mimeTypeForFile(currentItem().toLocalFile())
+                                  .name().startsWith(QLatin1String("video/")))
+        {
+            d->videoView->setCurrentUrl(currentItem());
+            return;
+        }
+#endif
+
         d->imageView->setLoadUrl(currentItem());
     }
     else
@@ -317,6 +339,18 @@ void SlideShow::slotLoadPrevItem()
 
     if (d->fileIndex >= 0 && d->fileIndex < num)
     {
+
+#ifdef HAVE_MEDIAPLAYER
+        QMimeDatabase mimeDB;
+
+        if (mimeDB.mimeTypeForFile(currentItem().toLocalFile())
+                                  .name().startsWith(QLatin1String("video/")))
+        {
+            d->videoView->setCurrentUrl(currentItem());
+            return;
+        }
+#endif
+
         d->imageView->setLoadUrl(currentItem());
     }
     else
@@ -344,10 +378,16 @@ void SlideShow::slotImageLoaded(bool loaded)
     else
     {
 #ifdef HAVE_MEDIAPLAYER
-        // Try to load item as video
-        d->videoView->setCurrentUrl(currentItem());
+        // Try to load only GIF Images
+        QMimeDatabase mimeDB;
+
+        if (mimeDB.mimeTypeForFile(currentItem().toLocalFile())
+                                  .name() == QLatin1String("image/gif"))
+        {
+            d->videoView->setCurrentUrl(currentItem());
+        }
 #else
-        slotVideoLoaded(false);
+        preloadNextItem();
 #endif
     }
 }
@@ -379,7 +419,7 @@ void SlideShow::slotVideoFinished()
 {
     if (d->fileIndex != -1)
     {
-        d->osd->pause(false);
+        d->osd->video(false);
         slotLoadNextItem();
     }
 }
@@ -409,6 +449,17 @@ void SlideShow::preloadNextItem()
     if (index < num)
     {
         QUrl nextItem = d->settings.fileList.value(index);
+
+#ifdef HAVE_MEDIAPLAYER
+        QMimeDatabase mimeDB;
+
+        if (mimeDB.mimeTypeForFile(nextItem.toLocalFile())
+                                   .name().startsWith(QLatin1String("video/")))
+        {
+            return;
+        }
+#endif
+
         d->imageView->setPreloadUrl(nextItem);
     }
 }
@@ -467,6 +518,12 @@ void SlideShow::keyPressEvent(QKeyEvent* e)
         return;
     }
 
+    if (e->key() == Qt::Key_F4)
+    {
+        d->osd->toggleProperties();
+        return;
+    }
+
     d->osd->toolBar()->keyPressEvent(e);
 }
 
@@ -475,13 +532,12 @@ bool SlideShow::eventFilter(QObject* obj, QEvent* ev)
     if (ev->type() == QEvent::MouseMove)
     {
         setCursor(QCursor(Qt::ArrowCursor));
-        d->mouseMoveTimer->setSingleShot(true);
-        d->mouseMoveTimer->start(1000);
 
 #ifdef HAVE_MEDIAPLAYER
         d->videoView->showIndicator(true);
 #endif
 
+        d->mouseMoveTimer->start();
         return false;
     }
 
@@ -491,7 +547,7 @@ bool SlideShow::eventFilter(QObject* obj, QEvent* ev)
 
 void SlideShow::slotMouseMoveTimeOut()
 {
-    if (!d->osd->toolBar()->underMouse())
+    if (!d->osd->isUnderMouse())
     {
         setCursor(QCursor(Qt::BlankCursor));
     }
@@ -539,28 +595,39 @@ void SlideShow::allowScreenSaver()
 
 void SlideShow::slotAssignRating(int rating)
 {
-    d->settings.pictInfoMap[currentItem()].rating = rating;
+    DInfoInterface::DInfoMap info;
+    DItemInfo item(info);
+    item.setRating(rating);
+    d->settings.iface->setItemInfo(currentItem(), info);
+
     dispatchCurrentInfoChange(currentItem());
     emit signalRatingChanged(currentItem(), rating);
 }
 
 void SlideShow::slotAssignColorLabel(int color)
 {
-    d->settings.pictInfoMap[currentItem()].colorLabel = color;
+    DInfoInterface::DInfoMap info;
+    DItemInfo item(info);
+    item.setColorLabel(color);
+    d->settings.iface->setItemInfo(currentItem(), info);
+
     dispatchCurrentInfoChange(currentItem());
     emit signalColorLabelChanged(currentItem(), color);
 }
 
 void SlideShow::slotAssignPickLabel(int pick)
 {
-    d->settings.pictInfoMap[currentItem()].pickLabel = pick;
+    DInfoInterface::DInfoMap info;
+    DItemInfo item(info);
+    item.setPickLabel(pick);
+    d->settings.iface->setItemInfo(currentItem(), info);
+
     dispatchCurrentInfoChange(currentItem());
     emit signalPickLabelChanged(currentItem(), pick);
 }
 
-void SlideShow::updateTags(const QUrl& url, const QStringList& tags)
+void SlideShow::updateTags(const QUrl& url, const QStringList& /*tags*/)
 {
-    d->settings.pictInfoMap[url].tags = tags;
     dispatchCurrentInfoChange(url);
 }
 
@@ -573,7 +640,7 @@ void SlideShow::dispatchCurrentInfoChange(const QUrl& url)
 {
     if (currentItem() == url)
     {
-        d->osd->setCurrentInfo(d->settings.pictInfoMap[currentItem()], currentItem());
+        d->osd->setCurrentUrl(currentItem());
     }
 }
 
@@ -616,4 +683,4 @@ void SlideShow::slotScreenSelected(int screen)
                                  << " :: " << deskRect;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
