@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-02-13
  * Description : slide show settings container.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,6 +23,10 @@
 
 #include "slideshowsettings.h"
 
+// Qt includes
+
+#include <QFontDatabase>
+
 // KDE includes
 
 #include <kconfiggroup.h>
@@ -30,7 +34,7 @@
 
 // Local includes
 
-#include "metadatasettings.h"
+#include "metaenginesettings.h"
 
 namespace Digikam
 {
@@ -49,7 +53,9 @@ const QString SlideShowSettings::configSlideShowPrintMakeModelEntry(QLatin1Strin
 const QString SlideShowSettings::configSlideShowPrintNameEntry(QLatin1String("SlideShowPrintName"));
 const QString SlideShowSettings::configSlideShowPrintTagsEntry(QLatin1String("SlideShowPrintTags"));
 const QString SlideShowSettings::configSlideShowPrintLabelsEntry(QLatin1String("SlideShowPrintLabels"));
+const QString SlideShowSettings::configSlideShowPrintRatingEntry(QLatin1String("SlideShowPrintRating"));
 const QString SlideShowSettings::configSlideShowProgressIndicatorEntry(QLatin1String("SlideShowProgressIndicator"));
+const QString SlideShowSettings::configSlideShowCaptionFontEntry(QLatin1String("SlideShowCaptionFont"));
 const QString SlideShowSettings::configSlideScreenEntry(QLatin1String("SlideScreen"));
 
 SlideShowSettings::SlideShowSettings()
@@ -64,6 +70,7 @@ SlideShowSettings::SlideShowSettings()
     printTitle            = false;
     printCapIfNoTitle     = false;
     printLabels           = false;
+    printRating           = false;
     printApertureFocal    = false;
     printMakeModel        = false;
     printExpoSensitivity  = false;
@@ -71,6 +78,8 @@ SlideShowSettings::SlideShowSettings()
     showProgressIndicator = true;
     slideScreen           = -2;
     autoPlayEnabled       = true;
+    captionFont           = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
+    iface                 = 0;
 }
 
 SlideShowSettings::~SlideShowSettings()
@@ -81,6 +90,7 @@ void SlideShowSettings::readFromConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupName);
+
     startWithCurrent          = group.readEntry(configSlideShowStartCurrentEntry,         false);
     delay                     = group.readEntry(configSlideShowDelayEntry,                5);
     loop                      = group.readEntry(configSlideShowLoopEntry,                 false);
@@ -94,15 +104,19 @@ void SlideShowSettings::readFromConfig()
     printCapIfNoTitle         = group.readEntry(configSlideShowPrintCapIfNoTitleEntry,    false);
     printTags                 = group.readEntry(configSlideShowPrintTagsEntry,            false);
     printLabels               = group.readEntry(configSlideShowPrintLabelsEntry,          false);
+    printRating               = group.readEntry(configSlideShowPrintRatingEntry,          false);
     showProgressIndicator     = group.readEntry(configSlideShowProgressIndicatorEntry,    true);
+    captionFont               = group.readEntry(configSlideShowCaptionFontEntry,
+                                                QFontDatabase::systemFont(QFontDatabase::GeneralFont));
     slideScreen               = group.readEntry(configSlideScreenEntry,                   -2);
-    exifRotate                = MetadataSettings::instance()->settings().exifRotate;
+    exifRotate                = MetaEngineSettings::instance()->settings().exifRotate;
 }
 
 void SlideShowSettings::writeToConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupName);
+
     group.writeEntry(configSlideShowStartCurrentEntry,         startWithCurrent);
     group.writeEntry(configSlideShowDelayEntry,                delay);
     group.writeEntry(configSlideShowLoopEntry,                 loop);
@@ -116,7 +130,9 @@ void SlideShowSettings::writeToConfig()
     group.writeEntry(configSlideShowPrintCapIfNoTitleEntry,    printCapIfNoTitle);
     group.writeEntry(configSlideShowPrintTagsEntry,            printTags);
     group.writeEntry(configSlideShowPrintLabelsEntry,          printLabels);
+    group.writeEntry(configSlideShowPrintRatingEntry,          printRating);
     group.writeEntry(configSlideShowProgressIndicatorEntry,    showProgressIndicator);
+    group.writeEntry(configSlideShowCaptionFontEntry,          captionFont);
     group.writeEntry(configSlideScreenEntry,                   slideScreen);
     group.sync();
 }
@@ -131,4 +147,4 @@ int SlideShowSettings::count() const
     return fileList.count();
 }
 
-}   // namespace Digikam
+} // namespace Digikam
