@@ -3,7 +3,7 @@
 # Script to build extra libraries using CentOS 6.
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -34,7 +34,8 @@ ChecksRunAsRoot
 StartScript
 ChecksCPUCores
 CentOS6Adjustments
-. /opt/rh/devtoolset-3/enable
+RegisterRemoteServers
+. /opt/rh/devtoolset-6/enable
 
 ORIG_WD="`pwd`"
 
@@ -47,7 +48,8 @@ rm -rf $BUILDING_DIR/* || true
 cmake3 $ORIG_WD/../3rdparty \
        -DCMAKE_INSTALL_PREFIX:PATH=/usr \
        -DINSTALL_ROOT=/usr \
-       -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR
+       -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
+       -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE
 
 # NOTE: The order to compile each component here is very important.
 
@@ -77,10 +79,9 @@ cmake3 --build . --config RelWithDebInfo --target ext_kxmlgui             -- -j$
 cmake3 --build . --config RelWithDebInfo --target ext_kbookmarks          -- -j$CPU_CORES
 cmake3 --build . --config RelWithDebInfo --target ext_kimageformats       -- -j$CPU_CORES
 
-# Extra support for Kipi-plugins and digiKam
+# Extra support for digiKam
 
 # libksane support
-cmake3 --build . --config RelWithDebInfo --target ext_kwallet             -- -j$CPU_CORES
 cmake3 --build . --config RelWithDebInfo --target ext_libksane            -- -j$CPU_CORES
 
 # Desktop integration support
