@@ -3,7 +3,7 @@
 # Script to build digiKam under Linux
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -39,7 +39,8 @@ ChecksRunAsRoot
 StartScript
 ChecksCPUCores
 CentOS6Adjustments
-. /opt/rh/devtoolset-3/enable
+RegisterRemoteServers
+. /opt/rh/devtoolset-6/enable
 
 #################################################################################################
 
@@ -50,48 +51,55 @@ ORIG_WD="`pwd`"
 #################################################################################################
 # Build digiKam in temporary directory and installation
 
-if [ -d "$DK_BUILDTEMP" ] ; then
-   echo "---------- Removing existing $DK_BUILDTEMP"
-   rm -rf "$DK_BUILDTEMP"
+if [ -d "$DK_BUILDTEMP/digikam-$DK_VERSION" ] ; then
+
+    echo "---------- Updating existing $DK_BUILDTEMP"
+
+    cd "$DK_BUILDTEMP"
+    cd digikam-$DK_VERSION
+
+    git reset --hard
+    git pull
+
+    mkdir -p build
+    cd build
+
+else
+
+    echo "---------- Creating $DK_BUILDTEMP"
+    mkdir -p "$DK_BUILDTEMP"
+
+    if [ $? -ne 0 ] ; then
+        echo "---------- Cannot create $DK_BUILDTEMP directory."
+        echo "---------- Aborting..."
+        exit;
+    fi
+
+    cd "$DK_BUILDTEMP"
+    echo -e "\n\n"
+    echo "---------- Downloading digiKam $DK_VERSION"
+
+    git clone --progress --verbose $DK_GITURL digikam-$DK_VERSION
+    cd digikam-$DK_VERSION
+    export GITSLAVE=".gitslave.bundle"
+    ./download-repos
+
+    if [ $? -ne 0 ] ; then
+        echo "---------- Cannot clone repositories."
+        echo "---------- Aborting..."
+        exit;
+    fi
+
+    git checkout $DK_VERSION
+
+    mkdir build
+    cd build
+
 fi
 
-echo "---------- Creating $DK_BUILDTEMP"
-mkdir "$DK_BUILDTEMP"
-
-if [ $? -ne 0 ] ; then
-    echo "---------- Cannot create $DK_BUILDTEMP directory."
-    echo "---------- Aborting..."
-    exit;
-fi
-
-cd "$DK_BUILDTEMP"
-echo -e "\n\n"
-echo "---------- Downloading digiKam $DK_VERSION"
-
-git clone git://anongit.kde.org/digikam-software-compilation.git digikam-$DK_VERSION
-cd digikam-$DK_VERSION
-export GITSLAVE=".gitslave.bundle"
-./download-repos
-
-if [ $? -ne 0 ] ; then
-    echo "---------- Cannot clone repositories."
-    echo "---------- Aborting..."
-    exit;
-fi
-
-cd ./core
-git checkout $DK_VERSION
-cd ../extra/kipi-plugins
-git checkout $KIPI_VERSION
-cd ../..
-
 echo -e "\n\n"
 echo "---------- Configure digiKam $DK_VERSION"
 
-rm -rf build
-mkdir build
-cd build
-
 cmake3 -G "Unix Makefiles" .. \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DCMAKE_INSTALL_PREFIX=/usr \
@@ -101,12 +109,6 @@ cmake3 -G "Unix Makefiles" .. \
       -DDIGIKAMSC_COMPILE_PO=ON \
       -DDIGIKAMSC_COMPILE_DOC=OFF \
       -DDIGIKAMSC_COMPILE_DIGIKAM=ON \
-      -DDIGIKAMSC_COMPILE_KIPIPLUGINS=ON \
-      -DDIGIKAMSC_COMPILE_LIBKIPI=ON \
-      -DDIGIKAMSC_COMPILE_LIBKSANE=OFF \
-      -DDIGIKAMSC_COMPILE_LIBMEDIAWIKI=ON \
-      -DDIGIKAMSC_COMPILE_LIBKVKONTAKTE=OFF \
-      -DENABLE_OPENCV3=ON \
       -DENABLE_KFILEMETADATASUPPORT=OFF \
       -DENABLE_AKONADICONTACTSUPPORT=OFF \
       -DENABLE_MYSQLSUPPORT=ON \
@@ -114,6 +116,8 @@ cmake3 -G "Unix Makefiles" .. \
       -DENABLE_MEDIAPLAYER=ON \
       -DENABLE_DBUS=ON \
       -DENABLE_APPSTYLES=ON \
+      -DENABLE_QWEBENGINE=$DK_QTWEBENGINE \
+      -DENABLE_FACESENGINE_DNN=ON \
       -DENABLE_KIO=OFF \
       -DENABLE_LEGACY=OFF \
       -Wno-dev
@@ -124,10 +128,6 @@ if [ $? -ne 0 ]; then
     exit;
 fi
 
-if [ -d ./extra/libmediawiki/src ]; then
-    ln -sf src ./extra/libmediawiki/MediaWiki
-fi
-
 cat ../build/core/app/utils/digikam_version.h | grep "digikam_version\[\]" | awk '{print $6}' | tr -d '";' > $ORIG_WD/data/RELEASEID.txt
 
 echo -e "\n\n"
