@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright (c) 2013-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2013-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -55,7 +55,7 @@ echo "Elaspsed time for script execution : $(($difftimelps / 3600 )) hours $((($
 }
 
 ########################################################################
-# For time execution measurement : shutdown
+# Adjust devel env.for Centos6
 CentOS6Adjustments()
 {
 
@@ -93,9 +93,34 @@ FILES=$(ldd $1 | grep "=>" | awk '{print $3}')
 
 for FILE in $FILES ; do
     if [ -f "$FILE" ] ; then
-        cp $FILE $2 2> /dev/null || true
+        cp -u $FILE $2 2> /dev/null || true
 #        echo "   ==> $FILE"
     fi
 done
 
 }
+
+########################################################################
+# Automatically register the remote servers has know hosts
+RegisterRemoteServers()
+{
+
+SERVER_LIST="\
+git.kde.org \
+milonia.kde.org \
+"
+
+if [[ ! -f ~/.ssh/known_hosts ]] ; then
+    touch ~/.ssh/known_hosts
+fi
+
+for server in $SERVER_LIST; do
+
+    echo "Register $server"
+
+    ssh-keygen -R $server
+    ssh-keyscan -H $server >> ~/.ssh/known_hosts
+
+done
+
+}
