@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -13,8 +13,18 @@ DOWNLOAD_DIR="/d"
 # Absolute path where are compiled all tarballs
 BUILDING_DIR="/b"
 
+# Absolute path where are installed all software components
+INSTALL_DIR="/usr"
+
+# Absolute path where are bundled all software components
+APP_IMG_DIR="/digikam.appdir"
+
 ########################################################################
 
+# URL to git repository to checkout digiKam source code
+# Read/write url is an alternative when official read only server is down.
+#DK_GITURL="git://anongit.kde.org/digikam.git"
+DK_GITURL="git@git.kde.org:digikam"
 
 # Location to build source code.
 DK_BUILDTEMP=$BUILDING_DIR/dktemp
@@ -24,9 +34,7 @@ DK_BUILDTEMP=$BUILDING_DIR/dktemp
 # If you want to package current implemntation from git, use "master" as tag.
 #DK_VERSION=v5.5.0
 DK_VERSION=master
-#DK_VERSION=development/garbagecollection
-#KIPI_VERSION=v5.5.0
-KIPI_VERSION=master
+#DK_VERSION=gsoc18-exporttools-o2
 
 # Installer sub version to differentiates newer updates of the installer itself, even if the underlying application hasn’t changed.
 #DK_EPOCH="-01"
@@ -36,7 +44,13 @@ DK_EPOCH="-`date "+%Y%m%dT%H%M%S"`"
 # Installer will include or not digiKam debug symbols
 DK_DEBUG=1
 
+# Option to use QtWebEngine instead QtWebkit
+DK_QTWEBENGINE=0
+
+# Sign bundles with GPG. Passphrase must be hosted in ~/.gnupg/dkorg-gpg-pwd.txt
+DK_SIGN=0
+
 # Upload automatically bundle to files.kde.org (pre-release only).
 DK_UPLOAD=1
-DK_UPLOADURL="digikam@racnoss.kde.org"
+DK_UPLOADURL="digikam@milonia.kde.org"
 DK_UPLOADDIR="/srv/archives/files/digikam/"
