@@ -4,7 +4,7 @@
 # This script must be run as sudo
 #
 # Copyright (c) 2015,      Shanti, <listaccount at revenant dot org>
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -39,6 +39,7 @@ ChecksRunAsRoot
 ChecksXCodeCLI
 ChecksCPUCores
 OsxCodeName
+#RegisterRemoteServers
 
 #################################################################################################
 
@@ -226,12 +227,14 @@ fi
 
 echo -e "\n"
 
-port install cmake \
+port install \
+             ld64 +ld64_xcode \
+             cmake \
              libpng \
              jpeg \
              tiff \
              boost \
-             eigen3 +gcc5 \
+             eigen3 \
              gettext \
              libusb \
              libgphoto2 \
@@ -242,18 +245,16 @@ port install cmake \
              libxslt \
              libical \
              lensfun \
-             opencv \
              bison \
              ffmpeg \
-             sane-backends \
-             qt58 \
-             qt58-qtimageformats \
-             qt58-qtwebkit \
-             qt58-sqlite-plugin \
-             qt58-mysql-plugin \
-             qt58-qtscript \
-             wget +ssl
-
+             qt511 \
+             qt511-qtimageformats \
+             qt511-qtwebkit \
+             qt511-sqlite-plugin \
+             qt511-mysql-plugin \
+             qt511-qtscript \
+             wget +ssl \
+             sane-backends
 echo -e "\n"
 
 echo -e "---------- Compilation logs of Macports packages with suspicious installation\n"
@@ -282,6 +283,7 @@ cmake $ORIG_WD/../3rdparty \
        -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
        -Wno-dev
 
+cmake --build . --config RelWithDebInfo --target ext_opencv -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_exiv2  -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_qtav   -- -j$CPU_CORES
 
