@@ -3,7 +3,7 @@
 # Script to build extra libraries using MacPorts env.
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -38,6 +38,7 @@ ChecksRunAsRoot
 ChecksXCodeCLI
 ChecksCPUCores
 OsxCodeName
+#RegisterRemoteServers
 
 #################################################################################################
 
@@ -96,8 +97,7 @@ cmake --build . --config RelWithDebInfo --target ext_kbookmarks          -- -j$C
 cmake --build . --config RelWithDebInfo --target ext_kimageformats       -- -j$CPU_CORES
 
 # libksane support
-cmake --build . --config RelWithDebInfo --target ext_kwallet             -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_libksane            -- -j$CPU_CORES
+#cmake --build . --config RelWithDebInfo --target ext_libksane            -- -j$CPU_CORES
 
 # Geolocation support
 cmake --build . --config RelWithDebInfo --target ext_marble              -- -j$CPU_CORES
