@@ -3,7 +3,7 @@
 # Script to build digiKam using MacPorts
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -38,6 +38,7 @@ ChecksRunAsRoot
 ChecksXCodeCLI
 ChecksCPUCores
 OsxCodeName
+#RegisterRemoteServers
 
 #################################################################################################
 
@@ -50,47 +51,57 @@ export PATH=$INSTALL_PREFIX/bin:/$INSTALL_PREFIX/sbin:$ORIG_PATH
 #################################################################################################
 # Build digiKam in temporary directory and installation
 
-if [ -d "$DK_BUILDTEMP" ] ; then
-   echo "---------- Removing existing $DK_BUILDTEMP"
-   rm -rf "$DK_BUILDTEMP"
+if [ -d "$DK_BUILDTEMP/digikam-$DK_VERSION" ] ; then
+
+    echo "---------- Updating existing $DK_BUILDTEMP"
+
+    cd "$DK_BUILDTEMP"
+    cd digikam-$DK_VERSION
+
+    git reset --hard
+    git pull
+
+    mkdir -p build
+
+else
+
+    echo "---------- Creating $DK_BUILDTEMP"
+    mkdir -p "$DK_BUILDTEMP"
+
+    if [ $? -ne 0 ] ; then
+        echo "---------- Cannot create $DK_BUILDTEMP directory."
+        echo "---------- Aborting..."
+        exit;
+    fi
+
+    cd "$DK_BUILDTEMP"
+    echo -e "\n\n"
+    echo "---------- Downloading digiKam $DK_VERSION"
+
+    git clone --progress --verbose $DK_GITURL digikam-$DK_VERSION
+    cd digikam-$DK_VERSION
+    export GITSLAVE=".gitslave.bundle"
+    ./download-repos
+
+    if [ $? -ne 0 ] ; then
+        echo "---------- Cannot clone repositories."
+        echo "---------- Aborting..."
+        exit;
+    fi
+
+    git checkout $DK_VERSION
+
+    mkdir build
+
 fi
 
-echo "---------- Creating $DK_BUILDTEMP"
-mkdir "$DK_BUILDTEMP"
-
-if [ $? -ne 0 ] ; then
-    echo "---------- Cannot create $DK_BUILDTEMP directory."
-    echo "---------- Aborting..."
-    exit;
-fi
-
-cd "$DK_BUILDTEMP"
-echo -e "\n\n"
-echo "---------- Downloading digiKam $DK_VERSION"
-
-git clone git://anongit.kde.org/digikam-software-compilation.git digikam-$DK_VERSION
-cd digikam-$DK_VERSION
-export GITSLAVE=".gitslave.bundle"
-./download-repos
-
-if [ $? -ne 0 ] ; then
-    echo "---------- Cannot clone repositories."
-    echo "---------- Aborting..."
-    exit;
-fi
-
-git -C ./core checkout $DK_VERSION
-git -C ./extra/kipi-plugins checkout $KIPI_VERSION
-
-cp -f $ORIG_WD/../../../bootstrap.macports $DK_BUILDTEMP/digikam-$DK_VERSION
-
 echo -e "\n\n"
 echo "---------- Configure digiKam $DK_VERSION"
 
-sed -e "s/DIGIKAMSC_CHECKOUT_PO=OFF/DIGIKAMSC_CHECKOUT_PO=ON/g" ./bootstrap.macports > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.macports
-sed -e "s/DIGIKAMSC_COMPILE_PO=OFF/DIGIKAMSC_COMPILE_PO=ON/g"   ./bootstrap.macports > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.macports
-sed -e "s/DBUILD_TESTING=ON/DBUILD_TESTING=OFF/g"               ./bootstrap.macports > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.macports
-sed -e "s/DENABLE_DBUS=ON/DENABLE_DBUS=OFF/g"                   ./bootstrap.macports > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.macports
+sed -e "s/DIGIKAMSC_CHECKOUT_PO=OFF/DIGIKAMSC_CHECKOUT_PO=ON/g" ./bootstrap.macports > ./tmp.macports ; mv -f ./tmp.macports ./bootstrap.macports
+sed -e "s/DIGIKAMSC_COMPILE_PO=OFF/DIGIKAMSC_COMPILE_PO=ON/g"   ./bootstrap.macports > ./tmp.macports ; mv -f ./tmp.macports ./bootstrap.macports
+sed -e "s/DBUILD_TESTING=ON/DBUILD_TESTING=OFF/g"               ./bootstrap.macports > ./tmp.macports ; mv -f ./tmp.macports ./bootstrap.macports
+sed -e "s/DENABLE_DBUS=ON/DENABLE_DBUS=OFF/g"                   ./bootstrap.macports > ./tmp.macports ; mv -f ./tmp.macports ./bootstrap.macports
 chmod +x ./bootstrap.macports
 
 cp -f $ORIG_WD/fixbundledatapath.sh $DK_BUILDTEMP/digikam-$DK_VERSION
