@@ -2,7 +2,7 @@
 
 # Script to build a bundle MXE installation with all digiKam low level dependencies in a dedicated directory.
 #
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -31,6 +31,7 @@ echo "-----------------------------------------------------------------------"
 . ./common.sh
 StartScript
 ChecksCPUCores
+RegisterRemoteServers
 
 #################################################################################################
 
@@ -118,7 +119,6 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      eigen \
      jasper \
      zlib \
-     expat \
      mman-win32 \
      pthreads \
      qtbase \
@@ -130,7 +130,6 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      qtscript \
      ffmpeg \
      openal \
-     lensfun \
      libical
 
 echo -e "\n"
@@ -175,6 +174,9 @@ ${MXE_BUILD_TARGETS}-cmake $ORIG_WD/../3rdparty \
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_opencv     -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_exiv2      -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_qtav       -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_lensfun    -- -j$CPU_CORES
+#${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_libgphoto2 -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_drmingw    -- -j$CPU_CORES
 
 #################################################################################################
 
