@@ -3,7 +3,7 @@
 # Script to build digiKam using MXE
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -32,6 +32,7 @@ echo "---------------------------------------------------"
 . ./common.sh
 StartScript
 ChecksCPUCores
+RegisterRemoteServers
 
 #################################################################################################
 
@@ -45,48 +46,58 @@ cd $MXE_BUILDROOT
 #################################################################################################
 # Build digiKam in temporary directory and installation
 
-if [ -d "$DK_BUILDTEMP" ] ; then
-   echo "---------- Removing existing $DK_BUILDTEMP"
-   rm -rf "$DK_BUILDTEMP"
+if [ -d "$DK_BUILDTEMP/digikam-$DK_VERSION" ] ; then
+
+    echo "---------- Updating existing $DK_BUILDTEMP"
+
+    cd "$DK_BUILDTEMP"
+    cd digikam-$DK_VERSION
+
+    git reset --hard
+    git pull
+
+    mkdir -p build.mxe
+
+else
+
+    echo "---------- Creating $DK_BUILDTEMP"
+    mkdir -p "$DK_BUILDTEMP"
+
+    if [ $? -ne 0 ] ; then
+        echo "---------- Cannot create $DK_BUILDTEMP directory."
+        echo "---------- Aborting..."
+        exit;
+    fi
+
+    cd "$DK_BUILDTEMP"
+    echo -e "\n\n"
+    echo "---------- Downloading digiKam $DK_VERSION"
+
+    git clone --progress --verbose $DK_GITURL digikam-$DK_VERSION
+    cd digikam-$DK_VERSION
+    export GITSLAVE=".gitslave.bundle"
+    ./download-repos
+
+    if [ $? -ne 0 ] ; then
+        echo "---------- Cannot clone repositories."
+        echo "---------- Aborting..."
+        exit;
+    fi
+
+    git checkout $DK_VERSION
+
+    mkdir build.mxe
+
 fi
 
-echo "---------- Creating $DK_BUILDTEMP"
-mkdir "$DK_BUILDTEMP"
-
-if [ $? -ne 0 ] ; then
-    echo "---------- Cannot create $DK_BUILDTEMP directory."
-    echo "---------- Aborting..."
-    exit;
-fi
-
-cd "$DK_BUILDTEMP"
-echo -e "\n\n"
-echo "---------- Downloading digiKam $DK_VERSION"
-
-git clone git://anongit.kde.org/digikam-software-compilation.git digikam-$DK_VERSION
-cd digikam-$DK_VERSION
-export GITSLAVE=".gitslave.bundle"
-./download-repos
-
-if [ $? -ne 0 ] ; then
-    echo "---------- Cannot clone repositories."
-    echo "---------- Aborting..."
-    exit;
-fi
-
-git -C ./core checkout $DK_VERSION
-git -C ./extra/kipi-plugins checkout $KIPI_VERSION
-
 echo -e "\n\n"
 echo "---------- Configure digiKam $DK_VERSION"
 
-rm -rf build
-mkdir build
-
 sed -e "s/DIGIKAMSC_CHECKOUT_PO=OFF/DIGIKAMSC_CHECKOUT_PO=ON/g" ./bootstrap.mxe > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.mxe
 sed -e "s/DIGIKAMSC_COMPILE_PO=OFF/DIGIKAMSC_COMPILE_PO=ON/g"   ./bootstrap.mxe > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.mxe
 sed -e "s/DBUILD_TESTING=ON/DBUILD_TESTING=OFF/g"               ./bootstrap.mxe > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.mxe
 sed -e "s/DENABLE_DBUS=ON/DENABLE_DBUS=OFF/g"                   ./bootstrap.mxe > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.mxe
+sed -e "s/DENABLE_DRMINGW=OFF/DENABLE_DRMINGW=ON/g"             ./bootstrap.mxe > ./tmp.mxe ; mv -f ./tmp.mxe ./bootstrap.mxe
 
 chmod +x ./bootstrap.mxe
 
@@ -98,12 +109,12 @@ if [ $? -ne 0 ]; then
     exit;
 fi
 
-cat ./build/core/app/utils/digikam_version.h | grep "digikam_version\[\]" | awk '{print $6}' | tr -d '";' > $ORIG_WD/data/RELEASEID.txt
+cat ./build.mxe/core/app/utils/digikam_version.h | grep "digikam_version\[\]" | awk '{print $6}' | tr -d '";' > $ORIG_WD/data/RELEASEID.txt
 
 echo -e "\n\n"
 echo "---------- Building digiKam $DK_VERSION"
 
-cd build
+cd build.mxe
 make -j$CPU_CORES
 
 if [ $? -ne 0 ]; then
